## Uconv/EUC-JIS-2004
## Copyright 2004 by yoshidam
##

require 'uconv'

module Uconv
  EUCJIS2004_UCS_MAP = {
    "\xa1\xc0"=>0xff3c,
    "\xa2\xaf"=>0xff07,
    "\xa2\xb0"=>0xff02,
    "\xa2\xb1"=>0xff0d,
    "\xa2\xb2"=>0xff5e,
    "\xa2\xb3"=>0x3033,
    "\xa2\xb4"=>0x3034,
    "\xa2\xb5"=>0x3035,
    "\xa2\xb6"=>0x303b,
    "\xa2\xb7"=>0x303c,
    "\xa2\xb8"=>0x30ff,
    "\xa2\xb9"=>0x309f,
    "\xa2\xc2"=>0x2284,
    "\xa2\xc3"=>0x2285,
    "\xa2\xc4"=>0x228a,
    "\xa2\xc5"=>0x228b,
    "\xa2\xc6"=>0x2209,
    "\xa2\xc7"=>0x2205,
    "\xa2\xc8"=>0x2305,
    "\xa2\xc9"=>0x2306,
    "\xa2\xd1"=>0x2295,
    "\xa2\xd2"=>0x2296,
    "\xa2\xd3"=>0x2297,
    "\xa2\xd4"=>0x2225,
    "\xa2\xd5"=>0x2226,
    "\xa2\xd6"=>0xff5f,
    "\xa2\xd7"=>0xff60,
    "\xa2\xd8"=>0x3018,
    "\xa2\xd9"=>0x3019,
    "\xa2\xda"=>0x3016,
    "\xa2\xdb"=>0x3017,
    "\xa2\xeb"=>0x2262,
    "\xa2\xec"=>0x2243,
    "\xa2\xed"=>0x2245,
    "\xa2\xee"=>0x2248,
    "\xa2\xef"=>0x2276,
    "\xa2\xf0"=>0x2277,
    "\xa2\xf1"=>0x2194,
    "\xa2\xfa"=>0x266e,
    "\xa2\xfb"=>0x266b,
    "\xa2\xfc"=>0x266c,
    "\xa2\xfd"=>0x2669,
    "\xa3\xa1"=>0x25b7,
    "\xa3\xa2"=>0x25b6,
    "\xa3\xa3"=>0x25c1,
    "\xa3\xa4"=>0x25c0,
    "\xa3\xa5"=>0x2197,
    "\xa3\xa6"=>0x2198,
    "\xa3\xa7"=>0x2196,
    "\xa3\xa8"=>0x2199,
    "\xa3\xa9"=>0x21c4,
    "\xa3\xaa"=>0x21e8,
    "\xa3\xab"=>0x21e6,
    "\xa3\xac"=>0x21e7,
    "\xa3\xad"=>0x21e9,
    "\xa3\xae"=>0x2934,
    "\xa3\xaf"=>0x2935,
    "\xa3\xba"=>0x2299,
    "\xa3\xbb"=>0x25c9,
    "\xa3\xbc"=>0x303d,
    "\xa3\xbd"=>0xfe46,
    "\xa3\xbe"=>0xfe45,
    "\xa3\xbf"=>0x25e6,
    "\xa3\xc0"=>0x2022,
    "\xa3\xdb"=>0x2213,
    "\xa3\xdc"=>0x2135,
    "\xa3\xdd"=>0x210f,
    "\xa3\xde"=>0x33cb,
    "\xa3\xdf"=>0x2113,
    "\xa3\xe0"=>0x2127,
    "\xa3\xfb"=>0x30a0,
    "\xa3\xfc"=>0x2013,
    "\xa3\xfd"=>0x29fa,
    "\xa3\xfe"=>0x29fb,
    "\xa4\xf4"=>0x3094,
    "\xa4\xf5"=>0x3095,
    "\xa4\xf6"=>0x3096,
#    "\xa4\xf7"=>0x304b, # U+309A
#    "\xa4\xf8"=>0x304d, # U+309A
#    "\xa4\xf9"=>0x304f, # U+309A
#    "\xa4\xfa"=>0x3051, # U+309A
#    "\xa4\xfb"=>0x3053, # U+309A
#    "\xa5\xf7"=>0x30ab, # U+309A
#    "\xa5\xf8"=>0x30ad, # U+309A
#    "\xa5\xf9"=>0x30af, # U+309A
#    "\xa5\xfa"=>0x30b1, # U+309A
#    "\xa5\xfb"=>0x30b3, # U+309A
#    "\xa5\xfc"=>0x30bb, # U+309A
#    "\xa5\xfd"=>0x30c4, # U+309A
#    "\xa5\xfe"=>0x30c8, # U+309A
    "\xa6\xb9"=>0x2664,
    "\xa6\xba"=>0x2660,
    "\xa6\xbb"=>0x2662,
    "\xa6\xbc"=>0x2666,
    "\xa6\xbd"=>0x2661,
    "\xa6\xbe"=>0x2665,
    "\xa6\xbf"=>0x2667,
    "\xa6\xc0"=>0x2663,
    "\xa6\xd9"=>0x03c2,
    "\xa6\xda"=>0x24f5,
    "\xa6\xdb"=>0x24f6,
    "\xa6\xdc"=>0x24f7,
    "\xa6\xdd"=>0x24f8,
    "\xa6\xde"=>0x24f9,
    "\xa6\xdf"=>0x24fa,
    "\xa6\xe0"=>0x24fb,
    "\xa6\xe1"=>0x24fc,
    "\xa6\xe2"=>0x24fd,
    "\xa6\xe3"=>0x24fe,
    "\xa6\xe4"=>0x2616,
    "\xa6\xe5"=>0x2617,
    "\xa6\xe6"=>0x3020,
    "\xa6\xe7"=>0x260e,
    "\xa6\xe8"=>0x2600,
    "\xa6\xe9"=>0x2601,
    "\xa6\xea"=>0x2602,
    "\xa6\xeb"=>0x2603,
    "\xa6\xec"=>0x2668,
    "\xa6\xed"=>0x25b1,
    "\xa6\xee"=>0x31f0,
    "\xa6\xef"=>0x31f1,
    "\xa6\xf0"=>0x31f2,
    "\xa6\xf1"=>0x31f3,
    "\xa6\xf2"=>0x31f4,
    "\xa6\xf3"=>0x31f5,
    "\xa6\xf4"=>0x31f6,
    "\xa6\xf5"=>0x31f7,
    "\xa6\xf6"=>0x31f8,
    "\xa6\xf7"=>0x31f9,
#    "\xa6\xf8"=>0x31f7, # U+309A
    "\xa6\xf9"=>0x31fa,
    "\xa6\xfa"=>0x31fb,
    "\xa6\xfb"=>0x31fc,
    "\xa6\xfc"=>0x31fd,
    "\xa6\xfd"=>0x31fe,
    "\xa6\xfe"=>0x31ff,
    "\xa7\xc2"=>0x23be,
    "\xa7\xc3"=>0x23bf,
    "\xa7\xc4"=>0x23c0,
    "\xa7\xc5"=>0x23c1,
    "\xa7\xc6"=>0x23c2,
    "\xa7\xc7"=>0x23c3,
    "\xa7\xc8"=>0x23c4,
    "\xa7\xc9"=>0x23c5,
    "\xa7\xca"=>0x23c6,
    "\xa7\xcb"=>0x23c7,
    "\xa7\xcc"=>0x23c8,
    "\xa7\xcd"=>0x23c9,
    "\xa7\xce"=>0x23ca,
    "\xa7\xcf"=>0x23cb,
    "\xa7\xd0"=>0x23cc,
    "\xa7\xf2"=>0x30f7,
    "\xa7\xf3"=>0x30f8,
    "\xa7\xf4"=>0x30f9,
    "\xa7\xf5"=>0x30fa,
    "\xa7\xf6"=>0x22da,
    "\xa7\xf7"=>0x22db,
    "\xa7\xf8"=>0x2153,
    "\xa7\xf9"=>0x2154,
    "\xa7\xfa"=>0x2155,
    "\xa7\xfb"=>0x2713,
    "\xa7\xfc"=>0x2318,
    "\xa7\xfd"=>0x2423,
    "\xa7\xfe"=>0x23ce,
    "\xa8\xc1"=>0x3251,
    "\xa8\xc2"=>0x3252,
    "\xa8\xc3"=>0x3253,
    "\xa8\xc4"=>0x3254,
    "\xa8\xc5"=>0x3255,
    "\xa8\xc6"=>0x3256,
    "\xa8\xc7"=>0x3257,
    "\xa8\xc8"=>0x3258,
    "\xa8\xc9"=>0x3259,
    "\xa8\xca"=>0x325a,
    "\xa8\xcb"=>0x325b,
    "\xa8\xcc"=>0x325c,
    "\xa8\xcd"=>0x325d,
    "\xa8\xce"=>0x325e,
    "\xa8\xcf"=>0x325f,
    "\xa8\xd0"=>0x32b1,
    "\xa8\xd1"=>0x32b2,
    "\xa8\xd2"=>0x32b3,
    "\xa8\xd3"=>0x32b4,
    "\xa8\xd4"=>0x32b5,
    "\xa8\xd5"=>0x32b6,
    "\xa8\xd6"=>0x32b7,
    "\xa8\xd7"=>0x32b8,
    "\xa8\xd8"=>0x32b9,
    "\xa8\xd9"=>0x32ba,
    "\xa8\xda"=>0x32bb,
    "\xa8\xdb"=>0x32bc,
    "\xa8\xdc"=>0x32bd,
    "\xa8\xdd"=>0x32be,
    "\xa8\xde"=>0x32bf,
    "\xa8\xe7"=>0x25d0,
    "\xa8\xe8"=>0x25d1,
    "\xa8\xe9"=>0x25d2,
    "\xa8\xea"=>0x25d3,
    "\xa8\xeb"=>0x203c,
    "\xa8\xec"=>0x2047,
    "\xa8\xed"=>0x2048,
    "\xa8\xee"=>0x2049,
    "\xa8\xef"=>0x01cd,
    "\xa8\xf0"=>0x01ce,
    "\xa8\xf1"=>0x01d0,
    "\xa8\xf2"=>0x1e3e,
    "\xa8\xf3"=>0x1e3f,
    "\xa8\xf4"=>0x01f8,
    "\xa8\xf5"=>0x01f9,
    "\xa8\xf6"=>0x01d1,
    "\xa8\xf7"=>0x01d2,
    "\xa8\xf8"=>0x01d4,
    "\xa8\xf9"=>0x01d6,
    "\xa8\xfa"=>0x01d8,
    "\xa8\xfb"=>0x01da,
    "\xa8\xfc"=>0x01dc,
    "\xa9\xa1"=>0x20ac,
    "\xa9\xa2"=>0x00a0,
    "\xa9\xa3"=>0x00a1,
    "\xa9\xa4"=>0x00a4,
    "\xa9\xa5"=>0x00a6,
    "\xa9\xa6"=>0x00a9,
    "\xa9\xa7"=>0x00aa,
    "\xa9\xa8"=>0x00ab,
    "\xa9\xa9"=>0x00ad,
    "\xa9\xaa"=>0x00ae,
    "\xa9\xab"=>0x00af,
    "\xa9\xac"=>0x00b2,
    "\xa9\xad"=>0x00b3,
    "\xa9\xae"=>0x00b7,
    "\xa9\xaf"=>0x00b8,
    "\xa9\xb0"=>0x00b9,
    "\xa9\xb1"=>0x00ba,
    "\xa9\xb2"=>0x00bb,
    "\xa9\xb3"=>0x00bc,
    "\xa9\xb4"=>0x00bd,
    "\xa9\xb5"=>0x00be,
    "\xa9\xb6"=>0x00bf,
    "\xa9\xb7"=>0x00c0,
    "\xa9\xb8"=>0x00c1,
    "\xa9\xb9"=>0x00c2,
    "\xa9\xba"=>0x00c3,
    "\xa9\xbb"=>0x00c4,
    "\xa9\xbc"=>0x00c5,
    "\xa9\xbd"=>0x00c6,
    "\xa9\xbe"=>0x00c7,
    "\xa9\xbf"=>0x00c8,
    "\xa9\xc0"=>0x00c9,
    "\xa9\xc1"=>0x00ca,
    "\xa9\xc2"=>0x00cb,
    "\xa9\xc3"=>0x00cc,
    "\xa9\xc4"=>0x00cd,
    "\xa9\xc5"=>0x00ce,
    "\xa9\xc6"=>0x00cf,
    "\xa9\xc7"=>0x00d0,
    "\xa9\xc8"=>0x00d1,
    "\xa9\xc9"=>0x00d2,
    "\xa9\xca"=>0x00d3,
    "\xa9\xcb"=>0x00d4,
    "\xa9\xcc"=>0x00d5,
    "\xa9\xcd"=>0x00d6,
    "\xa9\xce"=>0x00d8,
    "\xa9\xcf"=>0x00d9,
    "\xa9\xd0"=>0x00da,
    "\xa9\xd1"=>0x00db,
    "\xa9\xd2"=>0x00dc,
    "\xa9\xd3"=>0x00dd,
    "\xa9\xd4"=>0x00de,
    "\xa9\xd5"=>0x00df,
    "\xa9\xd6"=>0x00e0,
    "\xa9\xd7"=>0x00e1,
    "\xa9\xd8"=>0x00e2,
    "\xa9\xd9"=>0x00e3,
    "\xa9\xda"=>0x00e4,
    "\xa9\xdb"=>0x00e5,
    "\xa9\xdc"=>0x00e6,
    "\xa9\xdd"=>0x00e7,
    "\xa9\xde"=>0x00e8,
    "\xa9\xdf"=>0x00e9,
    "\xa9\xe0"=>0x00ea,
    "\xa9\xe1"=>0x00eb,
    "\xa9\xe2"=>0x00ec,
    "\xa9\xe3"=>0x00ed,
    "\xa9\xe4"=>0x00ee,
    "\xa9\xe5"=>0x00ef,
    "\xa9\xe6"=>0x00f0,
    "\xa9\xe7"=>0x00f1,
    "\xa9\xe8"=>0x00f2,
    "\xa9\xe9"=>0x00f3,
    "\xa9\xea"=>0x00f4,
    "\xa9\xeb"=>0x00f5,
    "\xa9\xec"=>0x00f6,
    "\xa9\xed"=>0x00f8,
    "\xa9\xee"=>0x00f9,
    "\xa9\xef"=>0x00fa,
    "\xa9\xf0"=>0x00fb,
    "\xa9\xf1"=>0x00fc,
    "\xa9\xf2"=>0x00fd,
    "\xa9\xf3"=>0x00fe,
    "\xa9\xf4"=>0x00ff,
    "\xa9\xf5"=>0x0100,
    "\xa9\xf6"=>0x012a,
    "\xa9\xf7"=>0x016a,
    "\xa9\xf8"=>0x0112,
    "\xa9\xf9"=>0x014c,
    "\xa9\xfa"=>0x0101,
    "\xa9\xfb"=>0x012b,
    "\xa9\xfc"=>0x016b,
    "\xa9\xfd"=>0x0113,
    "\xa9\xfe"=>0x014d,
    "\xaa\xa1"=>0x0104,
    "\xaa\xa2"=>0x02d8,
    "\xaa\xa3"=>0x0141,
    "\xaa\xa4"=>0x013d,
    "\xaa\xa5"=>0x015a,
    "\xaa\xa6"=>0x0160,
    "\xaa\xa7"=>0x015e,
    "\xaa\xa8"=>0x0164,
    "\xaa\xa9"=>0x0179,
    "\xaa\xaa"=>0x017d,
    "\xaa\xab"=>0x017b,
    "\xaa\xac"=>0x0105,
    "\xaa\xad"=>0x02db,
    "\xaa\xae"=>0x0142,
    "\xaa\xaf"=>0x013e,
    "\xaa\xb0"=>0x015b,
    "\xaa\xb1"=>0x02c7,
    "\xaa\xb2"=>0x0161,
    "\xaa\xb3"=>0x015f,
    "\xaa\xb4"=>0x0165,
    "\xaa\xb5"=>0x017a,
    "\xaa\xb6"=>0x02dd,
    "\xaa\xb7"=>0x017e,
    "\xaa\xb8"=>0x017c,
    "\xaa\xb9"=>0x0154,
    "\xaa\xba"=>0x0102,
    "\xaa\xbb"=>0x0139,
    "\xaa\xbc"=>0x0106,
    "\xaa\xbd"=>0x010c,
    "\xaa\xbe"=>0x0118,
    "\xaa\xbf"=>0x011a,
    "\xaa\xc0"=>0x010e,
    "\xaa\xc1"=>0x0143,
    "\xaa\xc2"=>0x0147,
    "\xaa\xc3"=>0x0150,
    "\xaa\xc4"=>0x0158,
    "\xaa\xc5"=>0x016e,
    "\xaa\xc6"=>0x0170,
    "\xaa\xc7"=>0x0162,
    "\xaa\xc8"=>0x0155,
    "\xaa\xc9"=>0x0103,
    "\xaa\xca"=>0x013a,
    "\xaa\xcb"=>0x0107,
    "\xaa\xcc"=>0x010d,
    "\xaa\xcd"=>0x0119,
    "\xaa\xce"=>0x011b,
    "\xaa\xcf"=>0x010f,
    "\xaa\xd0"=>0x0111,
    "\xaa\xd1"=>0x0144,
    "\xaa\xd2"=>0x0148,
    "\xaa\xd3"=>0x0151,
    "\xaa\xd4"=>0x0159,
    "\xaa\xd5"=>0x016f,
    "\xaa\xd6"=>0x0171,
    "\xaa\xd7"=>0x0163,
    "\xaa\xd8"=>0x02d9,
    "\xaa\xd9"=>0x0108,
    "\xaa\xda"=>0x011c,
    "\xaa\xdb"=>0x0124,
    "\xaa\xdc"=>0x0134,
    "\xaa\xdd"=>0x015c,
    "\xaa\xde"=>0x016c,
    "\xaa\xdf"=>0x0109,
    "\xaa\xe0"=>0x011d,
    "\xaa\xe1"=>0x0125,
    "\xaa\xe2"=>0x0135,
    "\xaa\xe3"=>0x015d,
    "\xaa\xe4"=>0x016d,
    "\xaa\xe5"=>0x0271,
    "\xaa\xe6"=>0x028b,
    "\xaa\xe7"=>0x027e,
    "\xaa\xe8"=>0x0283,
    "\xaa\xe9"=>0x0292,
    "\xaa\xea"=>0x026c,
    "\xaa\xeb"=>0x026e,
    "\xaa\xec"=>0x0279,
    "\xaa\xed"=>0x0288,
    "\xaa\xee"=>0x0256,
    "\xaa\xef"=>0x0273,
    "\xaa\xf0"=>0x027d,
    "\xaa\xf1"=>0x0282,
    "\xaa\xf2"=>0x0290,
    "\xaa\xf3"=>0x027b,
    "\xaa\xf4"=>0x026d,
    "\xaa\xf5"=>0x025f,
    "\xaa\xf6"=>0x0272,
    "\xaa\xf7"=>0x029d,
    "\xaa\xf8"=>0x028e,
    "\xaa\xf9"=>0x0261,
    "\xaa\xfa"=>0x014b,
    "\xaa\xfb"=>0x0270,
    "\xaa\xfc"=>0x0281,
    "\xaa\xfd"=>0x0127,
    "\xaa\xfe"=>0x0295,
    "\xab\xa1"=>0x0294,
    "\xab\xa2"=>0x0266,
    "\xab\xa3"=>0x0298,
    "\xab\xa4"=>0x01c2,
    "\xab\xa5"=>0x0253,
    "\xab\xa6"=>0x0257,
    "\xab\xa7"=>0x0284,
    "\xab\xa8"=>0x0260,
    "\xab\xa9"=>0x0193,
    "\xab\xaa"=>0x0153,
    "\xab\xab"=>0x0152,
    "\xab\xac"=>0x0268,
    "\xab\xad"=>0x0289,
    "\xab\xae"=>0x0258,
    "\xab\xaf"=>0x0275,
    "\xab\xb0"=>0x0259,
    "\xab\xb1"=>0x025c,
    "\xab\xb2"=>0x025e,
    "\xab\xb3"=>0x0250,
    "\xab\xb4"=>0x026f,
    "\xab\xb5"=>0x028a,
    "\xab\xb6"=>0x0264,
    "\xab\xb7"=>0x028c,
    "\xab\xb8"=>0x0254,
    "\xab\xb9"=>0x0251,
    "\xab\xba"=>0x0252,
    "\xab\xbb"=>0x028d,
    "\xab\xbc"=>0x0265,
    "\xab\xbd"=>0x02a2,
    "\xab\xbe"=>0x02a1,
    "\xab\xbf"=>0x0255,
    "\xab\xc0"=>0x0291,
    "\xab\xc1"=>0x027a,
    "\xab\xc2"=>0x0267,
    "\xab\xc3"=>0x025a,
#    "\xab\xc4"=>0x00e6,  # U+0300
    "\xab\xc5"=>0x01fd,
    "\xab\xc6"=>0x1f70,
    "\xab\xc7"=>0x1f71,
#    "\xab\xc8"=>0x0254,  # U+0300
#    "\xab\xc9"=>0x0254,  # U+0301
#    "\xab\xca"=>0x028c,  # U+0300
#    "\xab\xcb"=>0x028c,  # U+0301
#    "\xab\xcc"=>0x0259,  # U+0300
#    "\xab\xcd"=>0x0259,  # U+0301
#    "\xab\xce"=>0x025a,  # U+0300
#    "\xab\xcf"=>0x025a,  # U+0301
    "\xab\xd0"=>0x1f72,
    "\xab\xd1"=>0x1f73,
    "\xab\xd2"=>0x0361,
    "\xab\xd3"=>0x02c8,
    "\xab\xd4"=>0x02cc,
    "\xab\xd5"=>0x02d0,
    "\xab\xd6"=>0x02d1,
    "\xab\xd7"=>0x0306,
    "\xab\xd8"=>0x203f,
    "\xab\xd9"=>0x030b,
    "\xab\xda"=>0x0301,
    "\xab\xdb"=>0x0304,
    "\xab\xdc"=>0x0300,
    "\xab\xdd"=>0x030f,
    "\xab\xde"=>0x030c,
    "\xab\xdf"=>0x0302,
    "\xab\xe0"=>0x02e5,
    "\xab\xe1"=>0x02e6,
    "\xab\xe2"=>0x02e7,
    "\xab\xe3"=>0x02e8,
    "\xab\xe4"=>0x02e9,
#    "\xab\xe5"=>0x02e9,  # U+02E5
#    "\xab\xe6"=>0x02e5,  # U+02E9
    "\xab\xe7"=>0x0325,
    "\xab\xe8"=>0x032c,
    "\xab\xe9"=>0x0339,
    "\xab\xea"=>0x031c,
    "\xab\xeb"=>0x031f,
    "\xab\xec"=>0x0320,
    "\xab\xed"=>0x0308,
    "\xab\xee"=>0x033d,
    "\xab\xef"=>0x0329,
    "\xab\xf0"=>0x032f,
    "\xab\xf1"=>0x02de,
    "\xab\xf2"=>0x0324,
    "\xab\xf3"=>0x0330,
    "\xab\xf4"=>0x033c,
    "\xab\xf5"=>0x0334,
    "\xab\xf6"=>0x031d,
    "\xab\xf7"=>0x031e,
    "\xab\xf8"=>0x0318,
    "\xab\xf9"=>0x0319,
    "\xab\xfa"=>0x032a,
    "\xab\xfb"=>0x033a,
    "\xab\xfc"=>0x033b,
    "\xab\xfd"=>0x0303,
    "\xab\xfe"=>0x031a,
    "\xac\xa1"=>0x2776,
    "\xac\xa2"=>0x2777,
    "\xac\xa3"=>0x2778,
    "\xac\xa4"=>0x2779,
    "\xac\xa5"=>0x277a,
    "\xac\xa6"=>0x277b,
    "\xac\xa7"=>0x277c,
    "\xac\xa8"=>0x277d,
    "\xac\xa9"=>0x277e,
    "\xac\xaa"=>0x277f,
    "\xac\xab"=>0x24eb,
    "\xac\xac"=>0x24ec,
    "\xac\xad"=>0x24ed,
    "\xac\xae"=>0x24ee,
    "\xac\xaf"=>0x24ef,
    "\xac\xb0"=>0x24f0,
    "\xac\xb1"=>0x24f1,
    "\xac\xb2"=>0x24f2,
    "\xac\xb3"=>0x24f3,
    "\xac\xb4"=>0x24f4,
    "\xac\xb5"=>0x2170,
    "\xac\xb6"=>0x2171,
    "\xac\xb7"=>0x2172,
    "\xac\xb8"=>0x2173,
    "\xac\xb9"=>0x2174,
    "\xac\xba"=>0x2175,
    "\xac\xbb"=>0x2176,
    "\xac\xbc"=>0x2177,
    "\xac\xbd"=>0x2178,
    "\xac\xbe"=>0x2179,
    "\xac\xbf"=>0x217a,
    "\xac\xc0"=>0x217b,
    "\xac\xc1"=>0x24d0,
    "\xac\xc2"=>0x24d1,
    "\xac\xc3"=>0x24d2,
    "\xac\xc4"=>0x24d3,
    "\xac\xc5"=>0x24d4,
    "\xac\xc6"=>0x24d5,
    "\xac\xc7"=>0x24d6,
    "\xac\xc8"=>0x24d7,
    "\xac\xc9"=>0x24d8,
    "\xac\xca"=>0x24d9,
    "\xac\xcb"=>0x24da,
    "\xac\xcc"=>0x24db,
    "\xac\xcd"=>0x24dc,
    "\xac\xce"=>0x24dd,
    "\xac\xcf"=>0x24de,
    "\xac\xd0"=>0x24df,
    "\xac\xd1"=>0x24e0,
    "\xac\xd2"=>0x24e1,
    "\xac\xd3"=>0x24e2,
    "\xac\xd4"=>0x24e3,
    "\xac\xd5"=>0x24e4,
    "\xac\xd6"=>0x24e5,
    "\xac\xd7"=>0x24e6,
    "\xac\xd8"=>0x24e7,
    "\xac\xd9"=>0x24e8,
    "\xac\xda"=>0x24e9,
    "\xac\xdb"=>0x32d0,
    "\xac\xdc"=>0x32d1,
    "\xac\xdd"=>0x32d2,
    "\xac\xde"=>0x32d3,
    "\xac\xdf"=>0x32d4,
    "\xac\xe0"=>0x32d5,
    "\xac\xe1"=>0x32d6,
    "\xac\xe2"=>0x32d7,
    "\xac\xe3"=>0x32d8,
    "\xac\xe4"=>0x32d9,
    "\xac\xe5"=>0x32da,
    "\xac\xe6"=>0x32db,
    "\xac\xe7"=>0x32dc,
    "\xac\xe8"=>0x32dd,
    "\xac\xe9"=>0x32de,
    "\xac\xea"=>0x32df,
    "\xac\xeb"=>0x32e0,
    "\xac\xec"=>0x32e1,
    "\xac\xed"=>0x32e2,
    "\xac\xee"=>0x32e3,
    "\xac\xef"=>0x32fa,
    "\xac\xf0"=>0x32e9,
    "\xac\xf1"=>0x32e5,
    "\xac\xf2"=>0x32ed,
    "\xac\xf3"=>0x32ec,
    "\xac\xfd"=>0x2051,
    "\xac\xfe"=>0x2042,
    "\xad\xa1"=>0x2460,
    "\xad\xa2"=>0x2461,
    "\xad\xa3"=>0x2462,
    "\xad\xa4"=>0x2463,
    "\xad\xa5"=>0x2464,
    "\xad\xa6"=>0x2465,
    "\xad\xa7"=>0x2466,
    "\xad\xa8"=>0x2467,
    "\xad\xa9"=>0x2468,
    "\xad\xaa"=>0x2469,
    "\xad\xab"=>0x246a,
    "\xad\xac"=>0x246b,
    "\xad\xad"=>0x246c,
    "\xad\xae"=>0x246d,
    "\xad\xaf"=>0x246e,
    "\xad\xb0"=>0x246f,
    "\xad\xb1"=>0x2470,
    "\xad\xb2"=>0x2471,
    "\xad\xb3"=>0x2472,
    "\xad\xb4"=>0x2473,
    "\xad\xb5"=>0x2160,
    "\xad\xb6"=>0x2161,
    "\xad\xb7"=>0x2162,
    "\xad\xb8"=>0x2163,
    "\xad\xb9"=>0x2164,
    "\xad\xba"=>0x2165,
    "\xad\xbb"=>0x2166,
    "\xad\xbc"=>0x2167,
    "\xad\xbd"=>0x2168,
    "\xad\xbe"=>0x2169,
    "\xad\xbf"=>0x216a,
    "\xad\xc0"=>0x3349,
    "\xad\xc1"=>0x3314,
    "\xad\xc2"=>0x3322,
    "\xad\xc3"=>0x334d,
    "\xad\xc4"=>0x3318,
    "\xad\xc5"=>0x3327,
    "\xad\xc6"=>0x3303,
    "\xad\xc7"=>0x3336,
    "\xad\xc8"=>0x3351,
    "\xad\xc9"=>0x3357,
    "\xad\xca"=>0x330d,
    "\xad\xcb"=>0x3326,
    "\xad\xcc"=>0x3323,
    "\xad\xcd"=>0x332b,
    "\xad\xce"=>0x334a,
    "\xad\xcf"=>0x333b,
    "\xad\xd0"=>0x339c,
    "\xad\xd1"=>0x339d,
    "\xad\xd2"=>0x339e,
    "\xad\xd3"=>0x338e,
    "\xad\xd4"=>0x338f,
    "\xad\xd5"=>0x33c4,
    "\xad\xd6"=>0x33a1,
    "\xad\xd7"=>0x216b,
    "\xad\xdf"=>0x337b,
    "\xad\xe0"=>0x301d,
    "\xad\xe1"=>0x301f,
    "\xad\xe2"=>0x2116,
    "\xad\xe3"=>0x33cd,
    "\xad\xe4"=>0x2121,
    "\xad\xe5"=>0x32a4,
    "\xad\xe6"=>0x32a5,
    "\xad\xe7"=>0x32a6,
    "\xad\xe8"=>0x32a7,
    "\xad\xe9"=>0x32a8,
    "\xad\xea"=>0x3231,
    "\xad\xeb"=>0x3232,
    "\xad\xec"=>0x3239,
    "\xad\xed"=>0x337e,
    "\xad\xee"=>0x337d,
    "\xad\xef"=>0x337c,
    "\xad\xf3"=>0x222e,
    "\xad\xf8"=>0x221f,
    "\xad\xf9"=>0x22bf,
    "\xad\xfd"=>0x2756,
    "\xad\xfe"=>0x261e,
    "\xae\xa1"=>0x4ff1, # [2004]
    "\xae\xa2"=>0x2000b,
    "\xae\xa3"=>0x3402,
    "\xae\xa4"=>0x4e28,
    "\xae\xa5"=>0x4e2f,
    "\xae\xa6"=>0x4e30,
    "\xae\xa7"=>0x4e8d,
    "\xae\xa8"=>0x4ee1,
    "\xae\xa9"=>0x4efd,
    "\xae\xaa"=>0x4eff,
    "\xae\xab"=>0x4f03,
    "\xae\xac"=>0x4f0b,
    "\xae\xad"=>0x4f60,
    "\xae\xae"=>0x4f48,
    "\xae\xaf"=>0x4f49,
    "\xae\xb0"=>0x4f56,
    "\xae\xb1"=>0x4f5f,
    "\xae\xb2"=>0x4f6a,
    "\xae\xb3"=>0x4f6c,
    "\xae\xb4"=>0x4f7e,
    "\xae\xb5"=>0x4f8a,
    "\xae\xb6"=>0x4f94,
    "\xae\xb7"=>0x4f97,
    "\xae\xb8"=>0xfa30,
    "\xae\xb9"=>0x4fc9,
    "\xae\xba"=>0x4fe0,
    "\xae\xbb"=>0x5001,
    "\xae\xbc"=>0x5002,
    "\xae\xbd"=>0x500e,
    "\xae\xbe"=>0x5018,
    "\xae\xbf"=>0x5027,
    "\xae\xc0"=>0x502e,
    "\xae\xc1"=>0x5040,
    "\xae\xc2"=>0x503b,
    "\xae\xc3"=>0x5041,
    "\xae\xc4"=>0x5094,
    "\xae\xc5"=>0x50cc,
    "\xae\xc6"=>0x50f2,
    "\xae\xc7"=>0x50d0,
    "\xae\xc8"=>0x50e6,
    "\xae\xc9"=>0xfa31,
    "\xae\xca"=>0x5106,
    "\xae\xcb"=>0x5103,
    "\xae\xcc"=>0x510b,
    "\xae\xcd"=>0x511e,
    "\xae\xce"=>0x5135,
    "\xae\xcf"=>0x514a,
    "\xae\xd0"=>0xfa32,
    "\xae\xd1"=>0x5155,
    "\xae\xd2"=>0x5157,
    "\xae\xd3"=>0x34b5,
    "\xae\xd4"=>0x519d,
    "\xae\xd5"=>0x51c3,
    "\xae\xd6"=>0x51ca,
    "\xae\xd7"=>0x51de,
    "\xae\xd8"=>0x51e2,
    "\xae\xd9"=>0x51ee,
    "\xae\xda"=>0x5201,
    "\xae\xdb"=>0x34db,
    "\xae\xdc"=>0x5213,
    "\xae\xdd"=>0x5215,
    "\xae\xde"=>0x5249,
    "\xae\xdf"=>0x5257,
    "\xae\xe0"=>0x5261,
    "\xae\xe1"=>0x5293,
    "\xae\xe2"=>0x52c8,
    "\xae\xe3"=>0xfa33,
    "\xae\xe4"=>0x52cc,
    "\xae\xe5"=>0x52d0,
    "\xae\xe6"=>0x52d6,
    "\xae\xe7"=>0x52db,
    "\xae\xe8"=>0xfa34,
    "\xae\xe9"=>0x52f0,
    "\xae\xea"=>0x52fb,
    "\xae\xeb"=>0x5300,
    "\xae\xec"=>0x5307,
    "\xae\xed"=>0x531c,
    "\xae\xee"=>0xfa35,
    "\xae\xef"=>0x5361,
    "\xae\xf0"=>0x5363,
    "\xae\xf1"=>0x537d,
    "\xae\xf2"=>0x5393,
    "\xae\xf3"=>0x539d,
    "\xae\xf4"=>0x53b2,
    "\xae\xf5"=>0x5412,
    "\xae\xf6"=>0x5427,
    "\xae\xf7"=>0x544d,
    "\xae\xf8"=>0x549c,
    "\xae\xf9"=>0x546b,
    "\xae\xfa"=>0x5474,
    "\xae\xfb"=>0x547f,
    "\xae\xfc"=>0x5488,
    "\xae\xfd"=>0x5496,
    "\xae\xfe"=>0x54a1,
    "\xaf\xa1"=>0x54a9,
    "\xaf\xa2"=>0x54c6,
    "\xaf\xa3"=>0x54ff,
    "\xaf\xa4"=>0x550e,
    "\xaf\xa5"=>0x552b,
    "\xaf\xa6"=>0x5535,
    "\xaf\xa7"=>0x5550,
    "\xaf\xa8"=>0x555e,
    "\xaf\xa9"=>0x5581,
    "\xaf\xaa"=>0x5586,
    "\xaf\xab"=>0x558e,
    "\xaf\xac"=>0xfa36,
    "\xaf\xad"=>0x55ad,
    "\xaf\xae"=>0x55ce,
    "\xaf\xaf"=>0xfa37,
    "\xaf\xb0"=>0x5608,
    "\xaf\xb1"=>0x560e,
    "\xaf\xb2"=>0x563b,
    "\xaf\xb3"=>0x5649,
    "\xaf\xb4"=>0x5676,
    "\xaf\xb5"=>0x5666,
    "\xaf\xb6"=>0xfa38,
    "\xaf\xb7"=>0x566f,
    "\xaf\xb8"=>0x5671,
    "\xaf\xb9"=>0x5672,
    "\xaf\xba"=>0x5699,
    "\xaf\xbb"=>0x569e,
    "\xaf\xbc"=>0x56a9,
    "\xaf\xbd"=>0x56ac,
    "\xaf\xbe"=>0x56b3,
    "\xaf\xbf"=>0x56c9,
    "\xaf\xc0"=>0x56ca,
    "\xaf\xc1"=>0x570a,
    "\xaf\xc2"=>0x2123d,
    "\xaf\xc3"=>0x5721,
    "\xaf\xc4"=>0x572f,
    "\xaf\xc5"=>0x5733,
    "\xaf\xc6"=>0x5734,
    "\xaf\xc7"=>0x5770,
    "\xaf\xc8"=>0x5777,
    "\xaf\xc9"=>0x577c,
    "\xaf\xca"=>0x579c,
    "\xaf\xcb"=>0xfa0f,
    "\xaf\xcc"=>0x2131b,
    "\xaf\xcd"=>0x57b8,
    "\xaf\xce"=>0x57c7,
    "\xaf\xcf"=>0x57c8,
    "\xaf\xd0"=>0x57cf,
    "\xaf\xd1"=>0x57e4,
    "\xaf\xd2"=>0x57ed,
    "\xaf\xd3"=>0x57f5,
    "\xaf\xd4"=>0x57f6,
    "\xaf\xd5"=>0x57ff,
    "\xaf\xd6"=>0x5809,
    "\xaf\xd7"=>0xfa10,
    "\xaf\xd8"=>0x5861,
    "\xaf\xd9"=>0x5864,
    "\xaf\xda"=>0xfa39,
    "\xaf\xdb"=>0x587c,
    "\xaf\xdc"=>0x5889,
    "\xaf\xdd"=>0x589e,
    "\xaf\xde"=>0xfa3a,
    "\xaf\xdf"=>0x58a9,
    "\xaf\xe0"=>0x2146e,
    "\xaf\xe1"=>0x58d2,
    "\xaf\xe2"=>0x58ce,
    "\xaf\xe3"=>0x58d4,
    "\xaf\xe4"=>0x58da,
    "\xaf\xe5"=>0x58e0,
    "\xaf\xe6"=>0x58e9,
    "\xaf\xe7"=>0x590c,
    "\xaf\xe8"=>0x8641,
    "\xaf\xe9"=>0x595d,
    "\xaf\xea"=>0x596d,
    "\xaf\xeb"=>0x598b,
    "\xaf\xec"=>0x5992,
    "\xaf\xed"=>0x59a4,
    "\xaf\xee"=>0x59c3,
    "\xaf\xef"=>0x59d2,
    "\xaf\xf0"=>0x59dd,
    "\xaf\xf1"=>0x5a13,
    "\xaf\xf2"=>0x5a23,
    "\xaf\xf3"=>0x5a67,
    "\xaf\xf4"=>0x5a6d,
    "\xaf\xf5"=>0x5a77,
    "\xaf\xf6"=>0x5a7e,
    "\xaf\xf7"=>0x5a84,
    "\xaf\xf8"=>0x5a9e,
    "\xaf\xf9"=>0x5aa7,
    "\xaf\xfa"=>0x5ac4,
    "\xaf\xfb"=>0x218bd,
    "\xaf\xfc"=>0x5b19,
    "\xaf\xfd"=>0x5b25,
    "\xaf\xfe"=>0x525d,  # [2004]
    "\xcf\xd4"=>0x20b9f, # [2004]
    "\xcf\xd5"=>0x5b41,
    "\xcf\xd6"=>0x5b56,
    "\xcf\xd7"=>0x5b7d,
    "\xcf\xd8"=>0x5b93,
    "\xcf\xd9"=>0x5bd8,
    "\xcf\xda"=>0x5bec,
    "\xcf\xdb"=>0x5c12,
    "\xcf\xdc"=>0x5c1e,
    "\xcf\xdd"=>0x5c23,
    "\xcf\xde"=>0x5c2b,
    "\xcf\xdf"=>0x378d,
    "\xcf\xe0"=>0x5c62,
    "\xcf\xe1"=>0xfa3b,
    "\xcf\xe2"=>0xfa3c,
    "\xcf\xe3"=>0x216b4,
    "\xcf\xe4"=>0x5c7a,
    "\xcf\xe5"=>0x5c8f,
    "\xcf\xe6"=>0x5c9f,
    "\xcf\xe7"=>0x5ca3,
    "\xcf\xe8"=>0x5caa,
    "\xcf\xe9"=>0x5cba,
    "\xcf\xea"=>0x5ccb,
    "\xcf\xeb"=>0x5cd0,
    "\xcf\xec"=>0x5cd2,
    "\xcf\xed"=>0x5cf4,
    "\xcf\xee"=>0x21e34,
    "\xcf\xef"=>0x37e2,
    "\xcf\xf0"=>0x5d0d,
    "\xcf\xf1"=>0x5d27,
    "\xcf\xf2"=>0xfa11,
    "\xcf\xf3"=>0x5d46,
    "\xcf\xf4"=>0x5d47,
    "\xcf\xf5"=>0x5d53,
    "\xcf\xf6"=>0x5d4a,
    "\xcf\xf7"=>0x5d6d,
    "\xcf\xf8"=>0x5d81,
    "\xcf\xf9"=>0x5da0,
    "\xcf\xfa"=>0x5da4,
    "\xcf\xfb"=>0x5da7,
    "\xcf\xfc"=>0x5db8,
    "\xcf\xfd"=>0x5dcb,
    "\xcf\xfe"=>0x541e, # [2004]
    "\xf4\xa7"=>0x5653, # [2004]
    "\xf4\xa8"=>0x5de2,
    "\xf4\xa9"=>0x5e14,
    "\xf4\xaa"=>0x5e18,
    "\xf4\xab"=>0x5e58,
    "\xf4\xac"=>0x5e5e,
    "\xf4\xad"=>0x5ebe,
    "\xf4\xae"=>0xf928,
    "\xf4\xaf"=>0x5ecb,
    "\xf4\xb0"=>0x5ef9,
    "\xf4\xb1"=>0x5f00,
    "\xf4\xb2"=>0x5f02,
    "\xf4\xb3"=>0x5f07,
    "\xf4\xb4"=>0x5f1d,
    "\xf4\xb5"=>0x5f23,
    "\xf4\xb6"=>0x5f34,
    "\xf4\xb7"=>0x5f36,
    "\xf4\xb8"=>0x5f3d,
    "\xf4\xb9"=>0x5f40,
    "\xf4\xba"=>0x5f45,
    "\xf4\xbb"=>0x5f54,
    "\xf4\xbc"=>0x5f58,
    "\xf4\xbd"=>0x5f64,
    "\xf4\xbe"=>0x5f67,
    "\xf4\xbf"=>0x5f7d,
    "\xf4\xc0"=>0x5f89,
    "\xf4\xc1"=>0x5f9c,
    "\xf4\xc2"=>0x5fa7,
    "\xf4\xc3"=>0x5faf,
    "\xf4\xc4"=>0x5fb5,
    "\xf4\xc5"=>0x5fb7,
    "\xf4\xc6"=>0x5fc9,
    "\xf4\xc7"=>0x5fde,
    "\xf4\xc8"=>0x5fe1,
    "\xf4\xc9"=>0x5fe9,
    "\xf4\xca"=>0x600d,
    "\xf4\xcb"=>0x6014,
    "\xf4\xcc"=>0x6018,
    "\xf4\xcd"=>0x6033,
    "\xf4\xce"=>0x6035,
    "\xf4\xcf"=>0x6047,
    "\xf4\xd0"=>0xfa3d,
    "\xf4\xd1"=>0x609d,
    "\xf4\xd2"=>0x609e,
    "\xf4\xd3"=>0x60cb,
    "\xf4\xd4"=>0x60d4,
    "\xf4\xd5"=>0x60d5,
    "\xf4\xd6"=>0x60dd,
    "\xf4\xd7"=>0x60f8,
    "\xf4\xd8"=>0x611c,
    "\xf4\xd9"=>0x612b,
    "\xf4\xda"=>0x6130,
    "\xf4\xdb"=>0x6137,
    "\xf4\xdc"=>0xfa3e,
    "\xf4\xdd"=>0x618d,
    "\xf4\xde"=>0xfa3f,
    "\xf4\xdf"=>0x61bc,
    "\xf4\xe0"=>0x61b9,
    "\xf4\xe1"=>0xfa40,
    "\xf4\xe2"=>0x6222,
    "\xf4\xe3"=>0x623e,
    "\xf4\xe4"=>0x6243,
    "\xf4\xe5"=>0x6256,
    "\xf4\xe6"=>0x625a,
    "\xf4\xe7"=>0x626f,
    "\xf4\xe8"=>0x6285,
    "\xf4\xe9"=>0x62c4,
    "\xf4\xea"=>0x62d6,
    "\xf4\xeb"=>0x62fc,
    "\xf4\xec"=>0x630a,
    "\xf4\xed"=>0x6318,
    "\xf4\xee"=>0x6339,
    "\xf4\xef"=>0x6343,
    "\xf4\xf0"=>0x6365,
    "\xf4\xf1"=>0x637c,
    "\xf4\xf2"=>0x63e5,
    "\xf4\xf3"=>0x63ed,
    "\xf4\xf4"=>0x63f5,
    "\xf4\xf5"=>0x6410,
    "\xf4\xf6"=>0x6414,
    "\xf4\xf7"=>0x6422,
    "\xf4\xf8"=>0x6479,
    "\xf4\xf9"=>0x6451,
    "\xf4\xfa"=>0x6460,
    "\xf4\xfb"=>0x646d,
    "\xf4\xfc"=>0x64ce,
    "\xf4\xfd"=>0x64be,
    "\xf4\xfe"=>0x64bf,
    "\xf5\xa1"=>0x64c4,
    "\xf5\xa2"=>0x64ca,
    "\xf5\xa3"=>0x64d0,
    "\xf5\xa4"=>0x64f7,
    "\xf5\xa5"=>0x64fb,
    "\xf5\xa6"=>0x6522,
    "\xf5\xa7"=>0x6529,
    "\xf5\xa8"=>0xfa41,
    "\xf5\xa9"=>0x6567,
    "\xf5\xaa"=>0x659d,
    "\xf5\xab"=>0xfa42,
    "\xf5\xac"=>0x6600,
    "\xf5\xad"=>0x6609,
    "\xf5\xae"=>0x6615,
    "\xf5\xaf"=>0x661e,
    "\xf5\xb0"=>0x663a,
    "\xf5\xb1"=>0x6622,
    "\xf5\xb2"=>0x6624,
    "\xf5\xb3"=>0x662b,
    "\xf5\xb4"=>0x6630,
    "\xf5\xb5"=>0x6631,
    "\xf5\xb6"=>0x6633,
    "\xf5\xb7"=>0x66fb,
    "\xf5\xb8"=>0x6648,
    "\xf5\xb9"=>0x664c,
    "\xf5\xba"=>0x231c4,
    "\xf5\xbb"=>0x6659,
    "\xf5\xbc"=>0x665a,
    "\xf5\xbd"=>0x6661,
    "\xf5\xbe"=>0x6665,
    "\xf5\xbf"=>0x6673,
    "\xf5\xc0"=>0x6677,
    "\xf5\xc1"=>0x6678,
    "\xf5\xc2"=>0x668d,
    "\xf5\xc3"=>0xfa43,
    "\xf5\xc4"=>0x66a0,
    "\xf5\xc5"=>0x66b2,
    "\xf5\xc6"=>0x66bb,
    "\xf5\xc7"=>0x66c6,
    "\xf5\xc8"=>0x66c8,
    "\xf5\xc9"=>0x3b22,
    "\xf5\xca"=>0x66db,
    "\xf5\xcb"=>0x66e8,
    "\xf5\xcc"=>0x66fa,
    "\xf5\xcd"=>0x6713,
    "\xf5\xce"=>0xf929,
    "\xf5\xcf"=>0x6733,
    "\xf5\xd0"=>0x6766,
    "\xf5\xd1"=>0x6747,
    "\xf5\xd2"=>0x6748,
    "\xf5\xd3"=>0x677b,
    "\xf5\xd4"=>0x6781,
    "\xf5\xd5"=>0x6793,
    "\xf5\xd6"=>0x6798,
    "\xf5\xd7"=>0x679b,
    "\xf5\xd8"=>0x67bb,
    "\xf5\xd9"=>0x67f9,
    "\xf5\xda"=>0x67c0,
    "\xf5\xdb"=>0x67d7,
    "\xf5\xdc"=>0x67fc,
    "\xf5\xdd"=>0x6801,
    "\xf5\xde"=>0x6852,
    "\xf5\xdf"=>0x681d,
    "\xf5\xe0"=>0x682c,
    "\xf5\xe1"=>0x6831,
    "\xf5\xe2"=>0x685b,
    "\xf5\xe3"=>0x6872,
    "\xf5\xe4"=>0x6875,
    "\xf5\xe5"=>0xfa44,
    "\xf5\xe6"=>0x68a3,
    "\xf5\xe7"=>0x68a5,
    "\xf5\xe8"=>0x68b2,
    "\xf5\xe9"=>0x68c8,
    "\xf5\xea"=>0x68d0,
    "\xf5\xeb"=>0x68e8,
    "\xf5\xec"=>0x68ed,
    "\xf5\xed"=>0x68f0,
    "\xf5\xee"=>0x68f1,
    "\xf5\xef"=>0x68fc,
    "\xf5\xf0"=>0x690a,
    "\xf5\xf1"=>0x6949,
    "\xf5\xf2"=>0x235c4,
    "\xf5\xf3"=>0x6935,
    "\xf5\xf4"=>0x6942,
    "\xf5\xf5"=>0x6957,
    "\xf5\xf6"=>0x6963,
    "\xf5\xf7"=>0x6964,
    "\xf5\xf8"=>0x6968,
    "\xf5\xf9"=>0x6980,
    "\xf5\xfa"=>0xfa14,
    "\xf5\xfb"=>0x69a5,
    "\xf5\xfc"=>0x69ad,
    "\xf5\xfd"=>0x69cf,
    "\xf5\xfe"=>0x3bb6,
    "\xf6\xa1"=>0x3bc3,
    "\xf6\xa2"=>0x69e2,
    "\xf6\xa3"=>0x69e9,
    "\xf6\xa4"=>0x69ea,
    "\xf6\xa5"=>0x69f5,
    "\xf6\xa6"=>0x69f6,
    "\xf6\xa7"=>0x6a0f,
    "\xf6\xa8"=>0x6a15,
    "\xf6\xa9"=>0x2373f,
    "\xf6\xaa"=>0x6a3b,
    "\xf6\xab"=>0x6a3e,
    "\xf6\xac"=>0x6a45,
    "\xf6\xad"=>0x6a50,
    "\xf6\xae"=>0x6a56,
    "\xf6\xaf"=>0x6a5b,
    "\xf6\xb0"=>0x6a6b,
    "\xf6\xb1"=>0x6a73,
    "\xf6\xb2"=>0x23763,
    "\xf6\xb3"=>0x6a89,
    "\xf6\xb4"=>0x6a94,
    "\xf6\xb5"=>0x6a9d,
    "\xf6\xb6"=>0x6a9e,
    "\xf6\xb7"=>0x6aa5,
    "\xf6\xb8"=>0x6ae4,
    "\xf6\xb9"=>0x6ae7,
    "\xf6\xba"=>0x3c0f,
    "\xf6\xbb"=>0xf91d,
    "\xf6\xbc"=>0x6b1b,
    "\xf6\xbd"=>0x6b1e,
    "\xf6\xbe"=>0x6b2c,
    "\xf6\xbf"=>0x6b35,
    "\xf6\xc0"=>0x6b46,
    "\xf6\xc1"=>0x6b56,
    "\xf6\xc2"=>0x6b60,
    "\xf6\xc3"=>0x6b65,
    "\xf6\xc4"=>0x6b67,
    "\xf6\xc5"=>0x6b77,
    "\xf6\xc6"=>0x6b82,
    "\xf6\xc7"=>0x6ba9,
    "\xf6\xc8"=>0x6bad,
    "\xf6\xc9"=>0xf970,
    "\xf6\xca"=>0x6bcf,
    "\xf6\xcb"=>0x6bd6,
    "\xf6\xcc"=>0x6bd7,
    "\xf6\xcd"=>0x6bff,
    "\xf6\xce"=>0x6c05,
    "\xf6\xcf"=>0x6c10,
    "\xf6\xd0"=>0x6c33,
    "\xf6\xd1"=>0x6c59,
    "\xf6\xd2"=>0x6c5c,
    "\xf6\xd3"=>0x6caa,
    "\xf6\xd4"=>0x6c74,
    "\xf6\xd5"=>0x6c76,
    "\xf6\xd6"=>0x6c85,
    "\xf6\xd7"=>0x6c86,
    "\xf6\xd8"=>0x6c98,
    "\xf6\xd9"=>0x6c9c,
    "\xf6\xda"=>0x6cfb,
    "\xf6\xdb"=>0x6cc6,
    "\xf6\xdc"=>0x6cd4,
    "\xf6\xdd"=>0x6ce0,
    "\xf6\xde"=>0x6ceb,
    "\xf6\xdf"=>0x6cee,
    "\xf6\xe0"=>0x23cfe,
    "\xf6\xe1"=>0x6d04,
    "\xf6\xe2"=>0x6d0e,
    "\xf6\xe3"=>0x6d2e,
    "\xf6\xe4"=>0x6d31,
    "\xf6\xe5"=>0x6d39,
    "\xf6\xe6"=>0x6d3f,
    "\xf6\xe7"=>0x6d58,
    "\xf6\xe8"=>0x6d65,
    "\xf6\xe9"=>0xfa45,
    "\xf6\xea"=>0x6d82,
    "\xf6\xeb"=>0x6d87,
    "\xf6\xec"=>0x6d89,
    "\xf6\xed"=>0x6d94,
    "\xf6\xee"=>0x6daa,
    "\xf6\xef"=>0x6dac,
    "\xf6\xf0"=>0x6dbf,
    "\xf6\xf1"=>0x6dc4,
    "\xf6\xf2"=>0x6dd6,
    "\xf6\xf3"=>0x6dda,
    "\xf6\xf4"=>0x6ddb,
    "\xf6\xf5"=>0x6ddd,
    "\xf6\xf6"=>0x6dfc,
    "\xf6\xf7"=>0xfa46,
    "\xf6\xf8"=>0x6e34,
    "\xf6\xf9"=>0x6e44,
    "\xf6\xfa"=>0x6e5c,
    "\xf6\xfb"=>0x6e5e,
    "\xf6\xfc"=>0x6eab,
    "\xf6\xfd"=>0x6eb1,
    "\xf6\xfe"=>0x6ec1,
    "\xf7\xa1"=>0x6ec7,
    "\xf7\xa2"=>0x6ece,
    "\xf7\xa3"=>0x6f10,
    "\xf7\xa4"=>0x6f1a,
    "\xf7\xa5"=>0xfa47,
    "\xf7\xa6"=>0x6f2a,
    "\xf7\xa7"=>0x6f2f,
    "\xf7\xa8"=>0x6f33,
    "\xf7\xa9"=>0x6f51,
    "\xf7\xaa"=>0x6f59,
    "\xf7\xab"=>0x6f5e,
    "\xf7\xac"=>0x6f61,
    "\xf7\xad"=>0x6f62,
    "\xf7\xae"=>0x6f7e,
    "\xf7\xaf"=>0x6f88,
    "\xf7\xb0"=>0x6f8c,
    "\xf7\xb1"=>0x6f8d,
    "\xf7\xb2"=>0x6f94,
    "\xf7\xb3"=>0x6fa0,
    "\xf7\xb4"=>0x6fa7,
    "\xf7\xb5"=>0x6fb6,
    "\xf7\xb6"=>0x6fbc,
    "\xf7\xb7"=>0x6fc7,
    "\xf7\xb8"=>0x6fca,
    "\xf7\xb9"=>0x6ff9,
    "\xf7\xba"=>0x6ff0,
    "\xf7\xbb"=>0x6ff5,
    "\xf7\xbc"=>0x7005,
    "\xf7\xbd"=>0x7006,
    "\xf7\xbe"=>0x7028,
    "\xf7\xbf"=>0x704a,
    "\xf7\xc0"=>0x705d,
    "\xf7\xc1"=>0x705e,
    "\xf7\xc2"=>0x704e,
    "\xf7\xc3"=>0x7064,
    "\xf7\xc4"=>0x7075,
    "\xf7\xc5"=>0x7085,
    "\xf7\xc6"=>0x70a4,
    "\xf7\xc7"=>0x70ab,
    "\xf7\xc8"=>0x70b7,
    "\xf7\xc9"=>0x70d4,
    "\xf7\xca"=>0x70d8,
    "\xf7\xcb"=>0x70e4,
    "\xf7\xcc"=>0x710f,
    "\xf7\xcd"=>0x712b,
    "\xf7\xce"=>0x711e,
    "\xf7\xcf"=>0x7120,
    "\xf7\xd0"=>0x712e,
    "\xf7\xd1"=>0x7130,
    "\xf7\xd2"=>0x7146,
    "\xf7\xd3"=>0x7147,
    "\xf7\xd4"=>0x7151,
    "\xf7\xd5"=>0xfa48,
    "\xf7\xd6"=>0x7152,
    "\xf7\xd7"=>0x715c,
    "\xf7\xd8"=>0x7160,
    "\xf7\xd9"=>0x7168,
    "\xf7\xda"=>0xfa15,
    "\xf7\xdb"=>0x7185,
    "\xf7\xdc"=>0x7187,
    "\xf7\xdd"=>0x7192,
    "\xf7\xde"=>0x71c1,
    "\xf7\xdf"=>0x71ba,
    "\xf7\xe0"=>0x71c4,
    "\xf7\xe1"=>0x71fe,
    "\xf7\xe2"=>0x7200,
    "\xf7\xe3"=>0x7215,
    "\xf7\xe4"=>0x7255,
    "\xf7\xe5"=>0x7256,
    "\xf7\xe6"=>0x3e3f,
    "\xf7\xe7"=>0x728d,
    "\xf7\xe8"=>0x729b,
    "\xf7\xe9"=>0x72be,
    "\xf7\xea"=>0x72c0,
    "\xf7\xeb"=>0x72fb,
    "\xf7\xec"=>0x247f1,
    "\xf7\xed"=>0x7327,
    "\xf7\xee"=>0x7328,
    "\xf7\xef"=>0xfa16,
    "\xf7\xf0"=>0x7350,
    "\xf7\xf1"=>0x7366,
    "\xf7\xf2"=>0x737c,
    "\xf7\xf3"=>0x7395,
    "\xf7\xf4"=>0x739f,
    "\xf7\xf5"=>0x73a0,
    "\xf7\xf6"=>0x73a2,
    "\xf7\xf7"=>0x73a6,
    "\xf7\xf8"=>0x73ab,
    "\xf7\xf9"=>0x73c9,
    "\xf7\xfa"=>0x73cf,
    "\xf7\xfb"=>0x73d6,
    "\xf7\xfc"=>0x73d9,
    "\xf7\xfd"=>0x73e3,
    "\xf7\xfe"=>0x73e9,
    "\xf8\xa1"=>0x7407,
    "\xf8\xa2"=>0x740a,
    "\xf8\xa3"=>0x741a,
    "\xf8\xa4"=>0x741b,
    "\xf8\xa5"=>0xfa4a,
    "\xf8\xa6"=>0x7426,
    "\xf8\xa7"=>0x7428,
    "\xf8\xa8"=>0x742a,
    "\xf8\xa9"=>0x742b,
    "\xf8\xaa"=>0x742c,
    "\xf8\xab"=>0x742e,
    "\xf8\xac"=>0x742f,
    "\xf8\xad"=>0x7430,
    "\xf8\xae"=>0x7444,
    "\xf8\xaf"=>0x7446,
    "\xf8\xb0"=>0x7447,
    "\xf8\xb1"=>0x744b,
    "\xf8\xb2"=>0x7457,
    "\xf8\xb3"=>0x7462,
    "\xf8\xb4"=>0x746b,
    "\xf8\xb5"=>0x746d,
    "\xf8\xb6"=>0x7486,
    "\xf8\xb7"=>0x7487,
    "\xf8\xb8"=>0x7489,
    "\xf8\xb9"=>0x7498,
    "\xf8\xba"=>0x749c,
    "\xf8\xbb"=>0x749f,
    "\xf8\xbc"=>0x74a3,
    "\xf8\xbd"=>0x7490,
    "\xf8\xbe"=>0x74a6,
    "\xf8\xbf"=>0x74a8,
    "\xf8\xc0"=>0x74a9,
    "\xf8\xc1"=>0x74b5,
    "\xf8\xc2"=>0x74bf,
    "\xf8\xc3"=>0x74c8,
    "\xf8\xc4"=>0x74c9,
    "\xf8\xc5"=>0x74da,
    "\xf8\xc6"=>0x74ff,
    "\xf8\xc7"=>0x7501,
    "\xf8\xc8"=>0x7517,
    "\xf8\xc9"=>0x752f,
    "\xf8\xca"=>0x756f,
    "\xf8\xcb"=>0x7579,
    "\xf8\xcc"=>0x7592,
    "\xf8\xcd"=>0x3f72,
    "\xf8\xce"=>0x75ce,
    "\xf8\xcf"=>0x75e4,
    "\xf8\xd0"=>0x7600,
    "\xf8\xd1"=>0x7602,
    "\xf8\xd2"=>0x7608,
    "\xf8\xd3"=>0x7615,
    "\xf8\xd4"=>0x7616,
    "\xf8\xd5"=>0x7619,
    "\xf8\xd6"=>0x761e,
    "\xf8\xd7"=>0x762d,
    "\xf8\xd8"=>0x7635,
    "\xf8\xd9"=>0x7643,
    "\xf8\xda"=>0x764b,
    "\xf8\xdb"=>0x7664,
    "\xf8\xdc"=>0x7665,
    "\xf8\xdd"=>0x766d,
    "\xf8\xde"=>0x766f,
    "\xf8\xdf"=>0x7671,
    "\xf8\xe0"=>0x7681,
    "\xf8\xe1"=>0x769b,
    "\xf8\xe2"=>0x769d,
    "\xf8\xe3"=>0x769e,
    "\xf8\xe4"=>0x76a6,
    "\xf8\xe5"=>0x76aa,
    "\xf8\xe6"=>0x76b6,
    "\xf8\xe7"=>0x76c5,
    "\xf8\xe8"=>0x76cc,
    "\xf8\xe9"=>0x76ce,
    "\xf8\xea"=>0x76d4,
    "\xf8\xeb"=>0x76e6,
    "\xf8\xec"=>0x76f1,
    "\xf8\xed"=>0x76fc,
    "\xf8\xee"=>0x770a,
    "\xf8\xef"=>0x7719,
    "\xf8\xf0"=>0x7734,
    "\xf8\xf1"=>0x7736,
    "\xf8\xf2"=>0x7746,
    "\xf8\xf3"=>0x774d,
    "\xf8\xf4"=>0x774e,
    "\xf8\xf5"=>0x775c,
    "\xf8\xf6"=>0x775f,
    "\xf8\xf7"=>0x7762,
    "\xf8\xf8"=>0x777a,
    "\xf8\xf9"=>0x7780,
    "\xf8\xfa"=>0x7794,
    "\xf8\xfb"=>0x77aa,
    "\xf8\xfc"=>0x77e0,
    "\xf8\xfd"=>0x782d,
    "\xf8\xfe"=>0x2548e,
    "\xf9\xa1"=>0x7843,
    "\xf9\xa2"=>0x784e,
    "\xf9\xa3"=>0x784f,
    "\xf9\xa4"=>0x7851,
    "\xf9\xa5"=>0x7868,
    "\xf9\xa6"=>0x786e,
    "\xf9\xa7"=>0xfa4b,
    "\xf9\xa8"=>0x78b0,
    "\xf9\xa9"=>0x2550e,
    "\xf9\xaa"=>0x78ad,
    "\xf9\xab"=>0x78e4,
    "\xf9\xac"=>0x78f2,
    "\xf9\xad"=>0x7900,
    "\xf9\xae"=>0x78f7,
    "\xf9\xaf"=>0x791c,
    "\xf9\xb0"=>0x792e,
    "\xf9\xb1"=>0x7931,
    "\xf9\xb2"=>0x7934,
    "\xf9\xb3"=>0xfa4c,
    "\xf9\xb4"=>0xfa4d,
    "\xf9\xb5"=>0x7945,
    "\xf9\xb6"=>0x7946,
    "\xf9\xb7"=>0xfa4e,
    "\xf9\xb8"=>0xfa4f,
    "\xf9\xb9"=>0xfa50,
    "\xf9\xba"=>0x795c,
    "\xf9\xbb"=>0xfa51,
    "\xf9\xbc"=>0xfa19,
    "\xf9\xbd"=>0xfa1a,
    "\xf9\xbe"=>0x7979,
    "\xf9\xbf"=>0xfa52,
    "\xf9\xc0"=>0xfa53,
    "\xf9\xc1"=>0xfa1b,
    "\xf9\xc2"=>0x7998,
    "\xf9\xc3"=>0x79b1,
    "\xf9\xc4"=>0x79b8,
    "\xf9\xc5"=>0x79c8,
    "\xf9\xc6"=>0x79ca,
    "\xf9\xc7"=>0x25771,
    "\xf9\xc8"=>0x79d4,
    "\xf9\xc9"=>0x79de,
    "\xf9\xca"=>0x79eb,
    "\xf9\xcb"=>0x79ed,
    "\xf9\xcc"=>0x7a03,
    "\xf9\xcd"=>0xfa54,
    "\xf9\xce"=>0x7a39,
    "\xf9\xcf"=>0x7a5d,
    "\xf9\xd0"=>0x7a6d,
    "\xf9\xd1"=>0xfa55,
    "\xf9\xd2"=>0x7a85,
    "\xf9\xd3"=>0x7aa0,
    "\xf9\xd4"=>0x259c4,
    "\xf9\xd5"=>0x7ab3,
    "\xf9\xd6"=>0x7abb,
    "\xf9\xd7"=>0x7ace,
    "\xf9\xd8"=>0x7aeb,
    "\xf9\xd9"=>0x7afd,
    "\xf9\xda"=>0x7b12,
    "\xf9\xdb"=>0x7b2d,
    "\xf9\xdc"=>0x7b3b,
    "\xf9\xdd"=>0x7b47,
    "\xf9\xde"=>0x7b4e,
    "\xf9\xdf"=>0x7b60,
    "\xf9\xe0"=>0x7b6d,
    "\xf9\xe1"=>0x7b6f,
    "\xf9\xe2"=>0x7b72,
    "\xf9\xe3"=>0x7b9e,
    "\xf9\xe4"=>0xfa56,
    "\xf9\xe5"=>0x7bd7,
    "\xf9\xe6"=>0x7bd9,
    "\xf9\xe7"=>0x7c01,
    "\xf9\xe8"=>0x7c31,
    "\xf9\xe9"=>0x7c1e,
    "\xf9\xea"=>0x7c20,
    "\xf9\xeb"=>0x7c33,
    "\xf9\xec"=>0x7c36,
    "\xf9\xed"=>0x4264,
    "\xf9\xee"=>0x25da1,
    "\xf9\xef"=>0x7c59,
    "\xf9\xf0"=>0x7c6d,
    "\xf9\xf1"=>0x7c79,
    "\xf9\xf2"=>0x7c8f,
    "\xf9\xf3"=>0x7c94,
    "\xf9\xf4"=>0x7ca0,
    "\xf9\xf5"=>0x7cbc,
    "\xf9\xf6"=>0x7cd5,
    "\xf9\xf7"=>0x7cd9,
    "\xf9\xf8"=>0x7cdd,
    "\xf9\xf9"=>0x7d07,
    "\xf9\xfa"=>0x7d08,
    "\xf9\xfb"=>0x7d13,
    "\xf9\xfc"=>0x7d1d,
    "\xf9\xfd"=>0x7d23,
    "\xf9\xfe"=>0x7d31,
    "\xfa\xa1"=>0x7d41,
    "\xfa\xa2"=>0x7d48,
    "\xfa\xa3"=>0x7d53,
    "\xfa\xa4"=>0x7d5c,
    "\xfa\xa5"=>0x7d7a,
    "\xfa\xa6"=>0x7d83,
    "\xfa\xa7"=>0x7d8b,
    "\xfa\xa8"=>0x7da0,
    "\xfa\xa9"=>0x7da6,
    "\xfa\xaa"=>0x7dc2,
    "\xfa\xab"=>0x7dcc,
    "\xfa\xac"=>0x7dd6,
    "\xfa\xad"=>0x7de3,
    "\xfa\xae"=>0xfa57,
    "\xfa\xaf"=>0x7e28,
    "\xfa\xb0"=>0x7e08,
    "\xfa\xb1"=>0x7e11,
    "\xfa\xb2"=>0x7e15,
    "\xfa\xb3"=>0xfa59,
    "\xfa\xb4"=>0x7e47,
    "\xfa\xb5"=>0x7e52,
    "\xfa\xb6"=>0x7e61,
    "\xfa\xb7"=>0x7e8a,
    "\xfa\xb8"=>0x7e8d,
    "\xfa\xb9"=>0x7f47,
    "\xfa\xba"=>0xfa5a,
    "\xfa\xbb"=>0x7f91,
    "\xfa\xbc"=>0x7f97,
    "\xfa\xbd"=>0x7fbf,
    "\xfa\xbe"=>0x7fce,
    "\xfa\xbf"=>0x7fdb,
    "\xfa\xc0"=>0x7fdf,
    "\xfa\xc1"=>0x7fec,
    "\xfa\xc2"=>0x7fee,
    "\xfa\xc3"=>0x7ffa,
    "\xfa\xc4"=>0xfa5b,
    "\xfa\xc5"=>0x8014,
    "\xfa\xc6"=>0x8026,
    "\xfa\xc7"=>0x8035,
    "\xfa\xc8"=>0x8037,
    "\xfa\xc9"=>0x803c,
    "\xfa\xca"=>0x80ca,
    "\xfa\xcb"=>0x80d7,
    "\xfa\xcc"=>0x80e0,
    "\xfa\xcd"=>0x80f3,
    "\xfa\xce"=>0x8118,
    "\xfa\xcf"=>0x814a,
    "\xfa\xd0"=>0x8160,
    "\xfa\xd1"=>0x8167,
    "\xfa\xd2"=>0x8168,
    "\xfa\xd3"=>0x816d,
    "\xfa\xd4"=>0x81bb,
    "\xfa\xd5"=>0x81ca,
    "\xfa\xd6"=>0x81cf,
    "\xfa\xd7"=>0x81d7,
    "\xfa\xd8"=>0xfa5c,
    "\xfa\xd9"=>0x4453,
    "\xfa\xda"=>0x445b,
    "\xfa\xdb"=>0x8260,
    "\xfa\xdc"=>0x8274,
    "\xfa\xdd"=>0x26aff,
    "\xfa\xde"=>0x828e,
    "\xfa\xdf"=>0x82a1,
    "\xfa\xe0"=>0x82a3,
    "\xfa\xe1"=>0x82a4,
    "\xfa\xe2"=>0x82a9,
    "\xfa\xe3"=>0x82ae,
    "\xfa\xe4"=>0x82b7,
    "\xfa\xe5"=>0x82be,
    "\xfa\xe6"=>0x82bf,
    "\xfa\xe7"=>0x82c6,
    "\xfa\xe8"=>0x82d5,
    "\xfa\xe9"=>0x82fd,
    "\xfa\xea"=>0x82fe,
    "\xfa\xeb"=>0x8300,
    "\xfa\xec"=>0x8301,
    "\xfa\xed"=>0x8362,
    "\xfa\xee"=>0x8322,
    "\xfa\xef"=>0x832d,
    "\xfa\xf0"=>0x833a,
    "\xfa\xf1"=>0x8343,
    "\xfa\xf2"=>0x8347,
    "\xfa\xf3"=>0x8351,
    "\xfa\xf4"=>0x8355,
    "\xfa\xf5"=>0x837d,
    "\xfa\xf6"=>0x8386,
    "\xfa\xf7"=>0x8392,
    "\xfa\xf8"=>0x8398,
    "\xfa\xf9"=>0x83a7,
    "\xfa\xfa"=>0x83a9,
    "\xfa\xfb"=>0x83bf,
    "\xfa\xfc"=>0x83c0,
    "\xfa\xfd"=>0x83c7,
    "\xfa\xfe"=>0x83cf,
    "\xfb\xa1"=>0x83d1,
    "\xfb\xa2"=>0x83e1,
    "\xfb\xa3"=>0x83ea,
    "\xfb\xa4"=>0x8401,
    "\xfb\xa5"=>0x8406,
    "\xfb\xa6"=>0x840a,
    "\xfb\xa7"=>0xfa5f,
    "\xfb\xa8"=>0x8448,
    "\xfb\xa9"=>0x845f,
    "\xfb\xaa"=>0x8470,
    "\xfb\xab"=>0x8473,
    "\xfb\xac"=>0x8485,
    "\xfb\xad"=>0x849e,
    "\xfb\xae"=>0x84af,
    "\xfb\xaf"=>0x84b4,
    "\xfb\xb0"=>0x84ba,
    "\xfb\xb1"=>0x84c0,
    "\xfb\xb2"=>0x84c2,
    "\xfb\xb3"=>0x26e40,
    "\xfb\xb4"=>0x8532,
    "\xfb\xb5"=>0x851e,
    "\xfb\xb6"=>0x8523,
    "\xfb\xb7"=>0x852f,
    "\xfb\xb8"=>0x8559,
    "\xfb\xb9"=>0x8564,
    "\xfb\xba"=>0xfa1f,
    "\xfb\xbb"=>0x85ad,
    "\xfb\xbc"=>0x857a,
    "\xfb\xbd"=>0x858c,
    "\xfb\xbe"=>0x858f,
    "\xfb\xbf"=>0x85a2,
    "\xfb\xc0"=>0x85b0,
    "\xfb\xc1"=>0x85cb,
    "\xfb\xc2"=>0x85ce,
    "\xfb\xc3"=>0x85ed,
    "\xfb\xc4"=>0x8612,
    "\xfb\xc5"=>0x85ff,
    "\xfb\xc6"=>0x8604,
    "\xfb\xc7"=>0x8605,
    "\xfb\xc8"=>0x8610,
    "\xfb\xc9"=>0x270f4,
    "\xfb\xca"=>0x8618,
    "\xfb\xcb"=>0x8629,
    "\xfb\xcc"=>0x8638,
    "\xfb\xcd"=>0x8657,
    "\xfb\xce"=>0x865b,
    "\xfb\xcf"=>0xf936,
    "\xfb\xd0"=>0x8662,
    "\xfb\xd1"=>0x459d,
    "\xfb\xd2"=>0x866c,
    "\xfb\xd3"=>0x8675,
    "\xfb\xd4"=>0x8698,
    "\xfb\xd5"=>0x86b8,
    "\xfb\xd6"=>0x86fa,
    "\xfb\xd7"=>0x86fc,
    "\xfb\xd8"=>0x86fd,
    "\xfb\xd9"=>0x870b,
    "\xfb\xda"=>0x8771,
    "\xfb\xdb"=>0x8787,
    "\xfb\xdc"=>0x8788,
    "\xfb\xdd"=>0x87ac,
    "\xfb\xde"=>0x87ad,
    "\xfb\xdf"=>0x87b5,
    "\xfb\xe0"=>0x45ea,
    "\xfb\xe1"=>0x87d6,
    "\xfb\xe2"=>0x87ec,
    "\xfb\xe3"=>0x8806,
    "\xfb\xe4"=>0x880a,
    "\xfb\xe5"=>0x8810,
    "\xfb\xe6"=>0x8814,
    "\xfb\xe7"=>0x881f,
    "\xfb\xe8"=>0x8898,
    "\xfb\xe9"=>0x88aa,
    "\xfb\xea"=>0x88ca,
    "\xfb\xeb"=>0x88ce,
    "\xfb\xec"=>0x27684,
    "\xfb\xed"=>0x88f5,
    "\xfb\xee"=>0x891c,
    "\xfb\xef"=>0xfa60,
    "\xfb\xf0"=>0x8918,
    "\xfb\xf1"=>0x8919,
    "\xfb\xf2"=>0x891a,
    "\xfb\xf3"=>0x8927,
    "\xfb\xf4"=>0x8930,
    "\xfb\xf5"=>0x8932,
    "\xfb\xf6"=>0x8939,
    "\xfb\xf7"=>0x8940,
    "\xfb\xf8"=>0x8994,
    "\xfb\xf9"=>0xfa61,
    "\xfb\xfa"=>0x89d4,
    "\xfb\xfb"=>0x89e5,
    "\xfb\xfc"=>0x89f6,
    "\xfb\xfd"=>0x8a12,
    "\xfb\xfe"=>0x8a15,
    "\xfc\xa1"=>0x8a22,
    "\xfc\xa2"=>0x8a37,
    "\xfc\xa3"=>0x8a47,
    "\xfc\xa4"=>0x8a4e,
    "\xfc\xa5"=>0x8a5d,
    "\xfc\xa6"=>0x8a61,
    "\xfc\xa7"=>0x8a75,
    "\xfc\xa8"=>0x8a79,
    "\xfc\xa9"=>0x8aa7,
    "\xfc\xaa"=>0x8ad0,
    "\xfc\xab"=>0x8adf,
    "\xfc\xac"=>0x8af4,
    "\xfc\xad"=>0x8af6,
    "\xfc\xae"=>0xfa22,
    "\xfc\xaf"=>0xfa62,
    "\xfc\xb0"=>0xfa63,
    "\xfc\xb1"=>0x8b46,
    "\xfc\xb2"=>0x8b54,
    "\xfc\xb3"=>0x8b59,
    "\xfc\xb4"=>0x8b69,
    "\xfc\xb5"=>0x8b9d,
    "\xfc\xb6"=>0x8c49,
    "\xfc\xb7"=>0x8c68,
    "\xfc\xb8"=>0xfa64,
    "\xfc\xb9"=>0x8ce1,
    "\xfc\xba"=>0x8cf4,
    "\xfc\xbb"=>0x8cf8,
    "\xfc\xbc"=>0x8cfe,
    "\xfc\xbd"=>0xfa65,
    "\xfc\xbe"=>0x8d12,
    "\xfc\xbf"=>0x8d1b,
    "\xfc\xc0"=>0x8daf,
    "\xfc\xc1"=>0x8dce,
    "\xfc\xc2"=>0x8dd1,
    "\xfc\xc3"=>0x8dd7,
    "\xfc\xc4"=>0x8e20,
    "\xfc\xc5"=>0x8e23,
    "\xfc\xc6"=>0x8e3d,
    "\xfc\xc7"=>0x8e70,
    "\xfc\xc8"=>0x8e7b,
    "\xfc\xc9"=>0x28277,
    "\xfc\xca"=>0x8ec0,
    "\xfc\xcb"=>0x4844,
    "\xfc\xcc"=>0x8efa,
    "\xfc\xcd"=>0x8f1e,
    "\xfc\xce"=>0x8f2d,
    "\xfc\xcf"=>0x8f36,
    "\xfc\xd0"=>0x8f54,
    "\xfc\xd1"=>0x283cd,
    "\xfc\xd2"=>0x8fa6,
    "\xfc\xd3"=>0x8fb5,
    "\xfc\xd4"=>0x8fe4,
    "\xfc\xd5"=>0x8fe8,
    "\xfc\xd6"=>0x8fee,
    "\xfc\xd7"=>0x9008,
    "\xfc\xd8"=>0x902d,
    "\xfc\xd9"=>0xfa67,
    "\xfc\xda"=>0x9088,
    "\xfc\xdb"=>0x9095,
    "\xfc\xdc"=>0x9097,
    "\xfc\xdd"=>0x9099,
    "\xfc\xde"=>0x909b,
    "\xfc\xdf"=>0x90a2,
    "\xfc\xe0"=>0x90b3,
    "\xfc\xe1"=>0x90be,
    "\xfc\xe2"=>0x90c4,
    "\xfc\xe3"=>0x90c5,
    "\xfc\xe4"=>0x90c7,
    "\xfc\xe5"=>0x90d7,
    "\xfc\xe6"=>0x90dd,
    "\xfc\xe7"=>0x90de,
    "\xfc\xe8"=>0x90ef,
    "\xfc\xe9"=>0x90f4,
    "\xfc\xea"=>0xfa26,
    "\xfc\xeb"=>0x9114,
    "\xfc\xec"=>0x9115,
    "\xfc\xed"=>0x9116,
    "\xfc\xee"=>0x9122,
    "\xfc\xef"=>0x9123,
    "\xfc\xf0"=>0x9127,
    "\xfc\xf1"=>0x912f,
    "\xfc\xf2"=>0x9131,
    "\xfc\xf3"=>0x9134,
    "\xfc\xf4"=>0x913d,
    "\xfc\xf5"=>0x9148,
    "\xfc\xf6"=>0x915b,
    "\xfc\xf7"=>0x9183,
    "\xfc\xf8"=>0x919e,
    "\xfc\xf9"=>0x91ac,
    "\xfc\xfa"=>0x91b1,
    "\xfc\xfb"=>0x91bc,
    "\xfc\xfc"=>0x91d7,
    "\xfc\xfd"=>0x91fb,
    "\xfc\xfe"=>0x91e4,
    "\xfd\xa1"=>0x91e5,
    "\xfd\xa2"=>0x91ed,
    "\xfd\xa3"=>0x91f1,
    "\xfd\xa4"=>0x9207,
    "\xfd\xa5"=>0x9210,
    "\xfd\xa6"=>0x9238,
    "\xfd\xa7"=>0x9239,
    "\xfd\xa8"=>0x923a,
    "\xfd\xa9"=>0x923c,
    "\xfd\xaa"=>0x9240,
    "\xfd\xab"=>0x9243,
    "\xfd\xac"=>0x924f,
    "\xfd\xad"=>0x9278,
    "\xfd\xae"=>0x9288,
    "\xfd\xaf"=>0x92c2,
    "\xfd\xb0"=>0x92cb,
    "\xfd\xb1"=>0x92cc,
    "\xfd\xb2"=>0x92d3,
    "\xfd\xb3"=>0x92e0,
    "\xfd\xb4"=>0x92ff,
    "\xfd\xb5"=>0x9304,
    "\xfd\xb6"=>0x931f,
    "\xfd\xb7"=>0x9321,
    "\xfd\xb8"=>0x9325,
    "\xfd\xb9"=>0x9348,
    "\xfd\xba"=>0x9349,
    "\xfd\xbb"=>0x934a,
    "\xfd\xbc"=>0x9364,
    "\xfd\xbd"=>0x9365,
    "\xfd\xbe"=>0x936a,
    "\xfd\xbf"=>0x9370,
    "\xfd\xc0"=>0x939b,
    "\xfd\xc1"=>0x93a3,
    "\xfd\xc2"=>0x93ba,
    "\xfd\xc3"=>0x93c6,
    "\xfd\xc4"=>0x93de,
    "\xfd\xc5"=>0x93df,
    "\xfd\xc6"=>0x9404,
    "\xfd\xc7"=>0x93fd,
    "\xfd\xc8"=>0x9433,
    "\xfd\xc9"=>0x944a,
    "\xfd\xca"=>0x9463,
    "\xfd\xcb"=>0x946b,
    "\xfd\xcc"=>0x9471,
    "\xfd\xcd"=>0x9472,
    "\xfd\xce"=>0x958e,
    "\xfd\xcf"=>0x959f,
    "\xfd\xd0"=>0x95a6,
    "\xfd\xd1"=>0x95a9,
    "\xfd\xd2"=>0x95ac,
    "\xfd\xd3"=>0x95b6,
    "\xfd\xd4"=>0x95bd,
    "\xfd\xd5"=>0x95cb,
    "\xfd\xd6"=>0x95d0,
    "\xfd\xd7"=>0x95d3,
    "\xfd\xd8"=>0x49b0,
    "\xfd\xd9"=>0x95da,
    "\xfd\xda"=>0x95de,
    "\xfd\xdb"=>0x9658,
    "\xfd\xdc"=>0x9684,
    "\xfd\xdd"=>0xf9dc,
    "\xfd\xde"=>0x969d,
    "\xfd\xdf"=>0x96a4,
    "\xfd\xe0"=>0x96a5,
    "\xfd\xe1"=>0x96d2,
    "\xfd\xe2"=>0x96de,
    "\xfd\xe3"=>0xfa68,
    "\xfd\xe4"=>0x96e9,
    "\xfd\xe5"=>0x96ef,
    "\xfd\xe6"=>0x9733,
    "\xfd\xe7"=>0x973b,
    "\xfd\xe8"=>0x974d,
    "\xfd\xe9"=>0x974e,
    "\xfd\xea"=>0x974f,
    "\xfd\xeb"=>0x975a,
    "\xfd\xec"=>0x976e,
    "\xfd\xed"=>0x9773,
    "\xfd\xee"=>0x9795,
    "\xfd\xef"=>0x97ae,
    "\xfd\xf0"=>0x97ba,
    "\xfd\xf1"=>0x97c1,
    "\xfd\xf2"=>0x97c9,
    "\xfd\xf3"=>0x97de,
    "\xfd\xf4"=>0x97db,
    "\xfd\xf5"=>0x97f4,
    "\xfd\xf6"=>0xfa69,
    "\xfd\xf7"=>0x980a,
    "\xfd\xf8"=>0x981e,
    "\xfd\xf9"=>0x982b,
    "\xfd\xfa"=>0x9830,
    "\xfd\xfb"=>0xfa6a,
    "\xfd\xfc"=>0x9852,
    "\xfd\xfd"=>0x9853,
    "\xfd\xfe"=>0x9856,
    "\xfe\xa1"=>0x9857,
    "\xfe\xa2"=>0x9859,
    "\xfe\xa3"=>0x985a,
    "\xfe\xa4"=>0xf9d0,
    "\xfe\xa5"=>0x9865,
    "\xfe\xa6"=>0x986c,
    "\xfe\xa7"=>0x98ba,
    "\xfe\xa8"=>0x98c8,
    "\xfe\xa9"=>0x98e7,
    "\xfe\xaa"=>0x9958,
    "\xfe\xab"=>0x999e,
    "\xfe\xac"=>0x9a02,
    "\xfe\xad"=>0x9a03,
    "\xfe\xae"=>0x9a24,
    "\xfe\xaf"=>0x9a2d,
    "\xfe\xb0"=>0x9a2e,
    "\xfe\xb1"=>0x9a38,
    "\xfe\xb2"=>0x9a4a,
    "\xfe\xb3"=>0x9a4e,
    "\xfe\xb4"=>0x9a52,
    "\xfe\xb5"=>0x9ab6,
    "\xfe\xb6"=>0x9ac1,
    "\xfe\xb7"=>0x9ac3,
    "\xfe\xb8"=>0x9ace,
    "\xfe\xb9"=>0x9ad6,
    "\xfe\xba"=>0x9af9,
    "\xfe\xbb"=>0x9b02,
    "\xfe\xbc"=>0x9b08,
    "\xfe\xbd"=>0x9b20,
    "\xfe\xbe"=>0x4c17,
    "\xfe\xbf"=>0x9b2d,
    "\xfe\xc0"=>0x9b5e,
    "\xfe\xc1"=>0x9b79,
    "\xfe\xc2"=>0x9b66,
    "\xfe\xc3"=>0x9b72,
    "\xfe\xc4"=>0x9b75,
    "\xfe\xc5"=>0x9b84,
    "\xfe\xc6"=>0x9b8a,
    "\xfe\xc7"=>0x9b8f,
    "\xfe\xc8"=>0x9b9e,
    "\xfe\xc9"=>0x9ba7,
    "\xfe\xca"=>0x9bc1,
    "\xfe\xcb"=>0x9bce,
    "\xfe\xcc"=>0x9be5,
    "\xfe\xcd"=>0x9bf8,
    "\xfe\xce"=>0x9bfd,
    "\xfe\xcf"=>0x9c00,
    "\xfe\xd0"=>0x9c23,
    "\xfe\xd1"=>0x9c41,
    "\xfe\xd2"=>0x9c4f,
    "\xfe\xd3"=>0x9c50,
    "\xfe\xd4"=>0x9c53,
    "\xfe\xd5"=>0x9c63,
    "\xfe\xd6"=>0x9c65,
    "\xfe\xd7"=>0x9c77,
    "\xfe\xd8"=>0x9d1d,
    "\xfe\xd9"=>0x9d1e,
    "\xfe\xda"=>0x9d43,
    "\xfe\xdb"=>0x9d47,
    "\xfe\xdc"=>0x9d52,
    "\xfe\xdd"=>0x9d63,
    "\xfe\xde"=>0x9d70,
    "\xfe\xdf"=>0x9d7c,
    "\xfe\xe0"=>0x9d8a,
    "\xfe\xe1"=>0x9d96,
    "\xfe\xe2"=>0x9dc0,
    "\xfe\xe3"=>0x9dac,
    "\xfe\xe4"=>0x9dbc,
    "\xfe\xe5"=>0x9dd7,
    "\xfe\xe6"=>0x2a190,
    "\xfe\xe7"=>0x9de7,
    "\xfe\xe8"=>0x9e07,
    "\xfe\xe9"=>0x9e15,
    "\xfe\xea"=>0x9e7c,
    "\xfe\xeb"=>0x9e9e,
    "\xfe\xec"=>0x9ea4,
    "\xfe\xed"=>0x9eac,
    "\xfe\xee"=>0x9eaf,
    "\xfe\xef"=>0x9eb4,
    "\xfe\xf0"=>0x9eb5,
    "\xfe\xf1"=>0x9ec3,
    "\xfe\xf2"=>0x9ed1,
    "\xfe\xf3"=>0x9f10,
    "\xfe\xf4"=>0x9f39,
    "\xfe\xf5"=>0x9f57,
    "\xfe\xf6"=>0x9f90,
    "\xfe\xf7"=>0x9f94,
    "\xfe\xf8"=>0x9f97,
    "\xfe\xf9"=>0x9fa2,
    "\xfe\xfa"=>0x59f8, # [2004]
    "\xfe\xfb"=>0x5c5b, # [2004]
    "\xfe\xfc"=>0x5e77, # [2004]
    "\xfe\xfd"=>0x7626, # [2004]
    "\xfe\xfe"=>0x7e6b, # [2004]
    "\x8f\xa1\xa1"=>0x20089,
    "\x8f\xa1\xa2"=>0x4e02,
    "\x8f\xa1\xa3"=>0x4e0f,
    "\x8f\xa1\xa4"=>0x4e12,
    "\x8f\xa1\xa5"=>0x4e29,
    "\x8f\xa1\xa6"=>0x4e2b,
    "\x8f\xa1\xa7"=>0x4e2e,
    "\x8f\xa1\xa8"=>0x4e40,
    "\x8f\xa1\xa9"=>0x4e47,
    "\x8f\xa1\xaa"=>0x4e48,
    "\x8f\xa1\xab"=>0x200a2,
    "\x8f\xa1\xac"=>0x4e51,
    "\x8f\xa1\xad"=>0x3406,
    "\x8f\xa1\xae"=>0x200a4,
    "\x8f\xa1\xaf"=>0x4e5a,
    "\x8f\xa1\xb0"=>0x4e69,
    "\x8f\xa1\xb1"=>0x4e9d,
    "\x8f\xa1\xb2"=>0x342c,
    "\x8f\xa1\xb3"=>0x342e,
    "\x8f\xa1\xb4"=>0x4eb9,
    "\x8f\xa1\xb5"=>0x4ebb,
    "\x8f\xa1\xb6"=>0x201a2,
    "\x8f\xa1\xb7"=>0x4ebc,
    "\x8f\xa1\xb8"=>0x4ec3,
    "\x8f\xa1\xb9"=>0x4ec8,
    "\x8f\xa1\xba"=>0x4ed0,
    "\x8f\xa1\xbb"=>0x4eeb,
    "\x8f\xa1\xbc"=>0x4eda,
    "\x8f\xa1\xbd"=>0x4ef1,
    "\x8f\xa1\xbe"=>0x4ef5,
    "\x8f\xa1\xbf"=>0x4f00,
    "\x8f\xa1\xc0"=>0x4f16,
    "\x8f\xa1\xc1"=>0x4f64,
    "\x8f\xa1\xc2"=>0x4f37,
    "\x8f\xa1\xc3"=>0x4f3e,
    "\x8f\xa1\xc4"=>0x4f54,
    "\x8f\xa1\xc5"=>0x4f58,
    "\x8f\xa1\xc6"=>0x20213,
    "\x8f\xa1\xc7"=>0x4f77,
    "\x8f\xa1\xc8"=>0x4f78,
    "\x8f\xa1\xc9"=>0x4f7a,
    "\x8f\xa1\xca"=>0x4f7d,
    "\x8f\xa1\xcb"=>0x4f82,
    "\x8f\xa1\xcc"=>0x4f85,
    "\x8f\xa1\xcd"=>0x4f92,
    "\x8f\xa1\xce"=>0x4f9a,
    "\x8f\xa1\xcf"=>0x4fe6,
    "\x8f\xa1\xd0"=>0x4fb2,
    "\x8f\xa1\xd1"=>0x4fbe,
    "\x8f\xa1\xd2"=>0x4fc5,
    "\x8f\xa1\xd3"=>0x4fcb,
    "\x8f\xa1\xd4"=>0x4fcf,
    "\x8f\xa1\xd5"=>0x4fd2,
    "\x8f\xa1\xd6"=>0x346a,
    "\x8f\xa1\xd7"=>0x4ff2,
    "\x8f\xa1\xd8"=>0x5000,
    "\x8f\xa1\xd9"=>0x5010,
    "\x8f\xa1\xda"=>0x5013,
    "\x8f\xa1\xdb"=>0x501c,
    "\x8f\xa1\xdc"=>0x501e,
    "\x8f\xa1\xdd"=>0x5022,
    "\x8f\xa1\xde"=>0x3468,
    "\x8f\xa1\xdf"=>0x5042,
    "\x8f\xa1\xe0"=>0x5046,
    "\x8f\xa1\xe1"=>0x504e,
    "\x8f\xa1\xe2"=>0x5053,
    "\x8f\xa1\xe3"=>0x5057,
    "\x8f\xa1\xe4"=>0x5063,
    "\x8f\xa1\xe5"=>0x5066,
    "\x8f\xa1\xe6"=>0x506a,
    "\x8f\xa1\xe7"=>0x5070,
    "\x8f\xa1\xe8"=>0x50a3,
    "\x8f\xa1\xe9"=>0x5088,
    "\x8f\xa1\xea"=>0x5092,
    "\x8f\xa1\xeb"=>0x5093,
    "\x8f\xa1\xec"=>0x5095,
    "\x8f\xa1\xed"=>0x5096,
    "\x8f\xa1\xee"=>0x509c,
    "\x8f\xa1\xef"=>0x50aa,
    "\x8f\xa1\xf0"=>0x2032b,
    "\x8f\xa1\xf1"=>0x50b1,
    "\x8f\xa1\xf2"=>0x50ba,
    "\x8f\xa1\xf3"=>0x50bb,
    "\x8f\xa1\xf4"=>0x50c4,
    "\x8f\xa1\xf5"=>0x50c7,
    "\x8f\xa1\xf6"=>0x50f3,
    "\x8f\xa1\xf7"=>0x20381,
    "\x8f\xa1\xf8"=>0x50ce,
    "\x8f\xa1\xf9"=>0x20371,
    "\x8f\xa1\xfa"=>0x50d4,
    "\x8f\xa1\xfb"=>0x50d9,
    "\x8f\xa1\xfc"=>0x50e1,
    "\x8f\xa1\xfd"=>0x50e9,
    "\x8f\xa1\xfe"=>0x3492,
    "\x8f\xa2\xaf"=>0,
    "\x8f\xa2\xb0"=>0,
    "\x8f\xa2\xb1"=>0,
    "\x8f\xa2\xb2"=>0,
    "\x8f\xa2\xb3"=>0,
    "\x8f\xa2\xb4"=>0,
    "\x8f\xa2\xb5"=>0,
    "\x8f\xa2\xb6"=>0,
    "\x8f\xa2\xb7"=>0,
    "\x8f\xa2\xb8"=>0,
    "\x8f\xa2\xb9"=>0,
    "\x8f\xa2\xc2"=>0,
    "\x8f\xa2\xc3"=>0,
    "\x8f\xa2\xc4"=>0,
    "\x8f\xa2\xeb"=>0,
    "\x8f\xa2\xec"=>0,
    "\x8f\xa2\xed"=>0,
    "\x8f\xa2\xee"=>0,
    "\x8f\xa2\xef"=>0,
    "\x8f\xa2\xf0"=>0,
    "\x8f\xa2\xf1"=>0,
    "\x8f\xa3\xa1"=>0x5108,
    "\x8f\xa3\xa2"=>0x203f9,
    "\x8f\xa3\xa3"=>0x5117,
    "\x8f\xa3\xa4"=>0x511b,
    "\x8f\xa3\xa5"=>0x2044a,
    "\x8f\xa3\xa6"=>0x5160,
    "\x8f\xa3\xa7"=>0x20509,
    "\x8f\xa3\xa8"=>0x5173,
    "\x8f\xa3\xa9"=>0x5183,
    "\x8f\xa3\xaa"=>0x518b,
    "\x8f\xa3\xab"=>0x34bc,
    "\x8f\xa3\xac"=>0x5198,
    "\x8f\xa3\xad"=>0x51a3,
    "\x8f\xa3\xae"=>0x51ad,
    "\x8f\xa3\xaf"=>0x34c7,
    "\x8f\xa3\xb0"=>0x51bc,
    "\x8f\xa3\xb1"=>0x205d6,
    "\x8f\xa3\xb2"=>0x20628,
    "\x8f\xa3\xb3"=>0x51f3,
    "\x8f\xa3\xb4"=>0x51f4,
    "\x8f\xa3\xb5"=>0x5202,
    "\x8f\xa3\xb6"=>0x5212,
    "\x8f\xa3\xb7"=>0x5216,
    "\x8f\xa3\xb8"=>0x2074f,
    "\x8f\xa3\xb9"=>0x5255,
    "\x8f\xa3\xba"=>0x525c,
    "\x8f\xa3\xbb"=>0x526c,
    "\x8f\xa3\xbc"=>0x5277,
    "\x8f\xa3\xbd"=>0x5284,
    "\x8f\xa3\xbe"=>0x5282,
    "\x8f\xa3\xbf"=>0x20807,
    "\x8f\xa3\xc0"=>0x5298,
    "\x8f\xa3\xc1"=>0x2083a,
    "\x8f\xa3\xc2"=>0x52a4,
    "\x8f\xa3\xc3"=>0x52a6,
    "\x8f\xa3\xc4"=>0x52af,
    "\x8f\xa3\xc5"=>0x52ba,
    "\x8f\xa3\xc6"=>0x52bb,
    "\x8f\xa3\xc7"=>0x52ca,
    "\x8f\xa3\xc8"=>0x351f,
    "\x8f\xa3\xc9"=>0x52d1,
    "\x8f\xa3\xca"=>0x208b9,
    "\x8f\xa3\xcb"=>0x52f7,
    "\x8f\xa3\xcc"=>0x530a,
    "\x8f\xa3\xcd"=>0x530b,
    "\x8f\xa3\xce"=>0x5324,
    "\x8f\xa3\xcf"=>0x5335,
    "\x8f\xa3\xd0"=>0x533e,
    "\x8f\xa3\xd1"=>0x5342,
    "\x8f\xa3\xd2"=>0x2097c,
    "\x8f\xa3\xd3"=>0x2099d,
    "\x8f\xa3\xd4"=>0x5367,
    "\x8f\xa3\xd5"=>0x536c,
    "\x8f\xa3\xd6"=>0x537a,
    "\x8f\xa3\xd7"=>0x53a4,
    "\x8f\xa3\xd8"=>0x53b4,
    "\x8f\xa3\xd9"=>0x20ad3,
    "\x8f\xa3\xda"=>0x53b7,
    "\x8f\xa3\xdb"=>0x53c0,
    "\x8f\xa3\xdc"=>0x20b1d,
    "\x8f\xa3\xdd"=>0x355d,
    "\x8f\xa3\xde"=>0x355e,
    "\x8f\xa3\xdf"=>0x53d5,
    "\x8f\xa3\xe0"=>0x53da,
    "\x8f\xa3\xe1"=>0x3563,
    "\x8f\xa3\xe2"=>0x53f4,
    "\x8f\xa3\xe3"=>0x53f5,
    "\x8f\xa3\xe4"=>0x5455,
    "\x8f\xa3\xe5"=>0x5424,
    "\x8f\xa3\xe6"=>0x5428,
    "\x8f\xa3\xe7"=>0x356e,
    "\x8f\xa3\xe8"=>0x5443,
    "\x8f\xa3\xe9"=>0x5462,
    "\x8f\xa3\xea"=>0x5466,
    "\x8f\xa3\xeb"=>0x546c,
    "\x8f\xa3\xec"=>0x548a,
    "\x8f\xa3\xed"=>0x548d,
    "\x8f\xa3\xee"=>0x5495,
    "\x8f\xa3\xef"=>0x54a0,
    "\x8f\xa3\xf0"=>0x54a6,
    "\x8f\xa3\xf1"=>0x54ad,
    "\x8f\xa3\xf2"=>0x54ae,
    "\x8f\xa3\xf3"=>0x54b7,
    "\x8f\xa3\xf4"=>0x54ba,
    "\x8f\xa3\xf5"=>0x54bf,
    "\x8f\xa3\xf6"=>0x54c3,
    "\x8f\xa3\xf7"=>0x20d45,
    "\x8f\xa3\xf8"=>0x54ec,
    "\x8f\xa3\xf9"=>0x54ef,
    "\x8f\xa3\xfa"=>0x54f1,
    "\x8f\xa3\xfb"=>0x54f3,
    "\x8f\xa3\xfc"=>0x5500,
    "\x8f\xa3\xfd"=>0x5501,
    "\x8f\xa3\xfe"=>0x5509,
    "\x8f\xa4\xa1"=>0x553c,
    "\x8f\xa4\xa2"=>0x5541,
    "\x8f\xa4\xa3"=>0x35a6,
    "\x8f\xa4\xa4"=>0x5547,
    "\x8f\xa4\xa5"=>0x554a,
    "\x8f\xa4\xa6"=>0x35a8,
    "\x8f\xa4\xa7"=>0x5560,
    "\x8f\xa4\xa8"=>0x5561,
    "\x8f\xa4\xa9"=>0x5564,
    "\x8f\xa4\xaa"=>0x20de1,
    "\x8f\xa4\xab"=>0x557d,
    "\x8f\xa4\xac"=>0x5582,
    "\x8f\xa4\xad"=>0x5588,
    "\x8f\xa4\xae"=>0x5591,
    "\x8f\xa4\xaf"=>0x35c5,
    "\x8f\xa4\xb0"=>0x55d2,
    "\x8f\xa4\xb1"=>0x20e95,
    "\x8f\xa4\xb2"=>0x20e6d,
    "\x8f\xa4\xb3"=>0x55bf,
    "\x8f\xa4\xb4"=>0x55c9,
    "\x8f\xa4\xb5"=>0x55cc,
    "\x8f\xa4\xb6"=>0x55d1,
    "\x8f\xa4\xb7"=>0x55dd,
    "\x8f\xa4\xb8"=>0x35da,
    "\x8f\xa4\xb9"=>0x55e2,
    "\x8f\xa4\xba"=>0x20e64,
    "\x8f\xa4\xbb"=>0x55e9,
    "\x8f\xa4\xbc"=>0x5628,
    "\x8f\xa4\xbd"=>0x20f5f,
    "\x8f\xa4\xbe"=>0x5607,
    "\x8f\xa4\xbf"=>0x5610,
    "\x8f\xa4\xc0"=>0x5630,
    "\x8f\xa4\xc1"=>0x5637,
    "\x8f\xa4\xc2"=>0x35f4,
    "\x8f\xa4\xc3"=>0x563d,
    "\x8f\xa4\xc4"=>0x563f,
    "\x8f\xa4\xc5"=>0x5640,
    "\x8f\xa4\xc6"=>0x5647,
    "\x8f\xa4\xc7"=>0x565e,
    "\x8f\xa4\xc8"=>0x5660,
    "\x8f\xa4\xc9"=>0x566d,
    "\x8f\xa4\xca"=>0x3605,
    "\x8f\xa4\xcb"=>0x5688,
    "\x8f\xa4\xcc"=>0x568c,
    "\x8f\xa4\xcd"=>0x5695,
    "\x8f\xa4\xce"=>0x569a,
    "\x8f\xa4\xcf"=>0x569d,
    "\x8f\xa4\xd0"=>0x56a8,
    "\x8f\xa4\xd1"=>0x56ad,
    "\x8f\xa4\xd2"=>0x56b2,
    "\x8f\xa4\xd3"=>0x56c5,
    "\x8f\xa4\xd4"=>0x56cd,
    "\x8f\xa4\xd5"=>0x56df,
    "\x8f\xa4\xd6"=>0x56e8,
    "\x8f\xa4\xd7"=>0x56f6,
    "\x8f\xa4\xd8"=>0x56f7,
    "\x8f\xa4\xd9"=>0x21201,
    "\x8f\xa4\xda"=>0x5715,
    "\x8f\xa4\xdb"=>0x5723,
    "\x8f\xa4\xdc"=>0x21255,
    "\x8f\xa4\xdd"=>0x5729,
    "\x8f\xa4\xde"=>0x2127b,
    "\x8f\xa4\xdf"=>0x5745,
    "\x8f\xa4\xe0"=>0x5746,
    "\x8f\xa4\xe1"=>0x574c,
    "\x8f\xa4\xe2"=>0x574d,
    "\x8f\xa4\xe3"=>0x21274,
    "\x8f\xa4\xe4"=>0x5768,
    "\x8f\xa4\xe5"=>0x576f,
    "\x8f\xa4\xe6"=>0x5773,
    "\x8f\xa4\xe7"=>0x5774,
    "\x8f\xa4\xe8"=>0x5775,
    "\x8f\xa4\xe9"=>0x577b,
    "\x8f\xa4\xea"=>0x212e4,
    "\x8f\xa4\xeb"=>0x212d7,
    "\x8f\xa4\xec"=>0x57ac,
    "\x8f\xa4\xed"=>0x579a,
    "\x8f\xa4\xee"=>0x579d,
    "\x8f\xa4\xef"=>0x579e,
    "\x8f\xa4\xf0"=>0x57a8,
    "\x8f\xa4\xf1"=>0x57d7,
    "\x8f\xa4\xf2"=>0x212fd,
    "\x8f\xa4\xf3"=>0x57cc,
    "\x8f\xa4\xf4"=>0x21336,
    "\x8f\xa4\xf5"=>0x21344,
    "\x8f\xa4\xf6"=>0x57de,
    "\x8f\xa4\xf7"=>0x57e6,
    "\x8f\xa4\xf8"=>0x57f0,
    "\x8f\xa4\xf9"=>0x364a,
    "\x8f\xa4\xfa"=>0x57f8,
    "\x8f\xa4\xfb"=>0x57fb,
    "\x8f\xa4\xfc"=>0x57fd,
    "\x8f\xa4\xfd"=>0x5804,
    "\x8f\xa4\xfe"=>0x581e,
    "\x8f\xa5\xa1"=>0x5820,
    "\x8f\xa5\xa2"=>0x5827,
    "\x8f\xa5\xa3"=>0x5832,
    "\x8f\xa5\xa4"=>0x5839,
    "\x8f\xa5\xa5"=>0x213c4,
    "\x8f\xa5\xa6"=>0x5849,
    "\x8f\xa5\xa7"=>0x584c,
    "\x8f\xa5\xa8"=>0x5867,
    "\x8f\xa5\xa9"=>0x588a,
    "\x8f\xa5\xaa"=>0x588b,
    "\x8f\xa5\xab"=>0x588d,
    "\x8f\xa5\xac"=>0x588f,
    "\x8f\xa5\xad"=>0x5890,
    "\x8f\xa5\xae"=>0x5894,
    "\x8f\xa5\xaf"=>0x589d,
    "\x8f\xa5\xb0"=>0x58aa,
    "\x8f\xa5\xb1"=>0x58b1,
    "\x8f\xa5\xb2"=>0x2146d,
    "\x8f\xa5\xb3"=>0x58c3,
    "\x8f\xa5\xb4"=>0x58cd,
    "\x8f\xa5\xb5"=>0x58e2,
    "\x8f\xa5\xb6"=>0x58f3,
    "\x8f\xa5\xb7"=>0x58f4,
    "\x8f\xa5\xb8"=>0x5905,
    "\x8f\xa5\xb9"=>0x5906,
    "\x8f\xa5\xba"=>0x590b,
    "\x8f\xa5\xbb"=>0x590d,
    "\x8f\xa5\xbc"=>0x5914,
    "\x8f\xa5\xbd"=>0x5924,
    "\x8f\xa5\xbe"=>0x215d7,
    "\x8f\xa5\xbf"=>0x3691,
    "\x8f\xa5\xc0"=>0x593d,
    "\x8f\xa5\xc1"=>0x3699,
    "\x8f\xa5\xc2"=>0x5946,
    "\x8f\xa5\xc3"=>0x3696,
    "\x8f\xa5\xc4"=>0x26c29,
    "\x8f\xa5\xc5"=>0x595b,
    "\x8f\xa5\xc6"=>0x595f,
    "\x8f\xa5\xc7"=>0x21647,
    "\x8f\xa5\xc8"=>0x5975,
    "\x8f\xa5\xc9"=>0x5976,
    "\x8f\xa5\xca"=>0x597c,
    "\x8f\xa5\xcb"=>0x599f,
    "\x8f\xa5\xcc"=>0x59ae,
    "\x8f\xa5\xcd"=>0x59bc,
    "\x8f\xa5\xce"=>0x59c8,
    "\x8f\xa5\xcf"=>0x59cd,
    "\x8f\xa5\xd0"=>0x59de,
    "\x8f\xa5\xd1"=>0x59e3,
    "\x8f\xa5\xd2"=>0x59e4,
    "\x8f\xa5\xd3"=>0x59e7,
    "\x8f\xa5\xd4"=>0x59ee,
    "\x8f\xa5\xd5"=>0x21706,
    "\x8f\xa5\xd6"=>0x21742,
    "\x8f\xa5\xd7"=>0x36cf,
    "\x8f\xa5\xd8"=>0x5a0c,
    "\x8f\xa5\xd9"=>0x5a0d,
    "\x8f\xa5\xda"=>0x5a17,
    "\x8f\xa5\xdb"=>0x5a27,
    "\x8f\xa5\xdc"=>0x5a2d,
    "\x8f\xa5\xdd"=>0x5a55,
    "\x8f\xa5\xde"=>0x5a65,
    "\x8f\xa5\xdf"=>0x5a7a,
    "\x8f\xa5\xe0"=>0x5a8b,
    "\x8f\xa5\xe1"=>0x5a9c,
    "\x8f\xa5\xe2"=>0x5a9f,
    "\x8f\xa5\xe3"=>0x5aa0,
    "\x8f\xa5\xe4"=>0x5aa2,
    "\x8f\xa5\xe5"=>0x5ab1,
    "\x8f\xa5\xe6"=>0x5ab3,
    "\x8f\xa5\xe7"=>0x5ab5,
    "\x8f\xa5\xe8"=>0x5aba,
    "\x8f\xa5\xe9"=>0x5abf,
    "\x8f\xa5\xea"=>0x5ada,
    "\x8f\xa5\xeb"=>0x5adc,
    "\x8f\xa5\xec"=>0x5ae0,
    "\x8f\xa5\xed"=>0x5ae5,
    "\x8f\xa5\xee"=>0x5af0,
    "\x8f\xa5\xef"=>0x5aee,
    "\x8f\xa5\xf0"=>0x5af5,
    "\x8f\xa5\xf1"=>0x5b00,
    "\x8f\xa5\xf2"=>0x5b08,
    "\x8f\xa5\xf3"=>0x5b17,
    "\x8f\xa5\xf4"=>0x5b34,
    "\x8f\xa5\xf5"=>0x5b2d,
    "\x8f\xa5\xf6"=>0x5b4c,
    "\x8f\xa5\xf7"=>0x5b52,
    "\x8f\xa5\xf8"=>0x5b68,
    "\x8f\xa5\xf9"=>0x5b6f,
    "\x8f\xa5\xfa"=>0x5b7c,
    "\x8f\xa5\xfb"=>0x5b7f,
    "\x8f\xa5\xfc"=>0x5b81,
    "\x8f\xa5\xfd"=>0x5b84,
    "\x8f\xa5\xfe"=>0x219c3,
    "\x8f\xa6\xe1"=>0,
    "\x8f\xa6\xe2"=>0,
    "\x8f\xa6\xe3"=>0,
    "\x8f\xa6\xe4"=>0,
    "\x8f\xa6\xe5"=>0,
    "\x8f\xa6\xe7"=>0,
    "\x8f\xa6\xe9"=>0,
    "\x8f\xa6\xea"=>0,
    "\x8f\xa6\xec"=>0,
    "\x8f\xa6\xf1"=>0,
    "\x8f\xa6\xf2"=>0,
    "\x8f\xa6\xf3"=>0,
    "\x8f\xa6\xf4"=>0,
    "\x8f\xa6\xf5"=>0,
    "\x8f\xa6\xf6"=>0,
    "\x8f\xa6\xf7"=>0,
    "\x8f\xa6\xf8"=>0,
    "\x8f\xa6\xf9"=>0,
    "\x8f\xa6\xfa"=>0,
    "\x8f\xa6\xfb"=>0,
    "\x8f\xa6\xfc"=>0,
    "\x8f\xa7\xc2"=>0,
    "\x8f\xa7\xc3"=>0,
    "\x8f\xa7\xc4"=>0,
    "\x8f\xa7\xc5"=>0,
    "\x8f\xa7\xc6"=>0,
    "\x8f\xa7\xc7"=>0,
    "\x8f\xa7\xc8"=>0,
    "\x8f\xa7\xc9"=>0,
    "\x8f\xa7\xca"=>0,
    "\x8f\xa7\xcb"=>0,
    "\x8f\xa7\xcc"=>0,
    "\x8f\xa7\xcd"=>0,
    "\x8f\xa7\xce"=>0,
    "\x8f\xa7\xf2"=>0,
    "\x8f\xa7\xf3"=>0,
    "\x8f\xa7\xf4"=>0,
    "\x8f\xa7\xf5"=>0,
    "\x8f\xa7\xf6"=>0,
    "\x8f\xa7\xf7"=>0,
    "\x8f\xa7\xf8"=>0,
    "\x8f\xa7\xf9"=>0,
    "\x8f\xa7\xfa"=>0,
    "\x8f\xa7\xfb"=>0,
    "\x8f\xa7\xfc"=>0,
    "\x8f\xa7\xfd"=>0,
    "\x8f\xa7\xfe"=>0,
    "\x8f\xa8\xa1"=>0x5b96,
    "\x8f\xa8\xa2"=>0x5bac,
    "\x8f\xa8\xa3"=>0x3761,
    "\x8f\xa8\xa4"=>0x5bc0,
    "\x8f\xa8\xa5"=>0x3762,
    "\x8f\xa8\xa6"=>0x5bce,
    "\x8f\xa8\xa7"=>0x5bd6,
    "\x8f\xa8\xa8"=>0x376c,
    "\x8f\xa8\xa9"=>0x376b,
    "\x8f\xa8\xaa"=>0x5bf1,
    "\x8f\xa8\xab"=>0x5bfd,
    "\x8f\xa8\xac"=>0x3775,
    "\x8f\xa8\xad"=>0x5c03,
    "\x8f\xa8\xae"=>0x5c29,
    "\x8f\xa8\xaf"=>0x5c30,
    "\x8f\xa8\xb0"=>0x21c56,
    "\x8f\xa8\xb1"=>0x5c5f,
    "\x8f\xa8\xb2"=>0x5c63,
    "\x8f\xa8\xb3"=>0x5c67,
    "\x8f\xa8\xb4"=>0x5c68,
    "\x8f\xa8\xb5"=>0x5c69,
    "\x8f\xa8\xb6"=>0x5c70,
    "\x8f\xa8\xb7"=>0x21d2d,
    "\x8f\xa8\xb8"=>0x21d45,
    "\x8f\xa8\xb9"=>0x5c7c,
    "\x8f\xa8\xba"=>0x21d78,
    "\x8f\xa8\xbb"=>0x21d62,
    "\x8f\xa8\xbc"=>0x5c88,
    "\x8f\xa8\xbd"=>0x5c8a,
    "\x8f\xa8\xbe"=>0x37c1,
    "\x8f\xa8\xbf"=>0x21da1,
    "\x8f\xa8\xc0"=>0x21d9c,
    "\x8f\xa8\xc1"=>0x5ca0,
    "\x8f\xa8\xc2"=>0x5ca2,
    "\x8f\xa8\xc3"=>0x5ca6,
    "\x8f\xa8\xc4"=>0x5ca7,
    "\x8f\xa8\xc5"=>0x21d92,
    "\x8f\xa8\xc6"=>0x5cad,
    "\x8f\xa8\xc7"=>0x5cb5,
    "\x8f\xa8\xc8"=>0x21db7,
    "\x8f\xa8\xc9"=>0x5cc9,
    "\x8f\xa8\xca"=>0x21de0,
    "\x8f\xa8\xcb"=>0x21e33,
    "\x8f\xa8\xcc"=>0x5d06,
    "\x8f\xa8\xcd"=>0x5d10,
    "\x8f\xa8\xce"=>0x5d2b,
    "\x8f\xa8\xcf"=>0x5d1d,
    "\x8f\xa8\xd0"=>0x5d20,
    "\x8f\xa8\xd1"=>0x5d24,
    "\x8f\xa8\xd2"=>0x5d26,
    "\x8f\xa8\xd3"=>0x5d31,
    "\x8f\xa8\xd4"=>0x5d39,
    "\x8f\xa8\xd5"=>0x5d42,
    "\x8f\xa8\xd6"=>0x37e8,
    "\x8f\xa8\xd7"=>0x5d61,
    "\x8f\xa8\xd8"=>0x5d6a,
    "\x8f\xa8\xd9"=>0x37f4,
    "\x8f\xa8\xda"=>0x5d70,
    "\x8f\xa8\xdb"=>0x21f1e,
    "\x8f\xa8\xdc"=>0x37fd,
    "\x8f\xa8\xdd"=>0x5d88,
    "\x8f\xa8\xde"=>0x3800,
    "\x8f\xa8\xdf"=>0x5d92,
    "\x8f\xa8\xe0"=>0x5d94,
    "\x8f\xa8\xe1"=>0x5d97,
    "\x8f\xa8\xe2"=>0x5d99,
    "\x8f\xa8\xe3"=>0x5db0,
    "\x8f\xa8\xe4"=>0x5db2,
    "\x8f\xa8\xe5"=>0x5db4,
    "\x8f\xa8\xe6"=>0x21f76,
    "\x8f\xa8\xe7"=>0x5db9,
    "\x8f\xa8\xe8"=>0x5dd1,
    "\x8f\xa8\xe9"=>0x5dd7,
    "\x8f\xa8\xea"=>0x5dd8,
    "\x8f\xa8\xeb"=>0x5de0,
    "\x8f\xa8\xec"=>0x21ffa,
    "\x8f\xa8\xed"=>0x5de4,
    "\x8f\xa8\xee"=>0x5de9,
    "\x8f\xa8\xef"=>0x382f,
    "\x8f\xa8\xf0"=>0x5e00,
    "\x8f\xa8\xf1"=>0x3836,
    "\x8f\xa8\xf2"=>0x5e12,
    "\x8f\xa8\xf3"=>0x5e15,
    "\x8f\xa8\xf4"=>0x3840,
    "\x8f\xa8\xf5"=>0x5e1f,
    "\x8f\xa8\xf6"=>0x5e2e,
    "\x8f\xa8\xf7"=>0x5e3e,
    "\x8f\xa8\xf8"=>0x5e49,
    "\x8f\xa8\xf9"=>0x385c,
    "\x8f\xa8\xfa"=>0x5e56,
    "\x8f\xa8\xfb"=>0x3861,
    "\x8f\xa8\xfc"=>0x5e6b,
    "\x8f\xa8\xfd"=>0x5e6c,
    "\x8f\xa8\xfe"=>0x5e6d,
    "\x8f\xa9\xa1"=>0,
    "\x8f\xa9\xa2"=>0,
    "\x8f\xa9\xa4"=>0,
    "\x8f\xa9\xa6"=>0,
    "\x8f\xa9\xa8"=>0,
    "\x8f\xa9\xa9"=>0,
    "\x8f\xa9\xab"=>0,
    "\x8f\xa9\xac"=>0,
    "\x8f\xa9\xad"=>0,
    "\x8f\xa9\xaf"=>0,
    "\x8f\xa9\xb0"=>0,
    "\x8f\xa9\xc1"=>0,
    "\x8f\xa9\xc2"=>0,
    "\x8f\xa9\xc3"=>0,
    "\x8f\xa9\xc4"=>0,
    "\x8f\xa9\xc5"=>0,
    "\x8f\xa9\xc6"=>0,
    "\x8f\xa9\xc7"=>0,
    "\x8f\xa9\xc8"=>0,
    "\x8f\xa9\xc9"=>0,
    "\x8f\xa9\xca"=>0,
    "\x8f\xa9\xcb"=>0,
    "\x8f\xa9\xcc"=>0,
    "\x8f\xa9\xcd"=>0,
    "\x8f\xa9\xce"=>0,
    "\x8f\xa9\xcf"=>0,
    "\x8f\xa9\xd0"=>0,
    "\x8f\xaa\xa1"=>0,
    "\x8f\xaa\xa2"=>0,
    "\x8f\xaa\xa3"=>0,
    "\x8f\xaa\xa4"=>0,
    "\x8f\xaa\xa5"=>0,
    "\x8f\xaa\xa6"=>0,
    "\x8f\xaa\xa7"=>0,
    "\x8f\xaa\xa8"=>0,
    "\x8f\xaa\xa9"=>0,
    "\x8f\xaa\xaa"=>0,
    "\x8f\xaa\xab"=>0,
    "\x8f\xaa\xac"=>0,
    "\x8f\xaa\xad"=>0,
    "\x8f\xaa\xae"=>0,
    "\x8f\xaa\xaf"=>0,
    "\x8f\xaa\xb0"=>0,
    "\x8f\xaa\xb1"=>0,
    "\x8f\xaa\xb2"=>0,
    "\x8f\xaa\xb3"=>0,
    "\x8f\xaa\xb4"=>0,
    "\x8f\xaa\xb5"=>0,
    "\x8f\xaa\xb6"=>0,
    "\x8f\xaa\xb7"=>0,
    "\x8f\xaa\xb8"=>0,
    "\x8f\xaa\xba"=>0,
    "\x8f\xaa\xbb"=>0,
    "\x8f\xaa\xbc"=>0,
    "\x8f\xaa\xbd"=>0,
    "\x8f\xaa\xbe"=>0,
    "\x8f\xaa\xbf"=>0,
    "\x8f\xaa\xc0"=>0,
    "\x8f\xaa\xc1"=>0,
    "\x8f\xaa\xc2"=>0,
    "\x8f\xaa\xc3"=>0,
    "\x8f\xaa\xc4"=>0,
    "\x8f\xaa\xc5"=>0,
    "\x8f\xaa\xc6"=>0,
    "\x8f\xaa\xc7"=>0,
    "\x8f\xaa\xc8"=>0,
    "\x8f\xaa\xc9"=>0,
    "\x8f\xaa\xca"=>0,
    "\x8f\xaa\xcb"=>0,
    "\x8f\xaa\xcc"=>0,
    "\x8f\xaa\xcd"=>0,
    "\x8f\xaa\xce"=>0,
    "\x8f\xaa\xcf"=>0,
    "\x8f\xaa\xd0"=>0,
    "\x8f\xaa\xd1"=>0,
    "\x8f\xaa\xd2"=>0,
    "\x8f\xaa\xd3"=>0,
    "\x8f\xaa\xd4"=>0,
    "\x8f\xaa\xd5"=>0,
    "\x8f\xaa\xd6"=>0,
    "\x8f\xaa\xd7"=>0,
    "\x8f\xaa\xd8"=>0,
    "\x8f\xaa\xd9"=>0,
    "\x8f\xaa\xda"=>0,
    "\x8f\xaa\xdb"=>0,
    "\x8f\xaa\xdc"=>0,
    "\x8f\xaa\xdd"=>0,
    "\x8f\xaa\xde"=>0,
    "\x8f\xaa\xdf"=>0,
    "\x8f\xaa\xe0"=>0,
    "\x8f\xaa\xe1"=>0,
    "\x8f\xaa\xe2"=>0,
    "\x8f\xaa\xe3"=>0,
    "\x8f\xaa\xe4"=>0,
    "\x8f\xaa\xe5"=>0,
    "\x8f\xaa\xe6"=>0,
    "\x8f\xaa\xe7"=>0,
    "\x8f\xaa\xe8"=>0,
    "\x8f\xaa\xe9"=>0,
    "\x8f\xaa\xea"=>0,
    "\x8f\xaa\xeb"=>0,
    "\x8f\xaa\xec"=>0,
    "\x8f\xaa\xed"=>0,
    "\x8f\xaa\xee"=>0,
    "\x8f\xaa\xef"=>0,
    "\x8f\xaa\xf0"=>0,
    "\x8f\xaa\xf1"=>0,
    "\x8f\xaa\xf2"=>0,
    "\x8f\xaa\xf3"=>0,
    "\x8f\xaa\xf4"=>0,
    "\x8f\xaa\xf5"=>0,
    "\x8f\xaa\xf6"=>0,
    "\x8f\xaa\xf7"=>0,
    "\x8f\xab\xa1"=>0,
    "\x8f\xab\xa2"=>0,
    "\x8f\xab\xa3"=>0,
    "\x8f\xab\xa4"=>0,
    "\x8f\xab\xa5"=>0,
    "\x8f\xab\xa6"=>0,
    "\x8f\xab\xa7"=>0,
    "\x8f\xab\xa8"=>0,
    "\x8f\xab\xa9"=>0,
    "\x8f\xab\xaa"=>0,
    "\x8f\xab\xab"=>0,
    "\x8f\xab\xac"=>0,
    "\x8f\xab\xad"=>0,
    "\x8f\xab\xae"=>0,
    "\x8f\xab\xaf"=>0,
    "\x8f\xab\xb0"=>0,
    "\x8f\xab\xb1"=>0,
    "\x8f\xab\xb2"=>0,
    "\x8f\xab\xb3"=>0,
    "\x8f\xab\xb4"=>0,
    "\x8f\xab\xb5"=>0,
    "\x8f\xab\xb6"=>0,
    "\x8f\xab\xb7"=>0,
    "\x8f\xab\xb8"=>0,
    "\x8f\xab\xb9"=>0,
    "\x8f\xab\xba"=>0,
    "\x8f\xab\xbb"=>0,
    "\x8f\xab\xbd"=>0,
    "\x8f\xab\xbe"=>0,
    "\x8f\xab\xbf"=>0,
    "\x8f\xab\xc0"=>0,
    "\x8f\xab\xc1"=>0,
    "\x8f\xab\xc2"=>0,
    "\x8f\xab\xc3"=>0,
    "\x8f\xab\xc5"=>0,
    "\x8f\xab\xc6"=>0,
    "\x8f\xab\xc7"=>0,
    "\x8f\xab\xc8"=>0,
    "\x8f\xab\xc9"=>0,
    "\x8f\xab\xca"=>0,
    "\x8f\xab\xcb"=>0,
    "\x8f\xab\xcc"=>0,
    "\x8f\xab\xcd"=>0,
    "\x8f\xab\xce"=>0,
    "\x8f\xab\xcf"=>0,
    "\x8f\xab\xd0"=>0,
    "\x8f\xab\xd1"=>0,
    "\x8f\xab\xd2"=>0,
    "\x8f\xab\xd3"=>0,
    "\x8f\xab\xd4"=>0,
    "\x8f\xab\xd5"=>0,
    "\x8f\xab\xd6"=>0,
    "\x8f\xab\xd7"=>0,
    "\x8f\xab\xd8"=>0,
    "\x8f\xab\xd9"=>0,
    "\x8f\xab\xda"=>0,
    "\x8f\xab\xdb"=>0,
    "\x8f\xab\xdc"=>0,
    "\x8f\xab\xdd"=>0,
    "\x8f\xab\xde"=>0,
    "\x8f\xab\xdf"=>0,
    "\x8f\xab\xe0"=>0,
    "\x8f\xab\xe1"=>0,
    "\x8f\xab\xe2"=>0,
    "\x8f\xab\xe3"=>0,
    "\x8f\xab\xe4"=>0,
    "\x8f\xab\xe5"=>0,
    "\x8f\xab\xe6"=>0,
    "\x8f\xab\xe7"=>0,
    "\x8f\xab\xe8"=>0,
    "\x8f\xab\xe9"=>0,
    "\x8f\xab\xea"=>0,
    "\x8f\xab\xeb"=>0,
    "\x8f\xab\xec"=>0,
    "\x8f\xab\xed"=>0,
    "\x8f\xab\xee"=>0,
    "\x8f\xab\xef"=>0,
    "\x8f\xab\xf0"=>0,
    "\x8f\xab\xf1"=>0,
    "\x8f\xab\xf2"=>0,
    "\x8f\xab\xf3"=>0,
    "\x8f\xab\xf4"=>0,
    "\x8f\xab\xf5"=>0,
    "\x8f\xab\xf6"=>0,
    "\x8f\xab\xf7"=>0,
    "\x8f\xac\xa1"=>0x5e6e,
    "\x8f\xac\xa2"=>0x2217b,
    "\x8f\xac\xa3"=>0x5ea5,
    "\x8f\xac\xa4"=>0x5eaa,
    "\x8f\xac\xa5"=>0x5eac,
    "\x8f\xac\xa6"=>0x5eb9,
    "\x8f\xac\xa7"=>0x5ebf,
    "\x8f\xac\xa8"=>0x5ec6,
    "\x8f\xac\xa9"=>0x5ed2,
    "\x8f\xac\xaa"=>0x5ed9,
    "\x8f\xac\xab"=>0x2231e,
    "\x8f\xac\xac"=>0x5efd,
    "\x8f\xac\xad"=>0x5f08,
    "\x8f\xac\xae"=>0x5f0e,
    "\x8f\xac\xaf"=>0x5f1c,
    "\x8f\xac\xb0"=>0x223ad,
    "\x8f\xac\xb1"=>0x5f1e,
    "\x8f\xac\xb2"=>0x5f47,
    "\x8f\xac\xb3"=>0x5f63,
    "\x8f\xac\xb4"=>0x5f72,
    "\x8f\xac\xb5"=>0x5f7e,
    "\x8f\xac\xb6"=>0x5f8f,
    "\x8f\xac\xb7"=>0x5fa2,
    "\x8f\xac\xb8"=>0x5fa4,
    "\x8f\xac\xb9"=>0x5fb8,
    "\x8f\xac\xba"=>0x5fc4,
    "\x8f\xac\xbb"=>0x38fa,
    "\x8f\xac\xbc"=>0x5fc7,
    "\x8f\xac\xbd"=>0x5fcb,
    "\x8f\xac\xbe"=>0x5fd2,
    "\x8f\xac\xbf"=>0x5fd3,
    "\x8f\xac\xc0"=>0x5fd4,
    "\x8f\xac\xc1"=>0x5fe2,
    "\x8f\xac\xc2"=>0x5fee,
    "\x8f\xac\xc3"=>0x5fef,
    "\x8f\xac\xc4"=>0x5ff3,
    "\x8f\xac\xc5"=>0x5ffc,
    "\x8f\xac\xc6"=>0x3917,
    "\x8f\xac\xc7"=>0x6017,
    "\x8f\xac\xc8"=>0x6022,
    "\x8f\xac\xc9"=>0x6024,
    "\x8f\xac\xca"=>0x391a,
    "\x8f\xac\xcb"=>0x604c,
    "\x8f\xac\xcc"=>0x607f,
    "\x8f\xac\xcd"=>0x608a,
    "\x8f\xac\xce"=>0x6095,
    "\x8f\xac\xcf"=>0x60a8,
    "\x8f\xac\xd0"=>0x226f3,
    "\x8f\xac\xd1"=>0x60b0,
    "\x8f\xac\xd2"=>0x60b1,
    "\x8f\xac\xd3"=>0x60be,
    "\x8f\xac\xd4"=>0x60c8,
    "\x8f\xac\xd5"=>0x60d9,
    "\x8f\xac\xd6"=>0x60db,
    "\x8f\xac\xd7"=>0x60ee,
    "\x8f\xac\xd8"=>0x60f2,
    "\x8f\xac\xd9"=>0x60f5,
    "\x8f\xac\xda"=>0x6110,
    "\x8f\xac\xdb"=>0x6112,
    "\x8f\xac\xdc"=>0x6113,
    "\x8f\xac\xdd"=>0x6119,
    "\x8f\xac\xde"=>0x611e,
    "\x8f\xac\xdf"=>0x613a,
    "\x8f\xac\xe0"=>0x396f,
    "\x8f\xac\xe1"=>0x6141,
    "\x8f\xac\xe2"=>0x6146,
    "\x8f\xac\xe3"=>0x6160,
    "\x8f\xac\xe4"=>0x617c,
    "\x8f\xac\xe5"=>0x2285b,
    "\x8f\xac\xe6"=>0x6192,
    "\x8f\xac\xe7"=>0x6193,
    "\x8f\xac\xe8"=>0x6197,
    "\x8f\xac\xe9"=>0x6198,
    "\x8f\xac\xea"=>0x61a5,
    "\x8f\xac\xeb"=>0x61a8,
    "\x8f\xac\xec"=>0x61ad,
    "\x8f\xac\xed"=>0x228ab,
    "\x8f\xac\xee"=>0x61d5,
    "\x8f\xac\xef"=>0x61dd,
    "\x8f\xac\xf0"=>0x61df,
    "\x8f\xac\xf1"=>0x61f5,
    "\x8f\xac\xf2"=>0x2298f,
    "\x8f\xac\xf3"=>0x6215,
    "\x8f\xac\xf4"=>0x6223,
    "\x8f\xac\xf5"=>0x6229,
    "\x8f\xac\xf6"=>0x6246,
    "\x8f\xac\xf7"=>0x624c,
    "\x8f\xac\xf8"=>0x6251,
    "\x8f\xac\xf9"=>0x6252,
    "\x8f\xac\xfa"=>0x6261,
    "\x8f\xac\xfb"=>0x6264,
    "\x8f\xac\xfc"=>0x627b,
    "\x8f\xac\xfd"=>0x626d,
    "\x8f\xac\xfe"=>0x6273,
    "\x8f\xad\xa1"=>0x6299,
    "\x8f\xad\xa2"=>0x62a6,
    "\x8f\xad\xa3"=>0x62d5,
    "\x8f\xad\xa4"=>0x22ab8,
    "\x8f\xad\xa5"=>0x62fd,
    "\x8f\xad\xa6"=>0x6303,
    "\x8f\xad\xa7"=>0x630d,
    "\x8f\xad\xa8"=>0x6310,
    "\x8f\xad\xa9"=>0x22b4f,
    "\x8f\xad\xaa"=>0x22b50,
    "\x8f\xad\xab"=>0x6332,
    "\x8f\xad\xac"=>0x6335,
    "\x8f\xad\xad"=>0x633b,
    "\x8f\xad\xae"=>0x633c,
    "\x8f\xad\xaf"=>0x6341,
    "\x8f\xad\xb0"=>0x6344,
    "\x8f\xad\xb1"=>0x634e,
    "\x8f\xad\xb2"=>0x22b46,
    "\x8f\xad\xb3"=>0x6359,
    "\x8f\xad\xb4"=>0x22c1d,
    "\x8f\xad\xb5"=>0x22ba6,
    "\x8f\xad\xb6"=>0x636c,
    "\x8f\xad\xb7"=>0x6384,
    "\x8f\xad\xb8"=>0x6399,
    "\x8f\xad\xb9"=>0x22c24,
    "\x8f\xad\xba"=>0x6394,
    "\x8f\xad\xbb"=>0x63bd,
    "\x8f\xad\xbc"=>0x63f7,
    "\x8f\xad\xbd"=>0x63d4,
    "\x8f\xad\xbe"=>0x63d5,
    "\x8f\xad\xbf"=>0x63dc,
    "\x8f\xad\xc0"=>0x63e0,
    "\x8f\xad\xc1"=>0x63eb,
    "\x8f\xad\xc2"=>0x63ec,
    "\x8f\xad\xc3"=>0x63f2,
    "\x8f\xad\xc4"=>0x6409,
    "\x8f\xad\xc5"=>0x641e,
    "\x8f\xad\xc6"=>0x6425,
    "\x8f\xad\xc7"=>0x6429,
    "\x8f\xad\xc8"=>0x642f,
    "\x8f\xad\xc9"=>0x645a,
    "\x8f\xad\xca"=>0x645b,
    "\x8f\xad\xcb"=>0x645d,
    "\x8f\xad\xcc"=>0x6473,
    "\x8f\xad\xcd"=>0x647d,
    "\x8f\xad\xce"=>0x6487,
    "\x8f\xad\xcf"=>0x6491,
    "\x8f\xad\xd0"=>0x649d,
    "\x8f\xad\xd1"=>0x649f,
    "\x8f\xad\xd2"=>0x64cb,
    "\x8f\xad\xd3"=>0x64cc,
    "\x8f\xad\xd4"=>0x64d5,
    "\x8f\xad\xd5"=>0x64d7,
    "\x8f\xad\xd6"=>0x22de1,
    "\x8f\xad\xd7"=>0x64e4,
    "\x8f\xad\xd8"=>0x64e5,
    "\x8f\xad\xd9"=>0x64ff,
    "\x8f\xad\xda"=>0x6504,
    "\x8f\xad\xdb"=>0x3a6e,
    "\x8f\xad\xdc"=>0x650f,
    "\x8f\xad\xdd"=>0x6514,
    "\x8f\xad\xde"=>0x6516,
    "\x8f\xad\xdf"=>0x3a73,
    "\x8f\xad\xe0"=>0x651e,
    "\x8f\xad\xe1"=>0x6532,
    "\x8f\xad\xe2"=>0x6544,
    "\x8f\xad\xe3"=>0x6554,
    "\x8f\xad\xe4"=>0x656b,
    "\x8f\xad\xe5"=>0x657a,
    "\x8f\xad\xe6"=>0x6581,
    "\x8f\xad\xe7"=>0x6584,
    "\x8f\xad\xe8"=>0x6585,
    "\x8f\xad\xe9"=>0x658a,
    "\x8f\xad\xea"=>0x65b2,
    "\x8f\xad\xeb"=>0x65b5,
    "\x8f\xad\xec"=>0x65b8,
    "\x8f\xad\xed"=>0x65bf,
    "\x8f\xad\xee"=>0x65c2,
    "\x8f\xad\xef"=>0x65c9,
    "\x8f\xad\xf0"=>0x65d4,
    "\x8f\xad\xf1"=>0x3ad6,
    "\x8f\xad\xf2"=>0x65f2,
    "\x8f\xad\xf3"=>0x65f9,
    "\x8f\xad\xf4"=>0x65fc,
    "\x8f\xad\xf5"=>0x6604,
    "\x8f\xad\xf6"=>0x6608,
    "\x8f\xad\xf7"=>0x6621,
    "\x8f\xad\xf8"=>0x662a,
    "\x8f\xad\xf9"=>0x6645,
    "\x8f\xad\xfa"=>0x6651,
    "\x8f\xad\xfb"=>0x664e,
    "\x8f\xad\xfc"=>0x3aea,
    "\x8f\xad\xfd"=>0x231c3,
    "\x8f\xad\xfe"=>0x6657,
    "\x8f\xae\xa1"=>0x665b,
    "\x8f\xae\xa2"=>0x6663,
    "\x8f\xae\xa3"=>0x231f5,
    "\x8f\xae\xa4"=>0x231b6,
    "\x8f\xae\xa5"=>0x666a,
    "\x8f\xae\xa6"=>0x666b,
    "\x8f\xae\xa7"=>0x666c,
    "\x8f\xae\xa8"=>0x666d,
    "\x8f\xae\xa9"=>0x667b,
    "\x8f\xae\xaa"=>0x6680,
    "\x8f\xae\xab"=>0x6690,
    "\x8f\xae\xac"=>0x6692,
    "\x8f\xae\xad"=>0x6699,
    "\x8f\xae\xae"=>0x3b0e,
    "\x8f\xae\xaf"=>0x66ad,
    "\x8f\xae\xb0"=>0x66b1,
    "\x8f\xae\xb1"=>0x66b5,
    "\x8f\xae\xb2"=>0x3b1a,
    "\x8f\xae\xb3"=>0x66bf,
    "\x8f\xae\xb4"=>0x3b1c,
    "\x8f\xae\xb5"=>0x66ec,
    "\x8f\xae\xb6"=>0x3ad7,
    "\x8f\xae\xb7"=>0x6701,
    "\x8f\xae\xb8"=>0x6705,
    "\x8f\xae\xb9"=>0x6712,
    "\x8f\xae\xba"=>0x23372,
    "\x8f\xae\xbb"=>0x6719,
    "\x8f\xae\xbc"=>0x233d3,
    "\x8f\xae\xbd"=>0x233d2,
    "\x8f\xae\xbe"=>0x674c,
    "\x8f\xae\xbf"=>0x674d,
    "\x8f\xae\xc0"=>0x6754,
    "\x8f\xae\xc1"=>0x675d,
    "\x8f\xae\xc2"=>0x233d0,
    "\x8f\xae\xc3"=>0x233e4,
    "\x8f\xae\xc4"=>0x233d5,
    "\x8f\xae\xc5"=>0x6774,
    "\x8f\xae\xc6"=>0x6776,
    "\x8f\xae\xc7"=>0x233da,
    "\x8f\xae\xc8"=>0x6792,
    "\x8f\xae\xc9"=>0x233df,
    "\x8f\xae\xca"=>0x8363,
    "\x8f\xae\xcb"=>0x6810,
    "\x8f\xae\xcc"=>0x67b0,
    "\x8f\xae\xcd"=>0x67b2,
    "\x8f\xae\xce"=>0x67c3,
    "\x8f\xae\xcf"=>0x67c8,
    "\x8f\xae\xd0"=>0x67d2,
    "\x8f\xae\xd1"=>0x67d9,
    "\x8f\xae\xd2"=>0x67db,
    "\x8f\xae\xd3"=>0x67f0,
    "\x8f\xae\xd4"=>0x67f7,
    "\x8f\xae\xd5"=>0x2344a,
    "\x8f\xae\xd6"=>0x23451,
    "\x8f\xae\xd7"=>0x2344b,
    "\x8f\xae\xd8"=>0x6818,
    "\x8f\xae\xd9"=>0x681f,
    "\x8f\xae\xda"=>0x682d,
    "\x8f\xae\xdb"=>0x23465,
    "\x8f\xae\xdc"=>0x6833,
    "\x8f\xae\xdd"=>0x683b,
    "\x8f\xae\xde"=>0x683e,
    "\x8f\xae\xdf"=>0x6844,
    "\x8f\xae\xe0"=>0x6845,
    "\x8f\xae\xe1"=>0x6849,
    "\x8f\xae\xe2"=>0x684c,
    "\x8f\xae\xe3"=>0x6855,
    "\x8f\xae\xe4"=>0x6857,
    "\x8f\xae\xe5"=>0x3b77,
    "\x8f\xae\xe6"=>0x686b,
    "\x8f\xae\xe7"=>0x686e,
    "\x8f\xae\xe8"=>0x687a,
    "\x8f\xae\xe9"=>0x687c,
    "\x8f\xae\xea"=>0x6882,
    "\x8f\xae\xeb"=>0x6890,
    "\x8f\xae\xec"=>0x6896,
    "\x8f\xae\xed"=>0x3b6d,
    "\x8f\xae\xee"=>0x6898,
    "\x8f\xae\xef"=>0x6899,
    "\x8f\xae\xf0"=>0x689a,
    "\x8f\xae\xf1"=>0x689c,
    "\x8f\xae\xf2"=>0x68aa,
    "\x8f\xae\xf3"=>0x68ab,
    "\x8f\xae\xf4"=>0x68b4,
    "\x8f\xae\xf5"=>0x68bb,
    "\x8f\xae\xf6"=>0x68fb,
    "\x8f\xae\xf7"=>0x234e4,
    "\x8f\xae\xf8"=>0x2355a,
    "\x8f\xae\xf9"=>0xfa13,
    "\x8f\xae\xfa"=>0x68c3,
    "\x8f\xae\xfb"=>0x68c5,
    "\x8f\xae\xfc"=>0x68cc,
    "\x8f\xae\xfd"=>0x68cf,
    "\x8f\xae\xfe"=>0x68d6,
    "\x8f\xaf\xa1"=>0x68d9,
    "\x8f\xaf\xa2"=>0x68e4,
    "\x8f\xaf\xa3"=>0x68e5,
    "\x8f\xaf\xa4"=>0x68ec,
    "\x8f\xaf\xa5"=>0x68f7,
    "\x8f\xaf\xa6"=>0x6903,
    "\x8f\xaf\xa7"=>0x6907,
    "\x8f\xaf\xa8"=>0x3b87,
    "\x8f\xaf\xa9"=>0x3b88,
    "\x8f\xaf\xaa"=>0x23594,
    "\x8f\xaf\xab"=>0x693b,
    "\x8f\xaf\xac"=>0x3b8d,
    "\x8f\xaf\xad"=>0x6946,
    "\x8f\xaf\xae"=>0x6969,
    "\x8f\xaf\xaf"=>0x696c,
    "\x8f\xaf\xb0"=>0x6972,
    "\x8f\xaf\xb1"=>0x697a,
    "\x8f\xaf\xb2"=>0x697f,
    "\x8f\xaf\xb3"=>0x6992,
    "\x8f\xaf\xb4"=>0x3ba4,
    "\x8f\xaf\xb5"=>0x6996,
    "\x8f\xaf\xb6"=>0x6998,
    "\x8f\xaf\xb7"=>0x69a6,
    "\x8f\xaf\xb8"=>0x69b0,
    "\x8f\xaf\xb9"=>0x69b7,
    "\x8f\xaf\xba"=>0x69ba,
    "\x8f\xaf\xbb"=>0x69bc,
    "\x8f\xaf\xbc"=>0x69c0,
    "\x8f\xaf\xbd"=>0x69d1,
    "\x8f\xaf\xbe"=>0x69d6,
    "\x8f\xaf\xbf"=>0x23639,
    "\x8f\xaf\xc0"=>0x23647,
    "\x8f\xaf\xc1"=>0x6a30,
    "\x8f\xaf\xc2"=>0x23638,
    "\x8f\xaf\xc3"=>0x2363a,
    "\x8f\xaf\xc4"=>0x69e3,
    "\x8f\xaf\xc5"=>0x69ee,
    "\x8f\xaf\xc6"=>0x69ef,
    "\x8f\xaf\xc7"=>0x69f3,
    "\x8f\xaf\xc8"=>0x3bcd,
    "\x8f\xaf\xc9"=>0x69f4,
    "\x8f\xaf\xca"=>0x69fe,
    "\x8f\xaf\xcb"=>0x6a11,
    "\x8f\xaf\xcc"=>0x6a1a,
    "\x8f\xaf\xcd"=>0x6a1d,
    "\x8f\xaf\xce"=>0x2371c,
    "\x8f\xaf\xcf"=>0x6a32,
    "\x8f\xaf\xd0"=>0x6a33,
    "\x8f\xaf\xd1"=>0x6a34,
    "\x8f\xaf\xd2"=>0x6a3f,
    "\x8f\xaf\xd3"=>0x6a46,
    "\x8f\xaf\xd4"=>0x6a49,
    "\x8f\xaf\xd5"=>0x6a7a,
    "\x8f\xaf\xd6"=>0x6a4e,
    "\x8f\xaf\xd7"=>0x6a52,
    "\x8f\xaf\xd8"=>0x6a64,
    "\x8f\xaf\xd9"=>0x2370c,
    "\x8f\xaf\xda"=>0x6a7e,
    "\x8f\xaf\xdb"=>0x6a83,
    "\x8f\xaf\xdc"=>0x6a8b,
    "\x8f\xaf\xdd"=>0x3bf0,
    "\x8f\xaf\xde"=>0x6a91,
    "\x8f\xaf\xdf"=>0x6a9f,
    "\x8f\xaf\xe0"=>0x6aa1,
    "\x8f\xaf\xe1"=>0x23764,
    "\x8f\xaf\xe2"=>0x6aab,
    "\x8f\xaf\xe3"=>0x6abd,
    "\x8f\xaf\xe4"=>0x6ac6,
    "\x8f\xaf\xe5"=>0x6ad4,
    "\x8f\xaf\xe6"=>0x6ad0,
    "\x8f\xaf\xe7"=>0x6adc,
    "\x8f\xaf\xe8"=>0x6add,
    "\x8f\xaf\xe9"=>0x237ff,
    "\x8f\xaf\xea"=>0x237e7,
    "\x8f\xaf\xeb"=>0x6aec,
    "\x8f\xaf\xec"=>0x6af1,
    "\x8f\xaf\xed"=>0x6af2,
    "\x8f\xaf\xee"=>0x6af3,
    "\x8f\xaf\xef"=>0x6afd,
    "\x8f\xaf\xf0"=>0x23824,
    "\x8f\xaf\xf1"=>0x6b0b,
    "\x8f\xaf\xf2"=>0x6b0f,
    "\x8f\xaf\xf3"=>0x6b10,
    "\x8f\xaf\xf4"=>0x6b11,
    "\x8f\xaf\xf5"=>0x2383d,
    "\x8f\xaf\xf6"=>0x6b17,
    "\x8f\xaf\xf7"=>0x3c26,
    "\x8f\xaf\xf8"=>0x6b2f,
    "\x8f\xaf\xf9"=>0x6b4a,
    "\x8f\xaf\xfa"=>0x6b58,
    "\x8f\xaf\xfb"=>0x6b6c,
    "\x8f\xaf\xfc"=>0x6b75,
    "\x8f\xaf\xfd"=>0x6b7a,
    "\x8f\xaf\xfe"=>0x6b81,
    "\x8f\xb0\xa1"=>0,
    "\x8f\xb0\xa2"=>0,
    "\x8f\xb0\xa3"=>0,
    "\x8f\xb0\xa4"=>0,
    "\x8f\xb0\xa5"=>0,
    "\x8f\xb0\xa6"=>0,
    "\x8f\xb0\xa7"=>0,
    "\x8f\xb0\xa8"=>0,
    "\x8f\xb0\xa9"=>0,
    "\x8f\xb0\xaa"=>0,
    "\x8f\xb0\xab"=>0,
    "\x8f\xb0\xac"=>0,
    "\x8f\xb0\xad"=>0,
    "\x8f\xb0\xae"=>0,
    "\x8f\xb0\xaf"=>0,
    "\x8f\xb0\xb0"=>0,
    "\x8f\xb0\xb1"=>0,
    "\x8f\xb0\xb2"=>0,
    "\x8f\xb0\xb3"=>0,
    "\x8f\xb0\xb4"=>0,
    "\x8f\xb0\xb5"=>0,
    "\x8f\xb0\xb6"=>0,
    "\x8f\xb0\xb7"=>0,
    "\x8f\xb0\xb8"=>0,
    "\x8f\xb0\xb9"=>0,
    "\x8f\xb0\xba"=>0,
    "\x8f\xb0\xbb"=>0,
    "\x8f\xb0\xbc"=>0,
    "\x8f\xb0\xbd"=>0,
    "\x8f\xb0\xbe"=>0,
    "\x8f\xb0\xbf"=>0,
    "\x8f\xb0\xc0"=>0,
    "\x8f\xb0\xc1"=>0,
    "\x8f\xb0\xc2"=>0,
    "\x8f\xb0\xc3"=>0,
    "\x8f\xb0\xc4"=>0,
    "\x8f\xb0\xc5"=>0,
    "\x8f\xb0\xc6"=>0,
    "\x8f\xb0\xc7"=>0,
    "\x8f\xb0\xc8"=>0,
    "\x8f\xb0\xc9"=>0,
    "\x8f\xb0\xca"=>0,
    "\x8f\xb0\xcb"=>0,
    "\x8f\xb0\xcc"=>0,
    "\x8f\xb0\xcd"=>0,
    "\x8f\xb0\xce"=>0,
    "\x8f\xb0\xcf"=>0,
    "\x8f\xb0\xd0"=>0,
    "\x8f\xb0\xd1"=>0,
    "\x8f\xb0\xd2"=>0,
    "\x8f\xb0\xd3"=>0,
    "\x8f\xb0\xd4"=>0,
    "\x8f\xb0\xd5"=>0,
    "\x8f\xb0\xd6"=>0,
    "\x8f\xb0\xd7"=>0,
    "\x8f\xb0\xd8"=>0,
    "\x8f\xb0\xd9"=>0,
    "\x8f\xb0\xda"=>0,
    "\x8f\xb0\xdb"=>0,
    "\x8f\xb0\xdc"=>0,
    "\x8f\xb0\xdd"=>0,
    "\x8f\xb0\xde"=>0,
    "\x8f\xb0\xdf"=>0,
    "\x8f\xb0\xe0"=>0,
    "\x8f\xb0\xe1"=>0,
    "\x8f\xb0\xe2"=>0,
    "\x8f\xb0\xe3"=>0,
    "\x8f\xb0\xe4"=>0,
    "\x8f\xb0\xe5"=>0,
    "\x8f\xb0\xe6"=>0,
    "\x8f\xb0\xe7"=>0,
    "\x8f\xb0\xe8"=>0,
    "\x8f\xb0\xe9"=>0,
    "\x8f\xb0\xea"=>0,
    "\x8f\xb0\xeb"=>0,
    "\x8f\xb0\xec"=>0,
    "\x8f\xb0\xed"=>0,
    "\x8f\xb0\xee"=>0,
    "\x8f\xb0\xef"=>0,
    "\x8f\xb0\xf0"=>0,
    "\x8f\xb0\xf1"=>0,
    "\x8f\xb0\xf2"=>0,
    "\x8f\xb0\xf3"=>0,
    "\x8f\xb0\xf4"=>0,
    "\x8f\xb0\xf5"=>0,
    "\x8f\xb0\xf6"=>0,
    "\x8f\xb0\xf7"=>0,
    "\x8f\xb0\xf8"=>0,
    "\x8f\xb0\xf9"=>0,
    "\x8f\xb0\xfa"=>0,
    "\x8f\xb0\xfb"=>0,
    "\x8f\xb0\xfc"=>0,
    "\x8f\xb0\xfd"=>0,
    "\x8f\xb0\xfe"=>0,
    "\x8f\xb1\xa1"=>0,
    "\x8f\xb1\xa2"=>0,
    "\x8f\xb1\xa3"=>0,
    "\x8f\xb1\xa4"=>0,
    "\x8f\xb1\xa5"=>0,
    "\x8f\xb1\xa6"=>0,
    "\x8f\xb1\xa7"=>0,
    "\x8f\xb1\xa8"=>0,
    "\x8f\xb1\xa9"=>0,
    "\x8f\xb1\xaa"=>0,
    "\x8f\xb1\xab"=>0,
    "\x8f\xb1\xac"=>0,
    "\x8f\xb1\xad"=>0,
    "\x8f\xb1\xae"=>0,
    "\x8f\xb1\xaf"=>0,
    "\x8f\xb1\xb0"=>0,
    "\x8f\xb1\xb1"=>0,
    "\x8f\xb1\xb2"=>0,
    "\x8f\xb1\xb3"=>0,
    "\x8f\xb1\xb4"=>0,
    "\x8f\xb1\xb5"=>0,
    "\x8f\xb1\xb6"=>0,
    "\x8f\xb1\xb7"=>0,
    "\x8f\xb1\xb8"=>0,
    "\x8f\xb1\xb9"=>0,
    "\x8f\xb1\xba"=>0,
    "\x8f\xb1\xbb"=>0,
    "\x8f\xb1\xbc"=>0,
    "\x8f\xb1\xbd"=>0,
    "\x8f\xb1\xbe"=>0,
    "\x8f\xb1\xbf"=>0,
    "\x8f\xb1\xc0"=>0,
    "\x8f\xb1\xc1"=>0,
    "\x8f\xb1\xc2"=>0,
    "\x8f\xb1\xc3"=>0,
    "\x8f\xb1\xc4"=>0,
    "\x8f\xb1\xc5"=>0,
    "\x8f\xb1\xc6"=>0,
    "\x8f\xb1\xc7"=>0,
    "\x8f\xb1\xc8"=>0,
    "\x8f\xb1\xc9"=>0,
    "\x8f\xb1\xca"=>0,
    "\x8f\xb1\xcb"=>0,
    "\x8f\xb1\xcc"=>0,
    "\x8f\xb1\xcd"=>0,
    "\x8f\xb1\xce"=>0,
    "\x8f\xb1\xcf"=>0,
    "\x8f\xb1\xd0"=>0,
    "\x8f\xb1\xd1"=>0,
    "\x8f\xb1\xd2"=>0,
    "\x8f\xb1\xd3"=>0,
    "\x8f\xb1\xd4"=>0,
    "\x8f\xb1\xd5"=>0,
    "\x8f\xb1\xd6"=>0,
    "\x8f\xb1\xd7"=>0,
    "\x8f\xb1\xd8"=>0,
    "\x8f\xb1\xd9"=>0,
    "\x8f\xb1\xda"=>0,
    "\x8f\xb1\xdb"=>0,
    "\x8f\xb1\xdc"=>0,
    "\x8f\xb1\xdd"=>0,
    "\x8f\xb1\xde"=>0,
    "\x8f\xb1\xdf"=>0,
    "\x8f\xb1\xe0"=>0,
    "\x8f\xb1\xe1"=>0,
    "\x8f\xb1\xe2"=>0,
    "\x8f\xb1\xe3"=>0,
    "\x8f\xb1\xe4"=>0,
    "\x8f\xb1\xe5"=>0,
    "\x8f\xb1\xe6"=>0,
    "\x8f\xb1\xe7"=>0,
    "\x8f\xb1\xe8"=>0,
    "\x8f\xb1\xe9"=>0,
    "\x8f\xb1\xea"=>0,
    "\x8f\xb1\xeb"=>0,
    "\x8f\xb1\xec"=>0,
    "\x8f\xb1\xed"=>0,
    "\x8f\xb1\xee"=>0,
    "\x8f\xb1\xef"=>0,
    "\x8f\xb1\xf0"=>0,
    "\x8f\xb1\xf1"=>0,
    "\x8f\xb1\xf2"=>0,
    "\x8f\xb1\xf3"=>0,
    "\x8f\xb1\xf4"=>0,
    "\x8f\xb1\xf5"=>0,
    "\x8f\xb1\xf6"=>0,
    "\x8f\xb1\xf7"=>0,
    "\x8f\xb1\xf8"=>0,
    "\x8f\xb1\xf9"=>0,
    "\x8f\xb1\xfa"=>0,
    "\x8f\xb1\xfb"=>0,
    "\x8f\xb1\xfc"=>0,
    "\x8f\xb1\xfd"=>0,
    "\x8f\xb1\xfe"=>0,
    "\x8f\xb2\xa1"=>0,
    "\x8f\xb2\xa2"=>0,
    "\x8f\xb2\xa3"=>0,
    "\x8f\xb2\xa4"=>0,
    "\x8f\xb2\xa5"=>0,
    "\x8f\xb2\xa6"=>0,
    "\x8f\xb2\xa7"=>0,
    "\x8f\xb2\xa8"=>0,
    "\x8f\xb2\xa9"=>0,
    "\x8f\xb2\xaa"=>0,
    "\x8f\xb2\xab"=>0,
    "\x8f\xb2\xac"=>0,
    "\x8f\xb2\xad"=>0,
    "\x8f\xb2\xae"=>0,
    "\x8f\xb2\xaf"=>0,
    "\x8f\xb2\xb0"=>0,
    "\x8f\xb2\xb1"=>0,
    "\x8f\xb2\xb2"=>0,
    "\x8f\xb2\xb3"=>0,
    "\x8f\xb2\xb4"=>0,
    "\x8f\xb2\xb5"=>0,
    "\x8f\xb2\xb6"=>0,
    "\x8f\xb2\xb7"=>0,
    "\x8f\xb2\xb8"=>0,
    "\x8f\xb2\xb9"=>0,
    "\x8f\xb2\xba"=>0,
    "\x8f\xb2\xbb"=>0,
    "\x8f\xb2\xbc"=>0,
    "\x8f\xb2\xbd"=>0,
    "\x8f\xb2\xbe"=>0,
    "\x8f\xb2\xbf"=>0,
    "\x8f\xb2\xc0"=>0,
    "\x8f\xb2\xc1"=>0,
    "\x8f\xb2\xc2"=>0,
    "\x8f\xb2\xc3"=>0,
    "\x8f\xb2\xc4"=>0,
    "\x8f\xb2\xc5"=>0,
    "\x8f\xb2\xc6"=>0,
    "\x8f\xb2\xc7"=>0,
    "\x8f\xb2\xc8"=>0,
    "\x8f\xb2\xc9"=>0,
    "\x8f\xb2\xca"=>0,
    "\x8f\xb2\xcb"=>0,
    "\x8f\xb2\xcc"=>0,
    "\x8f\xb2\xcd"=>0,
    "\x8f\xb2\xce"=>0,
    "\x8f\xb2\xcf"=>0,
    "\x8f\xb2\xd0"=>0,
    "\x8f\xb2\xd1"=>0,
    "\x8f\xb2\xd2"=>0,
    "\x8f\xb2\xd3"=>0,
    "\x8f\xb2\xd4"=>0,
    "\x8f\xb2\xd5"=>0,
    "\x8f\xb2\xd6"=>0,
    "\x8f\xb2\xd7"=>0,
    "\x8f\xb2\xd8"=>0,
    "\x8f\xb2\xd9"=>0,
    "\x8f\xb2\xda"=>0,
    "\x8f\xb2\xdb"=>0,
    "\x8f\xb2\xdc"=>0,
    "\x8f\xb2\xdd"=>0,
    "\x8f\xb2\xde"=>0,
    "\x8f\xb2\xdf"=>0,
    "\x8f\xb2\xe0"=>0,
    "\x8f\xb2\xe1"=>0,
    "\x8f\xb2\xe2"=>0,
    "\x8f\xb2\xe3"=>0,
    "\x8f\xb2\xe4"=>0,
    "\x8f\xb2\xe5"=>0,
    "\x8f\xb2\xe6"=>0,
    "\x8f\xb2\xe7"=>0,
    "\x8f\xb2\xe8"=>0,
    "\x8f\xb2\xe9"=>0,
    "\x8f\xb2\xea"=>0,
    "\x8f\xb2\xeb"=>0,
    "\x8f\xb2\xec"=>0,
    "\x8f\xb2\xed"=>0,
    "\x8f\xb2\xee"=>0,
    "\x8f\xb2\xef"=>0,
    "\x8f\xb2\xf0"=>0,
    "\x8f\xb2\xf1"=>0,
    "\x8f\xb2\xf2"=>0,
    "\x8f\xb2\xf3"=>0,
    "\x8f\xb2\xf4"=>0,
    "\x8f\xb2\xf5"=>0,
    "\x8f\xb2\xf6"=>0,
    "\x8f\xb2\xf7"=>0,
    "\x8f\xb2\xf8"=>0,
    "\x8f\xb2\xf9"=>0,
    "\x8f\xb2\xfa"=>0,
    "\x8f\xb2\xfb"=>0,
    "\x8f\xb2\xfc"=>0,
    "\x8f\xb2\xfd"=>0,
    "\x8f\xb2\xfe"=>0,
    "\x8f\xb3\xa1"=>0,
    "\x8f\xb3\xa2"=>0,
    "\x8f\xb3\xa3"=>0,
    "\x8f\xb3\xa4"=>0,
    "\x8f\xb3\xa5"=>0,
    "\x8f\xb3\xa6"=>0,
    "\x8f\xb3\xa7"=>0,
    "\x8f\xb3\xa8"=>0,
    "\x8f\xb3\xa9"=>0,
    "\x8f\xb3\xaa"=>0,
    "\x8f\xb3\xab"=>0,
    "\x8f\xb3\xac"=>0,
    "\x8f\xb3\xad"=>0,
    "\x8f\xb3\xae"=>0,
    "\x8f\xb3\xaf"=>0,
    "\x8f\xb3\xb0"=>0,
    "\x8f\xb3\xb1"=>0,
    "\x8f\xb3\xb2"=>0,
    "\x8f\xb3\xb3"=>0,
    "\x8f\xb3\xb4"=>0,
    "\x8f\xb3\xb5"=>0,
    "\x8f\xb3\xb6"=>0,
    "\x8f\xb3\xb7"=>0,
    "\x8f\xb3\xb8"=>0,
    "\x8f\xb3\xb9"=>0,
    "\x8f\xb3\xba"=>0,
    "\x8f\xb3\xbb"=>0,
    "\x8f\xb3\xbc"=>0,
    "\x8f\xb3\xbd"=>0,
    "\x8f\xb3\xbe"=>0,
    "\x8f\xb3\xbf"=>0,
    "\x8f\xb3\xc0"=>0,
    "\x8f\xb3\xc1"=>0,
    "\x8f\xb3\xc2"=>0,
    "\x8f\xb3\xc3"=>0,
    "\x8f\xb3\xc4"=>0,
    "\x8f\xb3\xc5"=>0,
    "\x8f\xb3\xc6"=>0,
    "\x8f\xb3\xc7"=>0,
    "\x8f\xb3\xc8"=>0,
    "\x8f\xb3\xc9"=>0,
    "\x8f\xb3\xca"=>0,
    "\x8f\xb3\xcb"=>0,
    "\x8f\xb3\xcc"=>0,
    "\x8f\xb3\xcd"=>0,
    "\x8f\xb3\xce"=>0,
    "\x8f\xb3\xcf"=>0,
    "\x8f\xb3\xd0"=>0,
    "\x8f\xb3\xd1"=>0,
    "\x8f\xb3\xd2"=>0,
    "\x8f\xb3\xd3"=>0,
    "\x8f\xb3\xd4"=>0,
    "\x8f\xb3\xd5"=>0,
    "\x8f\xb3\xd6"=>0,
    "\x8f\xb3\xd7"=>0,
    "\x8f\xb3\xd8"=>0,
    "\x8f\xb3\xd9"=>0,
    "\x8f\xb3\xda"=>0,
    "\x8f\xb3\xdb"=>0,
    "\x8f\xb3\xdc"=>0,
    "\x8f\xb3\xdd"=>0,
    "\x8f\xb3\xde"=>0,
    "\x8f\xb3\xdf"=>0,
    "\x8f\xb3\xe0"=>0,
    "\x8f\xb3\xe1"=>0,
    "\x8f\xb3\xe2"=>0,
    "\x8f\xb3\xe3"=>0,
    "\x8f\xb3\xe4"=>0,
    "\x8f\xb3\xe5"=>0,
    "\x8f\xb3\xe6"=>0,
    "\x8f\xb3\xe7"=>0,
    "\x8f\xb3\xe8"=>0,
    "\x8f\xb3\xe9"=>0,
    "\x8f\xb3\xea"=>0,
    "\x8f\xb3\xeb"=>0,
    "\x8f\xb3\xec"=>0,
    "\x8f\xb3\xed"=>0,
    "\x8f\xb3\xee"=>0,
    "\x8f\xb3\xef"=>0,
    "\x8f\xb3\xf0"=>0,
    "\x8f\xb3\xf1"=>0,
    "\x8f\xb3\xf2"=>0,
    "\x8f\xb3\xf3"=>0,
    "\x8f\xb3\xf4"=>0,
    "\x8f\xb3\xf5"=>0,
    "\x8f\xb3\xf6"=>0,
    "\x8f\xb3\xf7"=>0,
    "\x8f\xb3\xf8"=>0,
    "\x8f\xb3\xf9"=>0,
    "\x8f\xb3\xfa"=>0,
    "\x8f\xb3\xfb"=>0,
    "\x8f\xb3\xfc"=>0,
    "\x8f\xb3\xfd"=>0,
    "\x8f\xb3\xfe"=>0,
    "\x8f\xb4\xa1"=>0,
    "\x8f\xb4\xa2"=>0,
    "\x8f\xb4\xa3"=>0,
    "\x8f\xb4\xa4"=>0,
    "\x8f\xb4\xa5"=>0,
    "\x8f\xb4\xa6"=>0,
    "\x8f\xb4\xa7"=>0,
    "\x8f\xb4\xa8"=>0,
    "\x8f\xb4\xa9"=>0,
    "\x8f\xb4\xaa"=>0,
    "\x8f\xb4\xab"=>0,
    "\x8f\xb4\xac"=>0,
    "\x8f\xb4\xad"=>0,
    "\x8f\xb4\xae"=>0,
    "\x8f\xb4\xaf"=>0,
    "\x8f\xb4\xb0"=>0,
    "\x8f\xb4\xb1"=>0,
    "\x8f\xb4\xb2"=>0,
    "\x8f\xb4\xb3"=>0,
    "\x8f\xb4\xb4"=>0,
    "\x8f\xb4\xb5"=>0,
    "\x8f\xb4\xb6"=>0,
    "\x8f\xb4\xb7"=>0,
    "\x8f\xb4\xb8"=>0,
    "\x8f\xb4\xb9"=>0,
    "\x8f\xb4\xba"=>0,
    "\x8f\xb4\xbb"=>0,
    "\x8f\xb4\xbc"=>0,
    "\x8f\xb4\xbd"=>0,
    "\x8f\xb4\xbe"=>0,
    "\x8f\xb4\xbf"=>0,
    "\x8f\xb4\xc0"=>0,
    "\x8f\xb4\xc1"=>0,
    "\x8f\xb4\xc2"=>0,
    "\x8f\xb4\xc3"=>0,
    "\x8f\xb4\xc4"=>0,
    "\x8f\xb4\xc5"=>0,
    "\x8f\xb4\xc6"=>0,
    "\x8f\xb4\xc7"=>0,
    "\x8f\xb4\xc8"=>0,
    "\x8f\xb4\xc9"=>0,
    "\x8f\xb4\xca"=>0,
    "\x8f\xb4\xcb"=>0,
    "\x8f\xb4\xcc"=>0,
    "\x8f\xb4\xcd"=>0,
    "\x8f\xb4\xce"=>0,
    "\x8f\xb4\xcf"=>0,
    "\x8f\xb4\xd0"=>0,
    "\x8f\xb4\xd1"=>0,
    "\x8f\xb4\xd2"=>0,
    "\x8f\xb4\xd3"=>0,
    "\x8f\xb4\xd4"=>0,
    "\x8f\xb4\xd5"=>0,
    "\x8f\xb4\xd6"=>0,
    "\x8f\xb4\xd7"=>0,
    "\x8f\xb4\xd8"=>0,
    "\x8f\xb4\xd9"=>0,
    "\x8f\xb4\xda"=>0,
    "\x8f\xb4\xdb"=>0,
    "\x8f\xb4\xdc"=>0,
    "\x8f\xb4\xdd"=>0,
    "\x8f\xb4\xde"=>0,
    "\x8f\xb4\xdf"=>0,
    "\x8f\xb4\xe0"=>0,
    "\x8f\xb4\xe1"=>0,
    "\x8f\xb4\xe2"=>0,
    "\x8f\xb4\xe3"=>0,
    "\x8f\xb4\xe4"=>0,
    "\x8f\xb4\xe5"=>0,
    "\x8f\xb4\xe6"=>0,
    "\x8f\xb4\xe7"=>0,
    "\x8f\xb4\xe8"=>0,
    "\x8f\xb4\xe9"=>0,
    "\x8f\xb4\xea"=>0,
    "\x8f\xb4\xeb"=>0,
    "\x8f\xb4\xec"=>0,
    "\x8f\xb4\xed"=>0,
    "\x8f\xb4\xee"=>0,
    "\x8f\xb4\xef"=>0,
    "\x8f\xb4\xf0"=>0,
    "\x8f\xb4\xf1"=>0,
    "\x8f\xb4\xf2"=>0,
    "\x8f\xb4\xf3"=>0,
    "\x8f\xb4\xf4"=>0,
    "\x8f\xb4\xf5"=>0,
    "\x8f\xb4\xf6"=>0,
    "\x8f\xb4\xf7"=>0,
    "\x8f\xb4\xf8"=>0,
    "\x8f\xb4\xf9"=>0,
    "\x8f\xb4\xfa"=>0,
    "\x8f\xb4\xfb"=>0,
    "\x8f\xb4\xfc"=>0,
    "\x8f\xb4\xfd"=>0,
    "\x8f\xb4\xfe"=>0,
    "\x8f\xb5\xa1"=>0,
    "\x8f\xb5\xa2"=>0,
    "\x8f\xb5\xa3"=>0,
    "\x8f\xb5\xa4"=>0,
    "\x8f\xb5\xa5"=>0,
    "\x8f\xb5\xa6"=>0,
    "\x8f\xb5\xa7"=>0,
    "\x8f\xb5\xa8"=>0,
    "\x8f\xb5\xa9"=>0,
    "\x8f\xb5\xaa"=>0,
    "\x8f\xb5\xab"=>0,
    "\x8f\xb5\xac"=>0,
    "\x8f\xb5\xad"=>0,
    "\x8f\xb5\xae"=>0,
    "\x8f\xb5\xaf"=>0,
    "\x8f\xb5\xb0"=>0,
    "\x8f\xb5\xb1"=>0,
    "\x8f\xb5\xb2"=>0,
    "\x8f\xb5\xb3"=>0,
    "\x8f\xb5\xb4"=>0,
    "\x8f\xb5\xb5"=>0,
    "\x8f\xb5\xb6"=>0,
    "\x8f\xb5\xb7"=>0,
    "\x8f\xb5\xb8"=>0,
    "\x8f\xb5\xb9"=>0,
    "\x8f\xb5\xba"=>0,
    "\x8f\xb5\xbb"=>0,
    "\x8f\xb5\xbc"=>0,
    "\x8f\xb5\xbd"=>0,
    "\x8f\xb5\xbe"=>0,
    "\x8f\xb5\xbf"=>0,
    "\x8f\xb5\xc0"=>0,
    "\x8f\xb5\xc1"=>0,
    "\x8f\xb5\xc2"=>0,
    "\x8f\xb5\xc3"=>0,
    "\x8f\xb5\xc4"=>0,
    "\x8f\xb5\xc5"=>0,
    "\x8f\xb5\xc6"=>0,
    "\x8f\xb5\xc7"=>0,
    "\x8f\xb5\xc8"=>0,
    "\x8f\xb5\xc9"=>0,
    "\x8f\xb5\xca"=>0,
    "\x8f\xb5\xcb"=>0,
    "\x8f\xb5\xcc"=>0,
    "\x8f\xb5\xcd"=>0,
    "\x8f\xb5\xce"=>0,
    "\x8f\xb5\xcf"=>0,
    "\x8f\xb5\xd0"=>0,
    "\x8f\xb5\xd1"=>0,
    "\x8f\xb5\xd2"=>0,
    "\x8f\xb5\xd3"=>0,
    "\x8f\xb5\xd4"=>0,
    "\x8f\xb5\xd5"=>0,
    "\x8f\xb5\xd6"=>0,
    "\x8f\xb5\xd7"=>0,
    "\x8f\xb5\xd8"=>0,
    "\x8f\xb5\xd9"=>0,
    "\x8f\xb5\xda"=>0,
    "\x8f\xb5\xdb"=>0,
    "\x8f\xb5\xdc"=>0,
    "\x8f\xb5\xdd"=>0,
    "\x8f\xb5\xde"=>0,
    "\x8f\xb5\xdf"=>0,
    "\x8f\xb5\xe0"=>0,
    "\x8f\xb5\xe1"=>0,
    "\x8f\xb5\xe2"=>0,
    "\x8f\xb5\xe3"=>0,
    "\x8f\xb5\xe4"=>0,
    "\x8f\xb5\xe5"=>0,
    "\x8f\xb5\xe6"=>0,
    "\x8f\xb5\xe7"=>0,
    "\x8f\xb5\xe8"=>0,
    "\x8f\xb5\xe9"=>0,
    "\x8f\xb5\xea"=>0,
    "\x8f\xb5\xeb"=>0,
    "\x8f\xb5\xec"=>0,
    "\x8f\xb5\xed"=>0,
    "\x8f\xb5\xee"=>0,
    "\x8f\xb5\xef"=>0,
    "\x8f\xb5\xf0"=>0,
    "\x8f\xb5\xf1"=>0,
    "\x8f\xb5\xf2"=>0,
    "\x8f\xb5\xf3"=>0,
    "\x8f\xb5\xf4"=>0,
    "\x8f\xb5\xf5"=>0,
    "\x8f\xb5\xf6"=>0,
    "\x8f\xb5\xf7"=>0,
    "\x8f\xb5\xf8"=>0,
    "\x8f\xb5\xf9"=>0,
    "\x8f\xb5\xfa"=>0,
    "\x8f\xb5\xfb"=>0,
    "\x8f\xb5\xfc"=>0,
    "\x8f\xb5\xfd"=>0,
    "\x8f\xb5\xfe"=>0,
    "\x8f\xb6\xa1"=>0,
    "\x8f\xb6\xa2"=>0,
    "\x8f\xb6\xa3"=>0,
    "\x8f\xb6\xa4"=>0,
    "\x8f\xb6\xa5"=>0,
    "\x8f\xb6\xa6"=>0,
    "\x8f\xb6\xa7"=>0,
    "\x8f\xb6\xa8"=>0,
    "\x8f\xb6\xa9"=>0,
    "\x8f\xb6\xaa"=>0,
    "\x8f\xb6\xab"=>0,
    "\x8f\xb6\xac"=>0,
    "\x8f\xb6\xad"=>0,
    "\x8f\xb6\xae"=>0,
    "\x8f\xb6\xaf"=>0,
    "\x8f\xb6\xb0"=>0,
    "\x8f\xb6\xb1"=>0,
    "\x8f\xb6\xb2"=>0,
    "\x8f\xb6\xb3"=>0,
    "\x8f\xb6\xb4"=>0,
    "\x8f\xb6\xb5"=>0,
    "\x8f\xb6\xb6"=>0,
    "\x8f\xb6\xb7"=>0,
    "\x8f\xb6\xb8"=>0,
    "\x8f\xb6\xb9"=>0,
    "\x8f\xb6\xba"=>0,
    "\x8f\xb6\xbb"=>0,
    "\x8f\xb6\xbc"=>0,
    "\x8f\xb6\xbd"=>0,
    "\x8f\xb6\xbe"=>0,
    "\x8f\xb6\xbf"=>0,
    "\x8f\xb6\xc0"=>0,
    "\x8f\xb6\xc1"=>0,
    "\x8f\xb6\xc2"=>0,
    "\x8f\xb6\xc3"=>0,
    "\x8f\xb6\xc4"=>0,
    "\x8f\xb6\xc5"=>0,
    "\x8f\xb6\xc6"=>0,
    "\x8f\xb6\xc7"=>0,
    "\x8f\xb6\xc8"=>0,
    "\x8f\xb6\xc9"=>0,
    "\x8f\xb6\xca"=>0,
    "\x8f\xb6\xcb"=>0,
    "\x8f\xb6\xcc"=>0,
    "\x8f\xb6\xcd"=>0,
    "\x8f\xb6\xce"=>0,
    "\x8f\xb6\xcf"=>0,
    "\x8f\xb6\xd0"=>0,
    "\x8f\xb6\xd1"=>0,
    "\x8f\xb6\xd2"=>0,
    "\x8f\xb6\xd3"=>0,
    "\x8f\xb6\xd4"=>0,
    "\x8f\xb6\xd5"=>0,
    "\x8f\xb6\xd6"=>0,
    "\x8f\xb6\xd7"=>0,
    "\x8f\xb6\xd8"=>0,
    "\x8f\xb6\xd9"=>0,
    "\x8f\xb6\xda"=>0,
    "\x8f\xb6\xdb"=>0,
    "\x8f\xb6\xdc"=>0,
    "\x8f\xb6\xdd"=>0,
    "\x8f\xb6\xde"=>0,
    "\x8f\xb6\xdf"=>0,
    "\x8f\xb6\xe0"=>0,
    "\x8f\xb6\xe1"=>0,
    "\x8f\xb6\xe2"=>0,
    "\x8f\xb6\xe3"=>0,
    "\x8f\xb6\xe4"=>0,
    "\x8f\xb6\xe5"=>0,
    "\x8f\xb6\xe6"=>0,
    "\x8f\xb6\xe7"=>0,
    "\x8f\xb6\xe8"=>0,
    "\x8f\xb6\xe9"=>0,
    "\x8f\xb6\xea"=>0,
    "\x8f\xb6\xeb"=>0,
    "\x8f\xb6\xec"=>0,
    "\x8f\xb6\xed"=>0,
    "\x8f\xb6\xee"=>0,
    "\x8f\xb6\xef"=>0,
    "\x8f\xb6\xf0"=>0,
    "\x8f\xb6\xf1"=>0,
    "\x8f\xb6\xf2"=>0,
    "\x8f\xb6\xf3"=>0,
    "\x8f\xb6\xf4"=>0,
    "\x8f\xb6\xf5"=>0,
    "\x8f\xb6\xf6"=>0,
    "\x8f\xb6\xf7"=>0,
    "\x8f\xb6\xf8"=>0,
    "\x8f\xb6\xf9"=>0,
    "\x8f\xb6\xfa"=>0,
    "\x8f\xb6\xfb"=>0,
    "\x8f\xb6\xfc"=>0,
    "\x8f\xb6\xfd"=>0,
    "\x8f\xb6\xfe"=>0,
    "\x8f\xb7\xa1"=>0,
    "\x8f\xb7\xa2"=>0,
    "\x8f\xb7\xa3"=>0,
    "\x8f\xb7\xa4"=>0,
    "\x8f\xb7\xa5"=>0,
    "\x8f\xb7\xa6"=>0,
    "\x8f\xb7\xa7"=>0,
    "\x8f\xb7\xa8"=>0,
    "\x8f\xb7\xa9"=>0,
    "\x8f\xb7\xaa"=>0,
    "\x8f\xb7\xab"=>0,
    "\x8f\xb7\xac"=>0,
    "\x8f\xb7\xad"=>0,
    "\x8f\xb7\xae"=>0,
    "\x8f\xb7\xaf"=>0,
    "\x8f\xb7\xb0"=>0,
    "\x8f\xb7\xb1"=>0,
    "\x8f\xb7\xb2"=>0,
    "\x8f\xb7\xb3"=>0,
    "\x8f\xb7\xb4"=>0,
    "\x8f\xb7\xb5"=>0,
    "\x8f\xb7\xb6"=>0,
    "\x8f\xb7\xb7"=>0,
    "\x8f\xb7\xb8"=>0,
    "\x8f\xb7\xb9"=>0,
    "\x8f\xb7\xba"=>0,
    "\x8f\xb7\xbb"=>0,
    "\x8f\xb7\xbc"=>0,
    "\x8f\xb7\xbd"=>0,
    "\x8f\xb7\xbe"=>0,
    "\x8f\xb7\xbf"=>0,
    "\x8f\xb7\xc0"=>0,
    "\x8f\xb7\xc1"=>0,
    "\x8f\xb7\xc2"=>0,
    "\x8f\xb7\xc3"=>0,
    "\x8f\xb7\xc4"=>0,
    "\x8f\xb7\xc5"=>0,
    "\x8f\xb7\xc6"=>0,
    "\x8f\xb7\xc7"=>0,
    "\x8f\xb7\xc8"=>0,
    "\x8f\xb7\xc9"=>0,
    "\x8f\xb7\xca"=>0,
    "\x8f\xb7\xcb"=>0,
    "\x8f\xb7\xcc"=>0,
    "\x8f\xb7\xcd"=>0,
    "\x8f\xb7\xce"=>0,
    "\x8f\xb7\xcf"=>0,
    "\x8f\xb7\xd0"=>0,
    "\x8f\xb7\xd1"=>0,
    "\x8f\xb7\xd2"=>0,
    "\x8f\xb7\xd3"=>0,
    "\x8f\xb7\xd4"=>0,
    "\x8f\xb7\xd5"=>0,
    "\x8f\xb7\xd6"=>0,
    "\x8f\xb7\xd7"=>0,
    "\x8f\xb7\xd8"=>0,
    "\x8f\xb7\xd9"=>0,
    "\x8f\xb7\xda"=>0,
    "\x8f\xb7\xdb"=>0,
    "\x8f\xb7\xdc"=>0,
    "\x8f\xb7\xdd"=>0,
    "\x8f\xb7\xde"=>0,
    "\x8f\xb7\xdf"=>0,
    "\x8f\xb7\xe0"=>0,
    "\x8f\xb7\xe1"=>0,
    "\x8f\xb7\xe2"=>0,
    "\x8f\xb7\xe3"=>0,
    "\x8f\xb7\xe4"=>0,
    "\x8f\xb7\xe5"=>0,
    "\x8f\xb7\xe6"=>0,
    "\x8f\xb7\xe7"=>0,
    "\x8f\xb7\xe8"=>0,
    "\x8f\xb7\xe9"=>0,
    "\x8f\xb7\xea"=>0,
    "\x8f\xb7\xeb"=>0,
    "\x8f\xb7\xec"=>0,
    "\x8f\xb7\xed"=>0,
    "\x8f\xb7\xee"=>0,
    "\x8f\xb7\xef"=>0,
    "\x8f\xb7\xf0"=>0,
    "\x8f\xb7\xf1"=>0,
    "\x8f\xb7\xf2"=>0,
    "\x8f\xb7\xf3"=>0,
    "\x8f\xb7\xf4"=>0,
    "\x8f\xb7\xf5"=>0,
    "\x8f\xb7\xf6"=>0,
    "\x8f\xb7\xf7"=>0,
    "\x8f\xb7\xf8"=>0,
    "\x8f\xb7\xf9"=>0,
    "\x8f\xb7\xfa"=>0,
    "\x8f\xb7\xfb"=>0,
    "\x8f\xb7\xfc"=>0,
    "\x8f\xb7\xfd"=>0,
    "\x8f\xb7\xfe"=>0,
    "\x8f\xb8\xa1"=>0,
    "\x8f\xb8\xa2"=>0,
    "\x8f\xb8\xa3"=>0,
    "\x8f\xb8\xa4"=>0,
    "\x8f\xb8\xa5"=>0,
    "\x8f\xb8\xa6"=>0,
    "\x8f\xb8\xa7"=>0,
    "\x8f\xb8\xa8"=>0,
    "\x8f\xb8\xa9"=>0,
    "\x8f\xb8\xaa"=>0,
    "\x8f\xb8\xab"=>0,
    "\x8f\xb8\xac"=>0,
    "\x8f\xb8\xad"=>0,
    "\x8f\xb8\xae"=>0,
    "\x8f\xb8\xaf"=>0,
    "\x8f\xb8\xb0"=>0,
    "\x8f\xb8\xb1"=>0,
    "\x8f\xb8\xb2"=>0,
    "\x8f\xb8\xb3"=>0,
    "\x8f\xb8\xb4"=>0,
    "\x8f\xb8\xb5"=>0,
    "\x8f\xb8\xb6"=>0,
    "\x8f\xb8\xb7"=>0,
    "\x8f\xb8\xb8"=>0,
    "\x8f\xb8\xb9"=>0,
    "\x8f\xb8\xba"=>0,
    "\x8f\xb8\xbb"=>0,
    "\x8f\xb8\xbc"=>0,
    "\x8f\xb8\xbd"=>0,
    "\x8f\xb8\xbe"=>0,
    "\x8f\xb8\xbf"=>0,
    "\x8f\xb8\xc0"=>0,
    "\x8f\xb8\xc1"=>0,
    "\x8f\xb8\xc2"=>0,
    "\x8f\xb8\xc3"=>0,
    "\x8f\xb8\xc4"=>0,
    "\x8f\xb8\xc5"=>0,
    "\x8f\xb8\xc6"=>0,
    "\x8f\xb8\xc7"=>0,
    "\x8f\xb8\xc8"=>0,
    "\x8f\xb8\xc9"=>0,
    "\x8f\xb8\xca"=>0,
    "\x8f\xb8\xcb"=>0,
    "\x8f\xb8\xcc"=>0,
    "\x8f\xb8\xcd"=>0,
    "\x8f\xb8\xce"=>0,
    "\x8f\xb8\xcf"=>0,
    "\x8f\xb8\xd0"=>0,
    "\x8f\xb8\xd1"=>0,
    "\x8f\xb8\xd2"=>0,
    "\x8f\xb8\xd3"=>0,
    "\x8f\xb8\xd4"=>0,
    "\x8f\xb8\xd5"=>0,
    "\x8f\xb8\xd6"=>0,
    "\x8f\xb8\xd7"=>0,
    "\x8f\xb8\xd8"=>0,
    "\x8f\xb8\xd9"=>0,
    "\x8f\xb8\xda"=>0,
    "\x8f\xb8\xdb"=>0,
    "\x8f\xb8\xdc"=>0,
    "\x8f\xb8\xdd"=>0,
    "\x8f\xb8\xde"=>0,
    "\x8f\xb8\xdf"=>0,
    "\x8f\xb8\xe0"=>0,
    "\x8f\xb8\xe1"=>0,
    "\x8f\xb8\xe2"=>0,
    "\x8f\xb8\xe3"=>0,
    "\x8f\xb8\xe4"=>0,
    "\x8f\xb8\xe5"=>0,
    "\x8f\xb8\xe6"=>0,
    "\x8f\xb8\xe7"=>0,
    "\x8f\xb8\xe8"=>0,
    "\x8f\xb8\xe9"=>0,
    "\x8f\xb8\xea"=>0,
    "\x8f\xb8\xeb"=>0,
    "\x8f\xb8\xec"=>0,
    "\x8f\xb8\xed"=>0,
    "\x8f\xb8\xee"=>0,
    "\x8f\xb8\xef"=>0,
    "\x8f\xb8\xf0"=>0,
    "\x8f\xb8\xf1"=>0,
    "\x8f\xb8\xf2"=>0,
    "\x8f\xb8\xf3"=>0,
    "\x8f\xb8\xf4"=>0,
    "\x8f\xb8\xf5"=>0,
    "\x8f\xb8\xf6"=>0,
    "\x8f\xb8\xf7"=>0,
    "\x8f\xb8\xf8"=>0,
    "\x8f\xb8\xf9"=>0,
    "\x8f\xb8\xfa"=>0,
    "\x8f\xb8\xfb"=>0,
    "\x8f\xb8\xfc"=>0,
    "\x8f\xb8\xfd"=>0,
    "\x8f\xb8\xfe"=>0,
    "\x8f\xb9\xa1"=>0,
    "\x8f\xb9\xa2"=>0,
    "\x8f\xb9\xa3"=>0,
    "\x8f\xb9\xa4"=>0,
    "\x8f\xb9\xa5"=>0,
    "\x8f\xb9\xa6"=>0,
    "\x8f\xb9\xa7"=>0,
    "\x8f\xb9\xa8"=>0,
    "\x8f\xb9\xa9"=>0,
    "\x8f\xb9\xaa"=>0,
    "\x8f\xb9\xab"=>0,
    "\x8f\xb9\xac"=>0,
    "\x8f\xb9\xad"=>0,
    "\x8f\xb9\xae"=>0,
    "\x8f\xb9\xaf"=>0,
    "\x8f\xb9\xb0"=>0,
    "\x8f\xb9\xb1"=>0,
    "\x8f\xb9\xb2"=>0,
    "\x8f\xb9\xb3"=>0,
    "\x8f\xb9\xb4"=>0,
    "\x8f\xb9\xb5"=>0,
    "\x8f\xb9\xb6"=>0,
    "\x8f\xb9\xb7"=>0,
    "\x8f\xb9\xb8"=>0,
    "\x8f\xb9\xb9"=>0,
    "\x8f\xb9\xba"=>0,
    "\x8f\xb9\xbb"=>0,
    "\x8f\xb9\xbc"=>0,
    "\x8f\xb9\xbd"=>0,
    "\x8f\xb9\xbe"=>0,
    "\x8f\xb9\xbf"=>0,
    "\x8f\xb9\xc0"=>0,
    "\x8f\xb9\xc1"=>0,
    "\x8f\xb9\xc2"=>0,
    "\x8f\xb9\xc3"=>0,
    "\x8f\xb9\xc4"=>0,
    "\x8f\xb9\xc5"=>0,
    "\x8f\xb9\xc6"=>0,
    "\x8f\xb9\xc7"=>0,
    "\x8f\xb9\xc8"=>0,
    "\x8f\xb9\xc9"=>0,
    "\x8f\xb9\xca"=>0,
    "\x8f\xb9\xcb"=>0,
    "\x8f\xb9\xcc"=>0,
    "\x8f\xb9\xcd"=>0,
    "\x8f\xb9\xce"=>0,
    "\x8f\xb9\xcf"=>0,
    "\x8f\xb9\xd0"=>0,
    "\x8f\xb9\xd1"=>0,
    "\x8f\xb9\xd2"=>0,
    "\x8f\xb9\xd3"=>0,
    "\x8f\xb9\xd4"=>0,
    "\x8f\xb9\xd5"=>0,
    "\x8f\xb9\xd6"=>0,
    "\x8f\xb9\xd7"=>0,
    "\x8f\xb9\xd8"=>0,
    "\x8f\xb9\xd9"=>0,
    "\x8f\xb9\xda"=>0,
    "\x8f\xb9\xdb"=>0,
    "\x8f\xb9\xdc"=>0,
    "\x8f\xb9\xdd"=>0,
    "\x8f\xb9\xde"=>0,
    "\x8f\xb9\xdf"=>0,
    "\x8f\xb9\xe0"=>0,
    "\x8f\xb9\xe1"=>0,
    "\x8f\xb9\xe2"=>0,
    "\x8f\xb9\xe3"=>0,
    "\x8f\xb9\xe4"=>0,
    "\x8f\xb9\xe5"=>0,
    "\x8f\xb9\xe6"=>0,
    "\x8f\xb9\xe7"=>0,
    "\x8f\xb9\xe8"=>0,
    "\x8f\xb9\xe9"=>0,
    "\x8f\xb9\xea"=>0,
    "\x8f\xb9\xeb"=>0,
    "\x8f\xb9\xec"=>0,
    "\x8f\xb9\xed"=>0,
    "\x8f\xb9\xee"=>0,
    "\x8f\xb9\xef"=>0,
    "\x8f\xb9\xf0"=>0,
    "\x8f\xb9\xf1"=>0,
    "\x8f\xb9\xf2"=>0,
    "\x8f\xb9\xf3"=>0,
    "\x8f\xb9\xf4"=>0,
    "\x8f\xb9\xf5"=>0,
    "\x8f\xb9\xf6"=>0,
    "\x8f\xb9\xf7"=>0,
    "\x8f\xb9\xf8"=>0,
    "\x8f\xb9\xf9"=>0,
    "\x8f\xb9\xfa"=>0,
    "\x8f\xb9\xfb"=>0,
    "\x8f\xb9\xfc"=>0,
    "\x8f\xb9\xfd"=>0,
    "\x8f\xb9\xfe"=>0,
    "\x8f\xba\xa1"=>0,
    "\x8f\xba\xa2"=>0,
    "\x8f\xba\xa3"=>0,
    "\x8f\xba\xa4"=>0,
    "\x8f\xba\xa5"=>0,
    "\x8f\xba\xa6"=>0,
    "\x8f\xba\xa7"=>0,
    "\x8f\xba\xa8"=>0,
    "\x8f\xba\xa9"=>0,
    "\x8f\xba\xaa"=>0,
    "\x8f\xba\xab"=>0,
    "\x8f\xba\xac"=>0,
    "\x8f\xba\xad"=>0,
    "\x8f\xba\xae"=>0,
    "\x8f\xba\xaf"=>0,
    "\x8f\xba\xb0"=>0,
    "\x8f\xba\xb1"=>0,
    "\x8f\xba\xb2"=>0,
    "\x8f\xba\xb3"=>0,
    "\x8f\xba\xb4"=>0,
    "\x8f\xba\xb5"=>0,
    "\x8f\xba\xb6"=>0,
    "\x8f\xba\xb7"=>0,
    "\x8f\xba\xb8"=>0,
    "\x8f\xba\xb9"=>0,
    "\x8f\xba\xba"=>0,
    "\x8f\xba\xbb"=>0,
    "\x8f\xba\xbc"=>0,
    "\x8f\xba\xbd"=>0,
    "\x8f\xba\xbe"=>0,
    "\x8f\xba\xbf"=>0,
    "\x8f\xba\xc0"=>0,
    "\x8f\xba\xc1"=>0,
    "\x8f\xba\xc2"=>0,
    "\x8f\xba\xc3"=>0,
    "\x8f\xba\xc4"=>0,
    "\x8f\xba\xc5"=>0,
    "\x8f\xba\xc6"=>0,
    "\x8f\xba\xc7"=>0,
    "\x8f\xba\xc8"=>0,
    "\x8f\xba\xc9"=>0,
    "\x8f\xba\xca"=>0,
    "\x8f\xba\xcb"=>0,
    "\x8f\xba\xcc"=>0,
    "\x8f\xba\xcd"=>0,
    "\x8f\xba\xce"=>0,
    "\x8f\xba\xcf"=>0,
    "\x8f\xba\xd0"=>0,
    "\x8f\xba\xd1"=>0,
    "\x8f\xba\xd2"=>0,
    "\x8f\xba\xd3"=>0,
    "\x8f\xba\xd4"=>0,
    "\x8f\xba\xd5"=>0,
    "\x8f\xba\xd6"=>0,
    "\x8f\xba\xd7"=>0,
    "\x8f\xba\xd8"=>0,
    "\x8f\xba\xd9"=>0,
    "\x8f\xba\xda"=>0,
    "\x8f\xba\xdb"=>0,
    "\x8f\xba\xdc"=>0,
    "\x8f\xba\xdd"=>0,
    "\x8f\xba\xde"=>0,
    "\x8f\xba\xdf"=>0,
    "\x8f\xba\xe0"=>0,
    "\x8f\xba\xe1"=>0,
    "\x8f\xba\xe2"=>0,
    "\x8f\xba\xe3"=>0,
    "\x8f\xba\xe4"=>0,
    "\x8f\xba\xe5"=>0,
    "\x8f\xba\xe6"=>0,
    "\x8f\xba\xe7"=>0,
    "\x8f\xba\xe8"=>0,
    "\x8f\xba\xe9"=>0,
    "\x8f\xba\xea"=>0,
    "\x8f\xba\xeb"=>0,
    "\x8f\xba\xec"=>0,
    "\x8f\xba\xed"=>0,
    "\x8f\xba\xee"=>0,
    "\x8f\xba\xef"=>0,
    "\x8f\xba\xf0"=>0,
    "\x8f\xba\xf1"=>0,
    "\x8f\xba\xf2"=>0,
    "\x8f\xba\xf3"=>0,
    "\x8f\xba\xf4"=>0,
    "\x8f\xba\xf5"=>0,
    "\x8f\xba\xf6"=>0,
    "\x8f\xba\xf7"=>0,
    "\x8f\xba\xf8"=>0,
    "\x8f\xba\xf9"=>0,
    "\x8f\xba\xfa"=>0,
    "\x8f\xba\xfb"=>0,
    "\x8f\xba\xfc"=>0,
    "\x8f\xba\xfd"=>0,
    "\x8f\xba\xfe"=>0,
    "\x8f\xbb\xa1"=>0,
    "\x8f\xbb\xa2"=>0,
    "\x8f\xbb\xa3"=>0,
    "\x8f\xbb\xa4"=>0,
    "\x8f\xbb\xa5"=>0,
    "\x8f\xbb\xa6"=>0,
    "\x8f\xbb\xa7"=>0,
    "\x8f\xbb\xa8"=>0,
    "\x8f\xbb\xa9"=>0,
    "\x8f\xbb\xaa"=>0,
    "\x8f\xbb\xab"=>0,
    "\x8f\xbb\xac"=>0,
    "\x8f\xbb\xad"=>0,
    "\x8f\xbb\xae"=>0,
    "\x8f\xbb\xaf"=>0,
    "\x8f\xbb\xb0"=>0,
    "\x8f\xbb\xb1"=>0,
    "\x8f\xbb\xb2"=>0,
    "\x8f\xbb\xb3"=>0,
    "\x8f\xbb\xb4"=>0,
    "\x8f\xbb\xb5"=>0,
    "\x8f\xbb\xb6"=>0,
    "\x8f\xbb\xb7"=>0,
    "\x8f\xbb\xb8"=>0,
    "\x8f\xbb\xb9"=>0,
    "\x8f\xbb\xba"=>0,
    "\x8f\xbb\xbb"=>0,
    "\x8f\xbb\xbc"=>0,
    "\x8f\xbb\xbd"=>0,
    "\x8f\xbb\xbe"=>0,
    "\x8f\xbb\xbf"=>0,
    "\x8f\xbb\xc0"=>0,
    "\x8f\xbb\xc1"=>0,
    "\x8f\xbb\xc2"=>0,
    "\x8f\xbb\xc3"=>0,
    "\x8f\xbb\xc4"=>0,
    "\x8f\xbb\xc5"=>0,
    "\x8f\xbb\xc6"=>0,
    "\x8f\xbb\xc7"=>0,
    "\x8f\xbb\xc8"=>0,
    "\x8f\xbb\xc9"=>0,
    "\x8f\xbb\xca"=>0,
    "\x8f\xbb\xcb"=>0,
    "\x8f\xbb\xcc"=>0,
    "\x8f\xbb\xcd"=>0,
    "\x8f\xbb\xce"=>0,
    "\x8f\xbb\xcf"=>0,
    "\x8f\xbb\xd0"=>0,
    "\x8f\xbb\xd1"=>0,
    "\x8f\xbb\xd2"=>0,
    "\x8f\xbb\xd3"=>0,
    "\x8f\xbb\xd4"=>0,
    "\x8f\xbb\xd5"=>0,
    "\x8f\xbb\xd6"=>0,
    "\x8f\xbb\xd7"=>0,
    "\x8f\xbb\xd8"=>0,
    "\x8f\xbb\xd9"=>0,
    "\x8f\xbb\xda"=>0,
    "\x8f\xbb\xdb"=>0,
    "\x8f\xbb\xdc"=>0,
    "\x8f\xbb\xdd"=>0,
    "\x8f\xbb\xde"=>0,
    "\x8f\xbb\xdf"=>0,
    "\x8f\xbb\xe0"=>0,
    "\x8f\xbb\xe1"=>0,
    "\x8f\xbb\xe2"=>0,
    "\x8f\xbb\xe3"=>0,
    "\x8f\xbb\xe4"=>0,
    "\x8f\xbb\xe5"=>0,
    "\x8f\xbb\xe6"=>0,
    "\x8f\xbb\xe7"=>0,
    "\x8f\xbb\xe8"=>0,
    "\x8f\xbb\xe9"=>0,
    "\x8f\xbb\xea"=>0,
    "\x8f\xbb\xeb"=>0,
    "\x8f\xbb\xec"=>0,
    "\x8f\xbb\xed"=>0,
    "\x8f\xbb\xee"=>0,
    "\x8f\xbb\xef"=>0,
    "\x8f\xbb\xf0"=>0,
    "\x8f\xbb\xf1"=>0,
    "\x8f\xbb\xf2"=>0,
    "\x8f\xbb\xf3"=>0,
    "\x8f\xbb\xf4"=>0,
    "\x8f\xbb\xf5"=>0,
    "\x8f\xbb\xf6"=>0,
    "\x8f\xbb\xf7"=>0,
    "\x8f\xbb\xf8"=>0,
    "\x8f\xbb\xf9"=>0,
    "\x8f\xbb\xfa"=>0,
    "\x8f\xbb\xfb"=>0,
    "\x8f\xbb\xfc"=>0,
    "\x8f\xbb\xfd"=>0,
    "\x8f\xbb\xfe"=>0,
    "\x8f\xbc\xa1"=>0,
    "\x8f\xbc\xa2"=>0,
    "\x8f\xbc\xa3"=>0,
    "\x8f\xbc\xa4"=>0,
    "\x8f\xbc\xa5"=>0,
    "\x8f\xbc\xa6"=>0,
    "\x8f\xbc\xa7"=>0,
    "\x8f\xbc\xa8"=>0,
    "\x8f\xbc\xa9"=>0,
    "\x8f\xbc\xaa"=>0,
    "\x8f\xbc\xab"=>0,
    "\x8f\xbc\xac"=>0,
    "\x8f\xbc\xad"=>0,
    "\x8f\xbc\xae"=>0,
    "\x8f\xbc\xaf"=>0,
    "\x8f\xbc\xb0"=>0,
    "\x8f\xbc\xb1"=>0,
    "\x8f\xbc\xb2"=>0,
    "\x8f\xbc\xb3"=>0,
    "\x8f\xbc\xb4"=>0,
    "\x8f\xbc\xb5"=>0,
    "\x8f\xbc\xb6"=>0,
    "\x8f\xbc\xb7"=>0,
    "\x8f\xbc\xb8"=>0,
    "\x8f\xbc\xb9"=>0,
    "\x8f\xbc\xba"=>0,
    "\x8f\xbc\xbb"=>0,
    "\x8f\xbc\xbc"=>0,
    "\x8f\xbc\xbd"=>0,
    "\x8f\xbc\xbe"=>0,
    "\x8f\xbc\xbf"=>0,
    "\x8f\xbc\xc0"=>0,
    "\x8f\xbc\xc1"=>0,
    "\x8f\xbc\xc2"=>0,
    "\x8f\xbc\xc3"=>0,
    "\x8f\xbc\xc4"=>0,
    "\x8f\xbc\xc5"=>0,
    "\x8f\xbc\xc6"=>0,
    "\x8f\xbc\xc7"=>0,
    "\x8f\xbc\xc8"=>0,
    "\x8f\xbc\xc9"=>0,
    "\x8f\xbc\xca"=>0,
    "\x8f\xbc\xcb"=>0,
    "\x8f\xbc\xcc"=>0,
    "\x8f\xbc\xcd"=>0,
    "\x8f\xbc\xce"=>0,
    "\x8f\xbc\xcf"=>0,
    "\x8f\xbc\xd0"=>0,
    "\x8f\xbc\xd1"=>0,
    "\x8f\xbc\xd2"=>0,
    "\x8f\xbc\xd3"=>0,
    "\x8f\xbc\xd4"=>0,
    "\x8f\xbc\xd5"=>0,
    "\x8f\xbc\xd6"=>0,
    "\x8f\xbc\xd7"=>0,
    "\x8f\xbc\xd8"=>0,
    "\x8f\xbc\xd9"=>0,
    "\x8f\xbc\xda"=>0,
    "\x8f\xbc\xdb"=>0,
    "\x8f\xbc\xdc"=>0,
    "\x8f\xbc\xdd"=>0,
    "\x8f\xbc\xde"=>0,
    "\x8f\xbc\xdf"=>0,
    "\x8f\xbc\xe0"=>0,
    "\x8f\xbc\xe1"=>0,
    "\x8f\xbc\xe2"=>0,
    "\x8f\xbc\xe3"=>0,
    "\x8f\xbc\xe4"=>0,
    "\x8f\xbc\xe5"=>0,
    "\x8f\xbc\xe6"=>0,
    "\x8f\xbc\xe7"=>0,
    "\x8f\xbc\xe8"=>0,
    "\x8f\xbc\xe9"=>0,
    "\x8f\xbc\xea"=>0,
    "\x8f\xbc\xeb"=>0,
    "\x8f\xbc\xec"=>0,
    "\x8f\xbc\xed"=>0,
    "\x8f\xbc\xee"=>0,
    "\x8f\xbc\xef"=>0,
    "\x8f\xbc\xf0"=>0,
    "\x8f\xbc\xf1"=>0,
    "\x8f\xbc\xf2"=>0,
    "\x8f\xbc\xf3"=>0,
    "\x8f\xbc\xf4"=>0,
    "\x8f\xbc\xf5"=>0,
    "\x8f\xbc\xf6"=>0,
    "\x8f\xbc\xf7"=>0,
    "\x8f\xbc\xf8"=>0,
    "\x8f\xbc\xf9"=>0,
    "\x8f\xbc\xfa"=>0,
    "\x8f\xbc\xfb"=>0,
    "\x8f\xbc\xfc"=>0,
    "\x8f\xbc\xfd"=>0,
    "\x8f\xbc\xfe"=>0,
    "\x8f\xbd\xa1"=>0,
    "\x8f\xbd\xa2"=>0,
    "\x8f\xbd\xa3"=>0,
    "\x8f\xbd\xa4"=>0,
    "\x8f\xbd\xa5"=>0,
    "\x8f\xbd\xa6"=>0,
    "\x8f\xbd\xa7"=>0,
    "\x8f\xbd\xa8"=>0,
    "\x8f\xbd\xa9"=>0,
    "\x8f\xbd\xaa"=>0,
    "\x8f\xbd\xab"=>0,
    "\x8f\xbd\xac"=>0,
    "\x8f\xbd\xad"=>0,
    "\x8f\xbd\xae"=>0,
    "\x8f\xbd\xaf"=>0,
    "\x8f\xbd\xb0"=>0,
    "\x8f\xbd\xb1"=>0,
    "\x8f\xbd\xb2"=>0,
    "\x8f\xbd\xb3"=>0,
    "\x8f\xbd\xb4"=>0,
    "\x8f\xbd\xb5"=>0,
    "\x8f\xbd\xb6"=>0,
    "\x8f\xbd\xb7"=>0,
    "\x8f\xbd\xb8"=>0,
    "\x8f\xbd\xb9"=>0,
    "\x8f\xbd\xba"=>0,
    "\x8f\xbd\xbb"=>0,
    "\x8f\xbd\xbc"=>0,
    "\x8f\xbd\xbd"=>0,
    "\x8f\xbd\xbe"=>0,
    "\x8f\xbd\xbf"=>0,
    "\x8f\xbd\xc0"=>0,
    "\x8f\xbd\xc1"=>0,
    "\x8f\xbd\xc2"=>0,
    "\x8f\xbd\xc3"=>0,
    "\x8f\xbd\xc4"=>0,
    "\x8f\xbd\xc5"=>0,
    "\x8f\xbd\xc6"=>0,
    "\x8f\xbd\xc7"=>0,
    "\x8f\xbd\xc8"=>0,
    "\x8f\xbd\xc9"=>0,
    "\x8f\xbd\xca"=>0,
    "\x8f\xbd\xcb"=>0,
    "\x8f\xbd\xcc"=>0,
    "\x8f\xbd\xcd"=>0,
    "\x8f\xbd\xce"=>0,
    "\x8f\xbd\xcf"=>0,
    "\x8f\xbd\xd0"=>0,
    "\x8f\xbd\xd1"=>0,
    "\x8f\xbd\xd2"=>0,
    "\x8f\xbd\xd3"=>0,
    "\x8f\xbd\xd4"=>0,
    "\x8f\xbd\xd5"=>0,
    "\x8f\xbd\xd6"=>0,
    "\x8f\xbd\xd7"=>0,
    "\x8f\xbd\xd8"=>0,
    "\x8f\xbd\xd9"=>0,
    "\x8f\xbd\xda"=>0,
    "\x8f\xbd\xdb"=>0,
    "\x8f\xbd\xdc"=>0,
    "\x8f\xbd\xdd"=>0,
    "\x8f\xbd\xde"=>0,
    "\x8f\xbd\xdf"=>0,
    "\x8f\xbd\xe0"=>0,
    "\x8f\xbd\xe1"=>0,
    "\x8f\xbd\xe2"=>0,
    "\x8f\xbd\xe3"=>0,
    "\x8f\xbd\xe4"=>0,
    "\x8f\xbd\xe5"=>0,
    "\x8f\xbd\xe6"=>0,
    "\x8f\xbd\xe7"=>0,
    "\x8f\xbd\xe8"=>0,
    "\x8f\xbd\xe9"=>0,
    "\x8f\xbd\xea"=>0,
    "\x8f\xbd\xeb"=>0,
    "\x8f\xbd\xec"=>0,
    "\x8f\xbd\xed"=>0,
    "\x8f\xbd\xee"=>0,
    "\x8f\xbd\xef"=>0,
    "\x8f\xbd\xf0"=>0,
    "\x8f\xbd\xf1"=>0,
    "\x8f\xbd\xf2"=>0,
    "\x8f\xbd\xf3"=>0,
    "\x8f\xbd\xf4"=>0,
    "\x8f\xbd\xf5"=>0,
    "\x8f\xbd\xf6"=>0,
    "\x8f\xbd\xf7"=>0,
    "\x8f\xbd\xf8"=>0,
    "\x8f\xbd\xf9"=>0,
    "\x8f\xbd\xfa"=>0,
    "\x8f\xbd\xfb"=>0,
    "\x8f\xbd\xfc"=>0,
    "\x8f\xbd\xfd"=>0,
    "\x8f\xbd\xfe"=>0,
    "\x8f\xbe\xa1"=>0,
    "\x8f\xbe\xa2"=>0,
    "\x8f\xbe\xa3"=>0,
    "\x8f\xbe\xa4"=>0,
    "\x8f\xbe\xa5"=>0,
    "\x8f\xbe\xa6"=>0,
    "\x8f\xbe\xa7"=>0,
    "\x8f\xbe\xa8"=>0,
    "\x8f\xbe\xa9"=>0,
    "\x8f\xbe\xaa"=>0,
    "\x8f\xbe\xab"=>0,
    "\x8f\xbe\xac"=>0,
    "\x8f\xbe\xad"=>0,
    "\x8f\xbe\xae"=>0,
    "\x8f\xbe\xaf"=>0,
    "\x8f\xbe\xb0"=>0,
    "\x8f\xbe\xb1"=>0,
    "\x8f\xbe\xb2"=>0,
    "\x8f\xbe\xb3"=>0,
    "\x8f\xbe\xb4"=>0,
    "\x8f\xbe\xb5"=>0,
    "\x8f\xbe\xb6"=>0,
    "\x8f\xbe\xb7"=>0,
    "\x8f\xbe\xb8"=>0,
    "\x8f\xbe\xb9"=>0,
    "\x8f\xbe\xba"=>0,
    "\x8f\xbe\xbb"=>0,
    "\x8f\xbe\xbc"=>0,
    "\x8f\xbe\xbd"=>0,
    "\x8f\xbe\xbe"=>0,
    "\x8f\xbe\xbf"=>0,
    "\x8f\xbe\xc0"=>0,
    "\x8f\xbe\xc1"=>0,
    "\x8f\xbe\xc2"=>0,
    "\x8f\xbe\xc3"=>0,
    "\x8f\xbe\xc4"=>0,
    "\x8f\xbe\xc5"=>0,
    "\x8f\xbe\xc6"=>0,
    "\x8f\xbe\xc7"=>0,
    "\x8f\xbe\xc8"=>0,
    "\x8f\xbe\xc9"=>0,
    "\x8f\xbe\xca"=>0,
    "\x8f\xbe\xcb"=>0,
    "\x8f\xbe\xcc"=>0,
    "\x8f\xbe\xcd"=>0,
    "\x8f\xbe\xce"=>0,
    "\x8f\xbe\xcf"=>0,
    "\x8f\xbe\xd0"=>0,
    "\x8f\xbe\xd1"=>0,
    "\x8f\xbe\xd2"=>0,
    "\x8f\xbe\xd3"=>0,
    "\x8f\xbe\xd4"=>0,
    "\x8f\xbe\xd5"=>0,
    "\x8f\xbe\xd6"=>0,
    "\x8f\xbe\xd7"=>0,
    "\x8f\xbe\xd8"=>0,
    "\x8f\xbe\xd9"=>0,
    "\x8f\xbe\xda"=>0,
    "\x8f\xbe\xdb"=>0,
    "\x8f\xbe\xdc"=>0,
    "\x8f\xbe\xdd"=>0,
    "\x8f\xbe\xde"=>0,
    "\x8f\xbe\xdf"=>0,
    "\x8f\xbe\xe0"=>0,
    "\x8f\xbe\xe1"=>0,
    "\x8f\xbe\xe2"=>0,
    "\x8f\xbe\xe3"=>0,
    "\x8f\xbe\xe4"=>0,
    "\x8f\xbe\xe5"=>0,
    "\x8f\xbe\xe6"=>0,
    "\x8f\xbe\xe7"=>0,
    "\x8f\xbe\xe8"=>0,
    "\x8f\xbe\xe9"=>0,
    "\x8f\xbe\xea"=>0,
    "\x8f\xbe\xeb"=>0,
    "\x8f\xbe\xec"=>0,
    "\x8f\xbe\xed"=>0,
    "\x8f\xbe\xee"=>0,
    "\x8f\xbe\xef"=>0,
    "\x8f\xbe\xf0"=>0,
    "\x8f\xbe\xf1"=>0,
    "\x8f\xbe\xf2"=>0,
    "\x8f\xbe\xf3"=>0,
    "\x8f\xbe\xf4"=>0,
    "\x8f\xbe\xf5"=>0,
    "\x8f\xbe\xf6"=>0,
    "\x8f\xbe\xf7"=>0,
    "\x8f\xbe\xf8"=>0,
    "\x8f\xbe\xf9"=>0,
    "\x8f\xbe\xfa"=>0,
    "\x8f\xbe\xfb"=>0,
    "\x8f\xbe\xfc"=>0,
    "\x8f\xbe\xfd"=>0,
    "\x8f\xbe\xfe"=>0,
    "\x8f\xbf\xa1"=>0,
    "\x8f\xbf\xa2"=>0,
    "\x8f\xbf\xa3"=>0,
    "\x8f\xbf\xa4"=>0,
    "\x8f\xbf\xa5"=>0,
    "\x8f\xbf\xa6"=>0,
    "\x8f\xbf\xa7"=>0,
    "\x8f\xbf\xa8"=>0,
    "\x8f\xbf\xa9"=>0,
    "\x8f\xbf\xaa"=>0,
    "\x8f\xbf\xab"=>0,
    "\x8f\xbf\xac"=>0,
    "\x8f\xbf\xad"=>0,
    "\x8f\xbf\xae"=>0,
    "\x8f\xbf\xaf"=>0,
    "\x8f\xbf\xb0"=>0,
    "\x8f\xbf\xb1"=>0,
    "\x8f\xbf\xb2"=>0,
    "\x8f\xbf\xb3"=>0,
    "\x8f\xbf\xb4"=>0,
    "\x8f\xbf\xb5"=>0,
    "\x8f\xbf\xb6"=>0,
    "\x8f\xbf\xb7"=>0,
    "\x8f\xbf\xb8"=>0,
    "\x8f\xbf\xb9"=>0,
    "\x8f\xbf\xba"=>0,
    "\x8f\xbf\xbb"=>0,
    "\x8f\xbf\xbc"=>0,
    "\x8f\xbf\xbd"=>0,
    "\x8f\xbf\xbe"=>0,
    "\x8f\xbf\xbf"=>0,
    "\x8f\xbf\xc0"=>0,
    "\x8f\xbf\xc1"=>0,
    "\x8f\xbf\xc2"=>0,
    "\x8f\xbf\xc3"=>0,
    "\x8f\xbf\xc4"=>0,
    "\x8f\xbf\xc5"=>0,
    "\x8f\xbf\xc6"=>0,
    "\x8f\xbf\xc7"=>0,
    "\x8f\xbf\xc8"=>0,
    "\x8f\xbf\xc9"=>0,
    "\x8f\xbf\xca"=>0,
    "\x8f\xbf\xcb"=>0,
    "\x8f\xbf\xcc"=>0,
    "\x8f\xbf\xcd"=>0,
    "\x8f\xbf\xce"=>0,
    "\x8f\xbf\xcf"=>0,
    "\x8f\xbf\xd0"=>0,
    "\x8f\xbf\xd1"=>0,
    "\x8f\xbf\xd2"=>0,
    "\x8f\xbf\xd3"=>0,
    "\x8f\xbf\xd4"=>0,
    "\x8f\xbf\xd5"=>0,
    "\x8f\xbf\xd6"=>0,
    "\x8f\xbf\xd7"=>0,
    "\x8f\xbf\xd8"=>0,
    "\x8f\xbf\xd9"=>0,
    "\x8f\xbf\xda"=>0,
    "\x8f\xbf\xdb"=>0,
    "\x8f\xbf\xdc"=>0,
    "\x8f\xbf\xdd"=>0,
    "\x8f\xbf\xde"=>0,
    "\x8f\xbf\xdf"=>0,
    "\x8f\xbf\xe0"=>0,
    "\x8f\xbf\xe1"=>0,
    "\x8f\xbf\xe2"=>0,
    "\x8f\xbf\xe3"=>0,
    "\x8f\xbf\xe4"=>0,
    "\x8f\xbf\xe5"=>0,
    "\x8f\xbf\xe6"=>0,
    "\x8f\xbf\xe7"=>0,
    "\x8f\xbf\xe8"=>0,
    "\x8f\xbf\xe9"=>0,
    "\x8f\xbf\xea"=>0,
    "\x8f\xbf\xeb"=>0,
    "\x8f\xbf\xec"=>0,
    "\x8f\xbf\xed"=>0,
    "\x8f\xbf\xee"=>0,
    "\x8f\xbf\xef"=>0,
    "\x8f\xbf\xf0"=>0,
    "\x8f\xbf\xf1"=>0,
    "\x8f\xbf\xf2"=>0,
    "\x8f\xbf\xf3"=>0,
    "\x8f\xbf\xf4"=>0,
    "\x8f\xbf\xf5"=>0,
    "\x8f\xbf\xf6"=>0,
    "\x8f\xbf\xf7"=>0,
    "\x8f\xbf\xf8"=>0,
    "\x8f\xbf\xf9"=>0,
    "\x8f\xbf\xfa"=>0,
    "\x8f\xbf\xfb"=>0,
    "\x8f\xbf\xfc"=>0,
    "\x8f\xbf\xfd"=>0,
    "\x8f\xbf\xfe"=>0,
    "\x8f\xc0\xa1"=>0,
    "\x8f\xc0\xa2"=>0,
    "\x8f\xc0\xa3"=>0,
    "\x8f\xc0\xa4"=>0,
    "\x8f\xc0\xa5"=>0,
    "\x8f\xc0\xa6"=>0,
    "\x8f\xc0\xa7"=>0,
    "\x8f\xc0\xa8"=>0,
    "\x8f\xc0\xa9"=>0,
    "\x8f\xc0\xaa"=>0,
    "\x8f\xc0\xab"=>0,
    "\x8f\xc0\xac"=>0,
    "\x8f\xc0\xad"=>0,
    "\x8f\xc0\xae"=>0,
    "\x8f\xc0\xaf"=>0,
    "\x8f\xc0\xb0"=>0,
    "\x8f\xc0\xb1"=>0,
    "\x8f\xc0\xb2"=>0,
    "\x8f\xc0\xb3"=>0,
    "\x8f\xc0\xb4"=>0,
    "\x8f\xc0\xb5"=>0,
    "\x8f\xc0\xb6"=>0,
    "\x8f\xc0\xb7"=>0,
    "\x8f\xc0\xb8"=>0,
    "\x8f\xc0\xb9"=>0,
    "\x8f\xc0\xba"=>0,
    "\x8f\xc0\xbb"=>0,
    "\x8f\xc0\xbc"=>0,
    "\x8f\xc0\xbd"=>0,
    "\x8f\xc0\xbe"=>0,
    "\x8f\xc0\xbf"=>0,
    "\x8f\xc0\xc0"=>0,
    "\x8f\xc0\xc1"=>0,
    "\x8f\xc0\xc2"=>0,
    "\x8f\xc0\xc3"=>0,
    "\x8f\xc0\xc4"=>0,
    "\x8f\xc0\xc5"=>0,
    "\x8f\xc0\xc6"=>0,
    "\x8f\xc0\xc7"=>0,
    "\x8f\xc0\xc8"=>0,
    "\x8f\xc0\xc9"=>0,
    "\x8f\xc0\xca"=>0,
    "\x8f\xc0\xcb"=>0,
    "\x8f\xc0\xcc"=>0,
    "\x8f\xc0\xcd"=>0,
    "\x8f\xc0\xce"=>0,
    "\x8f\xc0\xcf"=>0,
    "\x8f\xc0\xd0"=>0,
    "\x8f\xc0\xd1"=>0,
    "\x8f\xc0\xd2"=>0,
    "\x8f\xc0\xd3"=>0,
    "\x8f\xc0\xd4"=>0,
    "\x8f\xc0\xd5"=>0,
    "\x8f\xc0\xd6"=>0,
    "\x8f\xc0\xd7"=>0,
    "\x8f\xc0\xd8"=>0,
    "\x8f\xc0\xd9"=>0,
    "\x8f\xc0\xda"=>0,
    "\x8f\xc0\xdb"=>0,
    "\x8f\xc0\xdc"=>0,
    "\x8f\xc0\xdd"=>0,
    "\x8f\xc0\xde"=>0,
    "\x8f\xc0\xdf"=>0,
    "\x8f\xc0\xe0"=>0,
    "\x8f\xc0\xe1"=>0,
    "\x8f\xc0\xe2"=>0,
    "\x8f\xc0\xe3"=>0,
    "\x8f\xc0\xe4"=>0,
    "\x8f\xc0\xe5"=>0,
    "\x8f\xc0\xe6"=>0,
    "\x8f\xc0\xe7"=>0,
    "\x8f\xc0\xe8"=>0,
    "\x8f\xc0\xe9"=>0,
    "\x8f\xc0\xea"=>0,
    "\x8f\xc0\xeb"=>0,
    "\x8f\xc0\xec"=>0,
    "\x8f\xc0\xed"=>0,
    "\x8f\xc0\xee"=>0,
    "\x8f\xc0\xef"=>0,
    "\x8f\xc0\xf0"=>0,
    "\x8f\xc0\xf1"=>0,
    "\x8f\xc0\xf2"=>0,
    "\x8f\xc0\xf3"=>0,
    "\x8f\xc0\xf4"=>0,
    "\x8f\xc0\xf5"=>0,
    "\x8f\xc0\xf6"=>0,
    "\x8f\xc0\xf7"=>0,
    "\x8f\xc0\xf8"=>0,
    "\x8f\xc0\xf9"=>0,
    "\x8f\xc0\xfa"=>0,
    "\x8f\xc0\xfb"=>0,
    "\x8f\xc0\xfc"=>0,
    "\x8f\xc0\xfd"=>0,
    "\x8f\xc0\xfe"=>0,
    "\x8f\xc1\xa1"=>0,
    "\x8f\xc1\xa2"=>0,
    "\x8f\xc1\xa3"=>0,
    "\x8f\xc1\xa4"=>0,
    "\x8f\xc1\xa5"=>0,
    "\x8f\xc1\xa6"=>0,
    "\x8f\xc1\xa7"=>0,
    "\x8f\xc1\xa8"=>0,
    "\x8f\xc1\xa9"=>0,
    "\x8f\xc1\xaa"=>0,
    "\x8f\xc1\xab"=>0,
    "\x8f\xc1\xac"=>0,
    "\x8f\xc1\xad"=>0,
    "\x8f\xc1\xae"=>0,
    "\x8f\xc1\xaf"=>0,
    "\x8f\xc1\xb0"=>0,
    "\x8f\xc1\xb1"=>0,
    "\x8f\xc1\xb2"=>0,
    "\x8f\xc1\xb3"=>0,
    "\x8f\xc1\xb4"=>0,
    "\x8f\xc1\xb5"=>0,
    "\x8f\xc1\xb6"=>0,
    "\x8f\xc1\xb7"=>0,
    "\x8f\xc1\xb8"=>0,
    "\x8f\xc1\xb9"=>0,
    "\x8f\xc1\xba"=>0,
    "\x8f\xc1\xbb"=>0,
    "\x8f\xc1\xbc"=>0,
    "\x8f\xc1\xbd"=>0,
    "\x8f\xc1\xbe"=>0,
    "\x8f\xc1\xbf"=>0,
    "\x8f\xc1\xc0"=>0,
    "\x8f\xc1\xc1"=>0,
    "\x8f\xc1\xc2"=>0,
    "\x8f\xc1\xc3"=>0,
    "\x8f\xc1\xc4"=>0,
    "\x8f\xc1\xc5"=>0,
    "\x8f\xc1\xc6"=>0,
    "\x8f\xc1\xc7"=>0,
    "\x8f\xc1\xc8"=>0,
    "\x8f\xc1\xc9"=>0,
    "\x8f\xc1\xca"=>0,
    "\x8f\xc1\xcb"=>0,
    "\x8f\xc1\xcc"=>0,
    "\x8f\xc1\xcd"=>0,
    "\x8f\xc1\xce"=>0,
    "\x8f\xc1\xcf"=>0,
    "\x8f\xc1\xd0"=>0,
    "\x8f\xc1\xd1"=>0,
    "\x8f\xc1\xd2"=>0,
    "\x8f\xc1\xd3"=>0,
    "\x8f\xc1\xd4"=>0,
    "\x8f\xc1\xd5"=>0,
    "\x8f\xc1\xd6"=>0,
    "\x8f\xc1\xd7"=>0,
    "\x8f\xc1\xd8"=>0,
    "\x8f\xc1\xd9"=>0,
    "\x8f\xc1\xda"=>0,
    "\x8f\xc1\xdb"=>0,
    "\x8f\xc1\xdc"=>0,
    "\x8f\xc1\xdd"=>0,
    "\x8f\xc1\xde"=>0,
    "\x8f\xc1\xdf"=>0,
    "\x8f\xc1\xe0"=>0,
    "\x8f\xc1\xe1"=>0,
    "\x8f\xc1\xe2"=>0,
    "\x8f\xc1\xe3"=>0,
    "\x8f\xc1\xe4"=>0,
    "\x8f\xc1\xe5"=>0,
    "\x8f\xc1\xe6"=>0,
    "\x8f\xc1\xe7"=>0,
    "\x8f\xc1\xe8"=>0,
    "\x8f\xc1\xe9"=>0,
    "\x8f\xc1\xea"=>0,
    "\x8f\xc1\xeb"=>0,
    "\x8f\xc1\xec"=>0,
    "\x8f\xc1\xed"=>0,
    "\x8f\xc1\xee"=>0,
    "\x8f\xc1\xef"=>0,
    "\x8f\xc1\xf0"=>0,
    "\x8f\xc1\xf1"=>0,
    "\x8f\xc1\xf2"=>0,
    "\x8f\xc1\xf3"=>0,
    "\x8f\xc1\xf4"=>0,
    "\x8f\xc1\xf5"=>0,
    "\x8f\xc1\xf6"=>0,
    "\x8f\xc1\xf7"=>0,
    "\x8f\xc1\xf8"=>0,
    "\x8f\xc1\xf9"=>0,
    "\x8f\xc1\xfa"=>0,
    "\x8f\xc1\xfb"=>0,
    "\x8f\xc1\xfc"=>0,
    "\x8f\xc1\xfd"=>0,
    "\x8f\xc1\xfe"=>0,
    "\x8f\xc2\xa1"=>0,
    "\x8f\xc2\xa2"=>0,
    "\x8f\xc2\xa3"=>0,
    "\x8f\xc2\xa4"=>0,
    "\x8f\xc2\xa5"=>0,
    "\x8f\xc2\xa6"=>0,
    "\x8f\xc2\xa7"=>0,
    "\x8f\xc2\xa8"=>0,
    "\x8f\xc2\xa9"=>0,
    "\x8f\xc2\xaa"=>0,
    "\x8f\xc2\xab"=>0,
    "\x8f\xc2\xac"=>0,
    "\x8f\xc2\xad"=>0,
    "\x8f\xc2\xae"=>0,
    "\x8f\xc2\xaf"=>0,
    "\x8f\xc2\xb0"=>0,
    "\x8f\xc2\xb1"=>0,
    "\x8f\xc2\xb2"=>0,
    "\x8f\xc2\xb3"=>0,
    "\x8f\xc2\xb4"=>0,
    "\x8f\xc2\xb5"=>0,
    "\x8f\xc2\xb6"=>0,
    "\x8f\xc2\xb7"=>0,
    "\x8f\xc2\xb8"=>0,
    "\x8f\xc2\xb9"=>0,
    "\x8f\xc2\xba"=>0,
    "\x8f\xc2\xbb"=>0,
    "\x8f\xc2\xbc"=>0,
    "\x8f\xc2\xbd"=>0,
    "\x8f\xc2\xbe"=>0,
    "\x8f\xc2\xbf"=>0,
    "\x8f\xc2\xc0"=>0,
    "\x8f\xc2\xc1"=>0,
    "\x8f\xc2\xc2"=>0,
    "\x8f\xc2\xc3"=>0,
    "\x8f\xc2\xc4"=>0,
    "\x8f\xc2\xc5"=>0,
    "\x8f\xc2\xc6"=>0,
    "\x8f\xc2\xc7"=>0,
    "\x8f\xc2\xc8"=>0,
    "\x8f\xc2\xc9"=>0,
    "\x8f\xc2\xca"=>0,
    "\x8f\xc2\xcb"=>0,
    "\x8f\xc2\xcc"=>0,
    "\x8f\xc2\xcd"=>0,
    "\x8f\xc2\xce"=>0,
    "\x8f\xc2\xcf"=>0,
    "\x8f\xc2\xd0"=>0,
    "\x8f\xc2\xd1"=>0,
    "\x8f\xc2\xd2"=>0,
    "\x8f\xc2\xd3"=>0,
    "\x8f\xc2\xd4"=>0,
    "\x8f\xc2\xd5"=>0,
    "\x8f\xc2\xd6"=>0,
    "\x8f\xc2\xd7"=>0,
    "\x8f\xc2\xd8"=>0,
    "\x8f\xc2\xd9"=>0,
    "\x8f\xc2\xda"=>0,
    "\x8f\xc2\xdb"=>0,
    "\x8f\xc2\xdc"=>0,
    "\x8f\xc2\xdd"=>0,
    "\x8f\xc2\xde"=>0,
    "\x8f\xc2\xdf"=>0,
    "\x8f\xc2\xe0"=>0,
    "\x8f\xc2\xe1"=>0,
    "\x8f\xc2\xe2"=>0,
    "\x8f\xc2\xe3"=>0,
    "\x8f\xc2\xe4"=>0,
    "\x8f\xc2\xe5"=>0,
    "\x8f\xc2\xe6"=>0,
    "\x8f\xc2\xe7"=>0,
    "\x8f\xc2\xe8"=>0,
    "\x8f\xc2\xe9"=>0,
    "\x8f\xc2\xea"=>0,
    "\x8f\xc2\xeb"=>0,
    "\x8f\xc2\xec"=>0,
    "\x8f\xc2\xed"=>0,
    "\x8f\xc2\xee"=>0,
    "\x8f\xc2\xef"=>0,
    "\x8f\xc2\xf0"=>0,
    "\x8f\xc2\xf1"=>0,
    "\x8f\xc2\xf2"=>0,
    "\x8f\xc2\xf3"=>0,
    "\x8f\xc2\xf4"=>0,
    "\x8f\xc2\xf5"=>0,
    "\x8f\xc2\xf6"=>0,
    "\x8f\xc2\xf7"=>0,
    "\x8f\xc2\xf8"=>0,
    "\x8f\xc2\xf9"=>0,
    "\x8f\xc2\xfa"=>0,
    "\x8f\xc2\xfb"=>0,
    "\x8f\xc2\xfc"=>0,
    "\x8f\xc2\xfd"=>0,
    "\x8f\xc2\xfe"=>0,
    "\x8f\xc3\xa1"=>0,
    "\x8f\xc3\xa2"=>0,
    "\x8f\xc3\xa3"=>0,
    "\x8f\xc3\xa4"=>0,
    "\x8f\xc3\xa5"=>0,
    "\x8f\xc3\xa6"=>0,
    "\x8f\xc3\xa7"=>0,
    "\x8f\xc3\xa8"=>0,
    "\x8f\xc3\xa9"=>0,
    "\x8f\xc3\xaa"=>0,
    "\x8f\xc3\xab"=>0,
    "\x8f\xc3\xac"=>0,
    "\x8f\xc3\xad"=>0,
    "\x8f\xc3\xae"=>0,
    "\x8f\xc3\xaf"=>0,
    "\x8f\xc3\xb0"=>0,
    "\x8f\xc3\xb1"=>0,
    "\x8f\xc3\xb2"=>0,
    "\x8f\xc3\xb3"=>0,
    "\x8f\xc3\xb4"=>0,
    "\x8f\xc3\xb5"=>0,
    "\x8f\xc3\xb6"=>0,
    "\x8f\xc3\xb7"=>0,
    "\x8f\xc3\xb8"=>0,
    "\x8f\xc3\xb9"=>0,
    "\x8f\xc3\xba"=>0,
    "\x8f\xc3\xbb"=>0,
    "\x8f\xc3\xbc"=>0,
    "\x8f\xc3\xbd"=>0,
    "\x8f\xc3\xbe"=>0,
    "\x8f\xc3\xbf"=>0,
    "\x8f\xc3\xc0"=>0,
    "\x8f\xc3\xc1"=>0,
    "\x8f\xc3\xc2"=>0,
    "\x8f\xc3\xc3"=>0,
    "\x8f\xc3\xc4"=>0,
    "\x8f\xc3\xc5"=>0,
    "\x8f\xc3\xc6"=>0,
    "\x8f\xc3\xc7"=>0,
    "\x8f\xc3\xc8"=>0,
    "\x8f\xc3\xc9"=>0,
    "\x8f\xc3\xca"=>0,
    "\x8f\xc3\xcb"=>0,
    "\x8f\xc3\xcc"=>0,
    "\x8f\xc3\xcd"=>0,
    "\x8f\xc3\xce"=>0,
    "\x8f\xc3\xcf"=>0,
    "\x8f\xc3\xd0"=>0,
    "\x8f\xc3\xd1"=>0,
    "\x8f\xc3\xd2"=>0,
    "\x8f\xc3\xd3"=>0,
    "\x8f\xc3\xd4"=>0,
    "\x8f\xc3\xd5"=>0,
    "\x8f\xc3\xd6"=>0,
    "\x8f\xc3\xd7"=>0,
    "\x8f\xc3\xd8"=>0,
    "\x8f\xc3\xd9"=>0,
    "\x8f\xc3\xda"=>0,
    "\x8f\xc3\xdb"=>0,
    "\x8f\xc3\xdc"=>0,
    "\x8f\xc3\xdd"=>0,
    "\x8f\xc3\xde"=>0,
    "\x8f\xc3\xdf"=>0,
    "\x8f\xc3\xe0"=>0,
    "\x8f\xc3\xe1"=>0,
    "\x8f\xc3\xe2"=>0,
    "\x8f\xc3\xe3"=>0,
    "\x8f\xc3\xe4"=>0,
    "\x8f\xc3\xe5"=>0,
    "\x8f\xc3\xe6"=>0,
    "\x8f\xc3\xe7"=>0,
    "\x8f\xc3\xe8"=>0,
    "\x8f\xc3\xe9"=>0,
    "\x8f\xc3\xea"=>0,
    "\x8f\xc3\xeb"=>0,
    "\x8f\xc3\xec"=>0,
    "\x8f\xc3\xed"=>0,
    "\x8f\xc3\xee"=>0,
    "\x8f\xc3\xef"=>0,
    "\x8f\xc3\xf0"=>0,
    "\x8f\xc3\xf1"=>0,
    "\x8f\xc3\xf2"=>0,
    "\x8f\xc3\xf3"=>0,
    "\x8f\xc3\xf4"=>0,
    "\x8f\xc3\xf5"=>0,
    "\x8f\xc3\xf6"=>0,
    "\x8f\xc3\xf7"=>0,
    "\x8f\xc3\xf8"=>0,
    "\x8f\xc3\xf9"=>0,
    "\x8f\xc3\xfa"=>0,
    "\x8f\xc3\xfb"=>0,
    "\x8f\xc3\xfc"=>0,
    "\x8f\xc3\xfd"=>0,
    "\x8f\xc3\xfe"=>0,
    "\x8f\xc4\xa1"=>0,
    "\x8f\xc4\xa2"=>0,
    "\x8f\xc4\xa3"=>0,
    "\x8f\xc4\xa4"=>0,
    "\x8f\xc4\xa5"=>0,
    "\x8f\xc4\xa6"=>0,
    "\x8f\xc4\xa7"=>0,
    "\x8f\xc4\xa8"=>0,
    "\x8f\xc4\xa9"=>0,
    "\x8f\xc4\xaa"=>0,
    "\x8f\xc4\xab"=>0,
    "\x8f\xc4\xac"=>0,
    "\x8f\xc4\xad"=>0,
    "\x8f\xc4\xae"=>0,
    "\x8f\xc4\xaf"=>0,
    "\x8f\xc4\xb0"=>0,
    "\x8f\xc4\xb1"=>0,
    "\x8f\xc4\xb2"=>0,
    "\x8f\xc4\xb3"=>0,
    "\x8f\xc4\xb4"=>0,
    "\x8f\xc4\xb5"=>0,
    "\x8f\xc4\xb6"=>0,
    "\x8f\xc4\xb7"=>0,
    "\x8f\xc4\xb8"=>0,
    "\x8f\xc4\xb9"=>0,
    "\x8f\xc4\xba"=>0,
    "\x8f\xc4\xbb"=>0,
    "\x8f\xc4\xbc"=>0,
    "\x8f\xc4\xbd"=>0,
    "\x8f\xc4\xbe"=>0,
    "\x8f\xc4\xbf"=>0,
    "\x8f\xc4\xc0"=>0,
    "\x8f\xc4\xc1"=>0,
    "\x8f\xc4\xc2"=>0,
    "\x8f\xc4\xc3"=>0,
    "\x8f\xc4\xc4"=>0,
    "\x8f\xc4\xc5"=>0,
    "\x8f\xc4\xc6"=>0,
    "\x8f\xc4\xc7"=>0,
    "\x8f\xc4\xc8"=>0,
    "\x8f\xc4\xc9"=>0,
    "\x8f\xc4\xca"=>0,
    "\x8f\xc4\xcb"=>0,
    "\x8f\xc4\xcc"=>0,
    "\x8f\xc4\xcd"=>0,
    "\x8f\xc4\xce"=>0,
    "\x8f\xc4\xcf"=>0,
    "\x8f\xc4\xd0"=>0,
    "\x8f\xc4\xd1"=>0,
    "\x8f\xc4\xd2"=>0,
    "\x8f\xc4\xd3"=>0,
    "\x8f\xc4\xd4"=>0,
    "\x8f\xc4\xd5"=>0,
    "\x8f\xc4\xd6"=>0,
    "\x8f\xc4\xd7"=>0,
    "\x8f\xc4\xd8"=>0,
    "\x8f\xc4\xd9"=>0,
    "\x8f\xc4\xda"=>0,
    "\x8f\xc4\xdb"=>0,
    "\x8f\xc4\xdc"=>0,
    "\x8f\xc4\xdd"=>0,
    "\x8f\xc4\xde"=>0,
    "\x8f\xc4\xdf"=>0,
    "\x8f\xc4\xe0"=>0,
    "\x8f\xc4\xe1"=>0,
    "\x8f\xc4\xe2"=>0,
    "\x8f\xc4\xe3"=>0,
    "\x8f\xc4\xe4"=>0,
    "\x8f\xc4\xe5"=>0,
    "\x8f\xc4\xe6"=>0,
    "\x8f\xc4\xe7"=>0,
    "\x8f\xc4\xe8"=>0,
    "\x8f\xc4\xe9"=>0,
    "\x8f\xc4\xea"=>0,
    "\x8f\xc4\xeb"=>0,
    "\x8f\xc4\xec"=>0,
    "\x8f\xc4\xed"=>0,
    "\x8f\xc4\xee"=>0,
    "\x8f\xc4\xef"=>0,
    "\x8f\xc4\xf0"=>0,
    "\x8f\xc4\xf1"=>0,
    "\x8f\xc4\xf2"=>0,
    "\x8f\xc4\xf3"=>0,
    "\x8f\xc4\xf4"=>0,
    "\x8f\xc4\xf5"=>0,
    "\x8f\xc4\xf6"=>0,
    "\x8f\xc4\xf7"=>0,
    "\x8f\xc4\xf8"=>0,
    "\x8f\xc4\xf9"=>0,
    "\x8f\xc4\xfa"=>0,
    "\x8f\xc4\xfb"=>0,
    "\x8f\xc4\xfc"=>0,
    "\x8f\xc4\xfd"=>0,
    "\x8f\xc4\xfe"=>0,
    "\x8f\xc5\xa1"=>0,
    "\x8f\xc5\xa2"=>0,
    "\x8f\xc5\xa3"=>0,
    "\x8f\xc5\xa4"=>0,
    "\x8f\xc5\xa5"=>0,
    "\x8f\xc5\xa6"=>0,
    "\x8f\xc5\xa7"=>0,
    "\x8f\xc5\xa8"=>0,
    "\x8f\xc5\xa9"=>0,
    "\x8f\xc5\xaa"=>0,
    "\x8f\xc5\xab"=>0,
    "\x8f\xc5\xac"=>0,
    "\x8f\xc5\xad"=>0,
    "\x8f\xc5\xae"=>0,
    "\x8f\xc5\xaf"=>0,
    "\x8f\xc5\xb0"=>0,
    "\x8f\xc5\xb1"=>0,
    "\x8f\xc5\xb2"=>0,
    "\x8f\xc5\xb3"=>0,
    "\x8f\xc5\xb4"=>0,
    "\x8f\xc5\xb5"=>0,
    "\x8f\xc5\xb6"=>0,
    "\x8f\xc5\xb7"=>0,
    "\x8f\xc5\xb8"=>0,
    "\x8f\xc5\xb9"=>0,
    "\x8f\xc5\xba"=>0,
    "\x8f\xc5\xbb"=>0,
    "\x8f\xc5\xbc"=>0,
    "\x8f\xc5\xbd"=>0,
    "\x8f\xc5\xbe"=>0,
    "\x8f\xc5\xbf"=>0,
    "\x8f\xc5\xc0"=>0,
    "\x8f\xc5\xc1"=>0,
    "\x8f\xc5\xc2"=>0,
    "\x8f\xc5\xc3"=>0,
    "\x8f\xc5\xc4"=>0,
    "\x8f\xc5\xc5"=>0,
    "\x8f\xc5\xc6"=>0,
    "\x8f\xc5\xc7"=>0,
    "\x8f\xc5\xc8"=>0,
    "\x8f\xc5\xc9"=>0,
    "\x8f\xc5\xca"=>0,
    "\x8f\xc5\xcb"=>0,
    "\x8f\xc5\xcc"=>0,
    "\x8f\xc5\xcd"=>0,
    "\x8f\xc5\xce"=>0,
    "\x8f\xc5\xcf"=>0,
    "\x8f\xc5\xd0"=>0,
    "\x8f\xc5\xd1"=>0,
    "\x8f\xc5\xd2"=>0,
    "\x8f\xc5\xd3"=>0,
    "\x8f\xc5\xd4"=>0,
    "\x8f\xc5\xd5"=>0,
    "\x8f\xc5\xd6"=>0,
    "\x8f\xc5\xd7"=>0,
    "\x8f\xc5\xd8"=>0,
    "\x8f\xc5\xd9"=>0,
    "\x8f\xc5\xda"=>0,
    "\x8f\xc5\xdb"=>0,
    "\x8f\xc5\xdc"=>0,
    "\x8f\xc5\xdd"=>0,
    "\x8f\xc5\xde"=>0,
    "\x8f\xc5\xdf"=>0,
    "\x8f\xc5\xe0"=>0,
    "\x8f\xc5\xe1"=>0,
    "\x8f\xc5\xe2"=>0,
    "\x8f\xc5\xe3"=>0,
    "\x8f\xc5\xe4"=>0,
    "\x8f\xc5\xe5"=>0,
    "\x8f\xc5\xe6"=>0,
    "\x8f\xc5\xe7"=>0,
    "\x8f\xc5\xe8"=>0,
    "\x8f\xc5\xe9"=>0,
    "\x8f\xc5\xea"=>0,
    "\x8f\xc5\xeb"=>0,
    "\x8f\xc5\xec"=>0,
    "\x8f\xc5\xed"=>0,
    "\x8f\xc5\xee"=>0,
    "\x8f\xc5\xef"=>0,
    "\x8f\xc5\xf0"=>0,
    "\x8f\xc5\xf1"=>0,
    "\x8f\xc5\xf2"=>0,
    "\x8f\xc5\xf3"=>0,
    "\x8f\xc5\xf4"=>0,
    "\x8f\xc5\xf5"=>0,
    "\x8f\xc5\xf6"=>0,
    "\x8f\xc5\xf7"=>0,
    "\x8f\xc5\xf8"=>0,
    "\x8f\xc5\xf9"=>0,
    "\x8f\xc5\xfa"=>0,
    "\x8f\xc5\xfb"=>0,
    "\x8f\xc5\xfc"=>0,
    "\x8f\xc5\xfd"=>0,
    "\x8f\xc5\xfe"=>0,
    "\x8f\xc6\xa1"=>0,
    "\x8f\xc6\xa2"=>0,
    "\x8f\xc6\xa3"=>0,
    "\x8f\xc6\xa4"=>0,
    "\x8f\xc6\xa5"=>0,
    "\x8f\xc6\xa6"=>0,
    "\x8f\xc6\xa7"=>0,
    "\x8f\xc6\xa8"=>0,
    "\x8f\xc6\xa9"=>0,
    "\x8f\xc6\xaa"=>0,
    "\x8f\xc6\xab"=>0,
    "\x8f\xc6\xac"=>0,
    "\x8f\xc6\xad"=>0,
    "\x8f\xc6\xae"=>0,
    "\x8f\xc6\xaf"=>0,
    "\x8f\xc6\xb0"=>0,
    "\x8f\xc6\xb1"=>0,
    "\x8f\xc6\xb2"=>0,
    "\x8f\xc6\xb3"=>0,
    "\x8f\xc6\xb4"=>0,
    "\x8f\xc6\xb5"=>0,
    "\x8f\xc6\xb6"=>0,
    "\x8f\xc6\xb7"=>0,
    "\x8f\xc6\xb8"=>0,
    "\x8f\xc6\xb9"=>0,
    "\x8f\xc6\xba"=>0,
    "\x8f\xc6\xbb"=>0,
    "\x8f\xc6\xbc"=>0,
    "\x8f\xc6\xbd"=>0,
    "\x8f\xc6\xbe"=>0,
    "\x8f\xc6\xbf"=>0,
    "\x8f\xc6\xc0"=>0,
    "\x8f\xc6\xc1"=>0,
    "\x8f\xc6\xc2"=>0,
    "\x8f\xc6\xc3"=>0,
    "\x8f\xc6\xc4"=>0,
    "\x8f\xc6\xc5"=>0,
    "\x8f\xc6\xc6"=>0,
    "\x8f\xc6\xc7"=>0,
    "\x8f\xc6\xc8"=>0,
    "\x8f\xc6\xc9"=>0,
    "\x8f\xc6\xca"=>0,
    "\x8f\xc6\xcb"=>0,
    "\x8f\xc6\xcc"=>0,
    "\x8f\xc6\xcd"=>0,
    "\x8f\xc6\xce"=>0,
    "\x8f\xc6\xcf"=>0,
    "\x8f\xc6\xd0"=>0,
    "\x8f\xc6\xd1"=>0,
    "\x8f\xc6\xd2"=>0,
    "\x8f\xc6\xd3"=>0,
    "\x8f\xc6\xd4"=>0,
    "\x8f\xc6\xd5"=>0,
    "\x8f\xc6\xd6"=>0,
    "\x8f\xc6\xd7"=>0,
    "\x8f\xc6\xd8"=>0,
    "\x8f\xc6\xd9"=>0,
    "\x8f\xc6\xda"=>0,
    "\x8f\xc6\xdb"=>0,
    "\x8f\xc6\xdc"=>0,
    "\x8f\xc6\xdd"=>0,
    "\x8f\xc6\xde"=>0,
    "\x8f\xc6\xdf"=>0,
    "\x8f\xc6\xe0"=>0,
    "\x8f\xc6\xe1"=>0,
    "\x8f\xc6\xe2"=>0,
    "\x8f\xc6\xe3"=>0,
    "\x8f\xc6\xe4"=>0,
    "\x8f\xc6\xe5"=>0,
    "\x8f\xc6\xe6"=>0,
    "\x8f\xc6\xe7"=>0,
    "\x8f\xc6\xe8"=>0,
    "\x8f\xc6\xe9"=>0,
    "\x8f\xc6\xea"=>0,
    "\x8f\xc6\xeb"=>0,
    "\x8f\xc6\xec"=>0,
    "\x8f\xc6\xed"=>0,
    "\x8f\xc6\xee"=>0,
    "\x8f\xc6\xef"=>0,
    "\x8f\xc6\xf0"=>0,
    "\x8f\xc6\xf1"=>0,
    "\x8f\xc6\xf2"=>0,
    "\x8f\xc6\xf3"=>0,
    "\x8f\xc6\xf4"=>0,
    "\x8f\xc6\xf5"=>0,
    "\x8f\xc6\xf6"=>0,
    "\x8f\xc6\xf7"=>0,
    "\x8f\xc6\xf8"=>0,
    "\x8f\xc6\xf9"=>0,
    "\x8f\xc6\xfa"=>0,
    "\x8f\xc6\xfb"=>0,
    "\x8f\xc6\xfc"=>0,
    "\x8f\xc6\xfd"=>0,
    "\x8f\xc6\xfe"=>0,
    "\x8f\xc7\xa1"=>0,
    "\x8f\xc7\xa2"=>0,
    "\x8f\xc7\xa3"=>0,
    "\x8f\xc7\xa4"=>0,
    "\x8f\xc7\xa5"=>0,
    "\x8f\xc7\xa6"=>0,
    "\x8f\xc7\xa7"=>0,
    "\x8f\xc7\xa8"=>0,
    "\x8f\xc7\xa9"=>0,
    "\x8f\xc7\xaa"=>0,
    "\x8f\xc7\xab"=>0,
    "\x8f\xc7\xac"=>0,
    "\x8f\xc7\xad"=>0,
    "\x8f\xc7\xae"=>0,
    "\x8f\xc7\xaf"=>0,
    "\x8f\xc7\xb0"=>0,
    "\x8f\xc7\xb1"=>0,
    "\x8f\xc7\xb2"=>0,
    "\x8f\xc7\xb3"=>0,
    "\x8f\xc7\xb4"=>0,
    "\x8f\xc7\xb5"=>0,
    "\x8f\xc7\xb6"=>0,
    "\x8f\xc7\xb7"=>0,
    "\x8f\xc7\xb8"=>0,
    "\x8f\xc7\xb9"=>0,
    "\x8f\xc7\xba"=>0,
    "\x8f\xc7\xbb"=>0,
    "\x8f\xc7\xbc"=>0,
    "\x8f\xc7\xbd"=>0,
    "\x8f\xc7\xbe"=>0,
    "\x8f\xc7\xbf"=>0,
    "\x8f\xc7\xc0"=>0,
    "\x8f\xc7\xc1"=>0,
    "\x8f\xc7\xc2"=>0,
    "\x8f\xc7\xc3"=>0,
    "\x8f\xc7\xc4"=>0,
    "\x8f\xc7\xc5"=>0,
    "\x8f\xc7\xc6"=>0,
    "\x8f\xc7\xc7"=>0,
    "\x8f\xc7\xc8"=>0,
    "\x8f\xc7\xc9"=>0,
    "\x8f\xc7\xca"=>0,
    "\x8f\xc7\xcb"=>0,
    "\x8f\xc7\xcc"=>0,
    "\x8f\xc7\xcd"=>0,
    "\x8f\xc7\xce"=>0,
    "\x8f\xc7\xcf"=>0,
    "\x8f\xc7\xd0"=>0,
    "\x8f\xc7\xd1"=>0,
    "\x8f\xc7\xd2"=>0,
    "\x8f\xc7\xd3"=>0,
    "\x8f\xc7\xd4"=>0,
    "\x8f\xc7\xd5"=>0,
    "\x8f\xc7\xd6"=>0,
    "\x8f\xc7\xd7"=>0,
    "\x8f\xc7\xd8"=>0,
    "\x8f\xc7\xd9"=>0,
    "\x8f\xc7\xda"=>0,
    "\x8f\xc7\xdb"=>0,
    "\x8f\xc7\xdc"=>0,
    "\x8f\xc7\xdd"=>0,
    "\x8f\xc7\xde"=>0,
    "\x8f\xc7\xdf"=>0,
    "\x8f\xc7\xe0"=>0,
    "\x8f\xc7\xe1"=>0,
    "\x8f\xc7\xe2"=>0,
    "\x8f\xc7\xe3"=>0,
    "\x8f\xc7\xe4"=>0,
    "\x8f\xc7\xe5"=>0,
    "\x8f\xc7\xe6"=>0,
    "\x8f\xc7\xe7"=>0,
    "\x8f\xc7\xe8"=>0,
    "\x8f\xc7\xe9"=>0,
    "\x8f\xc7\xea"=>0,
    "\x8f\xc7\xeb"=>0,
    "\x8f\xc7\xec"=>0,
    "\x8f\xc7\xed"=>0,
    "\x8f\xc7\xee"=>0,
    "\x8f\xc7\xef"=>0,
    "\x8f\xc7\xf0"=>0,
    "\x8f\xc7\xf1"=>0,
    "\x8f\xc7\xf2"=>0,
    "\x8f\xc7\xf3"=>0,
    "\x8f\xc7\xf4"=>0,
    "\x8f\xc7\xf5"=>0,
    "\x8f\xc7\xf6"=>0,
    "\x8f\xc7\xf7"=>0,
    "\x8f\xc7\xf8"=>0,
    "\x8f\xc7\xf9"=>0,
    "\x8f\xc7\xfa"=>0,
    "\x8f\xc7\xfb"=>0,
    "\x8f\xc7\xfc"=>0,
    "\x8f\xc7\xfd"=>0,
    "\x8f\xc7\xfe"=>0,
    "\x8f\xc8\xa1"=>0,
    "\x8f\xc8\xa2"=>0,
    "\x8f\xc8\xa3"=>0,
    "\x8f\xc8\xa4"=>0,
    "\x8f\xc8\xa5"=>0,
    "\x8f\xc8\xa6"=>0,
    "\x8f\xc8\xa7"=>0,
    "\x8f\xc8\xa8"=>0,
    "\x8f\xc8\xa9"=>0,
    "\x8f\xc8\xaa"=>0,
    "\x8f\xc8\xab"=>0,
    "\x8f\xc8\xac"=>0,
    "\x8f\xc8\xad"=>0,
    "\x8f\xc8\xae"=>0,
    "\x8f\xc8\xaf"=>0,
    "\x8f\xc8\xb0"=>0,
    "\x8f\xc8\xb1"=>0,
    "\x8f\xc8\xb2"=>0,
    "\x8f\xc8\xb3"=>0,
    "\x8f\xc8\xb4"=>0,
    "\x8f\xc8\xb5"=>0,
    "\x8f\xc8\xb6"=>0,
    "\x8f\xc8\xb7"=>0,
    "\x8f\xc8\xb8"=>0,
    "\x8f\xc8\xb9"=>0,
    "\x8f\xc8\xba"=>0,
    "\x8f\xc8\xbb"=>0,
    "\x8f\xc8\xbc"=>0,
    "\x8f\xc8\xbd"=>0,
    "\x8f\xc8\xbe"=>0,
    "\x8f\xc8\xbf"=>0,
    "\x8f\xc8\xc0"=>0,
    "\x8f\xc8\xc1"=>0,
    "\x8f\xc8\xc2"=>0,
    "\x8f\xc8\xc3"=>0,
    "\x8f\xc8\xc4"=>0,
    "\x8f\xc8\xc5"=>0,
    "\x8f\xc8\xc6"=>0,
    "\x8f\xc8\xc7"=>0,
    "\x8f\xc8\xc8"=>0,
    "\x8f\xc8\xc9"=>0,
    "\x8f\xc8\xca"=>0,
    "\x8f\xc8\xcb"=>0,
    "\x8f\xc8\xcc"=>0,
    "\x8f\xc8\xcd"=>0,
    "\x8f\xc8\xce"=>0,
    "\x8f\xc8\xcf"=>0,
    "\x8f\xc8\xd0"=>0,
    "\x8f\xc8\xd1"=>0,
    "\x8f\xc8\xd2"=>0,
    "\x8f\xc8\xd3"=>0,
    "\x8f\xc8\xd4"=>0,
    "\x8f\xc8\xd5"=>0,
    "\x8f\xc8\xd6"=>0,
    "\x8f\xc8\xd7"=>0,
    "\x8f\xc8\xd8"=>0,
    "\x8f\xc8\xd9"=>0,
    "\x8f\xc8\xda"=>0,
    "\x8f\xc8\xdb"=>0,
    "\x8f\xc8\xdc"=>0,
    "\x8f\xc8\xdd"=>0,
    "\x8f\xc8\xde"=>0,
    "\x8f\xc8\xdf"=>0,
    "\x8f\xc8\xe0"=>0,
    "\x8f\xc8\xe1"=>0,
    "\x8f\xc8\xe2"=>0,
    "\x8f\xc8\xe3"=>0,
    "\x8f\xc8\xe4"=>0,
    "\x8f\xc8\xe5"=>0,
    "\x8f\xc8\xe6"=>0,
    "\x8f\xc8\xe7"=>0,
    "\x8f\xc8\xe8"=>0,
    "\x8f\xc8\xe9"=>0,
    "\x8f\xc8\xea"=>0,
    "\x8f\xc8\xeb"=>0,
    "\x8f\xc8\xec"=>0,
    "\x8f\xc8\xed"=>0,
    "\x8f\xc8\xee"=>0,
    "\x8f\xc8\xef"=>0,
    "\x8f\xc8\xf0"=>0,
    "\x8f\xc8\xf1"=>0,
    "\x8f\xc8\xf2"=>0,
    "\x8f\xc8\xf3"=>0,
    "\x8f\xc8\xf4"=>0,
    "\x8f\xc8\xf5"=>0,
    "\x8f\xc8\xf6"=>0,
    "\x8f\xc8\xf7"=>0,
    "\x8f\xc8\xf8"=>0,
    "\x8f\xc8\xf9"=>0,
    "\x8f\xc8\xfa"=>0,
    "\x8f\xc8\xfb"=>0,
    "\x8f\xc8\xfc"=>0,
    "\x8f\xc8\xfd"=>0,
    "\x8f\xc8\xfe"=>0,
    "\x8f\xc9\xa1"=>0,
    "\x8f\xc9\xa2"=>0,
    "\x8f\xc9\xa3"=>0,
    "\x8f\xc9\xa4"=>0,
    "\x8f\xc9\xa5"=>0,
    "\x8f\xc9\xa6"=>0,
    "\x8f\xc9\xa7"=>0,
    "\x8f\xc9\xa8"=>0,
    "\x8f\xc9\xa9"=>0,
    "\x8f\xc9\xaa"=>0,
    "\x8f\xc9\xab"=>0,
    "\x8f\xc9\xac"=>0,
    "\x8f\xc9\xad"=>0,
    "\x8f\xc9\xae"=>0,
    "\x8f\xc9\xaf"=>0,
    "\x8f\xc9\xb0"=>0,
    "\x8f\xc9\xb1"=>0,
    "\x8f\xc9\xb2"=>0,
    "\x8f\xc9\xb3"=>0,
    "\x8f\xc9\xb4"=>0,
    "\x8f\xc9\xb5"=>0,
    "\x8f\xc9\xb6"=>0,
    "\x8f\xc9\xb7"=>0,
    "\x8f\xc9\xb8"=>0,
    "\x8f\xc9\xb9"=>0,
    "\x8f\xc9\xba"=>0,
    "\x8f\xc9\xbb"=>0,
    "\x8f\xc9\xbc"=>0,
    "\x8f\xc9\xbd"=>0,
    "\x8f\xc9\xbe"=>0,
    "\x8f\xc9\xbf"=>0,
    "\x8f\xc9\xc0"=>0,
    "\x8f\xc9\xc1"=>0,
    "\x8f\xc9\xc2"=>0,
    "\x8f\xc9\xc3"=>0,
    "\x8f\xc9\xc4"=>0,
    "\x8f\xc9\xc5"=>0,
    "\x8f\xc9\xc6"=>0,
    "\x8f\xc9\xc7"=>0,
    "\x8f\xc9\xc8"=>0,
    "\x8f\xc9\xc9"=>0,
    "\x8f\xc9\xca"=>0,
    "\x8f\xc9\xcb"=>0,
    "\x8f\xc9\xcc"=>0,
    "\x8f\xc9\xcd"=>0,
    "\x8f\xc9\xce"=>0,
    "\x8f\xc9\xcf"=>0,
    "\x8f\xc9\xd0"=>0,
    "\x8f\xc9\xd1"=>0,
    "\x8f\xc9\xd2"=>0,
    "\x8f\xc9\xd3"=>0,
    "\x8f\xc9\xd4"=>0,
    "\x8f\xc9\xd5"=>0,
    "\x8f\xc9\xd6"=>0,
    "\x8f\xc9\xd7"=>0,
    "\x8f\xc9\xd8"=>0,
    "\x8f\xc9\xd9"=>0,
    "\x8f\xc9\xda"=>0,
    "\x8f\xc9\xdb"=>0,
    "\x8f\xc9\xdc"=>0,
    "\x8f\xc9\xdd"=>0,
    "\x8f\xc9\xde"=>0,
    "\x8f\xc9\xdf"=>0,
    "\x8f\xc9\xe0"=>0,
    "\x8f\xc9\xe1"=>0,
    "\x8f\xc9\xe2"=>0,
    "\x8f\xc9\xe3"=>0,
    "\x8f\xc9\xe4"=>0,
    "\x8f\xc9\xe5"=>0,
    "\x8f\xc9\xe6"=>0,
    "\x8f\xc9\xe7"=>0,
    "\x8f\xc9\xe8"=>0,
    "\x8f\xc9\xe9"=>0,
    "\x8f\xc9\xea"=>0,
    "\x8f\xc9\xeb"=>0,
    "\x8f\xc9\xec"=>0,
    "\x8f\xc9\xed"=>0,
    "\x8f\xc9\xee"=>0,
    "\x8f\xc9\xef"=>0,
    "\x8f\xc9\xf0"=>0,
    "\x8f\xc9\xf1"=>0,
    "\x8f\xc9\xf2"=>0,
    "\x8f\xc9\xf3"=>0,
    "\x8f\xc9\xf4"=>0,
    "\x8f\xc9\xf5"=>0,
    "\x8f\xc9\xf6"=>0,
    "\x8f\xc9\xf7"=>0,
    "\x8f\xc9\xf8"=>0,
    "\x8f\xc9\xf9"=>0,
    "\x8f\xc9\xfa"=>0,
    "\x8f\xc9\xfb"=>0,
    "\x8f\xc9\xfc"=>0,
    "\x8f\xc9\xfd"=>0,
    "\x8f\xc9\xfe"=>0,
    "\x8f\xca\xa1"=>0,
    "\x8f\xca\xa2"=>0,
    "\x8f\xca\xa3"=>0,
    "\x8f\xca\xa4"=>0,
    "\x8f\xca\xa5"=>0,
    "\x8f\xca\xa6"=>0,
    "\x8f\xca\xa7"=>0,
    "\x8f\xca\xa8"=>0,
    "\x8f\xca\xa9"=>0,
    "\x8f\xca\xaa"=>0,
    "\x8f\xca\xab"=>0,
    "\x8f\xca\xac"=>0,
    "\x8f\xca\xad"=>0,
    "\x8f\xca\xae"=>0,
    "\x8f\xca\xaf"=>0,
    "\x8f\xca\xb0"=>0,
    "\x8f\xca\xb1"=>0,
    "\x8f\xca\xb2"=>0,
    "\x8f\xca\xb3"=>0,
    "\x8f\xca\xb4"=>0,
    "\x8f\xca\xb5"=>0,
    "\x8f\xca\xb6"=>0,
    "\x8f\xca\xb7"=>0,
    "\x8f\xca\xb8"=>0,
    "\x8f\xca\xb9"=>0,
    "\x8f\xca\xba"=>0,
    "\x8f\xca\xbb"=>0,
    "\x8f\xca\xbc"=>0,
    "\x8f\xca\xbd"=>0,
    "\x8f\xca\xbe"=>0,
    "\x8f\xca\xbf"=>0,
    "\x8f\xca\xc0"=>0,
    "\x8f\xca\xc1"=>0,
    "\x8f\xca\xc2"=>0,
    "\x8f\xca\xc3"=>0,
    "\x8f\xca\xc4"=>0,
    "\x8f\xca\xc5"=>0,
    "\x8f\xca\xc6"=>0,
    "\x8f\xca\xc7"=>0,
    "\x8f\xca\xc8"=>0,
    "\x8f\xca\xc9"=>0,
    "\x8f\xca\xca"=>0,
    "\x8f\xca\xcb"=>0,
    "\x8f\xca\xcc"=>0,
    "\x8f\xca\xcd"=>0,
    "\x8f\xca\xce"=>0,
    "\x8f\xca\xcf"=>0,
    "\x8f\xca\xd0"=>0,
    "\x8f\xca\xd1"=>0,
    "\x8f\xca\xd2"=>0,
    "\x8f\xca\xd3"=>0,
    "\x8f\xca\xd4"=>0,
    "\x8f\xca\xd5"=>0,
    "\x8f\xca\xd6"=>0,
    "\x8f\xca\xd7"=>0,
    "\x8f\xca\xd8"=>0,
    "\x8f\xca\xd9"=>0,
    "\x8f\xca\xda"=>0,
    "\x8f\xca\xdb"=>0,
    "\x8f\xca\xdc"=>0,
    "\x8f\xca\xdd"=>0,
    "\x8f\xca\xde"=>0,
    "\x8f\xca\xdf"=>0,
    "\x8f\xca\xe0"=>0,
    "\x8f\xca\xe1"=>0,
    "\x8f\xca\xe2"=>0,
    "\x8f\xca\xe3"=>0,
    "\x8f\xca\xe4"=>0,
    "\x8f\xca\xe5"=>0,
    "\x8f\xca\xe6"=>0,
    "\x8f\xca\xe7"=>0,
    "\x8f\xca\xe8"=>0,
    "\x8f\xca\xe9"=>0,
    "\x8f\xca\xea"=>0,
    "\x8f\xca\xeb"=>0,
    "\x8f\xca\xec"=>0,
    "\x8f\xca\xed"=>0,
    "\x8f\xca\xee"=>0,
    "\x8f\xca\xef"=>0,
    "\x8f\xca\xf0"=>0,
    "\x8f\xca\xf1"=>0,
    "\x8f\xca\xf2"=>0,
    "\x8f\xca\xf3"=>0,
    "\x8f\xca\xf4"=>0,
    "\x8f\xca\xf5"=>0,
    "\x8f\xca\xf6"=>0,
    "\x8f\xca\xf7"=>0,
    "\x8f\xca\xf8"=>0,
    "\x8f\xca\xf9"=>0,
    "\x8f\xca\xfa"=>0,
    "\x8f\xca\xfb"=>0,
    "\x8f\xca\xfc"=>0,
    "\x8f\xca\xfd"=>0,
    "\x8f\xca\xfe"=>0,
    "\x8f\xcb\xa1"=>0,
    "\x8f\xcb\xa2"=>0,
    "\x8f\xcb\xa3"=>0,
    "\x8f\xcb\xa4"=>0,
    "\x8f\xcb\xa5"=>0,
    "\x8f\xcb\xa6"=>0,
    "\x8f\xcb\xa7"=>0,
    "\x8f\xcb\xa8"=>0,
    "\x8f\xcb\xa9"=>0,
    "\x8f\xcb\xaa"=>0,
    "\x8f\xcb\xab"=>0,
    "\x8f\xcb\xac"=>0,
    "\x8f\xcb\xad"=>0,
    "\x8f\xcb\xae"=>0,
    "\x8f\xcb\xaf"=>0,
    "\x8f\xcb\xb0"=>0,
    "\x8f\xcb\xb1"=>0,
    "\x8f\xcb\xb2"=>0,
    "\x8f\xcb\xb3"=>0,
    "\x8f\xcb\xb4"=>0,
    "\x8f\xcb\xb5"=>0,
    "\x8f\xcb\xb6"=>0,
    "\x8f\xcb\xb7"=>0,
    "\x8f\xcb\xb8"=>0,
    "\x8f\xcb\xb9"=>0,
    "\x8f\xcb\xba"=>0,
    "\x8f\xcb\xbb"=>0,
    "\x8f\xcb\xbc"=>0,
    "\x8f\xcb\xbd"=>0,
    "\x8f\xcb\xbe"=>0,
    "\x8f\xcb\xbf"=>0,
    "\x8f\xcb\xc0"=>0,
    "\x8f\xcb\xc1"=>0,
    "\x8f\xcb\xc2"=>0,
    "\x8f\xcb\xc3"=>0,
    "\x8f\xcb\xc4"=>0,
    "\x8f\xcb\xc5"=>0,
    "\x8f\xcb\xc6"=>0,
    "\x8f\xcb\xc7"=>0,
    "\x8f\xcb\xc8"=>0,
    "\x8f\xcb\xc9"=>0,
    "\x8f\xcb\xca"=>0,
    "\x8f\xcb\xcb"=>0,
    "\x8f\xcb\xcc"=>0,
    "\x8f\xcb\xcd"=>0,
    "\x8f\xcb\xce"=>0,
    "\x8f\xcb\xcf"=>0,
    "\x8f\xcb\xd0"=>0,
    "\x8f\xcb\xd1"=>0,
    "\x8f\xcb\xd2"=>0,
    "\x8f\xcb\xd3"=>0,
    "\x8f\xcb\xd4"=>0,
    "\x8f\xcb\xd5"=>0,
    "\x8f\xcb\xd6"=>0,
    "\x8f\xcb\xd7"=>0,
    "\x8f\xcb\xd8"=>0,
    "\x8f\xcb\xd9"=>0,
    "\x8f\xcb\xda"=>0,
    "\x8f\xcb\xdb"=>0,
    "\x8f\xcb\xdc"=>0,
    "\x8f\xcb\xdd"=>0,
    "\x8f\xcb\xde"=>0,
    "\x8f\xcb\xdf"=>0,
    "\x8f\xcb\xe0"=>0,
    "\x8f\xcb\xe1"=>0,
    "\x8f\xcb\xe2"=>0,
    "\x8f\xcb\xe3"=>0,
    "\x8f\xcb\xe4"=>0,
    "\x8f\xcb\xe5"=>0,
    "\x8f\xcb\xe6"=>0,
    "\x8f\xcb\xe7"=>0,
    "\x8f\xcb\xe8"=>0,
    "\x8f\xcb\xe9"=>0,
    "\x8f\xcb\xea"=>0,
    "\x8f\xcb\xeb"=>0,
    "\x8f\xcb\xec"=>0,
    "\x8f\xcb\xed"=>0,
    "\x8f\xcb\xee"=>0,
    "\x8f\xcb\xef"=>0,
    "\x8f\xcb\xf0"=>0,
    "\x8f\xcb\xf1"=>0,
    "\x8f\xcb\xf2"=>0,
    "\x8f\xcb\xf3"=>0,
    "\x8f\xcb\xf4"=>0,
    "\x8f\xcb\xf5"=>0,
    "\x8f\xcb\xf6"=>0,
    "\x8f\xcb\xf7"=>0,
    "\x8f\xcb\xf8"=>0,
    "\x8f\xcb\xf9"=>0,
    "\x8f\xcb\xfa"=>0,
    "\x8f\xcb\xfb"=>0,
    "\x8f\xcb\xfc"=>0,
    "\x8f\xcb\xfd"=>0,
    "\x8f\xcb\xfe"=>0,
    "\x8f\xcc\xa1"=>0,
    "\x8f\xcc\xa2"=>0,
    "\x8f\xcc\xa3"=>0,
    "\x8f\xcc\xa4"=>0,
    "\x8f\xcc\xa5"=>0,
    "\x8f\xcc\xa6"=>0,
    "\x8f\xcc\xa7"=>0,
    "\x8f\xcc\xa8"=>0,
    "\x8f\xcc\xa9"=>0,
    "\x8f\xcc\xaa"=>0,
    "\x8f\xcc\xab"=>0,
    "\x8f\xcc\xac"=>0,
    "\x8f\xcc\xad"=>0,
    "\x8f\xcc\xae"=>0,
    "\x8f\xcc\xaf"=>0,
    "\x8f\xcc\xb0"=>0,
    "\x8f\xcc\xb1"=>0,
    "\x8f\xcc\xb2"=>0,
    "\x8f\xcc\xb3"=>0,
    "\x8f\xcc\xb4"=>0,
    "\x8f\xcc\xb5"=>0,
    "\x8f\xcc\xb6"=>0,
    "\x8f\xcc\xb7"=>0,
    "\x8f\xcc\xb8"=>0,
    "\x8f\xcc\xb9"=>0,
    "\x8f\xcc\xba"=>0,
    "\x8f\xcc\xbb"=>0,
    "\x8f\xcc\xbc"=>0,
    "\x8f\xcc\xbd"=>0,
    "\x8f\xcc\xbe"=>0,
    "\x8f\xcc\xbf"=>0,
    "\x8f\xcc\xc0"=>0,
    "\x8f\xcc\xc1"=>0,
    "\x8f\xcc\xc2"=>0,
    "\x8f\xcc\xc3"=>0,
    "\x8f\xcc\xc4"=>0,
    "\x8f\xcc\xc5"=>0,
    "\x8f\xcc\xc6"=>0,
    "\x8f\xcc\xc7"=>0,
    "\x8f\xcc\xc8"=>0,
    "\x8f\xcc\xc9"=>0,
    "\x8f\xcc\xca"=>0,
    "\x8f\xcc\xcb"=>0,
    "\x8f\xcc\xcc"=>0,
    "\x8f\xcc\xcd"=>0,
    "\x8f\xcc\xce"=>0,
    "\x8f\xcc\xcf"=>0,
    "\x8f\xcc\xd0"=>0,
    "\x8f\xcc\xd1"=>0,
    "\x8f\xcc\xd2"=>0,
    "\x8f\xcc\xd3"=>0,
    "\x8f\xcc\xd4"=>0,
    "\x8f\xcc\xd5"=>0,
    "\x8f\xcc\xd6"=>0,
    "\x8f\xcc\xd7"=>0,
    "\x8f\xcc\xd8"=>0,
    "\x8f\xcc\xd9"=>0,
    "\x8f\xcc\xda"=>0,
    "\x8f\xcc\xdb"=>0,
    "\x8f\xcc\xdc"=>0,
    "\x8f\xcc\xdd"=>0,
    "\x8f\xcc\xde"=>0,
    "\x8f\xcc\xdf"=>0,
    "\x8f\xcc\xe0"=>0,
    "\x8f\xcc\xe1"=>0,
    "\x8f\xcc\xe2"=>0,
    "\x8f\xcc\xe3"=>0,
    "\x8f\xcc\xe4"=>0,
    "\x8f\xcc\xe5"=>0,
    "\x8f\xcc\xe6"=>0,
    "\x8f\xcc\xe7"=>0,
    "\x8f\xcc\xe8"=>0,
    "\x8f\xcc\xe9"=>0,
    "\x8f\xcc\xea"=>0,
    "\x8f\xcc\xeb"=>0,
    "\x8f\xcc\xec"=>0,
    "\x8f\xcc\xed"=>0,
    "\x8f\xcc\xee"=>0,
    "\x8f\xcc\xef"=>0,
    "\x8f\xcc\xf0"=>0,
    "\x8f\xcc\xf1"=>0,
    "\x8f\xcc\xf2"=>0,
    "\x8f\xcc\xf3"=>0,
    "\x8f\xcc\xf4"=>0,
    "\x8f\xcc\xf5"=>0,
    "\x8f\xcc\xf6"=>0,
    "\x8f\xcc\xf7"=>0,
    "\x8f\xcc\xf8"=>0,
    "\x8f\xcc\xf9"=>0,
    "\x8f\xcc\xfa"=>0,
    "\x8f\xcc\xfb"=>0,
    "\x8f\xcc\xfc"=>0,
    "\x8f\xcc\xfd"=>0,
    "\x8f\xcc\xfe"=>0,
    "\x8f\xcd\xa1"=>0,
    "\x8f\xcd\xa2"=>0,
    "\x8f\xcd\xa3"=>0,
    "\x8f\xcd\xa4"=>0,
    "\x8f\xcd\xa5"=>0,
    "\x8f\xcd\xa6"=>0,
    "\x8f\xcd\xa7"=>0,
    "\x8f\xcd\xa8"=>0,
    "\x8f\xcd\xa9"=>0,
    "\x8f\xcd\xaa"=>0,
    "\x8f\xcd\xab"=>0,
    "\x8f\xcd\xac"=>0,
    "\x8f\xcd\xad"=>0,
    "\x8f\xcd\xae"=>0,
    "\x8f\xcd\xaf"=>0,
    "\x8f\xcd\xb0"=>0,
    "\x8f\xcd\xb1"=>0,
    "\x8f\xcd\xb2"=>0,
    "\x8f\xcd\xb3"=>0,
    "\x8f\xcd\xb4"=>0,
    "\x8f\xcd\xb5"=>0,
    "\x8f\xcd\xb6"=>0,
    "\x8f\xcd\xb7"=>0,
    "\x8f\xcd\xb8"=>0,
    "\x8f\xcd\xb9"=>0,
    "\x8f\xcd\xba"=>0,
    "\x8f\xcd\xbb"=>0,
    "\x8f\xcd\xbc"=>0,
    "\x8f\xcd\xbd"=>0,
    "\x8f\xcd\xbe"=>0,
    "\x8f\xcd\xbf"=>0,
    "\x8f\xcd\xc0"=>0,
    "\x8f\xcd\xc1"=>0,
    "\x8f\xcd\xc2"=>0,
    "\x8f\xcd\xc3"=>0,
    "\x8f\xcd\xc4"=>0,
    "\x8f\xcd\xc5"=>0,
    "\x8f\xcd\xc6"=>0,
    "\x8f\xcd\xc7"=>0,
    "\x8f\xcd\xc8"=>0,
    "\x8f\xcd\xc9"=>0,
    "\x8f\xcd\xca"=>0,
    "\x8f\xcd\xcb"=>0,
    "\x8f\xcd\xcc"=>0,
    "\x8f\xcd\xcd"=>0,
    "\x8f\xcd\xce"=>0,
    "\x8f\xcd\xcf"=>0,
    "\x8f\xcd\xd0"=>0,
    "\x8f\xcd\xd1"=>0,
    "\x8f\xcd\xd2"=>0,
    "\x8f\xcd\xd3"=>0,
    "\x8f\xcd\xd4"=>0,
    "\x8f\xcd\xd5"=>0,
    "\x8f\xcd\xd6"=>0,
    "\x8f\xcd\xd7"=>0,
    "\x8f\xcd\xd8"=>0,
    "\x8f\xcd\xd9"=>0,
    "\x8f\xcd\xda"=>0,
    "\x8f\xcd\xdb"=>0,
    "\x8f\xcd\xdc"=>0,
    "\x8f\xcd\xdd"=>0,
    "\x8f\xcd\xde"=>0,
    "\x8f\xcd\xdf"=>0,
    "\x8f\xcd\xe0"=>0,
    "\x8f\xcd\xe1"=>0,
    "\x8f\xcd\xe2"=>0,
    "\x8f\xcd\xe3"=>0,
    "\x8f\xcd\xe4"=>0,
    "\x8f\xcd\xe5"=>0,
    "\x8f\xcd\xe6"=>0,
    "\x8f\xcd\xe7"=>0,
    "\x8f\xcd\xe8"=>0,
    "\x8f\xcd\xe9"=>0,
    "\x8f\xcd\xea"=>0,
    "\x8f\xcd\xeb"=>0,
    "\x8f\xcd\xec"=>0,
    "\x8f\xcd\xed"=>0,
    "\x8f\xcd\xee"=>0,
    "\x8f\xcd\xef"=>0,
    "\x8f\xcd\xf0"=>0,
    "\x8f\xcd\xf1"=>0,
    "\x8f\xcd\xf2"=>0,
    "\x8f\xcd\xf3"=>0,
    "\x8f\xcd\xf4"=>0,
    "\x8f\xcd\xf5"=>0,
    "\x8f\xcd\xf6"=>0,
    "\x8f\xcd\xf7"=>0,
    "\x8f\xcd\xf8"=>0,
    "\x8f\xcd\xf9"=>0,
    "\x8f\xcd\xfa"=>0,
    "\x8f\xcd\xfb"=>0,
    "\x8f\xcd\xfc"=>0,
    "\x8f\xcd\xfd"=>0,
    "\x8f\xcd\xfe"=>0,
    "\x8f\xce\xa1"=>0,
    "\x8f\xce\xa2"=>0,
    "\x8f\xce\xa3"=>0,
    "\x8f\xce\xa4"=>0,
    "\x8f\xce\xa5"=>0,
    "\x8f\xce\xa6"=>0,
    "\x8f\xce\xa7"=>0,
    "\x8f\xce\xa8"=>0,
    "\x8f\xce\xa9"=>0,
    "\x8f\xce\xaa"=>0,
    "\x8f\xce\xab"=>0,
    "\x8f\xce\xac"=>0,
    "\x8f\xce\xad"=>0,
    "\x8f\xce\xae"=>0,
    "\x8f\xce\xaf"=>0,
    "\x8f\xce\xb0"=>0,
    "\x8f\xce\xb1"=>0,
    "\x8f\xce\xb2"=>0,
    "\x8f\xce\xb3"=>0,
    "\x8f\xce\xb4"=>0,
    "\x8f\xce\xb5"=>0,
    "\x8f\xce\xb6"=>0,
    "\x8f\xce\xb7"=>0,
    "\x8f\xce\xb8"=>0,
    "\x8f\xce\xb9"=>0,
    "\x8f\xce\xba"=>0,
    "\x8f\xce\xbb"=>0,
    "\x8f\xce\xbc"=>0,
    "\x8f\xce\xbd"=>0,
    "\x8f\xce\xbe"=>0,
    "\x8f\xce\xbf"=>0,
    "\x8f\xce\xc0"=>0,
    "\x8f\xce\xc1"=>0,
    "\x8f\xce\xc2"=>0,
    "\x8f\xce\xc3"=>0,
    "\x8f\xce\xc4"=>0,
    "\x8f\xce\xc5"=>0,
    "\x8f\xce\xc6"=>0,
    "\x8f\xce\xc7"=>0,
    "\x8f\xce\xc8"=>0,
    "\x8f\xce\xc9"=>0,
    "\x8f\xce\xca"=>0,
    "\x8f\xce\xcb"=>0,
    "\x8f\xce\xcc"=>0,
    "\x8f\xce\xcd"=>0,
    "\x8f\xce\xce"=>0,
    "\x8f\xce\xcf"=>0,
    "\x8f\xce\xd0"=>0,
    "\x8f\xce\xd1"=>0,
    "\x8f\xce\xd2"=>0,
    "\x8f\xce\xd3"=>0,
    "\x8f\xce\xd4"=>0,
    "\x8f\xce\xd5"=>0,
    "\x8f\xce\xd6"=>0,
    "\x8f\xce\xd7"=>0,
    "\x8f\xce\xd8"=>0,
    "\x8f\xce\xd9"=>0,
    "\x8f\xce\xda"=>0,
    "\x8f\xce\xdb"=>0,
    "\x8f\xce\xdc"=>0,
    "\x8f\xce\xdd"=>0,
    "\x8f\xce\xde"=>0,
    "\x8f\xce\xdf"=>0,
    "\x8f\xce\xe0"=>0,
    "\x8f\xce\xe1"=>0,
    "\x8f\xce\xe2"=>0,
    "\x8f\xce\xe3"=>0,
    "\x8f\xce\xe4"=>0,
    "\x8f\xce\xe5"=>0,
    "\x8f\xce\xe6"=>0,
    "\x8f\xce\xe7"=>0,
    "\x8f\xce\xe8"=>0,
    "\x8f\xce\xe9"=>0,
    "\x8f\xce\xea"=>0,
    "\x8f\xce\xeb"=>0,
    "\x8f\xce\xec"=>0,
    "\x8f\xce\xed"=>0,
    "\x8f\xce\xee"=>0,
    "\x8f\xce\xef"=>0,
    "\x8f\xce\xf0"=>0,
    "\x8f\xce\xf1"=>0,
    "\x8f\xce\xf2"=>0,
    "\x8f\xce\xf3"=>0,
    "\x8f\xce\xf4"=>0,
    "\x8f\xce\xf5"=>0,
    "\x8f\xce\xf6"=>0,
    "\x8f\xce\xf7"=>0,
    "\x8f\xce\xf8"=>0,
    "\x8f\xce\xf9"=>0,
    "\x8f\xce\xfa"=>0,
    "\x8f\xce\xfb"=>0,
    "\x8f\xce\xfc"=>0,
    "\x8f\xce\xfd"=>0,
    "\x8f\xce\xfe"=>0,
    "\x8f\xcf\xa1"=>0,
    "\x8f\xcf\xa2"=>0,
    "\x8f\xcf\xa3"=>0,
    "\x8f\xcf\xa4"=>0,
    "\x8f\xcf\xa5"=>0,
    "\x8f\xcf\xa6"=>0,
    "\x8f\xcf\xa7"=>0,
    "\x8f\xcf\xa8"=>0,
    "\x8f\xcf\xa9"=>0,
    "\x8f\xcf\xaa"=>0,
    "\x8f\xcf\xab"=>0,
    "\x8f\xcf\xac"=>0,
    "\x8f\xcf\xad"=>0,
    "\x8f\xcf\xae"=>0,
    "\x8f\xcf\xaf"=>0,
    "\x8f\xcf\xb0"=>0,
    "\x8f\xcf\xb1"=>0,
    "\x8f\xcf\xb2"=>0,
    "\x8f\xcf\xb3"=>0,
    "\x8f\xcf\xb4"=>0,
    "\x8f\xcf\xb5"=>0,
    "\x8f\xcf\xb6"=>0,
    "\x8f\xcf\xb7"=>0,
    "\x8f\xcf\xb8"=>0,
    "\x8f\xcf\xb9"=>0,
    "\x8f\xcf\xba"=>0,
    "\x8f\xcf\xbb"=>0,
    "\x8f\xcf\xbc"=>0,
    "\x8f\xcf\xbd"=>0,
    "\x8f\xcf\xbe"=>0,
    "\x8f\xcf\xbf"=>0,
    "\x8f\xcf\xc0"=>0,
    "\x8f\xcf\xc1"=>0,
    "\x8f\xcf\xc2"=>0,
    "\x8f\xcf\xc3"=>0,
    "\x8f\xcf\xc4"=>0,
    "\x8f\xcf\xc5"=>0,
    "\x8f\xcf\xc6"=>0,
    "\x8f\xcf\xc7"=>0,
    "\x8f\xcf\xc8"=>0,
    "\x8f\xcf\xc9"=>0,
    "\x8f\xcf\xca"=>0,
    "\x8f\xcf\xcb"=>0,
    "\x8f\xcf\xcc"=>0,
    "\x8f\xcf\xcd"=>0,
    "\x8f\xcf\xce"=>0,
    "\x8f\xcf\xcf"=>0,
    "\x8f\xcf\xd0"=>0,
    "\x8f\xcf\xd1"=>0,
    "\x8f\xcf\xd2"=>0,
    "\x8f\xcf\xd3"=>0,
    "\x8f\xcf\xd4"=>0,
    "\x8f\xcf\xd5"=>0,
    "\x8f\xcf\xd6"=>0,
    "\x8f\xcf\xd7"=>0,
    "\x8f\xcf\xd8"=>0,
    "\x8f\xcf\xd9"=>0,
    "\x8f\xcf\xda"=>0,
    "\x8f\xcf\xdb"=>0,
    "\x8f\xcf\xdc"=>0,
    "\x8f\xcf\xdd"=>0,
    "\x8f\xcf\xde"=>0,
    "\x8f\xcf\xdf"=>0,
    "\x8f\xcf\xe0"=>0,
    "\x8f\xcf\xe1"=>0,
    "\x8f\xcf\xe2"=>0,
    "\x8f\xcf\xe3"=>0,
    "\x8f\xcf\xe4"=>0,
    "\x8f\xcf\xe5"=>0,
    "\x8f\xcf\xe6"=>0,
    "\x8f\xcf\xe7"=>0,
    "\x8f\xcf\xe8"=>0,
    "\x8f\xcf\xe9"=>0,
    "\x8f\xcf\xea"=>0,
    "\x8f\xcf\xeb"=>0,
    "\x8f\xcf\xec"=>0,
    "\x8f\xcf\xed"=>0,
    "\x8f\xcf\xee"=>0,
    "\x8f\xcf\xef"=>0,
    "\x8f\xcf\xf0"=>0,
    "\x8f\xcf\xf1"=>0,
    "\x8f\xcf\xf2"=>0,
    "\x8f\xcf\xf3"=>0,
    "\x8f\xcf\xf4"=>0,
    "\x8f\xcf\xf5"=>0,
    "\x8f\xcf\xf6"=>0,
    "\x8f\xcf\xf7"=>0,
    "\x8f\xcf\xf8"=>0,
    "\x8f\xcf\xf9"=>0,
    "\x8f\xcf\xfa"=>0,
    "\x8f\xcf\xfb"=>0,
    "\x8f\xcf\xfc"=>0,
    "\x8f\xcf\xfd"=>0,
    "\x8f\xcf\xfe"=>0,
    "\x8f\xd0\xa1"=>0,
    "\x8f\xd0\xa2"=>0,
    "\x8f\xd0\xa3"=>0,
    "\x8f\xd0\xa4"=>0,
    "\x8f\xd0\xa5"=>0,
    "\x8f\xd0\xa6"=>0,
    "\x8f\xd0\xa7"=>0,
    "\x8f\xd0\xa8"=>0,
    "\x8f\xd0\xa9"=>0,
    "\x8f\xd0\xaa"=>0,
    "\x8f\xd0\xab"=>0,
    "\x8f\xd0\xac"=>0,
    "\x8f\xd0\xad"=>0,
    "\x8f\xd0\xae"=>0,
    "\x8f\xd0\xaf"=>0,
    "\x8f\xd0\xb0"=>0,
    "\x8f\xd0\xb1"=>0,
    "\x8f\xd0\xb2"=>0,
    "\x8f\xd0\xb3"=>0,
    "\x8f\xd0\xb4"=>0,
    "\x8f\xd0\xb5"=>0,
    "\x8f\xd0\xb6"=>0,
    "\x8f\xd0\xb7"=>0,
    "\x8f\xd0\xb8"=>0,
    "\x8f\xd0\xb9"=>0,
    "\x8f\xd0\xba"=>0,
    "\x8f\xd0\xbb"=>0,
    "\x8f\xd0\xbc"=>0,
    "\x8f\xd0\xbd"=>0,
    "\x8f\xd0\xbe"=>0,
    "\x8f\xd0\xbf"=>0,
    "\x8f\xd0\xc0"=>0,
    "\x8f\xd0\xc1"=>0,
    "\x8f\xd0\xc2"=>0,
    "\x8f\xd0\xc3"=>0,
    "\x8f\xd0\xc4"=>0,
    "\x8f\xd0\xc5"=>0,
    "\x8f\xd0\xc6"=>0,
    "\x8f\xd0\xc7"=>0,
    "\x8f\xd0\xc8"=>0,
    "\x8f\xd0\xc9"=>0,
    "\x8f\xd0\xca"=>0,
    "\x8f\xd0\xcb"=>0,
    "\x8f\xd0\xcc"=>0,
    "\x8f\xd0\xcd"=>0,
    "\x8f\xd0\xce"=>0,
    "\x8f\xd0\xcf"=>0,
    "\x8f\xd0\xd0"=>0,
    "\x8f\xd0\xd1"=>0,
    "\x8f\xd0\xd2"=>0,
    "\x8f\xd0\xd3"=>0,
    "\x8f\xd0\xd4"=>0,
    "\x8f\xd0\xd5"=>0,
    "\x8f\xd0\xd6"=>0,
    "\x8f\xd0\xd7"=>0,
    "\x8f\xd0\xd8"=>0,
    "\x8f\xd0\xd9"=>0,
    "\x8f\xd0\xda"=>0,
    "\x8f\xd0\xdb"=>0,
    "\x8f\xd0\xdc"=>0,
    "\x8f\xd0\xdd"=>0,
    "\x8f\xd0\xde"=>0,
    "\x8f\xd0\xdf"=>0,
    "\x8f\xd0\xe0"=>0,
    "\x8f\xd0\xe1"=>0,
    "\x8f\xd0\xe2"=>0,
    "\x8f\xd0\xe3"=>0,
    "\x8f\xd0\xe4"=>0,
    "\x8f\xd0\xe5"=>0,
    "\x8f\xd0\xe6"=>0,
    "\x8f\xd0\xe7"=>0,
    "\x8f\xd0\xe8"=>0,
    "\x8f\xd0\xe9"=>0,
    "\x8f\xd0\xea"=>0,
    "\x8f\xd0\xeb"=>0,
    "\x8f\xd0\xec"=>0,
    "\x8f\xd0\xed"=>0,
    "\x8f\xd0\xee"=>0,
    "\x8f\xd0\xef"=>0,
    "\x8f\xd0\xf0"=>0,
    "\x8f\xd0\xf1"=>0,
    "\x8f\xd0\xf2"=>0,
    "\x8f\xd0\xf3"=>0,
    "\x8f\xd0\xf4"=>0,
    "\x8f\xd0\xf5"=>0,
    "\x8f\xd0\xf6"=>0,
    "\x8f\xd0\xf7"=>0,
    "\x8f\xd0\xf8"=>0,
    "\x8f\xd0\xf9"=>0,
    "\x8f\xd0\xfa"=>0,
    "\x8f\xd0\xfb"=>0,
    "\x8f\xd0\xfc"=>0,
    "\x8f\xd0\xfd"=>0,
    "\x8f\xd0\xfe"=>0,
    "\x8f\xd1\xa1"=>0,
    "\x8f\xd1\xa2"=>0,
    "\x8f\xd1\xa3"=>0,
    "\x8f\xd1\xa4"=>0,
    "\x8f\xd1\xa5"=>0,
    "\x8f\xd1\xa6"=>0,
    "\x8f\xd1\xa7"=>0,
    "\x8f\xd1\xa8"=>0,
    "\x8f\xd1\xa9"=>0,
    "\x8f\xd1\xaa"=>0,
    "\x8f\xd1\xab"=>0,
    "\x8f\xd1\xac"=>0,
    "\x8f\xd1\xad"=>0,
    "\x8f\xd1\xae"=>0,
    "\x8f\xd1\xaf"=>0,
    "\x8f\xd1\xb0"=>0,
    "\x8f\xd1\xb1"=>0,
    "\x8f\xd1\xb2"=>0,
    "\x8f\xd1\xb3"=>0,
    "\x8f\xd1\xb4"=>0,
    "\x8f\xd1\xb5"=>0,
    "\x8f\xd1\xb6"=>0,
    "\x8f\xd1\xb7"=>0,
    "\x8f\xd1\xb8"=>0,
    "\x8f\xd1\xb9"=>0,
    "\x8f\xd1\xba"=>0,
    "\x8f\xd1\xbb"=>0,
    "\x8f\xd1\xbc"=>0,
    "\x8f\xd1\xbd"=>0,
    "\x8f\xd1\xbe"=>0,
    "\x8f\xd1\xbf"=>0,
    "\x8f\xd1\xc0"=>0,
    "\x8f\xd1\xc1"=>0,
    "\x8f\xd1\xc2"=>0,
    "\x8f\xd1\xc3"=>0,
    "\x8f\xd1\xc4"=>0,
    "\x8f\xd1\xc5"=>0,
    "\x8f\xd1\xc6"=>0,
    "\x8f\xd1\xc7"=>0,
    "\x8f\xd1\xc8"=>0,
    "\x8f\xd1\xc9"=>0,
    "\x8f\xd1\xca"=>0,
    "\x8f\xd1\xcb"=>0,
    "\x8f\xd1\xcc"=>0,
    "\x8f\xd1\xcd"=>0,
    "\x8f\xd1\xce"=>0,
    "\x8f\xd1\xcf"=>0,
    "\x8f\xd1\xd0"=>0,
    "\x8f\xd1\xd1"=>0,
    "\x8f\xd1\xd2"=>0,
    "\x8f\xd1\xd3"=>0,
    "\x8f\xd1\xd4"=>0,
    "\x8f\xd1\xd5"=>0,
    "\x8f\xd1\xd6"=>0,
    "\x8f\xd1\xd7"=>0,
    "\x8f\xd1\xd8"=>0,
    "\x8f\xd1\xd9"=>0,
    "\x8f\xd1\xda"=>0,
    "\x8f\xd1\xdb"=>0,
    "\x8f\xd1\xdc"=>0,
    "\x8f\xd1\xdd"=>0,
    "\x8f\xd1\xde"=>0,
    "\x8f\xd1\xdf"=>0,
    "\x8f\xd1\xe0"=>0,
    "\x8f\xd1\xe1"=>0,
    "\x8f\xd1\xe2"=>0,
    "\x8f\xd1\xe3"=>0,
    "\x8f\xd1\xe4"=>0,
    "\x8f\xd1\xe5"=>0,
    "\x8f\xd1\xe6"=>0,
    "\x8f\xd1\xe7"=>0,
    "\x8f\xd1\xe8"=>0,
    "\x8f\xd1\xe9"=>0,
    "\x8f\xd1\xea"=>0,
    "\x8f\xd1\xeb"=>0,
    "\x8f\xd1\xec"=>0,
    "\x8f\xd1\xed"=>0,
    "\x8f\xd1\xee"=>0,
    "\x8f\xd1\xef"=>0,
    "\x8f\xd1\xf0"=>0,
    "\x8f\xd1\xf1"=>0,
    "\x8f\xd1\xf2"=>0,
    "\x8f\xd1\xf3"=>0,
    "\x8f\xd1\xf4"=>0,
    "\x8f\xd1\xf5"=>0,
    "\x8f\xd1\xf6"=>0,
    "\x8f\xd1\xf7"=>0,
    "\x8f\xd1\xf8"=>0,
    "\x8f\xd1\xf9"=>0,
    "\x8f\xd1\xfa"=>0,
    "\x8f\xd1\xfb"=>0,
    "\x8f\xd1\xfc"=>0,
    "\x8f\xd1\xfd"=>0,
    "\x8f\xd1\xfe"=>0,
    "\x8f\xd2\xa1"=>0,
    "\x8f\xd2\xa2"=>0,
    "\x8f\xd2\xa3"=>0,
    "\x8f\xd2\xa4"=>0,
    "\x8f\xd2\xa5"=>0,
    "\x8f\xd2\xa6"=>0,
    "\x8f\xd2\xa7"=>0,
    "\x8f\xd2\xa8"=>0,
    "\x8f\xd2\xa9"=>0,
    "\x8f\xd2\xaa"=>0,
    "\x8f\xd2\xab"=>0,
    "\x8f\xd2\xac"=>0,
    "\x8f\xd2\xad"=>0,
    "\x8f\xd2\xae"=>0,
    "\x8f\xd2\xaf"=>0,
    "\x8f\xd2\xb0"=>0,
    "\x8f\xd2\xb1"=>0,
    "\x8f\xd2\xb2"=>0,
    "\x8f\xd2\xb3"=>0,
    "\x8f\xd2\xb4"=>0,
    "\x8f\xd2\xb5"=>0,
    "\x8f\xd2\xb6"=>0,
    "\x8f\xd2\xb7"=>0,
    "\x8f\xd2\xb8"=>0,
    "\x8f\xd2\xb9"=>0,
    "\x8f\xd2\xba"=>0,
    "\x8f\xd2\xbb"=>0,
    "\x8f\xd2\xbc"=>0,
    "\x8f\xd2\xbd"=>0,
    "\x8f\xd2\xbe"=>0,
    "\x8f\xd2\xbf"=>0,
    "\x8f\xd2\xc0"=>0,
    "\x8f\xd2\xc1"=>0,
    "\x8f\xd2\xc2"=>0,
    "\x8f\xd2\xc3"=>0,
    "\x8f\xd2\xc4"=>0,
    "\x8f\xd2\xc5"=>0,
    "\x8f\xd2\xc6"=>0,
    "\x8f\xd2\xc7"=>0,
    "\x8f\xd2\xc8"=>0,
    "\x8f\xd2\xc9"=>0,
    "\x8f\xd2\xca"=>0,
    "\x8f\xd2\xcb"=>0,
    "\x8f\xd2\xcc"=>0,
    "\x8f\xd2\xcd"=>0,
    "\x8f\xd2\xce"=>0,
    "\x8f\xd2\xcf"=>0,
    "\x8f\xd2\xd0"=>0,
    "\x8f\xd2\xd1"=>0,
    "\x8f\xd2\xd2"=>0,
    "\x8f\xd2\xd3"=>0,
    "\x8f\xd2\xd4"=>0,
    "\x8f\xd2\xd5"=>0,
    "\x8f\xd2\xd6"=>0,
    "\x8f\xd2\xd7"=>0,
    "\x8f\xd2\xd8"=>0,
    "\x8f\xd2\xd9"=>0,
    "\x8f\xd2\xda"=>0,
    "\x8f\xd2\xdb"=>0,
    "\x8f\xd2\xdc"=>0,
    "\x8f\xd2\xdd"=>0,
    "\x8f\xd2\xde"=>0,
    "\x8f\xd2\xdf"=>0,
    "\x8f\xd2\xe0"=>0,
    "\x8f\xd2\xe1"=>0,
    "\x8f\xd2\xe2"=>0,
    "\x8f\xd2\xe3"=>0,
    "\x8f\xd2\xe4"=>0,
    "\x8f\xd2\xe5"=>0,
    "\x8f\xd2\xe6"=>0,
    "\x8f\xd2\xe7"=>0,
    "\x8f\xd2\xe8"=>0,
    "\x8f\xd2\xe9"=>0,
    "\x8f\xd2\xea"=>0,
    "\x8f\xd2\xeb"=>0,
    "\x8f\xd2\xec"=>0,
    "\x8f\xd2\xed"=>0,
    "\x8f\xd2\xee"=>0,
    "\x8f\xd2\xef"=>0,
    "\x8f\xd2\xf0"=>0,
    "\x8f\xd2\xf1"=>0,
    "\x8f\xd2\xf2"=>0,
    "\x8f\xd2\xf3"=>0,
    "\x8f\xd2\xf4"=>0,
    "\x8f\xd2\xf5"=>0,
    "\x8f\xd2\xf6"=>0,
    "\x8f\xd2\xf7"=>0,
    "\x8f\xd2\xf8"=>0,
    "\x8f\xd2\xf9"=>0,
    "\x8f\xd2\xfa"=>0,
    "\x8f\xd2\xfb"=>0,
    "\x8f\xd2\xfc"=>0,
    "\x8f\xd2\xfd"=>0,
    "\x8f\xd2\xfe"=>0,
    "\x8f\xd3\xa1"=>0,
    "\x8f\xd3\xa2"=>0,
    "\x8f\xd3\xa3"=>0,
    "\x8f\xd3\xa4"=>0,
    "\x8f\xd3\xa5"=>0,
    "\x8f\xd3\xa6"=>0,
    "\x8f\xd3\xa7"=>0,
    "\x8f\xd3\xa8"=>0,
    "\x8f\xd3\xa9"=>0,
    "\x8f\xd3\xaa"=>0,
    "\x8f\xd3\xab"=>0,
    "\x8f\xd3\xac"=>0,
    "\x8f\xd3\xad"=>0,
    "\x8f\xd3\xae"=>0,
    "\x8f\xd3\xaf"=>0,
    "\x8f\xd3\xb0"=>0,
    "\x8f\xd3\xb1"=>0,
    "\x8f\xd3\xb2"=>0,
    "\x8f\xd3\xb3"=>0,
    "\x8f\xd3\xb4"=>0,
    "\x8f\xd3\xb5"=>0,
    "\x8f\xd3\xb6"=>0,
    "\x8f\xd3\xb7"=>0,
    "\x8f\xd3\xb8"=>0,
    "\x8f\xd3\xb9"=>0,
    "\x8f\xd3\xba"=>0,
    "\x8f\xd3\xbb"=>0,
    "\x8f\xd3\xbc"=>0,
    "\x8f\xd3\xbd"=>0,
    "\x8f\xd3\xbe"=>0,
    "\x8f\xd3\xbf"=>0,
    "\x8f\xd3\xc0"=>0,
    "\x8f\xd3\xc1"=>0,
    "\x8f\xd3\xc2"=>0,
    "\x8f\xd3\xc3"=>0,
    "\x8f\xd3\xc4"=>0,
    "\x8f\xd3\xc5"=>0,
    "\x8f\xd3\xc6"=>0,
    "\x8f\xd3\xc7"=>0,
    "\x8f\xd3\xc8"=>0,
    "\x8f\xd3\xc9"=>0,
    "\x8f\xd3\xca"=>0,
    "\x8f\xd3\xcb"=>0,
    "\x8f\xd3\xcc"=>0,
    "\x8f\xd3\xcd"=>0,
    "\x8f\xd3\xce"=>0,
    "\x8f\xd3\xcf"=>0,
    "\x8f\xd3\xd0"=>0,
    "\x8f\xd3\xd1"=>0,
    "\x8f\xd3\xd2"=>0,
    "\x8f\xd3\xd3"=>0,
    "\x8f\xd3\xd4"=>0,
    "\x8f\xd3\xd5"=>0,
    "\x8f\xd3\xd6"=>0,
    "\x8f\xd3\xd7"=>0,
    "\x8f\xd3\xd8"=>0,
    "\x8f\xd3\xd9"=>0,
    "\x8f\xd3\xda"=>0,
    "\x8f\xd3\xdb"=>0,
    "\x8f\xd3\xdc"=>0,
    "\x8f\xd3\xdd"=>0,
    "\x8f\xd3\xde"=>0,
    "\x8f\xd3\xdf"=>0,
    "\x8f\xd3\xe0"=>0,
    "\x8f\xd3\xe1"=>0,
    "\x8f\xd3\xe2"=>0,
    "\x8f\xd3\xe3"=>0,
    "\x8f\xd3\xe4"=>0,
    "\x8f\xd3\xe5"=>0,
    "\x8f\xd3\xe6"=>0,
    "\x8f\xd3\xe7"=>0,
    "\x8f\xd3\xe8"=>0,
    "\x8f\xd3\xe9"=>0,
    "\x8f\xd3\xea"=>0,
    "\x8f\xd3\xeb"=>0,
    "\x8f\xd3\xec"=>0,
    "\x8f\xd3\xed"=>0,
    "\x8f\xd3\xee"=>0,
    "\x8f\xd3\xef"=>0,
    "\x8f\xd3\xf0"=>0,
    "\x8f\xd3\xf1"=>0,
    "\x8f\xd3\xf2"=>0,
    "\x8f\xd3\xf3"=>0,
    "\x8f\xd3\xf4"=>0,
    "\x8f\xd3\xf5"=>0,
    "\x8f\xd3\xf6"=>0,
    "\x8f\xd3\xf7"=>0,
    "\x8f\xd3\xf8"=>0,
    "\x8f\xd3\xf9"=>0,
    "\x8f\xd3\xfa"=>0,
    "\x8f\xd3\xfb"=>0,
    "\x8f\xd3\xfc"=>0,
    "\x8f\xd3\xfd"=>0,
    "\x8f\xd3\xfe"=>0,
    "\x8f\xd4\xa1"=>0,
    "\x8f\xd4\xa2"=>0,
    "\x8f\xd4\xa3"=>0,
    "\x8f\xd4\xa4"=>0,
    "\x8f\xd4\xa5"=>0,
    "\x8f\xd4\xa6"=>0,
    "\x8f\xd4\xa7"=>0,
    "\x8f\xd4\xa8"=>0,
    "\x8f\xd4\xa9"=>0,
    "\x8f\xd4\xaa"=>0,
    "\x8f\xd4\xab"=>0,
    "\x8f\xd4\xac"=>0,
    "\x8f\xd4\xad"=>0,
    "\x8f\xd4\xae"=>0,
    "\x8f\xd4\xaf"=>0,
    "\x8f\xd4\xb0"=>0,
    "\x8f\xd4\xb1"=>0,
    "\x8f\xd4\xb2"=>0,
    "\x8f\xd4\xb3"=>0,
    "\x8f\xd4\xb4"=>0,
    "\x8f\xd4\xb5"=>0,
    "\x8f\xd4\xb6"=>0,
    "\x8f\xd4\xb7"=>0,
    "\x8f\xd4\xb8"=>0,
    "\x8f\xd4\xb9"=>0,
    "\x8f\xd4\xba"=>0,
    "\x8f\xd4\xbb"=>0,
    "\x8f\xd4\xbc"=>0,
    "\x8f\xd4\xbd"=>0,
    "\x8f\xd4\xbe"=>0,
    "\x8f\xd4\xbf"=>0,
    "\x8f\xd4\xc0"=>0,
    "\x8f\xd4\xc1"=>0,
    "\x8f\xd4\xc2"=>0,
    "\x8f\xd4\xc3"=>0,
    "\x8f\xd4\xc4"=>0,
    "\x8f\xd4\xc5"=>0,
    "\x8f\xd4\xc6"=>0,
    "\x8f\xd4\xc7"=>0,
    "\x8f\xd4\xc8"=>0,
    "\x8f\xd4\xc9"=>0,
    "\x8f\xd4\xca"=>0,
    "\x8f\xd4\xcb"=>0,
    "\x8f\xd4\xcc"=>0,
    "\x8f\xd4\xcd"=>0,
    "\x8f\xd4\xce"=>0,
    "\x8f\xd4\xcf"=>0,
    "\x8f\xd4\xd0"=>0,
    "\x8f\xd4\xd1"=>0,
    "\x8f\xd4\xd2"=>0,
    "\x8f\xd4\xd3"=>0,
    "\x8f\xd4\xd4"=>0,
    "\x8f\xd4\xd5"=>0,
    "\x8f\xd4\xd6"=>0,
    "\x8f\xd4\xd7"=>0,
    "\x8f\xd4\xd8"=>0,
    "\x8f\xd4\xd9"=>0,
    "\x8f\xd4\xda"=>0,
    "\x8f\xd4\xdb"=>0,
    "\x8f\xd4\xdc"=>0,
    "\x8f\xd4\xdd"=>0,
    "\x8f\xd4\xde"=>0,
    "\x8f\xd4\xdf"=>0,
    "\x8f\xd4\xe0"=>0,
    "\x8f\xd4\xe1"=>0,
    "\x8f\xd4\xe2"=>0,
    "\x8f\xd4\xe3"=>0,
    "\x8f\xd4\xe4"=>0,
    "\x8f\xd4\xe5"=>0,
    "\x8f\xd4\xe6"=>0,
    "\x8f\xd4\xe7"=>0,
    "\x8f\xd4\xe8"=>0,
    "\x8f\xd4\xe9"=>0,
    "\x8f\xd4\xea"=>0,
    "\x8f\xd4\xeb"=>0,
    "\x8f\xd4\xec"=>0,
    "\x8f\xd4\xed"=>0,
    "\x8f\xd4\xee"=>0,
    "\x8f\xd4\xef"=>0,
    "\x8f\xd4\xf0"=>0,
    "\x8f\xd4\xf1"=>0,
    "\x8f\xd4\xf2"=>0,
    "\x8f\xd4\xf3"=>0,
    "\x8f\xd4\xf4"=>0,
    "\x8f\xd4\xf5"=>0,
    "\x8f\xd4\xf6"=>0,
    "\x8f\xd4\xf7"=>0,
    "\x8f\xd4\xf8"=>0,
    "\x8f\xd4\xf9"=>0,
    "\x8f\xd4\xfa"=>0,
    "\x8f\xd4\xfb"=>0,
    "\x8f\xd4\xfc"=>0,
    "\x8f\xd4\xfd"=>0,
    "\x8f\xd4\xfe"=>0,
    "\x8f\xd5\xa1"=>0,
    "\x8f\xd5\xa2"=>0,
    "\x8f\xd5\xa3"=>0,
    "\x8f\xd5\xa4"=>0,
    "\x8f\xd5\xa5"=>0,
    "\x8f\xd5\xa6"=>0,
    "\x8f\xd5\xa7"=>0,
    "\x8f\xd5\xa8"=>0,
    "\x8f\xd5\xa9"=>0,
    "\x8f\xd5\xaa"=>0,
    "\x8f\xd5\xab"=>0,
    "\x8f\xd5\xac"=>0,
    "\x8f\xd5\xad"=>0,
    "\x8f\xd5\xae"=>0,
    "\x8f\xd5\xaf"=>0,
    "\x8f\xd5\xb0"=>0,
    "\x8f\xd5\xb1"=>0,
    "\x8f\xd5\xb2"=>0,
    "\x8f\xd5\xb3"=>0,
    "\x8f\xd5\xb4"=>0,
    "\x8f\xd5\xb5"=>0,
    "\x8f\xd5\xb6"=>0,
    "\x8f\xd5\xb7"=>0,
    "\x8f\xd5\xb8"=>0,
    "\x8f\xd5\xb9"=>0,
    "\x8f\xd5\xba"=>0,
    "\x8f\xd5\xbb"=>0,
    "\x8f\xd5\xbc"=>0,
    "\x8f\xd5\xbd"=>0,
    "\x8f\xd5\xbe"=>0,
    "\x8f\xd5\xbf"=>0,
    "\x8f\xd5\xc0"=>0,
    "\x8f\xd5\xc1"=>0,
    "\x8f\xd5\xc2"=>0,
    "\x8f\xd5\xc3"=>0,
    "\x8f\xd5\xc4"=>0,
    "\x8f\xd5\xc5"=>0,
    "\x8f\xd5\xc6"=>0,
    "\x8f\xd5\xc7"=>0,
    "\x8f\xd5\xc8"=>0,
    "\x8f\xd5\xc9"=>0,
    "\x8f\xd5\xca"=>0,
    "\x8f\xd5\xcb"=>0,
    "\x8f\xd5\xcc"=>0,
    "\x8f\xd5\xcd"=>0,
    "\x8f\xd5\xce"=>0,
    "\x8f\xd5\xcf"=>0,
    "\x8f\xd5\xd0"=>0,
    "\x8f\xd5\xd1"=>0,
    "\x8f\xd5\xd2"=>0,
    "\x8f\xd5\xd3"=>0,
    "\x8f\xd5\xd4"=>0,
    "\x8f\xd5\xd5"=>0,
    "\x8f\xd5\xd6"=>0,
    "\x8f\xd5\xd7"=>0,
    "\x8f\xd5\xd8"=>0,
    "\x8f\xd5\xd9"=>0,
    "\x8f\xd5\xda"=>0,
    "\x8f\xd5\xdb"=>0,
    "\x8f\xd5\xdc"=>0,
    "\x8f\xd5\xdd"=>0,
    "\x8f\xd5\xde"=>0,
    "\x8f\xd5\xdf"=>0,
    "\x8f\xd5\xe0"=>0,
    "\x8f\xd5\xe1"=>0,
    "\x8f\xd5\xe2"=>0,
    "\x8f\xd5\xe3"=>0,
    "\x8f\xd5\xe4"=>0,
    "\x8f\xd5\xe5"=>0,
    "\x8f\xd5\xe6"=>0,
    "\x8f\xd5\xe7"=>0,
    "\x8f\xd5\xe8"=>0,
    "\x8f\xd5\xe9"=>0,
    "\x8f\xd5\xea"=>0,
    "\x8f\xd5\xeb"=>0,
    "\x8f\xd5\xec"=>0,
    "\x8f\xd5\xed"=>0,
    "\x8f\xd5\xee"=>0,
    "\x8f\xd5\xef"=>0,
    "\x8f\xd5\xf0"=>0,
    "\x8f\xd5\xf1"=>0,
    "\x8f\xd5\xf2"=>0,
    "\x8f\xd5\xf3"=>0,
    "\x8f\xd5\xf4"=>0,
    "\x8f\xd5\xf5"=>0,
    "\x8f\xd5\xf6"=>0,
    "\x8f\xd5\xf7"=>0,
    "\x8f\xd5\xf8"=>0,
    "\x8f\xd5\xf9"=>0,
    "\x8f\xd5\xfa"=>0,
    "\x8f\xd5\xfb"=>0,
    "\x8f\xd5\xfc"=>0,
    "\x8f\xd5\xfd"=>0,
    "\x8f\xd5\xfe"=>0,
    "\x8f\xd6\xa1"=>0,
    "\x8f\xd6\xa2"=>0,
    "\x8f\xd6\xa3"=>0,
    "\x8f\xd6\xa4"=>0,
    "\x8f\xd6\xa5"=>0,
    "\x8f\xd6\xa6"=>0,
    "\x8f\xd6\xa7"=>0,
    "\x8f\xd6\xa8"=>0,
    "\x8f\xd6\xa9"=>0,
    "\x8f\xd6\xaa"=>0,
    "\x8f\xd6\xab"=>0,
    "\x8f\xd6\xac"=>0,
    "\x8f\xd6\xad"=>0,
    "\x8f\xd6\xae"=>0,
    "\x8f\xd6\xaf"=>0,
    "\x8f\xd6\xb0"=>0,
    "\x8f\xd6\xb1"=>0,
    "\x8f\xd6\xb2"=>0,
    "\x8f\xd6\xb3"=>0,
    "\x8f\xd6\xb4"=>0,
    "\x8f\xd6\xb5"=>0,
    "\x8f\xd6\xb6"=>0,
    "\x8f\xd6\xb7"=>0,
    "\x8f\xd6\xb8"=>0,
    "\x8f\xd6\xb9"=>0,
    "\x8f\xd6\xba"=>0,
    "\x8f\xd6\xbb"=>0,
    "\x8f\xd6\xbc"=>0,
    "\x8f\xd6\xbd"=>0,
    "\x8f\xd6\xbe"=>0,
    "\x8f\xd6\xbf"=>0,
    "\x8f\xd6\xc0"=>0,
    "\x8f\xd6\xc1"=>0,
    "\x8f\xd6\xc2"=>0,
    "\x8f\xd6\xc3"=>0,
    "\x8f\xd6\xc4"=>0,
    "\x8f\xd6\xc5"=>0,
    "\x8f\xd6\xc6"=>0,
    "\x8f\xd6\xc7"=>0,
    "\x8f\xd6\xc8"=>0,
    "\x8f\xd6\xc9"=>0,
    "\x8f\xd6\xca"=>0,
    "\x8f\xd6\xcb"=>0,
    "\x8f\xd6\xcc"=>0,
    "\x8f\xd6\xcd"=>0,
    "\x8f\xd6\xce"=>0,
    "\x8f\xd6\xcf"=>0,
    "\x8f\xd6\xd0"=>0,
    "\x8f\xd6\xd1"=>0,
    "\x8f\xd6\xd2"=>0,
    "\x8f\xd6\xd3"=>0,
    "\x8f\xd6\xd4"=>0,
    "\x8f\xd6\xd5"=>0,
    "\x8f\xd6\xd6"=>0,
    "\x8f\xd6\xd7"=>0,
    "\x8f\xd6\xd8"=>0,
    "\x8f\xd6\xd9"=>0,
    "\x8f\xd6\xda"=>0,
    "\x8f\xd6\xdb"=>0,
    "\x8f\xd6\xdc"=>0,
    "\x8f\xd6\xdd"=>0,
    "\x8f\xd6\xde"=>0,
    "\x8f\xd6\xdf"=>0,
    "\x8f\xd6\xe0"=>0,
    "\x8f\xd6\xe1"=>0,
    "\x8f\xd6\xe2"=>0,
    "\x8f\xd6\xe3"=>0,
    "\x8f\xd6\xe4"=>0,
    "\x8f\xd6\xe5"=>0,
    "\x8f\xd6\xe6"=>0,
    "\x8f\xd6\xe7"=>0,
    "\x8f\xd6\xe8"=>0,
    "\x8f\xd6\xe9"=>0,
    "\x8f\xd6\xea"=>0,
    "\x8f\xd6\xeb"=>0,
    "\x8f\xd6\xec"=>0,
    "\x8f\xd6\xed"=>0,
    "\x8f\xd6\xee"=>0,
    "\x8f\xd6\xef"=>0,
    "\x8f\xd6\xf0"=>0,
    "\x8f\xd6\xf1"=>0,
    "\x8f\xd6\xf2"=>0,
    "\x8f\xd6\xf3"=>0,
    "\x8f\xd6\xf4"=>0,
    "\x8f\xd6\xf5"=>0,
    "\x8f\xd6\xf6"=>0,
    "\x8f\xd6\xf7"=>0,
    "\x8f\xd6\xf8"=>0,
    "\x8f\xd6\xf9"=>0,
    "\x8f\xd6\xfa"=>0,
    "\x8f\xd6\xfb"=>0,
    "\x8f\xd6\xfc"=>0,
    "\x8f\xd6\xfd"=>0,
    "\x8f\xd6\xfe"=>0,
    "\x8f\xd7\xa1"=>0,
    "\x8f\xd7\xa2"=>0,
    "\x8f\xd7\xa3"=>0,
    "\x8f\xd7\xa4"=>0,
    "\x8f\xd7\xa5"=>0,
    "\x8f\xd7\xa6"=>0,
    "\x8f\xd7\xa7"=>0,
    "\x8f\xd7\xa8"=>0,
    "\x8f\xd7\xa9"=>0,
    "\x8f\xd7\xaa"=>0,
    "\x8f\xd7\xab"=>0,
    "\x8f\xd7\xac"=>0,
    "\x8f\xd7\xad"=>0,
    "\x8f\xd7\xae"=>0,
    "\x8f\xd7\xaf"=>0,
    "\x8f\xd7\xb0"=>0,
    "\x8f\xd7\xb1"=>0,
    "\x8f\xd7\xb2"=>0,
    "\x8f\xd7\xb3"=>0,
    "\x8f\xd7\xb4"=>0,
    "\x8f\xd7\xb5"=>0,
    "\x8f\xd7\xb6"=>0,
    "\x8f\xd7\xb7"=>0,
    "\x8f\xd7\xb8"=>0,
    "\x8f\xd7\xb9"=>0,
    "\x8f\xd7\xba"=>0,
    "\x8f\xd7\xbb"=>0,
    "\x8f\xd7\xbc"=>0,
    "\x8f\xd7\xbd"=>0,
    "\x8f\xd7\xbe"=>0,
    "\x8f\xd7\xbf"=>0,
    "\x8f\xd7\xc0"=>0,
    "\x8f\xd7\xc1"=>0,
    "\x8f\xd7\xc2"=>0,
    "\x8f\xd7\xc3"=>0,
    "\x8f\xd7\xc4"=>0,
    "\x8f\xd7\xc5"=>0,
    "\x8f\xd7\xc6"=>0,
    "\x8f\xd7\xc7"=>0,
    "\x8f\xd7\xc8"=>0,
    "\x8f\xd7\xc9"=>0,
    "\x8f\xd7\xca"=>0,
    "\x8f\xd7\xcb"=>0,
    "\x8f\xd7\xcc"=>0,
    "\x8f\xd7\xcd"=>0,
    "\x8f\xd7\xce"=>0,
    "\x8f\xd7\xcf"=>0,
    "\x8f\xd7\xd0"=>0,
    "\x8f\xd7\xd1"=>0,
    "\x8f\xd7\xd2"=>0,
    "\x8f\xd7\xd3"=>0,
    "\x8f\xd7\xd4"=>0,
    "\x8f\xd7\xd5"=>0,
    "\x8f\xd7\xd6"=>0,
    "\x8f\xd7\xd7"=>0,
    "\x8f\xd7\xd8"=>0,
    "\x8f\xd7\xd9"=>0,
    "\x8f\xd7\xda"=>0,
    "\x8f\xd7\xdb"=>0,
    "\x8f\xd7\xdc"=>0,
    "\x8f\xd7\xdd"=>0,
    "\x8f\xd7\xde"=>0,
    "\x8f\xd7\xdf"=>0,
    "\x8f\xd7\xe0"=>0,
    "\x8f\xd7\xe1"=>0,
    "\x8f\xd7\xe2"=>0,
    "\x8f\xd7\xe3"=>0,
    "\x8f\xd7\xe4"=>0,
    "\x8f\xd7\xe5"=>0,
    "\x8f\xd7\xe6"=>0,
    "\x8f\xd7\xe7"=>0,
    "\x8f\xd7\xe8"=>0,
    "\x8f\xd7\xe9"=>0,
    "\x8f\xd7\xea"=>0,
    "\x8f\xd7\xeb"=>0,
    "\x8f\xd7\xec"=>0,
    "\x8f\xd7\xed"=>0,
    "\x8f\xd7\xee"=>0,
    "\x8f\xd7\xef"=>0,
    "\x8f\xd7\xf0"=>0,
    "\x8f\xd7\xf1"=>0,
    "\x8f\xd7\xf2"=>0,
    "\x8f\xd7\xf3"=>0,
    "\x8f\xd7\xf4"=>0,
    "\x8f\xd7\xf5"=>0,
    "\x8f\xd7\xf6"=>0,
    "\x8f\xd7\xf7"=>0,
    "\x8f\xd7\xf8"=>0,
    "\x8f\xd7\xf9"=>0,
    "\x8f\xd7\xfa"=>0,
    "\x8f\xd7\xfb"=>0,
    "\x8f\xd7\xfc"=>0,
    "\x8f\xd7\xfd"=>0,
    "\x8f\xd7\xfe"=>0,
    "\x8f\xd8\xa1"=>0,
    "\x8f\xd8\xa2"=>0,
    "\x8f\xd8\xa3"=>0,
    "\x8f\xd8\xa4"=>0,
    "\x8f\xd8\xa5"=>0,
    "\x8f\xd8\xa6"=>0,
    "\x8f\xd8\xa7"=>0,
    "\x8f\xd8\xa8"=>0,
    "\x8f\xd8\xa9"=>0,
    "\x8f\xd8\xaa"=>0,
    "\x8f\xd8\xab"=>0,
    "\x8f\xd8\xac"=>0,
    "\x8f\xd8\xad"=>0,
    "\x8f\xd8\xae"=>0,
    "\x8f\xd8\xaf"=>0,
    "\x8f\xd8\xb0"=>0,
    "\x8f\xd8\xb1"=>0,
    "\x8f\xd8\xb2"=>0,
    "\x8f\xd8\xb3"=>0,
    "\x8f\xd8\xb4"=>0,
    "\x8f\xd8\xb5"=>0,
    "\x8f\xd8\xb6"=>0,
    "\x8f\xd8\xb7"=>0,
    "\x8f\xd8\xb8"=>0,
    "\x8f\xd8\xb9"=>0,
    "\x8f\xd8\xba"=>0,
    "\x8f\xd8\xbb"=>0,
    "\x8f\xd8\xbc"=>0,
    "\x8f\xd8\xbd"=>0,
    "\x8f\xd8\xbe"=>0,
    "\x8f\xd8\xbf"=>0,
    "\x8f\xd8\xc0"=>0,
    "\x8f\xd8\xc1"=>0,
    "\x8f\xd8\xc2"=>0,
    "\x8f\xd8\xc3"=>0,
    "\x8f\xd8\xc4"=>0,
    "\x8f\xd8\xc5"=>0,
    "\x8f\xd8\xc6"=>0,
    "\x8f\xd8\xc7"=>0,
    "\x8f\xd8\xc8"=>0,
    "\x8f\xd8\xc9"=>0,
    "\x8f\xd8\xca"=>0,
    "\x8f\xd8\xcb"=>0,
    "\x8f\xd8\xcc"=>0,
    "\x8f\xd8\xcd"=>0,
    "\x8f\xd8\xce"=>0,
    "\x8f\xd8\xcf"=>0,
    "\x8f\xd8\xd0"=>0,
    "\x8f\xd8\xd1"=>0,
    "\x8f\xd8\xd2"=>0,
    "\x8f\xd8\xd3"=>0,
    "\x8f\xd8\xd4"=>0,
    "\x8f\xd8\xd5"=>0,
    "\x8f\xd8\xd6"=>0,
    "\x8f\xd8\xd7"=>0,
    "\x8f\xd8\xd8"=>0,
    "\x8f\xd8\xd9"=>0,
    "\x8f\xd8\xda"=>0,
    "\x8f\xd8\xdb"=>0,
    "\x8f\xd8\xdc"=>0,
    "\x8f\xd8\xdd"=>0,
    "\x8f\xd8\xde"=>0,
    "\x8f\xd8\xdf"=>0,
    "\x8f\xd8\xe0"=>0,
    "\x8f\xd8\xe1"=>0,
    "\x8f\xd8\xe2"=>0,
    "\x8f\xd8\xe3"=>0,
    "\x8f\xd8\xe4"=>0,
    "\x8f\xd8\xe5"=>0,
    "\x8f\xd8\xe6"=>0,
    "\x8f\xd8\xe7"=>0,
    "\x8f\xd8\xe8"=>0,
    "\x8f\xd8\xe9"=>0,
    "\x8f\xd8\xea"=>0,
    "\x8f\xd8\xeb"=>0,
    "\x8f\xd8\xec"=>0,
    "\x8f\xd8\xed"=>0,
    "\x8f\xd8\xee"=>0,
    "\x8f\xd8\xef"=>0,
    "\x8f\xd8\xf0"=>0,
    "\x8f\xd8\xf1"=>0,
    "\x8f\xd8\xf2"=>0,
    "\x8f\xd8\xf3"=>0,
    "\x8f\xd8\xf4"=>0,
    "\x8f\xd8\xf5"=>0,
    "\x8f\xd8\xf6"=>0,
    "\x8f\xd8\xf7"=>0,
    "\x8f\xd8\xf8"=>0,
    "\x8f\xd8\xf9"=>0,
    "\x8f\xd8\xfa"=>0,
    "\x8f\xd8\xfb"=>0,
    "\x8f\xd8\xfc"=>0,
    "\x8f\xd8\xfd"=>0,
    "\x8f\xd8\xfe"=>0,
    "\x8f\xd9\xa1"=>0,
    "\x8f\xd9\xa2"=>0,
    "\x8f\xd9\xa3"=>0,
    "\x8f\xd9\xa4"=>0,
    "\x8f\xd9\xa5"=>0,
    "\x8f\xd9\xa6"=>0,
    "\x8f\xd9\xa7"=>0,
    "\x8f\xd9\xa8"=>0,
    "\x8f\xd9\xa9"=>0,
    "\x8f\xd9\xaa"=>0,
    "\x8f\xd9\xab"=>0,
    "\x8f\xd9\xac"=>0,
    "\x8f\xd9\xad"=>0,
    "\x8f\xd9\xae"=>0,
    "\x8f\xd9\xaf"=>0,
    "\x8f\xd9\xb0"=>0,
    "\x8f\xd9\xb1"=>0,
    "\x8f\xd9\xb2"=>0,
    "\x8f\xd9\xb3"=>0,
    "\x8f\xd9\xb4"=>0,
    "\x8f\xd9\xb5"=>0,
    "\x8f\xd9\xb6"=>0,
    "\x8f\xd9\xb7"=>0,
    "\x8f\xd9\xb8"=>0,
    "\x8f\xd9\xb9"=>0,
    "\x8f\xd9\xba"=>0,
    "\x8f\xd9\xbb"=>0,
    "\x8f\xd9\xbc"=>0,
    "\x8f\xd9\xbd"=>0,
    "\x8f\xd9\xbe"=>0,
    "\x8f\xd9\xbf"=>0,
    "\x8f\xd9\xc0"=>0,
    "\x8f\xd9\xc1"=>0,
    "\x8f\xd9\xc2"=>0,
    "\x8f\xd9\xc3"=>0,
    "\x8f\xd9\xc4"=>0,
    "\x8f\xd9\xc5"=>0,
    "\x8f\xd9\xc6"=>0,
    "\x8f\xd9\xc7"=>0,
    "\x8f\xd9\xc8"=>0,
    "\x8f\xd9\xc9"=>0,
    "\x8f\xd9\xca"=>0,
    "\x8f\xd9\xcb"=>0,
    "\x8f\xd9\xcc"=>0,
    "\x8f\xd9\xcd"=>0,
    "\x8f\xd9\xce"=>0,
    "\x8f\xd9\xcf"=>0,
    "\x8f\xd9\xd0"=>0,
    "\x8f\xd9\xd1"=>0,
    "\x8f\xd9\xd2"=>0,
    "\x8f\xd9\xd3"=>0,
    "\x8f\xd9\xd4"=>0,
    "\x8f\xd9\xd5"=>0,
    "\x8f\xd9\xd6"=>0,
    "\x8f\xd9\xd7"=>0,
    "\x8f\xd9\xd8"=>0,
    "\x8f\xd9\xd9"=>0,
    "\x8f\xd9\xda"=>0,
    "\x8f\xd9\xdb"=>0,
    "\x8f\xd9\xdc"=>0,
    "\x8f\xd9\xdd"=>0,
    "\x8f\xd9\xde"=>0,
    "\x8f\xd9\xdf"=>0,
    "\x8f\xd9\xe0"=>0,
    "\x8f\xd9\xe1"=>0,
    "\x8f\xd9\xe2"=>0,
    "\x8f\xd9\xe3"=>0,
    "\x8f\xd9\xe4"=>0,
    "\x8f\xd9\xe5"=>0,
    "\x8f\xd9\xe6"=>0,
    "\x8f\xd9\xe7"=>0,
    "\x8f\xd9\xe8"=>0,
    "\x8f\xd9\xe9"=>0,
    "\x8f\xd9\xea"=>0,
    "\x8f\xd9\xeb"=>0,
    "\x8f\xd9\xec"=>0,
    "\x8f\xd9\xed"=>0,
    "\x8f\xd9\xee"=>0,
    "\x8f\xd9\xef"=>0,
    "\x8f\xd9\xf0"=>0,
    "\x8f\xd9\xf1"=>0,
    "\x8f\xd9\xf2"=>0,
    "\x8f\xd9\xf3"=>0,
    "\x8f\xd9\xf4"=>0,
    "\x8f\xd9\xf5"=>0,
    "\x8f\xd9\xf6"=>0,
    "\x8f\xd9\xf7"=>0,
    "\x8f\xd9\xf8"=>0,
    "\x8f\xd9\xf9"=>0,
    "\x8f\xd9\xfa"=>0,
    "\x8f\xd9\xfb"=>0,
    "\x8f\xd9\xfc"=>0,
    "\x8f\xd9\xfd"=>0,
    "\x8f\xd9\xfe"=>0,
    "\x8f\xda\xa1"=>0,
    "\x8f\xda\xa2"=>0,
    "\x8f\xda\xa3"=>0,
    "\x8f\xda\xa4"=>0,
    "\x8f\xda\xa5"=>0,
    "\x8f\xda\xa6"=>0,
    "\x8f\xda\xa7"=>0,
    "\x8f\xda\xa8"=>0,
    "\x8f\xda\xa9"=>0,
    "\x8f\xda\xaa"=>0,
    "\x8f\xda\xab"=>0,
    "\x8f\xda\xac"=>0,
    "\x8f\xda\xad"=>0,
    "\x8f\xda\xae"=>0,
    "\x8f\xda\xaf"=>0,
    "\x8f\xda\xb0"=>0,
    "\x8f\xda\xb1"=>0,
    "\x8f\xda\xb2"=>0,
    "\x8f\xda\xb3"=>0,
    "\x8f\xda\xb4"=>0,
    "\x8f\xda\xb5"=>0,
    "\x8f\xda\xb6"=>0,
    "\x8f\xda\xb7"=>0,
    "\x8f\xda\xb8"=>0,
    "\x8f\xda\xb9"=>0,
    "\x8f\xda\xba"=>0,
    "\x8f\xda\xbb"=>0,
    "\x8f\xda\xbc"=>0,
    "\x8f\xda\xbd"=>0,
    "\x8f\xda\xbe"=>0,
    "\x8f\xda\xbf"=>0,
    "\x8f\xda\xc0"=>0,
    "\x8f\xda\xc1"=>0,
    "\x8f\xda\xc2"=>0,
    "\x8f\xda\xc3"=>0,
    "\x8f\xda\xc4"=>0,
    "\x8f\xda\xc5"=>0,
    "\x8f\xda\xc6"=>0,
    "\x8f\xda\xc7"=>0,
    "\x8f\xda\xc8"=>0,
    "\x8f\xda\xc9"=>0,
    "\x8f\xda\xca"=>0,
    "\x8f\xda\xcb"=>0,
    "\x8f\xda\xcc"=>0,
    "\x8f\xda\xcd"=>0,
    "\x8f\xda\xce"=>0,
    "\x8f\xda\xcf"=>0,
    "\x8f\xda\xd0"=>0,
    "\x8f\xda\xd1"=>0,
    "\x8f\xda\xd2"=>0,
    "\x8f\xda\xd3"=>0,
    "\x8f\xda\xd4"=>0,
    "\x8f\xda\xd5"=>0,
    "\x8f\xda\xd6"=>0,
    "\x8f\xda\xd7"=>0,
    "\x8f\xda\xd8"=>0,
    "\x8f\xda\xd9"=>0,
    "\x8f\xda\xda"=>0,
    "\x8f\xda\xdb"=>0,
    "\x8f\xda\xdc"=>0,
    "\x8f\xda\xdd"=>0,
    "\x8f\xda\xde"=>0,
    "\x8f\xda\xdf"=>0,
    "\x8f\xda\xe0"=>0,
    "\x8f\xda\xe1"=>0,
    "\x8f\xda\xe2"=>0,
    "\x8f\xda\xe3"=>0,
    "\x8f\xda\xe4"=>0,
    "\x8f\xda\xe5"=>0,
    "\x8f\xda\xe6"=>0,
    "\x8f\xda\xe7"=>0,
    "\x8f\xda\xe8"=>0,
    "\x8f\xda\xe9"=>0,
    "\x8f\xda\xea"=>0,
    "\x8f\xda\xeb"=>0,
    "\x8f\xda\xec"=>0,
    "\x8f\xda\xed"=>0,
    "\x8f\xda\xee"=>0,
    "\x8f\xda\xef"=>0,
    "\x8f\xda\xf0"=>0,
    "\x8f\xda\xf1"=>0,
    "\x8f\xda\xf2"=>0,
    "\x8f\xda\xf3"=>0,
    "\x8f\xda\xf4"=>0,
    "\x8f\xda\xf5"=>0,
    "\x8f\xda\xf6"=>0,
    "\x8f\xda\xf7"=>0,
    "\x8f\xda\xf8"=>0,
    "\x8f\xda\xf9"=>0,
    "\x8f\xda\xfa"=>0,
    "\x8f\xda\xfb"=>0,
    "\x8f\xda\xfc"=>0,
    "\x8f\xda\xfd"=>0,
    "\x8f\xda\xfe"=>0,
    "\x8f\xdb\xa1"=>0,
    "\x8f\xdb\xa2"=>0,
    "\x8f\xdb\xa3"=>0,
    "\x8f\xdb\xa4"=>0,
    "\x8f\xdb\xa5"=>0,
    "\x8f\xdb\xa6"=>0,
    "\x8f\xdb\xa7"=>0,
    "\x8f\xdb\xa8"=>0,
    "\x8f\xdb\xa9"=>0,
    "\x8f\xdb\xaa"=>0,
    "\x8f\xdb\xab"=>0,
    "\x8f\xdb\xac"=>0,
    "\x8f\xdb\xad"=>0,
    "\x8f\xdb\xae"=>0,
    "\x8f\xdb\xaf"=>0,
    "\x8f\xdb\xb0"=>0,
    "\x8f\xdb\xb1"=>0,
    "\x8f\xdb\xb2"=>0,
    "\x8f\xdb\xb3"=>0,
    "\x8f\xdb\xb4"=>0,
    "\x8f\xdb\xb5"=>0,
    "\x8f\xdb\xb6"=>0,
    "\x8f\xdb\xb7"=>0,
    "\x8f\xdb\xb8"=>0,
    "\x8f\xdb\xb9"=>0,
    "\x8f\xdb\xba"=>0,
    "\x8f\xdb\xbb"=>0,
    "\x8f\xdb\xbc"=>0,
    "\x8f\xdb\xbd"=>0,
    "\x8f\xdb\xbe"=>0,
    "\x8f\xdb\xbf"=>0,
    "\x8f\xdb\xc0"=>0,
    "\x8f\xdb\xc1"=>0,
    "\x8f\xdb\xc2"=>0,
    "\x8f\xdb\xc3"=>0,
    "\x8f\xdb\xc4"=>0,
    "\x8f\xdb\xc5"=>0,
    "\x8f\xdb\xc6"=>0,
    "\x8f\xdb\xc7"=>0,
    "\x8f\xdb\xc8"=>0,
    "\x8f\xdb\xc9"=>0,
    "\x8f\xdb\xca"=>0,
    "\x8f\xdb\xcb"=>0,
    "\x8f\xdb\xcc"=>0,
    "\x8f\xdb\xcd"=>0,
    "\x8f\xdb\xce"=>0,
    "\x8f\xdb\xcf"=>0,
    "\x8f\xdb\xd0"=>0,
    "\x8f\xdb\xd1"=>0,
    "\x8f\xdb\xd2"=>0,
    "\x8f\xdb\xd3"=>0,
    "\x8f\xdb\xd4"=>0,
    "\x8f\xdb\xd5"=>0,
    "\x8f\xdb\xd6"=>0,
    "\x8f\xdb\xd7"=>0,
    "\x8f\xdb\xd8"=>0,
    "\x8f\xdb\xd9"=>0,
    "\x8f\xdb\xda"=>0,
    "\x8f\xdb\xdb"=>0,
    "\x8f\xdb\xdc"=>0,
    "\x8f\xdb\xdd"=>0,
    "\x8f\xdb\xde"=>0,
    "\x8f\xdb\xdf"=>0,
    "\x8f\xdb\xe0"=>0,
    "\x8f\xdb\xe1"=>0,
    "\x8f\xdb\xe2"=>0,
    "\x8f\xdb\xe3"=>0,
    "\x8f\xdb\xe4"=>0,
    "\x8f\xdb\xe5"=>0,
    "\x8f\xdb\xe6"=>0,
    "\x8f\xdb\xe7"=>0,
    "\x8f\xdb\xe8"=>0,
    "\x8f\xdb\xe9"=>0,
    "\x8f\xdb\xea"=>0,
    "\x8f\xdb\xeb"=>0,
    "\x8f\xdb\xec"=>0,
    "\x8f\xdb\xed"=>0,
    "\x8f\xdb\xee"=>0,
    "\x8f\xdb\xef"=>0,
    "\x8f\xdb\xf0"=>0,
    "\x8f\xdb\xf1"=>0,
    "\x8f\xdb\xf2"=>0,
    "\x8f\xdb\xf3"=>0,
    "\x8f\xdb\xf4"=>0,
    "\x8f\xdb\xf5"=>0,
    "\x8f\xdb\xf6"=>0,
    "\x8f\xdb\xf7"=>0,
    "\x8f\xdb\xf8"=>0,
    "\x8f\xdb\xf9"=>0,
    "\x8f\xdb\xfa"=>0,
    "\x8f\xdb\xfb"=>0,
    "\x8f\xdb\xfc"=>0,
    "\x8f\xdb\xfd"=>0,
    "\x8f\xdb\xfe"=>0,
    "\x8f\xdc\xa1"=>0,
    "\x8f\xdc\xa2"=>0,
    "\x8f\xdc\xa3"=>0,
    "\x8f\xdc\xa4"=>0,
    "\x8f\xdc\xa5"=>0,
    "\x8f\xdc\xa6"=>0,
    "\x8f\xdc\xa7"=>0,
    "\x8f\xdc\xa8"=>0,
    "\x8f\xdc\xa9"=>0,
    "\x8f\xdc\xaa"=>0,
    "\x8f\xdc\xab"=>0,
    "\x8f\xdc\xac"=>0,
    "\x8f\xdc\xad"=>0,
    "\x8f\xdc\xae"=>0,
    "\x8f\xdc\xaf"=>0,
    "\x8f\xdc\xb0"=>0,
    "\x8f\xdc\xb1"=>0,
    "\x8f\xdc\xb2"=>0,
    "\x8f\xdc\xb3"=>0,
    "\x8f\xdc\xb4"=>0,
    "\x8f\xdc\xb5"=>0,
    "\x8f\xdc\xb6"=>0,
    "\x8f\xdc\xb7"=>0,
    "\x8f\xdc\xb8"=>0,
    "\x8f\xdc\xb9"=>0,
    "\x8f\xdc\xba"=>0,
    "\x8f\xdc\xbb"=>0,
    "\x8f\xdc\xbc"=>0,
    "\x8f\xdc\xbd"=>0,
    "\x8f\xdc\xbe"=>0,
    "\x8f\xdc\xbf"=>0,
    "\x8f\xdc\xc0"=>0,
    "\x8f\xdc\xc1"=>0,
    "\x8f\xdc\xc2"=>0,
    "\x8f\xdc\xc3"=>0,
    "\x8f\xdc\xc4"=>0,
    "\x8f\xdc\xc5"=>0,
    "\x8f\xdc\xc6"=>0,
    "\x8f\xdc\xc7"=>0,
    "\x8f\xdc\xc8"=>0,
    "\x8f\xdc\xc9"=>0,
    "\x8f\xdc\xca"=>0,
    "\x8f\xdc\xcb"=>0,
    "\x8f\xdc\xcc"=>0,
    "\x8f\xdc\xcd"=>0,
    "\x8f\xdc\xce"=>0,
    "\x8f\xdc\xcf"=>0,
    "\x8f\xdc\xd0"=>0,
    "\x8f\xdc\xd1"=>0,
    "\x8f\xdc\xd2"=>0,
    "\x8f\xdc\xd3"=>0,
    "\x8f\xdc\xd4"=>0,
    "\x8f\xdc\xd5"=>0,
    "\x8f\xdc\xd6"=>0,
    "\x8f\xdc\xd7"=>0,
    "\x8f\xdc\xd8"=>0,
    "\x8f\xdc\xd9"=>0,
    "\x8f\xdc\xda"=>0,
    "\x8f\xdc\xdb"=>0,
    "\x8f\xdc\xdc"=>0,
    "\x8f\xdc\xdd"=>0,
    "\x8f\xdc\xde"=>0,
    "\x8f\xdc\xdf"=>0,
    "\x8f\xdc\xe0"=>0,
    "\x8f\xdc\xe1"=>0,
    "\x8f\xdc\xe2"=>0,
    "\x8f\xdc\xe3"=>0,
    "\x8f\xdc\xe4"=>0,
    "\x8f\xdc\xe5"=>0,
    "\x8f\xdc\xe6"=>0,
    "\x8f\xdc\xe7"=>0,
    "\x8f\xdc\xe8"=>0,
    "\x8f\xdc\xe9"=>0,
    "\x8f\xdc\xea"=>0,
    "\x8f\xdc\xeb"=>0,
    "\x8f\xdc\xec"=>0,
    "\x8f\xdc\xed"=>0,
    "\x8f\xdc\xee"=>0,
    "\x8f\xdc\xef"=>0,
    "\x8f\xdc\xf0"=>0,
    "\x8f\xdc\xf1"=>0,
    "\x8f\xdc\xf2"=>0,
    "\x8f\xdc\xf3"=>0,
    "\x8f\xdc\xf4"=>0,
    "\x8f\xdc\xf5"=>0,
    "\x8f\xdc\xf6"=>0,
    "\x8f\xdc\xf7"=>0,
    "\x8f\xdc\xf8"=>0,
    "\x8f\xdc\xf9"=>0,
    "\x8f\xdc\xfa"=>0,
    "\x8f\xdc\xfb"=>0,
    "\x8f\xdc\xfc"=>0,
    "\x8f\xdc\xfd"=>0,
    "\x8f\xdc\xfe"=>0,
    "\x8f\xdd\xa1"=>0,
    "\x8f\xdd\xa2"=>0,
    "\x8f\xdd\xa3"=>0,
    "\x8f\xdd\xa4"=>0,
    "\x8f\xdd\xa5"=>0,
    "\x8f\xdd\xa6"=>0,
    "\x8f\xdd\xa7"=>0,
    "\x8f\xdd\xa8"=>0,
    "\x8f\xdd\xa9"=>0,
    "\x8f\xdd\xaa"=>0,
    "\x8f\xdd\xab"=>0,
    "\x8f\xdd\xac"=>0,
    "\x8f\xdd\xad"=>0,
    "\x8f\xdd\xae"=>0,
    "\x8f\xdd\xaf"=>0,
    "\x8f\xdd\xb0"=>0,
    "\x8f\xdd\xb1"=>0,
    "\x8f\xdd\xb2"=>0,
    "\x8f\xdd\xb3"=>0,
    "\x8f\xdd\xb4"=>0,
    "\x8f\xdd\xb5"=>0,
    "\x8f\xdd\xb6"=>0,
    "\x8f\xdd\xb7"=>0,
    "\x8f\xdd\xb8"=>0,
    "\x8f\xdd\xb9"=>0,
    "\x8f\xdd\xba"=>0,
    "\x8f\xdd\xbb"=>0,
    "\x8f\xdd\xbc"=>0,
    "\x8f\xdd\xbd"=>0,
    "\x8f\xdd\xbe"=>0,
    "\x8f\xdd\xbf"=>0,
    "\x8f\xdd\xc0"=>0,
    "\x8f\xdd\xc1"=>0,
    "\x8f\xdd\xc2"=>0,
    "\x8f\xdd\xc3"=>0,
    "\x8f\xdd\xc4"=>0,
    "\x8f\xdd\xc5"=>0,
    "\x8f\xdd\xc6"=>0,
    "\x8f\xdd\xc7"=>0,
    "\x8f\xdd\xc8"=>0,
    "\x8f\xdd\xc9"=>0,
    "\x8f\xdd\xca"=>0,
    "\x8f\xdd\xcb"=>0,
    "\x8f\xdd\xcc"=>0,
    "\x8f\xdd\xcd"=>0,
    "\x8f\xdd\xce"=>0,
    "\x8f\xdd\xcf"=>0,
    "\x8f\xdd\xd0"=>0,
    "\x8f\xdd\xd1"=>0,
    "\x8f\xdd\xd2"=>0,
    "\x8f\xdd\xd3"=>0,
    "\x8f\xdd\xd4"=>0,
    "\x8f\xdd\xd5"=>0,
    "\x8f\xdd\xd6"=>0,
    "\x8f\xdd\xd7"=>0,
    "\x8f\xdd\xd8"=>0,
    "\x8f\xdd\xd9"=>0,
    "\x8f\xdd\xda"=>0,
    "\x8f\xdd\xdb"=>0,
    "\x8f\xdd\xdc"=>0,
    "\x8f\xdd\xdd"=>0,
    "\x8f\xdd\xde"=>0,
    "\x8f\xdd\xdf"=>0,
    "\x8f\xdd\xe0"=>0,
    "\x8f\xdd\xe1"=>0,
    "\x8f\xdd\xe2"=>0,
    "\x8f\xdd\xe3"=>0,
    "\x8f\xdd\xe4"=>0,
    "\x8f\xdd\xe5"=>0,
    "\x8f\xdd\xe6"=>0,
    "\x8f\xdd\xe7"=>0,
    "\x8f\xdd\xe8"=>0,
    "\x8f\xdd\xe9"=>0,
    "\x8f\xdd\xea"=>0,
    "\x8f\xdd\xeb"=>0,
    "\x8f\xdd\xec"=>0,
    "\x8f\xdd\xed"=>0,
    "\x8f\xdd\xee"=>0,
    "\x8f\xdd\xef"=>0,
    "\x8f\xdd\xf0"=>0,
    "\x8f\xdd\xf1"=>0,
    "\x8f\xdd\xf2"=>0,
    "\x8f\xdd\xf3"=>0,
    "\x8f\xdd\xf4"=>0,
    "\x8f\xdd\xf5"=>0,
    "\x8f\xdd\xf6"=>0,
    "\x8f\xdd\xf7"=>0,
    "\x8f\xdd\xf8"=>0,
    "\x8f\xdd\xf9"=>0,
    "\x8f\xdd\xfa"=>0,
    "\x8f\xdd\xfb"=>0,
    "\x8f\xdd\xfc"=>0,
    "\x8f\xdd\xfd"=>0,
    "\x8f\xdd\xfe"=>0,
    "\x8f\xde\xa1"=>0,
    "\x8f\xde\xa2"=>0,
    "\x8f\xde\xa3"=>0,
    "\x8f\xde\xa4"=>0,
    "\x8f\xde\xa5"=>0,
    "\x8f\xde\xa6"=>0,
    "\x8f\xde\xa7"=>0,
    "\x8f\xde\xa8"=>0,
    "\x8f\xde\xa9"=>0,
    "\x8f\xde\xaa"=>0,
    "\x8f\xde\xab"=>0,
    "\x8f\xde\xac"=>0,
    "\x8f\xde\xad"=>0,
    "\x8f\xde\xae"=>0,
    "\x8f\xde\xaf"=>0,
    "\x8f\xde\xb0"=>0,
    "\x8f\xde\xb1"=>0,
    "\x8f\xde\xb2"=>0,
    "\x8f\xde\xb3"=>0,
    "\x8f\xde\xb4"=>0,
    "\x8f\xde\xb5"=>0,
    "\x8f\xde\xb6"=>0,
    "\x8f\xde\xb7"=>0,
    "\x8f\xde\xb8"=>0,
    "\x8f\xde\xb9"=>0,
    "\x8f\xde\xba"=>0,
    "\x8f\xde\xbb"=>0,
    "\x8f\xde\xbc"=>0,
    "\x8f\xde\xbd"=>0,
    "\x8f\xde\xbe"=>0,
    "\x8f\xde\xbf"=>0,
    "\x8f\xde\xc0"=>0,
    "\x8f\xde\xc1"=>0,
    "\x8f\xde\xc2"=>0,
    "\x8f\xde\xc3"=>0,
    "\x8f\xde\xc4"=>0,
    "\x8f\xde\xc5"=>0,
    "\x8f\xde\xc6"=>0,
    "\x8f\xde\xc7"=>0,
    "\x8f\xde\xc8"=>0,
    "\x8f\xde\xc9"=>0,
    "\x8f\xde\xca"=>0,
    "\x8f\xde\xcb"=>0,
    "\x8f\xde\xcc"=>0,
    "\x8f\xde\xcd"=>0,
    "\x8f\xde\xce"=>0,
    "\x8f\xde\xcf"=>0,
    "\x8f\xde\xd0"=>0,
    "\x8f\xde\xd1"=>0,
    "\x8f\xde\xd2"=>0,
    "\x8f\xde\xd3"=>0,
    "\x8f\xde\xd4"=>0,
    "\x8f\xde\xd5"=>0,
    "\x8f\xde\xd6"=>0,
    "\x8f\xde\xd7"=>0,
    "\x8f\xde\xd8"=>0,
    "\x8f\xde\xd9"=>0,
    "\x8f\xde\xda"=>0,
    "\x8f\xde\xdb"=>0,
    "\x8f\xde\xdc"=>0,
    "\x8f\xde\xdd"=>0,
    "\x8f\xde\xde"=>0,
    "\x8f\xde\xdf"=>0,
    "\x8f\xde\xe0"=>0,
    "\x8f\xde\xe1"=>0,
    "\x8f\xde\xe2"=>0,
    "\x8f\xde\xe3"=>0,
    "\x8f\xde\xe4"=>0,
    "\x8f\xde\xe5"=>0,
    "\x8f\xde\xe6"=>0,
    "\x8f\xde\xe7"=>0,
    "\x8f\xde\xe8"=>0,
    "\x8f\xde\xe9"=>0,
    "\x8f\xde\xea"=>0,
    "\x8f\xde\xeb"=>0,
    "\x8f\xde\xec"=>0,
    "\x8f\xde\xed"=>0,
    "\x8f\xde\xee"=>0,
    "\x8f\xde\xef"=>0,
    "\x8f\xde\xf0"=>0,
    "\x8f\xde\xf1"=>0,
    "\x8f\xde\xf2"=>0,
    "\x8f\xde\xf3"=>0,
    "\x8f\xde\xf4"=>0,
    "\x8f\xde\xf5"=>0,
    "\x8f\xde\xf6"=>0,
    "\x8f\xde\xf7"=>0,
    "\x8f\xde\xf8"=>0,
    "\x8f\xde\xf9"=>0,
    "\x8f\xde\xfa"=>0,
    "\x8f\xde\xfb"=>0,
    "\x8f\xde\xfc"=>0,
    "\x8f\xde\xfd"=>0,
    "\x8f\xde\xfe"=>0,
    "\x8f\xdf\xa1"=>0,
    "\x8f\xdf\xa2"=>0,
    "\x8f\xdf\xa3"=>0,
    "\x8f\xdf\xa4"=>0,
    "\x8f\xdf\xa5"=>0,
    "\x8f\xdf\xa6"=>0,
    "\x8f\xdf\xa7"=>0,
    "\x8f\xdf\xa8"=>0,
    "\x8f\xdf\xa9"=>0,
    "\x8f\xdf\xaa"=>0,
    "\x8f\xdf\xab"=>0,
    "\x8f\xdf\xac"=>0,
    "\x8f\xdf\xad"=>0,
    "\x8f\xdf\xae"=>0,
    "\x8f\xdf\xaf"=>0,
    "\x8f\xdf\xb0"=>0,
    "\x8f\xdf\xb1"=>0,
    "\x8f\xdf\xb2"=>0,
    "\x8f\xdf\xb3"=>0,
    "\x8f\xdf\xb4"=>0,
    "\x8f\xdf\xb5"=>0,
    "\x8f\xdf\xb6"=>0,
    "\x8f\xdf\xb7"=>0,
    "\x8f\xdf\xb8"=>0,
    "\x8f\xdf\xb9"=>0,
    "\x8f\xdf\xba"=>0,
    "\x8f\xdf\xbb"=>0,
    "\x8f\xdf\xbc"=>0,
    "\x8f\xdf\xbd"=>0,
    "\x8f\xdf\xbe"=>0,
    "\x8f\xdf\xbf"=>0,
    "\x8f\xdf\xc0"=>0,
    "\x8f\xdf\xc1"=>0,
    "\x8f\xdf\xc2"=>0,
    "\x8f\xdf\xc3"=>0,
    "\x8f\xdf\xc4"=>0,
    "\x8f\xdf\xc5"=>0,
    "\x8f\xdf\xc6"=>0,
    "\x8f\xdf\xc7"=>0,
    "\x8f\xdf\xc8"=>0,
    "\x8f\xdf\xc9"=>0,
    "\x8f\xdf\xca"=>0,
    "\x8f\xdf\xcb"=>0,
    "\x8f\xdf\xcc"=>0,
    "\x8f\xdf\xcd"=>0,
    "\x8f\xdf\xce"=>0,
    "\x8f\xdf\xcf"=>0,
    "\x8f\xdf\xd0"=>0,
    "\x8f\xdf\xd1"=>0,
    "\x8f\xdf\xd2"=>0,
    "\x8f\xdf\xd3"=>0,
    "\x8f\xdf\xd4"=>0,
    "\x8f\xdf\xd5"=>0,
    "\x8f\xdf\xd6"=>0,
    "\x8f\xdf\xd7"=>0,
    "\x8f\xdf\xd8"=>0,
    "\x8f\xdf\xd9"=>0,
    "\x8f\xdf\xda"=>0,
    "\x8f\xdf\xdb"=>0,
    "\x8f\xdf\xdc"=>0,
    "\x8f\xdf\xdd"=>0,
    "\x8f\xdf\xde"=>0,
    "\x8f\xdf\xdf"=>0,
    "\x8f\xdf\xe0"=>0,
    "\x8f\xdf\xe1"=>0,
    "\x8f\xdf\xe2"=>0,
    "\x8f\xdf\xe3"=>0,
    "\x8f\xdf\xe4"=>0,
    "\x8f\xdf\xe5"=>0,
    "\x8f\xdf\xe6"=>0,
    "\x8f\xdf\xe7"=>0,
    "\x8f\xdf\xe8"=>0,
    "\x8f\xdf\xe9"=>0,
    "\x8f\xdf\xea"=>0,
    "\x8f\xdf\xeb"=>0,
    "\x8f\xdf\xec"=>0,
    "\x8f\xdf\xed"=>0,
    "\x8f\xdf\xee"=>0,
    "\x8f\xdf\xef"=>0,
    "\x8f\xdf\xf0"=>0,
    "\x8f\xdf\xf1"=>0,
    "\x8f\xdf\xf2"=>0,
    "\x8f\xdf\xf3"=>0,
    "\x8f\xdf\xf4"=>0,
    "\x8f\xdf\xf5"=>0,
    "\x8f\xdf\xf6"=>0,
    "\x8f\xdf\xf7"=>0,
    "\x8f\xdf\xf8"=>0,
    "\x8f\xdf\xf9"=>0,
    "\x8f\xdf\xfa"=>0,
    "\x8f\xdf\xfb"=>0,
    "\x8f\xdf\xfc"=>0,
    "\x8f\xdf\xfd"=>0,
    "\x8f\xdf\xfe"=>0,
    "\x8f\xe0\xa1"=>0,
    "\x8f\xe0\xa2"=>0,
    "\x8f\xe0\xa3"=>0,
    "\x8f\xe0\xa4"=>0,
    "\x8f\xe0\xa5"=>0,
    "\x8f\xe0\xa6"=>0,
    "\x8f\xe0\xa7"=>0,
    "\x8f\xe0\xa8"=>0,
    "\x8f\xe0\xa9"=>0,
    "\x8f\xe0\xaa"=>0,
    "\x8f\xe0\xab"=>0,
    "\x8f\xe0\xac"=>0,
    "\x8f\xe0\xad"=>0,
    "\x8f\xe0\xae"=>0,
    "\x8f\xe0\xaf"=>0,
    "\x8f\xe0\xb0"=>0,
    "\x8f\xe0\xb1"=>0,
    "\x8f\xe0\xb2"=>0,
    "\x8f\xe0\xb3"=>0,
    "\x8f\xe0\xb4"=>0,
    "\x8f\xe0\xb5"=>0,
    "\x8f\xe0\xb6"=>0,
    "\x8f\xe0\xb7"=>0,
    "\x8f\xe0\xb8"=>0,
    "\x8f\xe0\xb9"=>0,
    "\x8f\xe0\xba"=>0,
    "\x8f\xe0\xbb"=>0,
    "\x8f\xe0\xbc"=>0,
    "\x8f\xe0\xbd"=>0,
    "\x8f\xe0\xbe"=>0,
    "\x8f\xe0\xbf"=>0,
    "\x8f\xe0\xc0"=>0,
    "\x8f\xe0\xc1"=>0,
    "\x8f\xe0\xc2"=>0,
    "\x8f\xe0\xc3"=>0,
    "\x8f\xe0\xc4"=>0,
    "\x8f\xe0\xc5"=>0,
    "\x8f\xe0\xc6"=>0,
    "\x8f\xe0\xc7"=>0,
    "\x8f\xe0\xc8"=>0,
    "\x8f\xe0\xc9"=>0,
    "\x8f\xe0\xca"=>0,
    "\x8f\xe0\xcb"=>0,
    "\x8f\xe0\xcc"=>0,
    "\x8f\xe0\xcd"=>0,
    "\x8f\xe0\xce"=>0,
    "\x8f\xe0\xcf"=>0,
    "\x8f\xe0\xd0"=>0,
    "\x8f\xe0\xd1"=>0,
    "\x8f\xe0\xd2"=>0,
    "\x8f\xe0\xd3"=>0,
    "\x8f\xe0\xd4"=>0,
    "\x8f\xe0\xd5"=>0,
    "\x8f\xe0\xd6"=>0,
    "\x8f\xe0\xd7"=>0,
    "\x8f\xe0\xd8"=>0,
    "\x8f\xe0\xd9"=>0,
    "\x8f\xe0\xda"=>0,
    "\x8f\xe0\xdb"=>0,
    "\x8f\xe0\xdc"=>0,
    "\x8f\xe0\xdd"=>0,
    "\x8f\xe0\xde"=>0,
    "\x8f\xe0\xdf"=>0,
    "\x8f\xe0\xe0"=>0,
    "\x8f\xe0\xe1"=>0,
    "\x8f\xe0\xe2"=>0,
    "\x8f\xe0\xe3"=>0,
    "\x8f\xe0\xe4"=>0,
    "\x8f\xe0\xe5"=>0,
    "\x8f\xe0\xe6"=>0,
    "\x8f\xe0\xe7"=>0,
    "\x8f\xe0\xe8"=>0,
    "\x8f\xe0\xe9"=>0,
    "\x8f\xe0\xea"=>0,
    "\x8f\xe0\xeb"=>0,
    "\x8f\xe0\xec"=>0,
    "\x8f\xe0\xed"=>0,
    "\x8f\xe0\xee"=>0,
    "\x8f\xe0\xef"=>0,
    "\x8f\xe0\xf0"=>0,
    "\x8f\xe0\xf1"=>0,
    "\x8f\xe0\xf2"=>0,
    "\x8f\xe0\xf3"=>0,
    "\x8f\xe0\xf4"=>0,
    "\x8f\xe0\xf5"=>0,
    "\x8f\xe0\xf6"=>0,
    "\x8f\xe0\xf7"=>0,
    "\x8f\xe0\xf8"=>0,
    "\x8f\xe0\xf9"=>0,
    "\x8f\xe0\xfa"=>0,
    "\x8f\xe0\xfb"=>0,
    "\x8f\xe0\xfc"=>0,
    "\x8f\xe0\xfd"=>0,
    "\x8f\xe0\xfe"=>0,
    "\x8f\xe1\xa1"=>0,
    "\x8f\xe1\xa2"=>0,
    "\x8f\xe1\xa3"=>0,
    "\x8f\xe1\xa4"=>0,
    "\x8f\xe1\xa5"=>0,
    "\x8f\xe1\xa6"=>0,
    "\x8f\xe1\xa7"=>0,
    "\x8f\xe1\xa8"=>0,
    "\x8f\xe1\xa9"=>0,
    "\x8f\xe1\xaa"=>0,
    "\x8f\xe1\xab"=>0,
    "\x8f\xe1\xac"=>0,
    "\x8f\xe1\xad"=>0,
    "\x8f\xe1\xae"=>0,
    "\x8f\xe1\xaf"=>0,
    "\x8f\xe1\xb0"=>0,
    "\x8f\xe1\xb1"=>0,
    "\x8f\xe1\xb2"=>0,
    "\x8f\xe1\xb3"=>0,
    "\x8f\xe1\xb4"=>0,
    "\x8f\xe1\xb5"=>0,
    "\x8f\xe1\xb6"=>0,
    "\x8f\xe1\xb7"=>0,
    "\x8f\xe1\xb8"=>0,
    "\x8f\xe1\xb9"=>0,
    "\x8f\xe1\xba"=>0,
    "\x8f\xe1\xbb"=>0,
    "\x8f\xe1\xbc"=>0,
    "\x8f\xe1\xbd"=>0,
    "\x8f\xe1\xbe"=>0,
    "\x8f\xe1\xbf"=>0,
    "\x8f\xe1\xc0"=>0,
    "\x8f\xe1\xc1"=>0,
    "\x8f\xe1\xc2"=>0,
    "\x8f\xe1\xc3"=>0,
    "\x8f\xe1\xc4"=>0,
    "\x8f\xe1\xc5"=>0,
    "\x8f\xe1\xc6"=>0,
    "\x8f\xe1\xc7"=>0,
    "\x8f\xe1\xc8"=>0,
    "\x8f\xe1\xc9"=>0,
    "\x8f\xe1\xca"=>0,
    "\x8f\xe1\xcb"=>0,
    "\x8f\xe1\xcc"=>0,
    "\x8f\xe1\xcd"=>0,
    "\x8f\xe1\xce"=>0,
    "\x8f\xe1\xcf"=>0,
    "\x8f\xe1\xd0"=>0,
    "\x8f\xe1\xd1"=>0,
    "\x8f\xe1\xd2"=>0,
    "\x8f\xe1\xd3"=>0,
    "\x8f\xe1\xd4"=>0,
    "\x8f\xe1\xd5"=>0,
    "\x8f\xe1\xd6"=>0,
    "\x8f\xe1\xd7"=>0,
    "\x8f\xe1\xd8"=>0,
    "\x8f\xe1\xd9"=>0,
    "\x8f\xe1\xda"=>0,
    "\x8f\xe1\xdb"=>0,
    "\x8f\xe1\xdc"=>0,
    "\x8f\xe1\xdd"=>0,
    "\x8f\xe1\xde"=>0,
    "\x8f\xe1\xdf"=>0,
    "\x8f\xe1\xe0"=>0,
    "\x8f\xe1\xe1"=>0,
    "\x8f\xe1\xe2"=>0,
    "\x8f\xe1\xe3"=>0,
    "\x8f\xe1\xe4"=>0,
    "\x8f\xe1\xe5"=>0,
    "\x8f\xe1\xe6"=>0,
    "\x8f\xe1\xe7"=>0,
    "\x8f\xe1\xe8"=>0,
    "\x8f\xe1\xe9"=>0,
    "\x8f\xe1\xea"=>0,
    "\x8f\xe1\xeb"=>0,
    "\x8f\xe1\xec"=>0,
    "\x8f\xe1\xed"=>0,
    "\x8f\xe1\xee"=>0,
    "\x8f\xe1\xef"=>0,
    "\x8f\xe1\xf0"=>0,
    "\x8f\xe1\xf1"=>0,
    "\x8f\xe1\xf2"=>0,
    "\x8f\xe1\xf3"=>0,
    "\x8f\xe1\xf4"=>0,
    "\x8f\xe1\xf5"=>0,
    "\x8f\xe1\xf6"=>0,
    "\x8f\xe1\xf7"=>0,
    "\x8f\xe1\xf8"=>0,
    "\x8f\xe1\xf9"=>0,
    "\x8f\xe1\xfa"=>0,
    "\x8f\xe1\xfb"=>0,
    "\x8f\xe1\xfc"=>0,
    "\x8f\xe1\xfd"=>0,
    "\x8f\xe1\xfe"=>0,
    "\x8f\xe2\xa1"=>0,
    "\x8f\xe2\xa2"=>0,
    "\x8f\xe2\xa3"=>0,
    "\x8f\xe2\xa4"=>0,
    "\x8f\xe2\xa5"=>0,
    "\x8f\xe2\xa6"=>0,
    "\x8f\xe2\xa7"=>0,
    "\x8f\xe2\xa8"=>0,
    "\x8f\xe2\xa9"=>0,
    "\x8f\xe2\xaa"=>0,
    "\x8f\xe2\xab"=>0,
    "\x8f\xe2\xac"=>0,
    "\x8f\xe2\xad"=>0,
    "\x8f\xe2\xae"=>0,
    "\x8f\xe2\xaf"=>0,
    "\x8f\xe2\xb0"=>0,
    "\x8f\xe2\xb1"=>0,
    "\x8f\xe2\xb2"=>0,
    "\x8f\xe2\xb3"=>0,
    "\x8f\xe2\xb4"=>0,
    "\x8f\xe2\xb5"=>0,
    "\x8f\xe2\xb6"=>0,
    "\x8f\xe2\xb7"=>0,
    "\x8f\xe2\xb8"=>0,
    "\x8f\xe2\xb9"=>0,
    "\x8f\xe2\xba"=>0,
    "\x8f\xe2\xbb"=>0,
    "\x8f\xe2\xbc"=>0,
    "\x8f\xe2\xbd"=>0,
    "\x8f\xe2\xbe"=>0,
    "\x8f\xe2\xbf"=>0,
    "\x8f\xe2\xc0"=>0,
    "\x8f\xe2\xc1"=>0,
    "\x8f\xe2\xc2"=>0,
    "\x8f\xe2\xc3"=>0,
    "\x8f\xe2\xc4"=>0,
    "\x8f\xe2\xc5"=>0,
    "\x8f\xe2\xc6"=>0,
    "\x8f\xe2\xc7"=>0,
    "\x8f\xe2\xc8"=>0,
    "\x8f\xe2\xc9"=>0,
    "\x8f\xe2\xca"=>0,
    "\x8f\xe2\xcb"=>0,
    "\x8f\xe2\xcc"=>0,
    "\x8f\xe2\xcd"=>0,
    "\x8f\xe2\xce"=>0,
    "\x8f\xe2\xcf"=>0,
    "\x8f\xe2\xd0"=>0,
    "\x8f\xe2\xd1"=>0,
    "\x8f\xe2\xd2"=>0,
    "\x8f\xe2\xd3"=>0,
    "\x8f\xe2\xd4"=>0,
    "\x8f\xe2\xd5"=>0,
    "\x8f\xe2\xd6"=>0,
    "\x8f\xe2\xd7"=>0,
    "\x8f\xe2\xd8"=>0,
    "\x8f\xe2\xd9"=>0,
    "\x8f\xe2\xda"=>0,
    "\x8f\xe2\xdb"=>0,
    "\x8f\xe2\xdc"=>0,
    "\x8f\xe2\xdd"=>0,
    "\x8f\xe2\xde"=>0,
    "\x8f\xe2\xdf"=>0,
    "\x8f\xe2\xe0"=>0,
    "\x8f\xe2\xe1"=>0,
    "\x8f\xe2\xe2"=>0,
    "\x8f\xe2\xe3"=>0,
    "\x8f\xe2\xe4"=>0,
    "\x8f\xe2\xe5"=>0,
    "\x8f\xe2\xe6"=>0,
    "\x8f\xe2\xe7"=>0,
    "\x8f\xe2\xe8"=>0,
    "\x8f\xe2\xe9"=>0,
    "\x8f\xe2\xea"=>0,
    "\x8f\xe2\xeb"=>0,
    "\x8f\xe2\xec"=>0,
    "\x8f\xe2\xed"=>0,
    "\x8f\xe2\xee"=>0,
    "\x8f\xe2\xef"=>0,
    "\x8f\xe2\xf0"=>0,
    "\x8f\xe2\xf1"=>0,
    "\x8f\xe2\xf2"=>0,
    "\x8f\xe2\xf3"=>0,
    "\x8f\xe2\xf4"=>0,
    "\x8f\xe2\xf5"=>0,
    "\x8f\xe2\xf6"=>0,
    "\x8f\xe2\xf7"=>0,
    "\x8f\xe2\xf8"=>0,
    "\x8f\xe2\xf9"=>0,
    "\x8f\xe2\xfa"=>0,
    "\x8f\xe2\xfb"=>0,
    "\x8f\xe2\xfc"=>0,
    "\x8f\xe2\xfd"=>0,
    "\x8f\xe2\xfe"=>0,
    "\x8f\xe3\xa1"=>0,
    "\x8f\xe3\xa2"=>0,
    "\x8f\xe3\xa3"=>0,
    "\x8f\xe3\xa4"=>0,
    "\x8f\xe3\xa5"=>0,
    "\x8f\xe3\xa6"=>0,
    "\x8f\xe3\xa7"=>0,
    "\x8f\xe3\xa8"=>0,
    "\x8f\xe3\xa9"=>0,
    "\x8f\xe3\xaa"=>0,
    "\x8f\xe3\xab"=>0,
    "\x8f\xe3\xac"=>0,
    "\x8f\xe3\xad"=>0,
    "\x8f\xe3\xae"=>0,
    "\x8f\xe3\xaf"=>0,
    "\x8f\xe3\xb0"=>0,
    "\x8f\xe3\xb1"=>0,
    "\x8f\xe3\xb2"=>0,
    "\x8f\xe3\xb3"=>0,
    "\x8f\xe3\xb4"=>0,
    "\x8f\xe3\xb5"=>0,
    "\x8f\xe3\xb6"=>0,
    "\x8f\xe3\xb7"=>0,
    "\x8f\xe3\xb8"=>0,
    "\x8f\xe3\xb9"=>0,
    "\x8f\xe3\xba"=>0,
    "\x8f\xe3\xbb"=>0,
    "\x8f\xe3\xbc"=>0,
    "\x8f\xe3\xbd"=>0,
    "\x8f\xe3\xbe"=>0,
    "\x8f\xe3\xbf"=>0,
    "\x8f\xe3\xc0"=>0,
    "\x8f\xe3\xc1"=>0,
    "\x8f\xe3\xc2"=>0,
    "\x8f\xe3\xc3"=>0,
    "\x8f\xe3\xc4"=>0,
    "\x8f\xe3\xc5"=>0,
    "\x8f\xe3\xc6"=>0,
    "\x8f\xe3\xc7"=>0,
    "\x8f\xe3\xc8"=>0,
    "\x8f\xe3\xc9"=>0,
    "\x8f\xe3\xca"=>0,
    "\x8f\xe3\xcb"=>0,
    "\x8f\xe3\xcc"=>0,
    "\x8f\xe3\xcd"=>0,
    "\x8f\xe3\xce"=>0,
    "\x8f\xe3\xcf"=>0,
    "\x8f\xe3\xd0"=>0,
    "\x8f\xe3\xd1"=>0,
    "\x8f\xe3\xd2"=>0,
    "\x8f\xe3\xd3"=>0,
    "\x8f\xe3\xd4"=>0,
    "\x8f\xe3\xd5"=>0,
    "\x8f\xe3\xd6"=>0,
    "\x8f\xe3\xd7"=>0,
    "\x8f\xe3\xd8"=>0,
    "\x8f\xe3\xd9"=>0,
    "\x8f\xe3\xda"=>0,
    "\x8f\xe3\xdb"=>0,
    "\x8f\xe3\xdc"=>0,
    "\x8f\xe3\xdd"=>0,
    "\x8f\xe3\xde"=>0,
    "\x8f\xe3\xdf"=>0,
    "\x8f\xe3\xe0"=>0,
    "\x8f\xe3\xe1"=>0,
    "\x8f\xe3\xe2"=>0,
    "\x8f\xe3\xe3"=>0,
    "\x8f\xe3\xe4"=>0,
    "\x8f\xe3\xe5"=>0,
    "\x8f\xe3\xe6"=>0,
    "\x8f\xe3\xe7"=>0,
    "\x8f\xe3\xe8"=>0,
    "\x8f\xe3\xe9"=>0,
    "\x8f\xe3\xea"=>0,
    "\x8f\xe3\xeb"=>0,
    "\x8f\xe3\xec"=>0,
    "\x8f\xe3\xed"=>0,
    "\x8f\xe3\xee"=>0,
    "\x8f\xe3\xef"=>0,
    "\x8f\xe3\xf0"=>0,
    "\x8f\xe3\xf1"=>0,
    "\x8f\xe3\xf2"=>0,
    "\x8f\xe3\xf3"=>0,
    "\x8f\xe3\xf4"=>0,
    "\x8f\xe3\xf5"=>0,
    "\x8f\xe3\xf6"=>0,
    "\x8f\xe3\xf7"=>0,
    "\x8f\xe3\xf8"=>0,
    "\x8f\xe3\xf9"=>0,
    "\x8f\xe3\xfa"=>0,
    "\x8f\xe3\xfb"=>0,
    "\x8f\xe3\xfc"=>0,
    "\x8f\xe3\xfd"=>0,
    "\x8f\xe3\xfe"=>0,
    "\x8f\xe4\xa1"=>0,
    "\x8f\xe4\xa2"=>0,
    "\x8f\xe4\xa3"=>0,
    "\x8f\xe4\xa4"=>0,
    "\x8f\xe4\xa5"=>0,
    "\x8f\xe4\xa6"=>0,
    "\x8f\xe4\xa7"=>0,
    "\x8f\xe4\xa8"=>0,
    "\x8f\xe4\xa9"=>0,
    "\x8f\xe4\xaa"=>0,
    "\x8f\xe4\xab"=>0,
    "\x8f\xe4\xac"=>0,
    "\x8f\xe4\xad"=>0,
    "\x8f\xe4\xae"=>0,
    "\x8f\xe4\xaf"=>0,
    "\x8f\xe4\xb0"=>0,
    "\x8f\xe4\xb1"=>0,
    "\x8f\xe4\xb2"=>0,
    "\x8f\xe4\xb3"=>0,
    "\x8f\xe4\xb4"=>0,
    "\x8f\xe4\xb5"=>0,
    "\x8f\xe4\xb6"=>0,
    "\x8f\xe4\xb7"=>0,
    "\x8f\xe4\xb8"=>0,
    "\x8f\xe4\xb9"=>0,
    "\x8f\xe4\xba"=>0,
    "\x8f\xe4\xbb"=>0,
    "\x8f\xe4\xbc"=>0,
    "\x8f\xe4\xbd"=>0,
    "\x8f\xe4\xbe"=>0,
    "\x8f\xe4\xbf"=>0,
    "\x8f\xe4\xc0"=>0,
    "\x8f\xe4\xc1"=>0,
    "\x8f\xe4\xc2"=>0,
    "\x8f\xe4\xc3"=>0,
    "\x8f\xe4\xc4"=>0,
    "\x8f\xe4\xc5"=>0,
    "\x8f\xe4\xc6"=>0,
    "\x8f\xe4\xc7"=>0,
    "\x8f\xe4\xc8"=>0,
    "\x8f\xe4\xc9"=>0,
    "\x8f\xe4\xca"=>0,
    "\x8f\xe4\xcb"=>0,
    "\x8f\xe4\xcc"=>0,
    "\x8f\xe4\xcd"=>0,
    "\x8f\xe4\xce"=>0,
    "\x8f\xe4\xcf"=>0,
    "\x8f\xe4\xd0"=>0,
    "\x8f\xe4\xd1"=>0,
    "\x8f\xe4\xd2"=>0,
    "\x8f\xe4\xd3"=>0,
    "\x8f\xe4\xd4"=>0,
    "\x8f\xe4\xd5"=>0,
    "\x8f\xe4\xd6"=>0,
    "\x8f\xe4\xd7"=>0,
    "\x8f\xe4\xd8"=>0,
    "\x8f\xe4\xd9"=>0,
    "\x8f\xe4\xda"=>0,
    "\x8f\xe4\xdb"=>0,
    "\x8f\xe4\xdc"=>0,
    "\x8f\xe4\xdd"=>0,
    "\x8f\xe4\xde"=>0,
    "\x8f\xe4\xdf"=>0,
    "\x8f\xe4\xe0"=>0,
    "\x8f\xe4\xe1"=>0,
    "\x8f\xe4\xe2"=>0,
    "\x8f\xe4\xe3"=>0,
    "\x8f\xe4\xe4"=>0,
    "\x8f\xe4\xe5"=>0,
    "\x8f\xe4\xe6"=>0,
    "\x8f\xe4\xe7"=>0,
    "\x8f\xe4\xe8"=>0,
    "\x8f\xe4\xe9"=>0,
    "\x8f\xe4\xea"=>0,
    "\x8f\xe4\xeb"=>0,
    "\x8f\xe4\xec"=>0,
    "\x8f\xe4\xed"=>0,
    "\x8f\xe4\xee"=>0,
    "\x8f\xe4\xef"=>0,
    "\x8f\xe4\xf0"=>0,
    "\x8f\xe4\xf1"=>0,
    "\x8f\xe4\xf2"=>0,
    "\x8f\xe4\xf3"=>0,
    "\x8f\xe4\xf4"=>0,
    "\x8f\xe4\xf5"=>0,
    "\x8f\xe4\xf6"=>0,
    "\x8f\xe4\xf7"=>0,
    "\x8f\xe4\xf8"=>0,
    "\x8f\xe4\xf9"=>0,
    "\x8f\xe4\xfa"=>0,
    "\x8f\xe4\xfb"=>0,
    "\x8f\xe4\xfc"=>0,
    "\x8f\xe4\xfd"=>0,
    "\x8f\xe4\xfe"=>0,
    "\x8f\xe5\xa1"=>0,
    "\x8f\xe5\xa2"=>0,
    "\x8f\xe5\xa3"=>0,
    "\x8f\xe5\xa4"=>0,
    "\x8f\xe5\xa5"=>0,
    "\x8f\xe5\xa6"=>0,
    "\x8f\xe5\xa7"=>0,
    "\x8f\xe5\xa8"=>0,
    "\x8f\xe5\xa9"=>0,
    "\x8f\xe5\xaa"=>0,
    "\x8f\xe5\xab"=>0,
    "\x8f\xe5\xac"=>0,
    "\x8f\xe5\xad"=>0,
    "\x8f\xe5\xae"=>0,
    "\x8f\xe5\xaf"=>0,
    "\x8f\xe5\xb0"=>0,
    "\x8f\xe5\xb1"=>0,
    "\x8f\xe5\xb2"=>0,
    "\x8f\xe5\xb3"=>0,
    "\x8f\xe5\xb4"=>0,
    "\x8f\xe5\xb5"=>0,
    "\x8f\xe5\xb6"=>0,
    "\x8f\xe5\xb7"=>0,
    "\x8f\xe5\xb8"=>0,
    "\x8f\xe5\xb9"=>0,
    "\x8f\xe5\xba"=>0,
    "\x8f\xe5\xbb"=>0,
    "\x8f\xe5\xbc"=>0,
    "\x8f\xe5\xbd"=>0,
    "\x8f\xe5\xbe"=>0,
    "\x8f\xe5\xbf"=>0,
    "\x8f\xe5\xc0"=>0,
    "\x8f\xe5\xc1"=>0,
    "\x8f\xe5\xc2"=>0,
    "\x8f\xe5\xc3"=>0,
    "\x8f\xe5\xc4"=>0,
    "\x8f\xe5\xc5"=>0,
    "\x8f\xe5\xc6"=>0,
    "\x8f\xe5\xc7"=>0,
    "\x8f\xe5\xc8"=>0,
    "\x8f\xe5\xc9"=>0,
    "\x8f\xe5\xca"=>0,
    "\x8f\xe5\xcb"=>0,
    "\x8f\xe5\xcc"=>0,
    "\x8f\xe5\xcd"=>0,
    "\x8f\xe5\xce"=>0,
    "\x8f\xe5\xcf"=>0,
    "\x8f\xe5\xd0"=>0,
    "\x8f\xe5\xd1"=>0,
    "\x8f\xe5\xd2"=>0,
    "\x8f\xe5\xd3"=>0,
    "\x8f\xe5\xd4"=>0,
    "\x8f\xe5\xd5"=>0,
    "\x8f\xe5\xd6"=>0,
    "\x8f\xe5\xd7"=>0,
    "\x8f\xe5\xd8"=>0,
    "\x8f\xe5\xd9"=>0,
    "\x8f\xe5\xda"=>0,
    "\x8f\xe5\xdb"=>0,
    "\x8f\xe5\xdc"=>0,
    "\x8f\xe5\xdd"=>0,
    "\x8f\xe5\xde"=>0,
    "\x8f\xe5\xdf"=>0,
    "\x8f\xe5\xe0"=>0,
    "\x8f\xe5\xe1"=>0,
    "\x8f\xe5\xe2"=>0,
    "\x8f\xe5\xe3"=>0,
    "\x8f\xe5\xe4"=>0,
    "\x8f\xe5\xe5"=>0,
    "\x8f\xe5\xe6"=>0,
    "\x8f\xe5\xe7"=>0,
    "\x8f\xe5\xe8"=>0,
    "\x8f\xe5\xe9"=>0,
    "\x8f\xe5\xea"=>0,
    "\x8f\xe5\xeb"=>0,
    "\x8f\xe5\xec"=>0,
    "\x8f\xe5\xed"=>0,
    "\x8f\xe5\xee"=>0,
    "\x8f\xe5\xef"=>0,
    "\x8f\xe5\xf0"=>0,
    "\x8f\xe5\xf1"=>0,
    "\x8f\xe5\xf2"=>0,
    "\x8f\xe5\xf3"=>0,
    "\x8f\xe5\xf4"=>0,
    "\x8f\xe5\xf5"=>0,
    "\x8f\xe5\xf6"=>0,
    "\x8f\xe5\xf7"=>0,
    "\x8f\xe5\xf8"=>0,
    "\x8f\xe5\xf9"=>0,
    "\x8f\xe5\xfa"=>0,
    "\x8f\xe5\xfb"=>0,
    "\x8f\xe5\xfc"=>0,
    "\x8f\xe5\xfd"=>0,
    "\x8f\xe5\xfe"=>0,
    "\x8f\xe6\xa1"=>0,
    "\x8f\xe6\xa2"=>0,
    "\x8f\xe6\xa3"=>0,
    "\x8f\xe6\xa4"=>0,
    "\x8f\xe6\xa5"=>0,
    "\x8f\xe6\xa6"=>0,
    "\x8f\xe6\xa7"=>0,
    "\x8f\xe6\xa8"=>0,
    "\x8f\xe6\xa9"=>0,
    "\x8f\xe6\xaa"=>0,
    "\x8f\xe6\xab"=>0,
    "\x8f\xe6\xac"=>0,
    "\x8f\xe6\xad"=>0,
    "\x8f\xe6\xae"=>0,
    "\x8f\xe6\xaf"=>0,
    "\x8f\xe6\xb0"=>0,
    "\x8f\xe6\xb1"=>0,
    "\x8f\xe6\xb2"=>0,
    "\x8f\xe6\xb3"=>0,
    "\x8f\xe6\xb4"=>0,
    "\x8f\xe6\xb5"=>0,
    "\x8f\xe6\xb6"=>0,
    "\x8f\xe6\xb7"=>0,
    "\x8f\xe6\xb8"=>0,
    "\x8f\xe6\xb9"=>0,
    "\x8f\xe6\xba"=>0,
    "\x8f\xe6\xbb"=>0,
    "\x8f\xe6\xbc"=>0,
    "\x8f\xe6\xbd"=>0,
    "\x8f\xe6\xbe"=>0,
    "\x8f\xe6\xbf"=>0,
    "\x8f\xe6\xc0"=>0,
    "\x8f\xe6\xc1"=>0,
    "\x8f\xe6\xc2"=>0,
    "\x8f\xe6\xc3"=>0,
    "\x8f\xe6\xc4"=>0,
    "\x8f\xe6\xc5"=>0,
    "\x8f\xe6\xc6"=>0,
    "\x8f\xe6\xc7"=>0,
    "\x8f\xe6\xc8"=>0,
    "\x8f\xe6\xc9"=>0,
    "\x8f\xe6\xca"=>0,
    "\x8f\xe6\xcb"=>0,
    "\x8f\xe6\xcc"=>0,
    "\x8f\xe6\xcd"=>0,
    "\x8f\xe6\xce"=>0,
    "\x8f\xe6\xcf"=>0,
    "\x8f\xe6\xd0"=>0,
    "\x8f\xe6\xd1"=>0,
    "\x8f\xe6\xd2"=>0,
    "\x8f\xe6\xd3"=>0,
    "\x8f\xe6\xd4"=>0,
    "\x8f\xe6\xd5"=>0,
    "\x8f\xe6\xd6"=>0,
    "\x8f\xe6\xd7"=>0,
    "\x8f\xe6\xd8"=>0,
    "\x8f\xe6\xd9"=>0,
    "\x8f\xe6\xda"=>0,
    "\x8f\xe6\xdb"=>0,
    "\x8f\xe6\xdc"=>0,
    "\x8f\xe6\xdd"=>0,
    "\x8f\xe6\xde"=>0,
    "\x8f\xe6\xdf"=>0,
    "\x8f\xe6\xe0"=>0,
    "\x8f\xe6\xe1"=>0,
    "\x8f\xe6\xe2"=>0,
    "\x8f\xe6\xe3"=>0,
    "\x8f\xe6\xe4"=>0,
    "\x8f\xe6\xe5"=>0,
    "\x8f\xe6\xe6"=>0,
    "\x8f\xe6\xe7"=>0,
    "\x8f\xe6\xe8"=>0,
    "\x8f\xe6\xe9"=>0,
    "\x8f\xe6\xea"=>0,
    "\x8f\xe6\xeb"=>0,
    "\x8f\xe6\xec"=>0,
    "\x8f\xe6\xed"=>0,
    "\x8f\xe6\xee"=>0,
    "\x8f\xe6\xef"=>0,
    "\x8f\xe6\xf0"=>0,
    "\x8f\xe6\xf1"=>0,
    "\x8f\xe6\xf2"=>0,
    "\x8f\xe6\xf3"=>0,
    "\x8f\xe6\xf4"=>0,
    "\x8f\xe6\xf5"=>0,
    "\x8f\xe6\xf6"=>0,
    "\x8f\xe6\xf7"=>0,
    "\x8f\xe6\xf8"=>0,
    "\x8f\xe6\xf9"=>0,
    "\x8f\xe6\xfa"=>0,
    "\x8f\xe6\xfb"=>0,
    "\x8f\xe6\xfc"=>0,
    "\x8f\xe6\xfd"=>0,
    "\x8f\xe6\xfe"=>0,
    "\x8f\xe7\xa1"=>0,
    "\x8f\xe7\xa2"=>0,
    "\x8f\xe7\xa3"=>0,
    "\x8f\xe7\xa4"=>0,
    "\x8f\xe7\xa5"=>0,
    "\x8f\xe7\xa6"=>0,
    "\x8f\xe7\xa7"=>0,
    "\x8f\xe7\xa8"=>0,
    "\x8f\xe7\xa9"=>0,
    "\x8f\xe7\xaa"=>0,
    "\x8f\xe7\xab"=>0,
    "\x8f\xe7\xac"=>0,
    "\x8f\xe7\xad"=>0,
    "\x8f\xe7\xae"=>0,
    "\x8f\xe7\xaf"=>0,
    "\x8f\xe7\xb0"=>0,
    "\x8f\xe7\xb1"=>0,
    "\x8f\xe7\xb2"=>0,
    "\x8f\xe7\xb3"=>0,
    "\x8f\xe7\xb4"=>0,
    "\x8f\xe7\xb5"=>0,
    "\x8f\xe7\xb6"=>0,
    "\x8f\xe7\xb7"=>0,
    "\x8f\xe7\xb8"=>0,
    "\x8f\xe7\xb9"=>0,
    "\x8f\xe7\xba"=>0,
    "\x8f\xe7\xbb"=>0,
    "\x8f\xe7\xbc"=>0,
    "\x8f\xe7\xbd"=>0,
    "\x8f\xe7\xbe"=>0,
    "\x8f\xe7\xbf"=>0,
    "\x8f\xe7\xc0"=>0,
    "\x8f\xe7\xc1"=>0,
    "\x8f\xe7\xc2"=>0,
    "\x8f\xe7\xc3"=>0,
    "\x8f\xe7\xc4"=>0,
    "\x8f\xe7\xc5"=>0,
    "\x8f\xe7\xc6"=>0,
    "\x8f\xe7\xc7"=>0,
    "\x8f\xe7\xc8"=>0,
    "\x8f\xe7\xc9"=>0,
    "\x8f\xe7\xca"=>0,
    "\x8f\xe7\xcb"=>0,
    "\x8f\xe7\xcc"=>0,
    "\x8f\xe7\xcd"=>0,
    "\x8f\xe7\xce"=>0,
    "\x8f\xe7\xcf"=>0,
    "\x8f\xe7\xd0"=>0,
    "\x8f\xe7\xd1"=>0,
    "\x8f\xe7\xd2"=>0,
    "\x8f\xe7\xd3"=>0,
    "\x8f\xe7\xd4"=>0,
    "\x8f\xe7\xd5"=>0,
    "\x8f\xe7\xd6"=>0,
    "\x8f\xe7\xd7"=>0,
    "\x8f\xe7\xd8"=>0,
    "\x8f\xe7\xd9"=>0,
    "\x8f\xe7\xda"=>0,
    "\x8f\xe7\xdb"=>0,
    "\x8f\xe7\xdc"=>0,
    "\x8f\xe7\xdd"=>0,
    "\x8f\xe7\xde"=>0,
    "\x8f\xe7\xdf"=>0,
    "\x8f\xe7\xe0"=>0,
    "\x8f\xe7\xe1"=>0,
    "\x8f\xe7\xe2"=>0,
    "\x8f\xe7\xe3"=>0,
    "\x8f\xe7\xe4"=>0,
    "\x8f\xe7\xe5"=>0,
    "\x8f\xe7\xe6"=>0,
    "\x8f\xe7\xe7"=>0,
    "\x8f\xe7\xe8"=>0,
    "\x8f\xe7\xe9"=>0,
    "\x8f\xe7\xea"=>0,
    "\x8f\xe7\xeb"=>0,
    "\x8f\xe7\xec"=>0,
    "\x8f\xe7\xed"=>0,
    "\x8f\xe7\xee"=>0,
    "\x8f\xe7\xef"=>0,
    "\x8f\xe7\xf0"=>0,
    "\x8f\xe7\xf1"=>0,
    "\x8f\xe7\xf2"=>0,
    "\x8f\xe7\xf3"=>0,
    "\x8f\xe7\xf4"=>0,
    "\x8f\xe7\xf5"=>0,
    "\x8f\xe7\xf6"=>0,
    "\x8f\xe7\xf7"=>0,
    "\x8f\xe7\xf8"=>0,
    "\x8f\xe7\xf9"=>0,
    "\x8f\xe7\xfa"=>0,
    "\x8f\xe7\xfb"=>0,
    "\x8f\xe7\xfc"=>0,
    "\x8f\xe7\xfd"=>0,
    "\x8f\xe7\xfe"=>0,
    "\x8f\xe8\xa1"=>0,
    "\x8f\xe8\xa2"=>0,
    "\x8f\xe8\xa3"=>0,
    "\x8f\xe8\xa4"=>0,
    "\x8f\xe8\xa5"=>0,
    "\x8f\xe8\xa6"=>0,
    "\x8f\xe8\xa7"=>0,
    "\x8f\xe8\xa8"=>0,
    "\x8f\xe8\xa9"=>0,
    "\x8f\xe8\xaa"=>0,
    "\x8f\xe8\xab"=>0,
    "\x8f\xe8\xac"=>0,
    "\x8f\xe8\xad"=>0,
    "\x8f\xe8\xae"=>0,
    "\x8f\xe8\xaf"=>0,
    "\x8f\xe8\xb0"=>0,
    "\x8f\xe8\xb1"=>0,
    "\x8f\xe8\xb2"=>0,
    "\x8f\xe8\xb3"=>0,
    "\x8f\xe8\xb4"=>0,
    "\x8f\xe8\xb5"=>0,
    "\x8f\xe8\xb6"=>0,
    "\x8f\xe8\xb7"=>0,
    "\x8f\xe8\xb8"=>0,
    "\x8f\xe8\xb9"=>0,
    "\x8f\xe8\xba"=>0,
    "\x8f\xe8\xbb"=>0,
    "\x8f\xe8\xbc"=>0,
    "\x8f\xe8\xbd"=>0,
    "\x8f\xe8\xbe"=>0,
    "\x8f\xe8\xbf"=>0,
    "\x8f\xe8\xc0"=>0,
    "\x8f\xe8\xc1"=>0,
    "\x8f\xe8\xc2"=>0,
    "\x8f\xe8\xc3"=>0,
    "\x8f\xe8\xc4"=>0,
    "\x8f\xe8\xc5"=>0,
    "\x8f\xe8\xc6"=>0,
    "\x8f\xe8\xc7"=>0,
    "\x8f\xe8\xc8"=>0,
    "\x8f\xe8\xc9"=>0,
    "\x8f\xe8\xca"=>0,
    "\x8f\xe8\xcb"=>0,
    "\x8f\xe8\xcc"=>0,
    "\x8f\xe8\xcd"=>0,
    "\x8f\xe8\xce"=>0,
    "\x8f\xe8\xcf"=>0,
    "\x8f\xe8\xd0"=>0,
    "\x8f\xe8\xd1"=>0,
    "\x8f\xe8\xd2"=>0,
    "\x8f\xe8\xd3"=>0,
    "\x8f\xe8\xd4"=>0,
    "\x8f\xe8\xd5"=>0,
    "\x8f\xe8\xd6"=>0,
    "\x8f\xe8\xd7"=>0,
    "\x8f\xe8\xd8"=>0,
    "\x8f\xe8\xd9"=>0,
    "\x8f\xe8\xda"=>0,
    "\x8f\xe8\xdb"=>0,
    "\x8f\xe8\xdc"=>0,
    "\x8f\xe8\xdd"=>0,
    "\x8f\xe8\xde"=>0,
    "\x8f\xe8\xdf"=>0,
    "\x8f\xe8\xe0"=>0,
    "\x8f\xe8\xe1"=>0,
    "\x8f\xe8\xe2"=>0,
    "\x8f\xe8\xe3"=>0,
    "\x8f\xe8\xe4"=>0,
    "\x8f\xe8\xe5"=>0,
    "\x8f\xe8\xe6"=>0,
    "\x8f\xe8\xe7"=>0,
    "\x8f\xe8\xe8"=>0,
    "\x8f\xe8\xe9"=>0,
    "\x8f\xe8\xea"=>0,
    "\x8f\xe8\xeb"=>0,
    "\x8f\xe8\xec"=>0,
    "\x8f\xe8\xed"=>0,
    "\x8f\xe8\xee"=>0,
    "\x8f\xe8\xef"=>0,
    "\x8f\xe8\xf0"=>0,
    "\x8f\xe8\xf1"=>0,
    "\x8f\xe8\xf2"=>0,
    "\x8f\xe8\xf3"=>0,
    "\x8f\xe8\xf4"=>0,
    "\x8f\xe8\xf5"=>0,
    "\x8f\xe8\xf6"=>0,
    "\x8f\xe8\xf7"=>0,
    "\x8f\xe8\xf8"=>0,
    "\x8f\xe8\xf9"=>0,
    "\x8f\xe8\xfa"=>0,
    "\x8f\xe8\xfb"=>0,
    "\x8f\xe8\xfc"=>0,
    "\x8f\xe8\xfd"=>0,
    "\x8f\xe8\xfe"=>0,
    "\x8f\xe9\xa1"=>0,
    "\x8f\xe9\xa2"=>0,
    "\x8f\xe9\xa3"=>0,
    "\x8f\xe9\xa4"=>0,
    "\x8f\xe9\xa5"=>0,
    "\x8f\xe9\xa6"=>0,
    "\x8f\xe9\xa7"=>0,
    "\x8f\xe9\xa8"=>0,
    "\x8f\xe9\xa9"=>0,
    "\x8f\xe9\xaa"=>0,
    "\x8f\xe9\xab"=>0,
    "\x8f\xe9\xac"=>0,
    "\x8f\xe9\xad"=>0,
    "\x8f\xe9\xae"=>0,
    "\x8f\xe9\xaf"=>0,
    "\x8f\xe9\xb0"=>0,
    "\x8f\xe9\xb1"=>0,
    "\x8f\xe9\xb2"=>0,
    "\x8f\xe9\xb3"=>0,
    "\x8f\xe9\xb4"=>0,
    "\x8f\xe9\xb5"=>0,
    "\x8f\xe9\xb6"=>0,
    "\x8f\xe9\xb7"=>0,
    "\x8f\xe9\xb8"=>0,
    "\x8f\xe9\xb9"=>0,
    "\x8f\xe9\xba"=>0,
    "\x8f\xe9\xbb"=>0,
    "\x8f\xe9\xbc"=>0,
    "\x8f\xe9\xbd"=>0,
    "\x8f\xe9\xbe"=>0,
    "\x8f\xe9\xbf"=>0,
    "\x8f\xe9\xc0"=>0,
    "\x8f\xe9\xc1"=>0,
    "\x8f\xe9\xc2"=>0,
    "\x8f\xe9\xc3"=>0,
    "\x8f\xe9\xc4"=>0,
    "\x8f\xe9\xc5"=>0,
    "\x8f\xe9\xc6"=>0,
    "\x8f\xe9\xc7"=>0,
    "\x8f\xe9\xc8"=>0,
    "\x8f\xe9\xc9"=>0,
    "\x8f\xe9\xca"=>0,
    "\x8f\xe9\xcb"=>0,
    "\x8f\xe9\xcc"=>0,
    "\x8f\xe9\xcd"=>0,
    "\x8f\xe9\xce"=>0,
    "\x8f\xe9\xcf"=>0,
    "\x8f\xe9\xd0"=>0,
    "\x8f\xe9\xd1"=>0,
    "\x8f\xe9\xd2"=>0,
    "\x8f\xe9\xd3"=>0,
    "\x8f\xe9\xd4"=>0,
    "\x8f\xe9\xd5"=>0,
    "\x8f\xe9\xd6"=>0,
    "\x8f\xe9\xd7"=>0,
    "\x8f\xe9\xd8"=>0,
    "\x8f\xe9\xd9"=>0,
    "\x8f\xe9\xda"=>0,
    "\x8f\xe9\xdb"=>0,
    "\x8f\xe9\xdc"=>0,
    "\x8f\xe9\xdd"=>0,
    "\x8f\xe9\xde"=>0,
    "\x8f\xe9\xdf"=>0,
    "\x8f\xe9\xe0"=>0,
    "\x8f\xe9\xe1"=>0,
    "\x8f\xe9\xe2"=>0,
    "\x8f\xe9\xe3"=>0,
    "\x8f\xe9\xe4"=>0,
    "\x8f\xe9\xe5"=>0,
    "\x8f\xe9\xe6"=>0,
    "\x8f\xe9\xe7"=>0,
    "\x8f\xe9\xe8"=>0,
    "\x8f\xe9\xe9"=>0,
    "\x8f\xe9\xea"=>0,
    "\x8f\xe9\xeb"=>0,
    "\x8f\xe9\xec"=>0,
    "\x8f\xe9\xed"=>0,
    "\x8f\xe9\xee"=>0,
    "\x8f\xe9\xef"=>0,
    "\x8f\xe9\xf0"=>0,
    "\x8f\xe9\xf1"=>0,
    "\x8f\xe9\xf2"=>0,
    "\x8f\xe9\xf3"=>0,
    "\x8f\xe9\xf4"=>0,
    "\x8f\xe9\xf5"=>0,
    "\x8f\xe9\xf6"=>0,
    "\x8f\xe9\xf7"=>0,
    "\x8f\xe9\xf8"=>0,
    "\x8f\xe9\xf9"=>0,
    "\x8f\xe9\xfa"=>0,
    "\x8f\xe9\xfb"=>0,
    "\x8f\xe9\xfc"=>0,
    "\x8f\xe9\xfd"=>0,
    "\x8f\xe9\xfe"=>0,
    "\x8f\xea\xa1"=>0,
    "\x8f\xea\xa2"=>0,
    "\x8f\xea\xa3"=>0,
    "\x8f\xea\xa4"=>0,
    "\x8f\xea\xa5"=>0,
    "\x8f\xea\xa6"=>0,
    "\x8f\xea\xa7"=>0,
    "\x8f\xea\xa8"=>0,
    "\x8f\xea\xa9"=>0,
    "\x8f\xea\xaa"=>0,
    "\x8f\xea\xab"=>0,
    "\x8f\xea\xac"=>0,
    "\x8f\xea\xad"=>0,
    "\x8f\xea\xae"=>0,
    "\x8f\xea\xaf"=>0,
    "\x8f\xea\xb0"=>0,
    "\x8f\xea\xb1"=>0,
    "\x8f\xea\xb2"=>0,
    "\x8f\xea\xb3"=>0,
    "\x8f\xea\xb4"=>0,
    "\x8f\xea\xb5"=>0,
    "\x8f\xea\xb6"=>0,
    "\x8f\xea\xb7"=>0,
    "\x8f\xea\xb8"=>0,
    "\x8f\xea\xb9"=>0,
    "\x8f\xea\xba"=>0,
    "\x8f\xea\xbb"=>0,
    "\x8f\xea\xbc"=>0,
    "\x8f\xea\xbd"=>0,
    "\x8f\xea\xbe"=>0,
    "\x8f\xea\xbf"=>0,
    "\x8f\xea\xc0"=>0,
    "\x8f\xea\xc1"=>0,
    "\x8f\xea\xc2"=>0,
    "\x8f\xea\xc3"=>0,
    "\x8f\xea\xc4"=>0,
    "\x8f\xea\xc5"=>0,
    "\x8f\xea\xc6"=>0,
    "\x8f\xea\xc7"=>0,
    "\x8f\xea\xc8"=>0,
    "\x8f\xea\xc9"=>0,
    "\x8f\xea\xca"=>0,
    "\x8f\xea\xcb"=>0,
    "\x8f\xea\xcc"=>0,
    "\x8f\xea\xcd"=>0,
    "\x8f\xea\xce"=>0,
    "\x8f\xea\xcf"=>0,
    "\x8f\xea\xd0"=>0,
    "\x8f\xea\xd1"=>0,
    "\x8f\xea\xd2"=>0,
    "\x8f\xea\xd3"=>0,
    "\x8f\xea\xd4"=>0,
    "\x8f\xea\xd5"=>0,
    "\x8f\xea\xd6"=>0,
    "\x8f\xea\xd7"=>0,
    "\x8f\xea\xd8"=>0,
    "\x8f\xea\xd9"=>0,
    "\x8f\xea\xda"=>0,
    "\x8f\xea\xdb"=>0,
    "\x8f\xea\xdc"=>0,
    "\x8f\xea\xdd"=>0,
    "\x8f\xea\xde"=>0,
    "\x8f\xea\xdf"=>0,
    "\x8f\xea\xe0"=>0,
    "\x8f\xea\xe1"=>0,
    "\x8f\xea\xe2"=>0,
    "\x8f\xea\xe3"=>0,
    "\x8f\xea\xe4"=>0,
    "\x8f\xea\xe5"=>0,
    "\x8f\xea\xe6"=>0,
    "\x8f\xea\xe7"=>0,
    "\x8f\xea\xe8"=>0,
    "\x8f\xea\xe9"=>0,
    "\x8f\xea\xea"=>0,
    "\x8f\xea\xeb"=>0,
    "\x8f\xea\xec"=>0,
    "\x8f\xea\xed"=>0,
    "\x8f\xea\xee"=>0,
    "\x8f\xea\xef"=>0,
    "\x8f\xea\xf0"=>0,
    "\x8f\xea\xf1"=>0,
    "\x8f\xea\xf2"=>0,
    "\x8f\xea\xf3"=>0,
    "\x8f\xea\xf4"=>0,
    "\x8f\xea\xf5"=>0,
    "\x8f\xea\xf6"=>0,
    "\x8f\xea\xf7"=>0,
    "\x8f\xea\xf8"=>0,
    "\x8f\xea\xf9"=>0,
    "\x8f\xea\xfa"=>0,
    "\x8f\xea\xfb"=>0,
    "\x8f\xea\xfc"=>0,
    "\x8f\xea\xfd"=>0,
    "\x8f\xea\xfe"=>0,
    "\x8f\xeb\xa1"=>0,
    "\x8f\xeb\xa2"=>0,
    "\x8f\xeb\xa3"=>0,
    "\x8f\xeb\xa4"=>0,
    "\x8f\xeb\xa5"=>0,
    "\x8f\xeb\xa6"=>0,
    "\x8f\xeb\xa7"=>0,
    "\x8f\xeb\xa8"=>0,
    "\x8f\xeb\xa9"=>0,
    "\x8f\xeb\xaa"=>0,
    "\x8f\xeb\xab"=>0,
    "\x8f\xeb\xac"=>0,
    "\x8f\xeb\xad"=>0,
    "\x8f\xeb\xae"=>0,
    "\x8f\xeb\xaf"=>0,
    "\x8f\xeb\xb0"=>0,
    "\x8f\xeb\xb1"=>0,
    "\x8f\xeb\xb2"=>0,
    "\x8f\xeb\xb3"=>0,
    "\x8f\xeb\xb4"=>0,
    "\x8f\xeb\xb5"=>0,
    "\x8f\xeb\xb6"=>0,
    "\x8f\xeb\xb7"=>0,
    "\x8f\xeb\xb8"=>0,
    "\x8f\xeb\xb9"=>0,
    "\x8f\xeb\xba"=>0,
    "\x8f\xeb\xbb"=>0,
    "\x8f\xeb\xbc"=>0,
    "\x8f\xeb\xbd"=>0,
    "\x8f\xeb\xbe"=>0,
    "\x8f\xeb\xbf"=>0,
    "\x8f\xeb\xc0"=>0,
    "\x8f\xeb\xc1"=>0,
    "\x8f\xeb\xc2"=>0,
    "\x8f\xeb\xc3"=>0,
    "\x8f\xeb\xc4"=>0,
    "\x8f\xeb\xc5"=>0,
    "\x8f\xeb\xc6"=>0,
    "\x8f\xeb\xc7"=>0,
    "\x8f\xeb\xc8"=>0,
    "\x8f\xeb\xc9"=>0,
    "\x8f\xeb\xca"=>0,
    "\x8f\xeb\xcb"=>0,
    "\x8f\xeb\xcc"=>0,
    "\x8f\xeb\xcd"=>0,
    "\x8f\xeb\xce"=>0,
    "\x8f\xeb\xcf"=>0,
    "\x8f\xeb\xd0"=>0,
    "\x8f\xeb\xd1"=>0,
    "\x8f\xeb\xd2"=>0,
    "\x8f\xeb\xd3"=>0,
    "\x8f\xeb\xd4"=>0,
    "\x8f\xeb\xd5"=>0,
    "\x8f\xeb\xd6"=>0,
    "\x8f\xeb\xd7"=>0,
    "\x8f\xeb\xd8"=>0,
    "\x8f\xeb\xd9"=>0,
    "\x8f\xeb\xda"=>0,
    "\x8f\xeb\xdb"=>0,
    "\x8f\xeb\xdc"=>0,
    "\x8f\xeb\xdd"=>0,
    "\x8f\xeb\xde"=>0,
    "\x8f\xeb\xdf"=>0,
    "\x8f\xeb\xe0"=>0,
    "\x8f\xeb\xe1"=>0,
    "\x8f\xeb\xe2"=>0,
    "\x8f\xeb\xe3"=>0,
    "\x8f\xeb\xe4"=>0,
    "\x8f\xeb\xe5"=>0,
    "\x8f\xeb\xe6"=>0,
    "\x8f\xeb\xe7"=>0,
    "\x8f\xeb\xe8"=>0,
    "\x8f\xeb\xe9"=>0,
    "\x8f\xeb\xea"=>0,
    "\x8f\xeb\xeb"=>0,
    "\x8f\xeb\xec"=>0,
    "\x8f\xeb\xed"=>0,
    "\x8f\xeb\xee"=>0,
    "\x8f\xeb\xef"=>0,
    "\x8f\xeb\xf0"=>0,
    "\x8f\xeb\xf1"=>0,
    "\x8f\xeb\xf2"=>0,
    "\x8f\xeb\xf3"=>0,
    "\x8f\xeb\xf4"=>0,
    "\x8f\xeb\xf5"=>0,
    "\x8f\xeb\xf6"=>0,
    "\x8f\xeb\xf7"=>0,
    "\x8f\xeb\xf8"=>0,
    "\x8f\xeb\xf9"=>0,
    "\x8f\xeb\xfa"=>0,
    "\x8f\xeb\xfb"=>0,
    "\x8f\xeb\xfc"=>0,
    "\x8f\xeb\xfd"=>0,
    "\x8f\xeb\xfe"=>0,
    "\x8f\xec\xa1"=>0,
    "\x8f\xec\xa2"=>0,
    "\x8f\xec\xa3"=>0,
    "\x8f\xec\xa4"=>0,
    "\x8f\xec\xa5"=>0,
    "\x8f\xec\xa6"=>0,
    "\x8f\xec\xa7"=>0,
    "\x8f\xec\xa8"=>0,
    "\x8f\xec\xa9"=>0,
    "\x8f\xec\xaa"=>0,
    "\x8f\xec\xab"=>0,
    "\x8f\xec\xac"=>0,
    "\x8f\xec\xad"=>0,
    "\x8f\xec\xae"=>0,
    "\x8f\xec\xaf"=>0,
    "\x8f\xec\xb0"=>0,
    "\x8f\xec\xb1"=>0,
    "\x8f\xec\xb2"=>0,
    "\x8f\xec\xb3"=>0,
    "\x8f\xec\xb4"=>0,
    "\x8f\xec\xb5"=>0,
    "\x8f\xec\xb6"=>0,
    "\x8f\xec\xb7"=>0,
    "\x8f\xec\xb8"=>0,
    "\x8f\xec\xb9"=>0,
    "\x8f\xec\xba"=>0,
    "\x8f\xec\xbb"=>0,
    "\x8f\xec\xbc"=>0,
    "\x8f\xec\xbd"=>0,
    "\x8f\xec\xbe"=>0,
    "\x8f\xec\xbf"=>0,
    "\x8f\xec\xc0"=>0,
    "\x8f\xec\xc1"=>0,
    "\x8f\xec\xc2"=>0,
    "\x8f\xec\xc3"=>0,
    "\x8f\xec\xc4"=>0,
    "\x8f\xec\xc5"=>0,
    "\x8f\xec\xc6"=>0,
    "\x8f\xec\xc7"=>0,
    "\x8f\xec\xc8"=>0,
    "\x8f\xec\xc9"=>0,
    "\x8f\xec\xca"=>0,
    "\x8f\xec\xcb"=>0,
    "\x8f\xec\xcc"=>0,
    "\x8f\xec\xcd"=>0,
    "\x8f\xec\xce"=>0,
    "\x8f\xec\xcf"=>0,
    "\x8f\xec\xd0"=>0,
    "\x8f\xec\xd1"=>0,
    "\x8f\xec\xd2"=>0,
    "\x8f\xec\xd3"=>0,
    "\x8f\xec\xd4"=>0,
    "\x8f\xec\xd5"=>0,
    "\x8f\xec\xd6"=>0,
    "\x8f\xec\xd7"=>0,
    "\x8f\xec\xd8"=>0,
    "\x8f\xec\xd9"=>0,
    "\x8f\xec\xda"=>0,
    "\x8f\xec\xdb"=>0,
    "\x8f\xec\xdc"=>0,
    "\x8f\xec\xdd"=>0,
    "\x8f\xec\xde"=>0,
    "\x8f\xec\xdf"=>0,
    "\x8f\xec\xe0"=>0,
    "\x8f\xec\xe1"=>0,
    "\x8f\xec\xe2"=>0,
    "\x8f\xec\xe3"=>0,
    "\x8f\xec\xe4"=>0,
    "\x8f\xec\xe5"=>0,
    "\x8f\xec\xe6"=>0,
    "\x8f\xec\xe7"=>0,
    "\x8f\xec\xe8"=>0,
    "\x8f\xec\xe9"=>0,
    "\x8f\xec\xea"=>0,
    "\x8f\xec\xeb"=>0,
    "\x8f\xec\xec"=>0,
    "\x8f\xec\xed"=>0,
    "\x8f\xec\xee"=>0,
    "\x8f\xec\xef"=>0,
    "\x8f\xec\xf0"=>0,
    "\x8f\xec\xf1"=>0,
    "\x8f\xec\xf2"=>0,
    "\x8f\xec\xf3"=>0,
    "\x8f\xec\xf4"=>0,
    "\x8f\xec\xf5"=>0,
    "\x8f\xec\xf6"=>0,
    "\x8f\xec\xf7"=>0,
    "\x8f\xec\xf8"=>0,
    "\x8f\xec\xf9"=>0,
    "\x8f\xec\xfa"=>0,
    "\x8f\xec\xfb"=>0,
    "\x8f\xec\xfc"=>0,
    "\x8f\xec\xfd"=>0,
    "\x8f\xec\xfe"=>0,
    "\x8f\xed\xa1"=>0,
    "\x8f\xed\xa2"=>0,
    "\x8f\xed\xa3"=>0,
    "\x8f\xed\xa4"=>0,
    "\x8f\xed\xa5"=>0,
    "\x8f\xed\xa6"=>0,
    "\x8f\xed\xa7"=>0,
    "\x8f\xed\xa8"=>0,
    "\x8f\xed\xa9"=>0,
    "\x8f\xed\xaa"=>0,
    "\x8f\xed\xab"=>0,
    "\x8f\xed\xac"=>0,
    "\x8f\xed\xad"=>0,
    "\x8f\xed\xae"=>0,
    "\x8f\xed\xaf"=>0,
    "\x8f\xed\xb0"=>0,
    "\x8f\xed\xb1"=>0,
    "\x8f\xed\xb2"=>0,
    "\x8f\xed\xb3"=>0,
    "\x8f\xed\xb4"=>0,
    "\x8f\xed\xb5"=>0,
    "\x8f\xed\xb6"=>0,
    "\x8f\xed\xb7"=>0,
    "\x8f\xed\xb8"=>0,
    "\x8f\xed\xb9"=>0,
    "\x8f\xed\xba"=>0,
    "\x8f\xed\xbb"=>0,
    "\x8f\xed\xbc"=>0,
    "\x8f\xed\xbd"=>0,
    "\x8f\xed\xbe"=>0,
    "\x8f\xed\xbf"=>0,
    "\x8f\xed\xc0"=>0,
    "\x8f\xed\xc1"=>0,
    "\x8f\xed\xc2"=>0,
    "\x8f\xed\xc3"=>0,
    "\x8f\xed\xc4"=>0,
    "\x8f\xed\xc5"=>0,
    "\x8f\xed\xc6"=>0,
    "\x8f\xed\xc7"=>0,
    "\x8f\xed\xc8"=>0,
    "\x8f\xed\xc9"=>0,
    "\x8f\xed\xca"=>0,
    "\x8f\xed\xcb"=>0,
    "\x8f\xed\xcc"=>0,
    "\x8f\xed\xcd"=>0,
    "\x8f\xed\xce"=>0,
    "\x8f\xed\xcf"=>0,
    "\x8f\xed\xd0"=>0,
    "\x8f\xed\xd1"=>0,
    "\x8f\xed\xd2"=>0,
    "\x8f\xed\xd3"=>0,
    "\x8f\xed\xd4"=>0,
    "\x8f\xed\xd5"=>0,
    "\x8f\xed\xd6"=>0,
    "\x8f\xed\xd7"=>0,
    "\x8f\xed\xd8"=>0,
    "\x8f\xed\xd9"=>0,
    "\x8f\xed\xda"=>0,
    "\x8f\xed\xdb"=>0,
    "\x8f\xed\xdc"=>0,
    "\x8f\xed\xdd"=>0,
    "\x8f\xed\xde"=>0,
    "\x8f\xed\xdf"=>0,
    "\x8f\xed\xe0"=>0,
    "\x8f\xed\xe1"=>0,
    "\x8f\xed\xe2"=>0,
    "\x8f\xed\xe3"=>0,
    "\x8f\xee\xa1"=>0x6b9b,
    "\x8f\xee\xa2"=>0x6bae,
    "\x8f\xee\xa3"=>0x23a98,
    "\x8f\xee\xa4"=>0x6bbd,
    "\x8f\xee\xa5"=>0x6bbe,
    "\x8f\xee\xa6"=>0x6bc7,
    "\x8f\xee\xa7"=>0x6bc8,
    "\x8f\xee\xa8"=>0x6bc9,
    "\x8f\xee\xa9"=>0x6bda,
    "\x8f\xee\xaa"=>0x6be6,
    "\x8f\xee\xab"=>0x6be7,
    "\x8f\xee\xac"=>0x6bee,
    "\x8f\xee\xad"=>0x6bf1,
    "\x8f\xee\xae"=>0x6c02,
    "\x8f\xee\xaf"=>0x6c0a,
    "\x8f\xee\xb0"=>0x6c0e,
    "\x8f\xee\xb1"=>0x6c35,
    "\x8f\xee\xb2"=>0x6c36,
    "\x8f\xee\xb3"=>0x6c3a,
    "\x8f\xee\xb4"=>0x23c7f,
    "\x8f\xee\xb5"=>0x6c3f,
    "\x8f\xee\xb6"=>0x6c4d,
    "\x8f\xee\xb7"=>0x6c5b,
    "\x8f\xee\xb8"=>0x6c6d,
    "\x8f\xee\xb9"=>0x6c84,
    "\x8f\xee\xba"=>0x6c89,
    "\x8f\xee\xbb"=>0x3cc3,
    "\x8f\xee\xbc"=>0x6c94,
    "\x8f\xee\xbd"=>0x6c95,
    "\x8f\xee\xbe"=>0x6c97,
    "\x8f\xee\xbf"=>0x6cad,
    "\x8f\xee\xc0"=>0x6cc2,
    "\x8f\xee\xc1"=>0x6cd0,
    "\x8f\xee\xc2"=>0x3cd2,
    "\x8f\xee\xc3"=>0x6cd6,
    "\x8f\xee\xc4"=>0x6cda,
    "\x8f\xee\xc5"=>0x6cdc,
    "\x8f\xee\xc6"=>0x6ce9,
    "\x8f\xee\xc7"=>0x6cec,
    "\x8f\xee\xc8"=>0x6ced,
    "\x8f\xee\xc9"=>0x23d00,
    "\x8f\xee\xca"=>0x6d00,
    "\x8f\xee\xcb"=>0x6d0a,
    "\x8f\xee\xcc"=>0x6d24,
    "\x8f\xee\xcd"=>0x6d26,
    "\x8f\xee\xce"=>0x6d27,
    "\x8f\xee\xcf"=>0x6c67,
    "\x8f\xee\xd0"=>0x6d2f,
    "\x8f\xee\xd1"=>0x6d3c,
    "\x8f\xee\xd2"=>0x6d5b,
    "\x8f\xee\xd3"=>0x6d5e,
    "\x8f\xee\xd4"=>0x6d60,
    "\x8f\xee\xd5"=>0x6d70,
    "\x8f\xee\xd6"=>0x6d80,
    "\x8f\xee\xd7"=>0x6d81,
    "\x8f\xee\xd8"=>0x6d8a,
    "\x8f\xee\xd9"=>0x6d8d,
    "\x8f\xee\xda"=>0x6d91,
    "\x8f\xee\xdb"=>0x6d98,
    "\x8f\xee\xdc"=>0x23d40,
    "\x8f\xee\xdd"=>0x6e17,
    "\x8f\xee\xde"=>0x23dfa,
    "\x8f\xee\xdf"=>0x23df9,
    "\x8f\xee\xe0"=>0x23dd3,
    "\x8f\xee\xe1"=>0x6dab,
    "\x8f\xee\xe2"=>0x6dae,
    "\x8f\xee\xe3"=>0x6db4,
    "\x8f\xee\xe4"=>0x6dc2,
    "\x8f\xee\xe5"=>0x6d34,
    "\x8f\xee\xe6"=>0x6dc8,
    "\x8f\xee\xe7"=>0x6dce,
    "\x8f\xee\xe8"=>0x6dcf,
    "\x8f\xee\xe9"=>0x6dd0,
    "\x8f\xee\xea"=>0x6ddf,
    "\x8f\xee\xeb"=>0x6de9,
    "\x8f\xee\xec"=>0x6df6,
    "\x8f\xee\xed"=>0x6e36,
    "\x8f\xee\xee"=>0x6e1e,
    "\x8f\xee\xef"=>0x6e22,
    "\x8f\xee\xf0"=>0x6e27,
    "\x8f\xee\xf1"=>0x3d11,
    "\x8f\xee\xf2"=>0x6e32,
    "\x8f\xee\xf3"=>0x6e3c,
    "\x8f\xee\xf4"=>0x6e48,
    "\x8f\xee\xf5"=>0x6e49,
    "\x8f\xee\xf6"=>0x6e4b,
    "\x8f\xee\xf7"=>0x6e4c,
    "\x8f\xee\xf8"=>0x6e4f,
    "\x8f\xee\xf9"=>0x6e51,
    "\x8f\xee\xfa"=>0x6e53,
    "\x8f\xee\xfb"=>0x6e54,
    "\x8f\xee\xfc"=>0x6e57,
    "\x8f\xee\xfd"=>0x6e63,
    "\x8f\xee\xfe"=>0x3d1e,
    "\x8f\xef\xa1"=>0x6e93,
    "\x8f\xef\xa2"=>0x6ea7,
    "\x8f\xef\xa3"=>0x6eb4,
    "\x8f\xef\xa4"=>0x6ebf,
    "\x8f\xef\xa5"=>0x6ec3,
    "\x8f\xef\xa6"=>0x6eca,
    "\x8f\xef\xa7"=>0x6ed9,
    "\x8f\xef\xa8"=>0x6f35,
    "\x8f\xef\xa9"=>0x6eeb,
    "\x8f\xef\xaa"=>0x6ef9,
    "\x8f\xef\xab"=>0x6efb,
    "\x8f\xef\xac"=>0x6f0a,
    "\x8f\xef\xad"=>0x6f0c,
    "\x8f\xef\xae"=>0x6f18,
    "\x8f\xef\xaf"=>0x6f25,
    "\x8f\xef\xb0"=>0x6f36,
    "\x8f\xef\xb1"=>0x6f3c,
    "\x8f\xef\xb2"=>0x23f7e,
    "\x8f\xef\xb3"=>0x6f52,
    "\x8f\xef\xb4"=>0x6f57,
    "\x8f\xef\xb5"=>0x6f5a,
    "\x8f\xef\xb6"=>0x6f60,
    "\x8f\xef\xb7"=>0x6f68,
    "\x8f\xef\xb8"=>0x6f98,
    "\x8f\xef\xb9"=>0x6f7d,
    "\x8f\xef\xba"=>0x6f90,
    "\x8f\xef\xbb"=>0x6f96,
    "\x8f\xef\xbc"=>0x6fbe,
    "\x8f\xef\xbd"=>0x6f9f,
    "\x8f\xef\xbe"=>0x6fa5,
    "\x8f\xef\xbf"=>0x6faf,
    "\x8f\xef\xc0"=>0x3d64,
    "\x8f\xef\xc1"=>0x6fb5,
    "\x8f\xef\xc2"=>0x6fc8,
    "\x8f\xef\xc3"=>0x6fc9,
    "\x8f\xef\xc4"=>0x6fda,
    "\x8f\xef\xc5"=>0x6fde,
    "\x8f\xef\xc6"=>0x6fe9,
    "\x8f\xef\xc7"=>0x24096,
    "\x8f\xef\xc8"=>0x6ffc,
    "\x8f\xef\xc9"=>0x7000,
    "\x8f\xef\xca"=>0x7007,
    "\x8f\xef\xcb"=>0x700a,
    "\x8f\xef\xcc"=>0x7023,
    "\x8f\xef\xcd"=>0x24103,
    "\x8f\xef\xce"=>0x7039,
    "\x8f\xef\xcf"=>0x703a,
    "\x8f\xef\xd0"=>0x703c,
    "\x8f\xef\xd1"=>0x7043,
    "\x8f\xef\xd2"=>0x7047,
    "\x8f\xef\xd3"=>0x704b,
    "\x8f\xef\xd4"=>0x3d9a,
    "\x8f\xef\xd5"=>0x7054,
    "\x8f\xef\xd6"=>0x7065,
    "\x8f\xef\xd7"=>0x7069,
    "\x8f\xef\xd8"=>0x706c,
    "\x8f\xef\xd9"=>0x706e,
    "\x8f\xef\xda"=>0x7076,
    "\x8f\xef\xdb"=>0x707e,
    "\x8f\xef\xdc"=>0x7081,
    "\x8f\xef\xdd"=>0x7086,
    "\x8f\xef\xde"=>0x7095,
    "\x8f\xef\xdf"=>0x7097,
    "\x8f\xef\xe0"=>0x70bb,
    "\x8f\xef\xe1"=>0x241c6,
    "\x8f\xef\xe2"=>0x709f,
    "\x8f\xef\xe3"=>0x70b1,
    "\x8f\xef\xe4"=>0x241fe,
    "\x8f\xef\xe5"=>0x70ec,
    "\x8f\xef\xe6"=>0x70ca,
    "\x8f\xef\xe7"=>0x70d1,
    "\x8f\xef\xe8"=>0x70d3,
    "\x8f\xef\xe9"=>0x70dc,
    "\x8f\xef\xea"=>0x7103,
    "\x8f\xef\xeb"=>0x7104,
    "\x8f\xef\xec"=>0x7106,
    "\x8f\xef\xed"=>0x7107,
    "\x8f\xef\xee"=>0x7108,
    "\x8f\xef\xef"=>0x710c,
    "\x8f\xef\xf0"=>0x3dc0,
    "\x8f\xef\xf1"=>0x712f,
    "\x8f\xef\xf2"=>0x7131,
    "\x8f\xef\xf3"=>0x7150,
    "\x8f\xef\xf4"=>0x714a,
    "\x8f\xef\xf5"=>0x7153,
    "\x8f\xef\xf6"=>0x715e,
    "\x8f\xef\xf7"=>0x3dd4,
    "\x8f\xef\xf8"=>0x7196,
    "\x8f\xef\xf9"=>0x7180,
    "\x8f\xef\xfa"=>0x719b,
    "\x8f\xef\xfb"=>0x71a0,
    "\x8f\xef\xfc"=>0x71a2,
    "\x8f\xef\xfd"=>0x71ae,
    "\x8f\xef\xfe"=>0x71af,
    "\x8f\xf0\xa1"=>0x71b3,
    "\x8f\xf0\xa2"=>0x243bc,
    "\x8f\xf0\xa3"=>0x71cb,
    "\x8f\xf0\xa4"=>0x71d3,
    "\x8f\xf0\xa5"=>0x71d9,
    "\x8f\xf0\xa6"=>0x71dc,
    "\x8f\xf0\xa7"=>0x7207,
    "\x8f\xf0\xa8"=>0x3e05,
    "\x8f\xf0\xa9"=>0xfa49,
    "\x8f\xf0\xaa"=>0x722b,
    "\x8f\xf0\xab"=>0x7234,
    "\x8f\xf0\xac"=>0x7238,
    "\x8f\xf0\xad"=>0x7239,
    "\x8f\xf0\xae"=>0x4e2c,
    "\x8f\xf0\xaf"=>0x7242,
    "\x8f\xf0\xb0"=>0x7253,
    "\x8f\xf0\xb1"=>0x7257,
    "\x8f\xf0\xb2"=>0x7263,
    "\x8f\xf0\xb3"=>0x24629,
    "\x8f\xf0\xb4"=>0x726e,
    "\x8f\xf0\xb5"=>0x726f,
    "\x8f\xf0\xb6"=>0x7278,
    "\x8f\xf0\xb7"=>0x727f,
    "\x8f\xf0\xb8"=>0x728e,
    "\x8f\xf0\xb9"=>0x246a5,
    "\x8f\xf0\xba"=>0x72ad,
    "\x8f\xf0\xbb"=>0x72ae,
    "\x8f\xf0\xbc"=>0x72b0,
    "\x8f\xf0\xbd"=>0x72b1,
    "\x8f\xf0\xbe"=>0x72c1,
    "\x8f\xf0\xbf"=>0x3e60,
    "\x8f\xf0\xc0"=>0x72cc,
    "\x8f\xf0\xc1"=>0x3e66,
    "\x8f\xf0\xc2"=>0x3e68,
    "\x8f\xf0\xc3"=>0x72f3,
    "\x8f\xf0\xc4"=>0x72fa,
    "\x8f\xf0\xc5"=>0x7307,
    "\x8f\xf0\xc6"=>0x7312,
    "\x8f\xf0\xc7"=>0x7318,
    "\x8f\xf0\xc8"=>0x7319,
    "\x8f\xf0\xc9"=>0x3e83,
    "\x8f\xf0\xca"=>0x7339,
    "\x8f\xf0\xcb"=>0x732c,
    "\x8f\xf0\xcc"=>0x7331,
    "\x8f\xf0\xcd"=>0x7333,
    "\x8f\xf0\xce"=>0x733d,
    "\x8f\xf0\xcf"=>0x7352,
    "\x8f\xf0\xd0"=>0x3e94,
    "\x8f\xf0\xd1"=>0x736b,
    "\x8f\xf0\xd2"=>0x736c,
    "\x8f\xf0\xd3"=>0x24896,
    "\x8f\xf0\xd4"=>0x736e,
    "\x8f\xf0\xd5"=>0x736f,
    "\x8f\xf0\xd6"=>0x7371,
    "\x8f\xf0\xd7"=>0x7377,
    "\x8f\xf0\xd8"=>0x7381,
    "\x8f\xf0\xd9"=>0x7385,
    "\x8f\xf0\xda"=>0x738a,
    "\x8f\xf0\xdb"=>0x7394,
    "\x8f\xf0\xdc"=>0x7398,
    "\x8f\xf0\xdd"=>0x739c,
    "\x8f\xf0\xde"=>0x739e,
    "\x8f\xf0\xdf"=>0x73a5,
    "\x8f\xf0\xe0"=>0x73a8,
    "\x8f\xf0\xe1"=>0x73b5,
    "\x8f\xf0\xe2"=>0x73b7,
    "\x8f\xf0\xe3"=>0x73b9,
    "\x8f\xf0\xe4"=>0x73bc,
    "\x8f\xf0\xe5"=>0x73bf,
    "\x8f\xf0\xe6"=>0x73c5,
    "\x8f\xf0\xe7"=>0x73cb,
    "\x8f\xf0\xe8"=>0x73e1,
    "\x8f\xf0\xe9"=>0x73e7,
    "\x8f\xf0\xea"=>0x73f9,
    "\x8f\xf0\xeb"=>0x7413,
    "\x8f\xf0\xec"=>0x73fa,
    "\x8f\xf0\xed"=>0x7401,
    "\x8f\xf0\xee"=>0x7424,
    "\x8f\xf0\xef"=>0x7431,
    "\x8f\xf0\xf0"=>0x7439,
    "\x8f\xf0\xf1"=>0x7453,
    "\x8f\xf0\xf2"=>0x7440,
    "\x8f\xf0\xf3"=>0x7443,
    "\x8f\xf0\xf4"=>0x744d,
    "\x8f\xf0\xf5"=>0x7452,
    "\x8f\xf0\xf6"=>0x745d,
    "\x8f\xf0\xf7"=>0x7471,
    "\x8f\xf0\xf8"=>0x7481,
    "\x8f\xf0\xf9"=>0x7485,
    "\x8f\xf0\xfa"=>0x7488,
    "\x8f\xf0\xfb"=>0x24a4d,
    "\x8f\xf0\xfc"=>0x7492,
    "\x8f\xf0\xfd"=>0x7497,
    "\x8f\xf0\xfe"=>0x7499,
    "\x8f\xf1\xa1"=>0x74a0,
    "\x8f\xf1\xa2"=>0x74a1,
    "\x8f\xf1\xa3"=>0x74a5,
    "\x8f\xf1\xa4"=>0x74aa,
    "\x8f\xf1\xa5"=>0x74ab,
    "\x8f\xf1\xa6"=>0x74b9,
    "\x8f\xf1\xa7"=>0x74bb,
    "\x8f\xf1\xa8"=>0x74ba,
    "\x8f\xf1\xa9"=>0x74d6,
    "\x8f\xf1\xaa"=>0x74d8,
    "\x8f\xf1\xab"=>0x74de,
    "\x8f\xf1\xac"=>0x74ef,
    "\x8f\xf1\xad"=>0x74eb,
    "\x8f\xf1\xae"=>0x24b56,
    "\x8f\xf1\xaf"=>0x74fa,
    "\x8f\xf1\xb0"=>0x24b6f,
    "\x8f\xf1\xb1"=>0x7520,
    "\x8f\xf1\xb2"=>0x7524,
    "\x8f\xf1\xb3"=>0x752a,
    "\x8f\xf1\xb4"=>0x3f57,
    "\x8f\xf1\xb5"=>0x24c16,
    "\x8f\xf1\xb6"=>0x753d,
    "\x8f\xf1\xb7"=>0x753e,
    "\x8f\xf1\xb8"=>0x7540,
    "\x8f\xf1\xb9"=>0x7548,
    "\x8f\xf1\xba"=>0x754e,
    "\x8f\xf1\xbb"=>0x7550,
    "\x8f\xf1\xbc"=>0x7552,
    "\x8f\xf1\xbd"=>0x756c,
    "\x8f\xf1\xbe"=>0x7572,
    "\x8f\xf1\xbf"=>0x7571,
    "\x8f\xf1\xc0"=>0x757a,
    "\x8f\xf1\xc1"=>0x757d,
    "\x8f\xf1\xc2"=>0x757e,
    "\x8f\xf1\xc3"=>0x7581,
    "\x8f\xf1\xc4"=>0x24d14,
    "\x8f\xf1\xc5"=>0x758c,
    "\x8f\xf1\xc6"=>0x3f75,
    "\x8f\xf1\xc7"=>0x75a2,
    "\x8f\xf1\xc8"=>0x3f77,
    "\x8f\xf1\xc9"=>0x75b0,
    "\x8f\xf1\xca"=>0x75b7,
    "\x8f\xf1\xcb"=>0x75bf,
    "\x8f\xf1\xcc"=>0x75c0,
    "\x8f\xf1\xcd"=>0x75c6,
    "\x8f\xf1\xce"=>0x75cf,
    "\x8f\xf1\xcf"=>0x75d3,
    "\x8f\xf1\xd0"=>0x75dd,
    "\x8f\xf1\xd1"=>0x75df,
    "\x8f\xf1\xd2"=>0x75e0,
    "\x8f\xf1\xd3"=>0x75e7,
    "\x8f\xf1\xd4"=>0x75ec,
    "\x8f\xf1\xd5"=>0x75ee,
    "\x8f\xf1\xd6"=>0x75f1,
    "\x8f\xf1\xd7"=>0x75f9,
    "\x8f\xf1\xd8"=>0x7603,
    "\x8f\xf1\xd9"=>0x7618,
    "\x8f\xf1\xda"=>0x7607,
    "\x8f\xf1\xdb"=>0x760f,
    "\x8f\xf1\xdc"=>0x3fae,
    "\x8f\xf1\xdd"=>0x24e0e,
    "\x8f\xf1\xde"=>0x7613,
    "\x8f\xf1\xdf"=>0x761b,
    "\x8f\xf1\xe0"=>0x761c,
    "\x8f\xf1\xe1"=>0x24e37,
    "\x8f\xf1\xe2"=>0x7625,
    "\x8f\xf1\xe3"=>0x7628,
    "\x8f\xf1\xe4"=>0x763c,
    "\x8f\xf1\xe5"=>0x7633,
    "\x8f\xf1\xe6"=>0x24e6a,
    "\x8f\xf1\xe7"=>0x3fc9,
    "\x8f\xf1\xe8"=>0x7641,
    "\x8f\xf1\xe9"=>0x24e8b,
    "\x8f\xf1\xea"=>0x7649,
    "\x8f\xf1\xeb"=>0x7655,
    "\x8f\xf1\xec"=>0x3fd7,
    "\x8f\xf1\xed"=>0x766e,
    "\x8f\xf1\xee"=>0x7695,
    "\x8f\xf1\xef"=>0x769c,
    "\x8f\xf1\xf0"=>0x76a1,
    "\x8f\xf1\xf1"=>0x76a0,
    "\x8f\xf1\xf2"=>0x76a7,
    "\x8f\xf1\xf3"=>0x76a8,
    "\x8f\xf1\xf4"=>0x76af,
    "\x8f\xf1\xf5"=>0x2504a,
    "\x8f\xf1\xf6"=>0x76c9,
    "\x8f\xf1\xf7"=>0x25055,
    "\x8f\xf1\xf8"=>0x76e8,
    "\x8f\xf1\xf9"=>0x76ec,
    "\x8f\xf1\xfa"=>0x25122,
    "\x8f\xf1\xfb"=>0x7717,
    "\x8f\xf1\xfc"=>0x771a,
    "\x8f\xf1\xfd"=>0x772d,
    "\x8f\xf1\xfe"=>0x7735,
    "\x8f\xf2\xa1"=>0x251a9,
    "\x8f\xf2\xa2"=>0x4039,
    "\x8f\xf2\xa3"=>0x251e5,
    "\x8f\xf2\xa4"=>0x251cd,
    "\x8f\xf2\xa5"=>0x7758,
    "\x8f\xf2\xa6"=>0x7760,
    "\x8f\xf2\xa7"=>0x776a,
    "\x8f\xf2\xa8"=>0x2521e,
    "\x8f\xf2\xa9"=>0x7772,
    "\x8f\xf2\xaa"=>0x777c,
    "\x8f\xf2\xab"=>0x777d,
    "\x8f\xf2\xac"=>0x2524c,
    "\x8f\xf2\xad"=>0x4058,
    "\x8f\xf2\xae"=>0x779a,
    "\x8f\xf2\xaf"=>0x779f,
    "\x8f\xf2\xb0"=>0x77a2,
    "\x8f\xf2\xb1"=>0x77a4,
    "\x8f\xf2\xb2"=>0x77a9,
    "\x8f\xf2\xb3"=>0x77de,
    "\x8f\xf2\xb4"=>0x77df,
    "\x8f\xf2\xb5"=>0x77e4,
    "\x8f\xf2\xb6"=>0x77e6,
    "\x8f\xf2\xb7"=>0x77ea,
    "\x8f\xf2\xb8"=>0x77ec,
    "\x8f\xf2\xb9"=>0x4093,
    "\x8f\xf2\xba"=>0x77f0,
    "\x8f\xf2\xbb"=>0x77f4,
    "\x8f\xf2\xbc"=>0x77fb,
    "\x8f\xf2\xbd"=>0x2542e,
    "\x8f\xf2\xbe"=>0x7805,
    "\x8f\xf2\xbf"=>0x7806,
    "\x8f\xf2\xc0"=>0x7809,
    "\x8f\xf2\xc1"=>0x780d,
    "\x8f\xf2\xc2"=>0x7819,
    "\x8f\xf2\xc3"=>0x7821,
    "\x8f\xf2\xc4"=>0x782c,
    "\x8f\xf2\xc5"=>0x7847,
    "\x8f\xf2\xc6"=>0x7864,
    "\x8f\xf2\xc7"=>0x786a,
    "\x8f\xf2\xc8"=>0x254d9,
    "\x8f\xf2\xc9"=>0x788a,
    "\x8f\xf2\xca"=>0x7894,
    "\x8f\xf2\xcb"=>0x78a4,
    "\x8f\xf2\xcc"=>0x789d,
    "\x8f\xf2\xcd"=>0x789e,
    "\x8f\xf2\xce"=>0x789f,
    "\x8f\xf2\xcf"=>0x78bb,
    "\x8f\xf2\xd0"=>0x78c8,
    "\x8f\xf2\xd1"=>0x78cc,
    "\x8f\xf2\xd2"=>0x78ce,
    "\x8f\xf2\xd3"=>0x78d5,
    "\x8f\xf2\xd4"=>0x78e0,
    "\x8f\xf2\xd5"=>0x78e1,
    "\x8f\xf2\xd6"=>0x78e6,
    "\x8f\xf2\xd7"=>0x78f9,
    "\x8f\xf2\xd8"=>0x78fa,
    "\x8f\xf2\xd9"=>0x78fb,
    "\x8f\xf2\xda"=>0x78fe,
    "\x8f\xf2\xdb"=>0x255a7,
    "\x8f\xf2\xdc"=>0x7910,
    "\x8f\xf2\xdd"=>0x791b,
    "\x8f\xf2\xde"=>0x7930,
    "\x8f\xf2\xdf"=>0x7925,
    "\x8f\xf2\xe0"=>0x793b,
    "\x8f\xf2\xe1"=>0x794a,
    "\x8f\xf2\xe2"=>0x7958,
    "\x8f\xf2\xe3"=>0x795b,
    "\x8f\xf2\xe4"=>0x4105,
    "\x8f\xf2\xe5"=>0x7967,
    "\x8f\xf2\xe6"=>0x7972,
    "\x8f\xf2\xe7"=>0x7994,
    "\x8f\xf2\xe8"=>0x7995,
    "\x8f\xf2\xe9"=>0x7996,
    "\x8f\xf2\xea"=>0x799b,
    "\x8f\xf2\xeb"=>0x79a1,
    "\x8f\xf2\xec"=>0x79a9,
    "\x8f\xf2\xed"=>0x79b4,
    "\x8f\xf2\xee"=>0x79bb,
    "\x8f\xf2\xef"=>0x79c2,
    "\x8f\xf2\xf0"=>0x79c7,
    "\x8f\xf2\xf1"=>0x79cc,
    "\x8f\xf2\xf2"=>0x79cd,
    "\x8f\xf2\xf3"=>0x79d6,
    "\x8f\xf2\xf4"=>0x4148,
    "\x8f\xf2\xf5"=>0x257a9,
    "\x8f\xf2\xf6"=>0x257b4,
    "\x8f\xf2\xf7"=>0x414f,
    "\x8f\xf2\xf8"=>0x7a0a,
    "\x8f\xf2\xf9"=>0x7a11,
    "\x8f\xf2\xfa"=>0x7a15,
    "\x8f\xf2\xfb"=>0x7a1b,
    "\x8f\xf2\xfc"=>0x7a1e,
    "\x8f\xf2\xfd"=>0x4163,
    "\x8f\xf2\xfe"=>0x7a2d,
    "\x8f\xf3\xa1"=>0x7a38,
    "\x8f\xf3\xa2"=>0x7a47,
    "\x8f\xf3\xa3"=>0x7a4c,
    "\x8f\xf3\xa4"=>0x7a56,
    "\x8f\xf3\xa5"=>0x7a59,
    "\x8f\xf3\xa6"=>0x7a5c,
    "\x8f\xf3\xa7"=>0x7a5f,
    "\x8f\xf3\xa8"=>0x7a60,
    "\x8f\xf3\xa9"=>0x7a67,
    "\x8f\xf3\xaa"=>0x7a6a,
    "\x8f\xf3\xab"=>0x7a75,
    "\x8f\xf3\xac"=>0x7a78,
    "\x8f\xf3\xad"=>0x7a82,
    "\x8f\xf3\xae"=>0x7a8a,
    "\x8f\xf3\xaf"=>0x7a90,
    "\x8f\xf3\xb0"=>0x7aa3,
    "\x8f\xf3\xb1"=>0x7aac,
    "\x8f\xf3\xb2"=>0x259d4,
    "\x8f\xf3\xb3"=>0x41b4,
    "\x8f\xf3\xb4"=>0x7ab9,
    "\x8f\xf3\xb5"=>0x7abc,
    "\x8f\xf3\xb6"=>0x7abe,
    "\x8f\xf3\xb7"=>0x41bf,
    "\x8f\xf3\xb8"=>0x7acc,
    "\x8f\xf3\xb9"=>0x7ad1,
    "\x8f\xf3\xba"=>0x7ae7,
    "\x8f\xf3\xbb"=>0x7ae8,
    "\x8f\xf3\xbc"=>0x7af4,
    "\x8f\xf3\xbd"=>0x25ae4,
    "\x8f\xf3\xbe"=>0x25ae3,
    "\x8f\xf3\xbf"=>0x7b07,
    "\x8f\xf3\xc0"=>0x25af1,
    "\x8f\xf3\xc1"=>0x7b3d,
    "\x8f\xf3\xc2"=>0x7b27,
    "\x8f\xf3\xc3"=>0x7b2a,
    "\x8f\xf3\xc4"=>0x7b2e,
    "\x8f\xf3\xc5"=>0x7b2f,
    "\x8f\xf3\xc6"=>0x7b31,
    "\x8f\xf3\xc7"=>0x41e6,
    "\x8f\xf3\xc8"=>0x41f3,
    "\x8f\xf3\xc9"=>0x7b7f,
    "\x8f\xf3\xca"=>0x7b41,
    "\x8f\xf3\xcb"=>0x41ee,
    "\x8f\xf3\xcc"=>0x7b55,
    "\x8f\xf3\xcd"=>0x7b79,
    "\x8f\xf3\xce"=>0x7b64,
    "\x8f\xf3\xcf"=>0x7b66,
    "\x8f\xf3\xd0"=>0x7b69,
    "\x8f\xf3\xd1"=>0x7b73,
    "\x8f\xf3\xd2"=>0x25bb2,
    "\x8f\xf3\xd3"=>0x4207,
    "\x8f\xf3\xd4"=>0x7b90,
    "\x8f\xf3\xd5"=>0x7b91,
    "\x8f\xf3\xd6"=>0x7b9b,
    "\x8f\xf3\xd7"=>0x420e,
    "\x8f\xf3\xd8"=>0x7baf,
    "\x8f\xf3\xd9"=>0x7bb5,
    "\x8f\xf3\xda"=>0x7bbc,
    "\x8f\xf3\xdb"=>0x7bc5,
    "\x8f\xf3\xdc"=>0x7bca,
    "\x8f\xf3\xdd"=>0x25c4b,
    "\x8f\xf3\xde"=>0x25c64,
    "\x8f\xf3\xdf"=>0x7bd4,
    "\x8f\xf3\xe0"=>0x7bd6,
    "\x8f\xf3\xe1"=>0x7bda,
    "\x8f\xf3\xe2"=>0x7bea,
    "\x8f\xf3\xe3"=>0x7bf0,
    "\x8f\xf3\xe4"=>0x7c03,
    "\x8f\xf3\xe5"=>0x7c0b,
    "\x8f\xf3\xe6"=>0x7c0e,
    "\x8f\xf3\xe7"=>0x7c0f,
    "\x8f\xf3\xe8"=>0x7c26,
    "\x8f\xf3\xe9"=>0x7c45,
    "\x8f\xf3\xea"=>0x7c4a,
    "\x8f\xf3\xeb"=>0x7c51,
    "\x8f\xf3\xec"=>0x7c57,
    "\x8f\xf3\xed"=>0x7c5e,
    "\x8f\xf3\xee"=>0x7c61,
    "\x8f\xf3\xef"=>0x7c69,
    "\x8f\xf3\xf0"=>0x7c6e,
    "\x8f\xf3\xf1"=>0x7c6f,
    "\x8f\xf3\xf2"=>0x7c70,
    "\x8f\xf3\xf3"=>0x25e2e,
    "\x8f\xf3\xf4"=>0x25e56,
    "\x8f\xf3\xf5"=>0x25e65,
    "\x8f\xf3\xf6"=>0x7ca6,
    "\x8f\xf3\xf7"=>0x25e62,
    "\x8f\xf3\xf8"=>0x7cb6,
    "\x8f\xf3\xf9"=>0x7cb7,
    "\x8f\xf3\xfa"=>0x7cbf,
    "\x8f\xf3\xfb"=>0x25ed8,
    "\x8f\xf3\xfc"=>0x7cc4,
    "\x8f\xf3\xfd"=>0x25ec2,
    "\x8f\xf3\xfe"=>0x7cc8,
    "\x8f\xf4\xa1"=>0x7ccd,
    "\x8f\xf4\xa2"=>0x25ee8,
    "\x8f\xf4\xa3"=>0x7cd7,
    "\x8f\xf4\xa4"=>0x25f23,
    "\x8f\xf4\xa5"=>0x7ce6,
    "\x8f\xf4\xa6"=>0x7ceb,
    "\x8f\xf4\xa7"=>0x25f5c,
    "\x8f\xf4\xa8"=>0x7cf5,
    "\x8f\xf4\xa9"=>0x7d03,
    "\x8f\xf4\xaa"=>0x7d09,
    "\x8f\xf4\xab"=>0x42c6,
    "\x8f\xf4\xac"=>0x7d12,
    "\x8f\xf4\xad"=>0x7d1e,
    "\x8f\xf4\xae"=>0x25fe0,
    "\x8f\xf4\xaf"=>0x25fd4,
    "\x8f\xf4\xb0"=>0x7d3d,
    "\x8f\xf4\xb1"=>0x7d3e,
    "\x8f\xf4\xb2"=>0x7d40,
    "\x8f\xf4\xb3"=>0x7d47,
    "\x8f\xf4\xb4"=>0x2600c,
    "\x8f\xf4\xb5"=>0x25ffb,
    "\x8f\xf4\xb6"=>0x42d6,
    "\x8f\xf4\xb7"=>0x7d59,
    "\x8f\xf4\xb8"=>0x7d5a,
    "\x8f\xf4\xb9"=>0x7d6a,
    "\x8f\xf4\xba"=>0x7d70,
    "\x8f\xf4\xbb"=>0x42dd,
    "\x8f\xf4\xbc"=>0x7d7f,
    "\x8f\xf4\xbd"=>0x26017,
    "\x8f\xf4\xbe"=>0x7d86,
    "\x8f\xf4\xbf"=>0x7d88,
    "\x8f\xf4\xc0"=>0x7d8c,
    "\x8f\xf4\xc1"=>0x7d97,
    "\x8f\xf4\xc2"=>0x26060,
    "\x8f\xf4\xc3"=>0x7d9d,
    "\x8f\xf4\xc4"=>0x7da7,
    "\x8f\xf4\xc5"=>0x7daa,
    "\x8f\xf4\xc6"=>0x7db6,
    "\x8f\xf4\xc7"=>0x7db7,
    "\x8f\xf4\xc8"=>0x7dc0,
    "\x8f\xf4\xc9"=>0x7dd7,
    "\x8f\xf4\xca"=>0x7dd9,
    "\x8f\xf4\xcb"=>0x7de6,
    "\x8f\xf4\xcc"=>0x7df1,
    "\x8f\xf4\xcd"=>0x7df9,
    "\x8f\xf4\xce"=>0x4302,
    "\x8f\xf4\xcf"=>0x260ed,
    "\x8f\xf4\xd0"=>0xfa58,
    "\x8f\xf4\xd1"=>0x7e10,
    "\x8f\xf4\xd2"=>0x7e17,
    "\x8f\xf4\xd3"=>0x7e1d,
    "\x8f\xf4\xd4"=>0x7e20,
    "\x8f\xf4\xd5"=>0x7e27,
    "\x8f\xf4\xd6"=>0x7e2c,
    "\x8f\xf4\xd7"=>0x7e45,
    "\x8f\xf4\xd8"=>0x7e73,
    "\x8f\xf4\xd9"=>0x7e75,
    "\x8f\xf4\xda"=>0x7e7e,
    "\x8f\xf4\xdb"=>0x7e86,
    "\x8f\xf4\xdc"=>0x7e87,
    "\x8f\xf4\xdd"=>0x432b,
    "\x8f\xf4\xde"=>0x7e91,
    "\x8f\xf4\xdf"=>0x7e98,
    "\x8f\xf4\xe0"=>0x7e9a,
    "\x8f\xf4\xe1"=>0x4343,
    "\x8f\xf4\xe2"=>0x7f3c,
    "\x8f\xf4\xe3"=>0x7f3b,
    "\x8f\xf4\xe4"=>0x7f3e,
    "\x8f\xf4\xe5"=>0x7f43,
    "\x8f\xf4\xe6"=>0x7f44,
    "\x8f\xf4\xe7"=>0x7f4f,
    "\x8f\xf4\xe8"=>0x34c1,
    "\x8f\xf4\xe9"=>0x26270,
    "\x8f\xf4\xea"=>0x7f52,
    "\x8f\xf4\xeb"=>0x26286,
    "\x8f\xf4\xec"=>0x7f61,
    "\x8f\xf4\xed"=>0x7f63,
    "\x8f\xf4\xee"=>0x7f64,
    "\x8f\xf4\xef"=>0x7f6d,
    "\x8f\xf4\xf0"=>0x7f7d,
    "\x8f\xf4\xf1"=>0x7f7e,
    "\x8f\xf4\xf2"=>0x2634c,
    "\x8f\xf4\xf3"=>0x7f90,
    "\x8f\xf4\xf4"=>0x517b,
    "\x8f\xf4\xf5"=>0x23d0e,
    "\x8f\xf4\xf6"=>0x7f96,
    "\x8f\xf4\xf7"=>0x7f9c,
    "\x8f\xf4\xf8"=>0x7fad,
    "\x8f\xf4\xf9"=>0x26402,
    "\x8f\xf4\xfa"=>0x7fc3,
    "\x8f\xf4\xfb"=>0x7fcf,
    "\x8f\xf4\xfc"=>0x7fe3,
    "\x8f\xf4\xfd"=>0x7fe5,
    "\x8f\xf4\xfe"=>0x7fef,
    "\x8f\xf5\xa1"=>0x7ff2,
    "\x8f\xf5\xa2"=>0x8002,
    "\x8f\xf5\xa3"=>0x800a,
    "\x8f\xf5\xa4"=>0x8008,
    "\x8f\xf5\xa5"=>0x800e,
    "\x8f\xf5\xa6"=>0x8011,
    "\x8f\xf5\xa7"=>0x8016,
    "\x8f\xf5\xa8"=>0x8024,
    "\x8f\xf5\xa9"=>0x802c,
    "\x8f\xf5\xaa"=>0x8030,
    "\x8f\xf5\xab"=>0x8043,
    "\x8f\xf5\xac"=>0x8066,
    "\x8f\xf5\xad"=>0x8071,
    "\x8f\xf5\xae"=>0x8075,
    "\x8f\xf5\xaf"=>0x807b,
    "\x8f\xf5\xb0"=>0x8099,
    "\x8f\xf5\xb1"=>0x809c,
    "\x8f\xf5\xb2"=>0x80a4,
    "\x8f\xf5\xb3"=>0x80a7,
    "\x8f\xf5\xb4"=>0x80b8,
    "\x8f\xf5\xb5"=>0x2667e,
    "\x8f\xf5\xb6"=>0x80c5,
    "\x8f\xf5\xb7"=>0x80d5,
    "\x8f\xf5\xb8"=>0x80d8,
    "\x8f\xf5\xb9"=>0x80e6,
    "\x8f\xf5\xba"=>0x266b0,
    "\x8f\xf5\xbb"=>0x810d,
    "\x8f\xf5\xbc"=>0x80f5,
    "\x8f\xf5\xbd"=>0x80fb,
    "\x8f\xf5\xbe"=>0x43ee,
    "\x8f\xf5\xbf"=>0x8135,
    "\x8f\xf5\xc0"=>0x8116,
    "\x8f\xf5\xc1"=>0x811e,
    "\x8f\xf5\xc2"=>0x43f0,
    "\x8f\xf5\xc3"=>0x8124,
    "\x8f\xf5\xc4"=>0x8127,
    "\x8f\xf5\xc5"=>0x812c,
    "\x8f\xf5\xc6"=>0x2671d,
    "\x8f\xf5\xc7"=>0x813d,
    "\x8f\xf5\xc8"=>0x4408,
    "\x8f\xf5\xc9"=>0x8169,
    "\x8f\xf5\xca"=>0x4417,
    "\x8f\xf5\xcb"=>0x8181,
    "\x8f\xf5\xcc"=>0x441c,
    "\x8f\xf5\xcd"=>0x8184,
    "\x8f\xf5\xce"=>0x8185,
    "\x8f\xf5\xcf"=>0x4422,
    "\x8f\xf5\xd0"=>0x8198,
    "\x8f\xf5\xd1"=>0x81b2,
    "\x8f\xf5\xd2"=>0x81c1,
    "\x8f\xf5\xd3"=>0x81c3,
    "\x8f\xf5\xd4"=>0x81d6,
    "\x8f\xf5\xd5"=>0x81db,
    "\x8f\xf5\xd6"=>0x268dd,
    "\x8f\xf5\xd7"=>0x81e4,
    "\x8f\xf5\xd8"=>0x268ea,
    "\x8f\xf5\xd9"=>0x81ec,
    "\x8f\xf5\xda"=>0x26951,
    "\x8f\xf5\xdb"=>0x81fd,
    "\x8f\xf5\xdc"=>0x81ff,
    "\x8f\xf5\xdd"=>0x2696f,
    "\x8f\xf5\xde"=>0x8204,
    "\x8f\xf5\xdf"=>0x269dd,
    "\x8f\xf5\xe0"=>0x8219,
    "\x8f\xf5\xe1"=>0x8221,
    "\x8f\xf5\xe2"=>0x8222,
    "\x8f\xf5\xe3"=>0x26a1e,
    "\x8f\xf5\xe4"=>0x8232,
    "\x8f\xf5\xe5"=>0x8234,
    "\x8f\xf5\xe6"=>0x823c,
    "\x8f\xf5\xe7"=>0x8246,
    "\x8f\xf5\xe8"=>0x8249,
    "\x8f\xf5\xe9"=>0x8245,
    "\x8f\xf5\xea"=>0x26a58,
    "\x8f\xf5\xeb"=>0x824b,
    "\x8f\xf5\xec"=>0x4476,
    "\x8f\xf5\xed"=>0x824f,
    "\x8f\xf5\xee"=>0x447a,
    "\x8f\xf5\xef"=>0x8257,
    "\x8f\xf5\xf0"=>0x26a8c,
    "\x8f\xf5\xf1"=>0x825c,
    "\x8f\xf5\xf2"=>0x8263,
    "\x8f\xf5\xf3"=>0x26ab7,
    "\x8f\xf5\xf4"=>0xfa5d,
    "\x8f\xf5\xf5"=>0xfa5e,
    "\x8f\xf5\xf6"=>0x8279,
    "\x8f\xf5\xf7"=>0x4491,
    "\x8f\xf5\xf8"=>0x827d,
    "\x8f\xf5\xf9"=>0x827f,
    "\x8f\xf5\xfa"=>0x8283,
    "\x8f\xf5\xfb"=>0x828a,
    "\x8f\xf5\xfc"=>0x8293,
    "\x8f\xf5\xfd"=>0x82a7,
    "\x8f\xf5\xfe"=>0x82a8,
    "\x8f\xf6\xa1"=>0x82b2,
    "\x8f\xf6\xa2"=>0x82b4,
    "\x8f\xf6\xa3"=>0x82ba,
    "\x8f\xf6\xa4"=>0x82bc,
    "\x8f\xf6\xa5"=>0x82e2,
    "\x8f\xf6\xa6"=>0x82e8,
    "\x8f\xf6\xa7"=>0x82f7,
    "\x8f\xf6\xa8"=>0x8307,
    "\x8f\xf6\xa9"=>0x8308,
    "\x8f\xf6\xaa"=>0x830c,
    "\x8f\xf6\xab"=>0x8354,
    "\x8f\xf6\xac"=>0x831b,
    "\x8f\xf6\xad"=>0x831d,
    "\x8f\xf6\xae"=>0x8330,
    "\x8f\xf6\xaf"=>0x833c,
    "\x8f\xf6\xb0"=>0x8344,
    "\x8f\xf6\xb1"=>0x8357,
    "\x8f\xf6\xb2"=>0x44be,
    "\x8f\xf6\xb3"=>0x837f,
    "\x8f\xf6\xb4"=>0x44d4,
    "\x8f\xf6\xb5"=>0x44b3,
    "\x8f\xf6\xb6"=>0x838d,
    "\x8f\xf6\xb7"=>0x8394,
    "\x8f\xf6\xb8"=>0x8395,
    "\x8f\xf6\xb9"=>0x839b,
    "\x8f\xf6\xba"=>0x839d,
    "\x8f\xf6\xbb"=>0x83c9,
    "\x8f\xf6\xbc"=>0x83d0,
    "\x8f\xf6\xbd"=>0x83d4,
    "\x8f\xf6\xbe"=>0x83dd,
    "\x8f\xf6\xbf"=>0x83e5,
    "\x8f\xf6\xc0"=>0x83f9,
    "\x8f\xf6\xc1"=>0x840f,
    "\x8f\xf6\xc2"=>0x8411,
    "\x8f\xf6\xc3"=>0x8415,
    "\x8f\xf6\xc4"=>0x26c73,
    "\x8f\xf6\xc5"=>0x8417,
    "\x8f\xf6\xc6"=>0x8439,
    "\x8f\xf6\xc7"=>0x844a,
    "\x8f\xf6\xc8"=>0x844f,
    "\x8f\xf6\xc9"=>0x8451,
    "\x8f\xf6\xca"=>0x8452,
    "\x8f\xf6\xcb"=>0x8459,
    "\x8f\xf6\xcc"=>0x845a,
    "\x8f\xf6\xcd"=>0x845c,
    "\x8f\xf6\xce"=>0x26cdd,
    "\x8f\xf6\xcf"=>0x8465,
    "\x8f\xf6\xd0"=>0x8476,
    "\x8f\xf6\xd1"=>0x8478,
    "\x8f\xf6\xd2"=>0x847c,
    "\x8f\xf6\xd3"=>0x8481,
    "\x8f\xf6\xd4"=>0x450d,
    "\x8f\xf6\xd5"=>0x84dc,
    "\x8f\xf6\xd6"=>0x8497,
    "\x8f\xf6\xd7"=>0x84a6,
    "\x8f\xf6\xd8"=>0x84be,
    "\x8f\xf6\xd9"=>0x4508,
    "\x8f\xf6\xda"=>0x84ce,
    "\x8f\xf6\xdb"=>0x84cf,
    "\x8f\xf6\xdc"=>0x84d3,
    "\x8f\xf6\xdd"=>0x26e65,
    "\x8f\xf6\xde"=>0x84e7,
    "\x8f\xf6\xdf"=>0x84ea,
    "\x8f\xf6\xe0"=>0x84ef,
    "\x8f\xf6\xe1"=>0x84f0,
    "\x8f\xf6\xe2"=>0x84f1,
    "\x8f\xf6\xe3"=>0x84fa,
    "\x8f\xf6\xe4"=>0x84fd,
    "\x8f\xf6\xe5"=>0x850c,
    "\x8f\xf6\xe6"=>0x851b,
    "\x8f\xf6\xe7"=>0x8524,
    "\x8f\xf6\xe8"=>0x8525,
    "\x8f\xf6\xe9"=>0x852b,
    "\x8f\xf6\xea"=>0x8534,
    "\x8f\xf6\xeb"=>0x854f,
    "\x8f\xf6\xec"=>0x856f,
    "\x8f\xf6\xed"=>0x4525,
    "\x8f\xf6\xee"=>0x4543,
    "\x8f\xf6\xef"=>0x853e,
    "\x8f\xf6\xf0"=>0x8551,
    "\x8f\xf6\xf1"=>0x8553,
    "\x8f\xf6\xf2"=>0x855e,
    "\x8f\xf6\xf3"=>0x8561,
    "\x8f\xf6\xf4"=>0x8562,
    "\x8f\xf6\xf5"=>0x26f94,
    "\x8f\xf6\xf6"=>0x857b,
    "\x8f\xf6\xf7"=>0x857d,
    "\x8f\xf6\xf8"=>0x857f,
    "\x8f\xf6\xf9"=>0x8581,
    "\x8f\xf6\xfa"=>0x8586,
    "\x8f\xf6\xfb"=>0x8593,
    "\x8f\xf6\xfc"=>0x859d,
    "\x8f\xf6\xfd"=>0x859f,
    "\x8f\xf6\xfe"=>0x26ff8,
    "\x8f\xf7\xa1"=>0x26ff6,
    "\x8f\xf7\xa2"=>0x26ff7,
    "\x8f\xf7\xa3"=>0x85b7,
    "\x8f\xf7\xa4"=>0x85bc,
    "\x8f\xf7\xa5"=>0x85c7,
    "\x8f\xf7\xa6"=>0x85ca,
    "\x8f\xf7\xa7"=>0x85d8,
    "\x8f\xf7\xa8"=>0x85d9,
    "\x8f\xf7\xa9"=>0x85df,
    "\x8f\xf7\xaa"=>0x85e1,
    "\x8f\xf7\xab"=>0x85e6,
    "\x8f\xf7\xac"=>0x85f6,
    "\x8f\xf7\xad"=>0x8600,
    "\x8f\xf7\xae"=>0x8611,
    "\x8f\xf7\xaf"=>0x861e,
    "\x8f\xf7\xb0"=>0x8621,
    "\x8f\xf7\xb1"=>0x8624,
    "\x8f\xf7\xb2"=>0x8627,
    "\x8f\xf7\xb3"=>0x2710d,
    "\x8f\xf7\xb4"=>0x8639,
    "\x8f\xf7\xb5"=>0x863c,
    "\x8f\xf7\xb6"=>0x27139,
    "\x8f\xf7\xb7"=>0x8640,
    "\x8f\xf7\xb8"=>0xfa20,
    "\x8f\xf7\xb9"=>0x8653,
    "\x8f\xf7\xba"=>0x8656,
    "\x8f\xf7\xbb"=>0x866f,
    "\x8f\xf7\xbc"=>0x8677,
    "\x8f\xf7\xbd"=>0x867a,
    "\x8f\xf7\xbe"=>0x8687,
    "\x8f\xf7\xbf"=>0x8689,
    "\x8f\xf7\xc0"=>0x868d,
    "\x8f\xf7\xc1"=>0x8691,
    "\x8f\xf7\xc2"=>0x869c,
    "\x8f\xf7\xc3"=>0x869d,
    "\x8f\xf7\xc4"=>0x86a8,
    "\x8f\xf7\xc5"=>0xfa21,
    "\x8f\xf7\xc6"=>0x86b1,
    "\x8f\xf7\xc7"=>0x86b3,
    "\x8f\xf7\xc8"=>0x86c1,
    "\x8f\xf7\xc9"=>0x86c3,
    "\x8f\xf7\xca"=>0x86d1,
    "\x8f\xf7\xcb"=>0x86d5,
    "\x8f\xf7\xcc"=>0x86d7,
    "\x8f\xf7\xcd"=>0x86e3,
    "\x8f\xf7\xce"=>0x86e6,
    "\x8f\xf7\xcf"=>0x45b8,
    "\x8f\xf7\xd0"=>0x8705,
    "\x8f\xf7\xd1"=>0x8707,
    "\x8f\xf7\xd2"=>0x870e,
    "\x8f\xf7\xd3"=>0x8710,
    "\x8f\xf7\xd4"=>0x8713,
    "\x8f\xf7\xd5"=>0x8719,
    "\x8f\xf7\xd6"=>0x871f,
    "\x8f\xf7\xd7"=>0x8721,
    "\x8f\xf7\xd8"=>0x8723,
    "\x8f\xf7\xd9"=>0x8731,
    "\x8f\xf7\xda"=>0x873a,
    "\x8f\xf7\xdb"=>0x873e,
    "\x8f\xf7\xdc"=>0x8740,
    "\x8f\xf7\xdd"=>0x8743,
    "\x8f\xf7\xde"=>0x8751,
    "\x8f\xf7\xdf"=>0x8758,
    "\x8f\xf7\xe0"=>0x8764,
    "\x8f\xf7\xe1"=>0x8765,
    "\x8f\xf7\xe2"=>0x8772,
    "\x8f\xf7\xe3"=>0x877c,
    "\x8f\xf7\xe4"=>0x273db,
    "\x8f\xf7\xe5"=>0x273da,
    "\x8f\xf7\xe6"=>0x87a7,
    "\x8f\xf7\xe7"=>0x8789,
    "\x8f\xf7\xe8"=>0x878b,
    "\x8f\xf7\xe9"=>0x8793,
    "\x8f\xf7\xea"=>0x87a0,
    "\x8f\xf7\xeb"=>0x273fe,
    "\x8f\xf7\xec"=>0x45e5,
    "\x8f\xf7\xed"=>0x87be,
    "\x8f\xf7\xee"=>0x27410,
    "\x8f\xf7\xef"=>0x87c1,
    "\x8f\xf7\xf0"=>0x87ce,
    "\x8f\xf7\xf1"=>0x87f5,
    "\x8f\xf7\xf2"=>0x87df,
    "\x8f\xf7\xf3"=>0x27449,
    "\x8f\xf7\xf4"=>0x87e3,
    "\x8f\xf7\xf5"=>0x87e5,
    "\x8f\xf7\xf6"=>0x87e6,
    "\x8f\xf7\xf7"=>0x87ea,
    "\x8f\xf7\xf8"=>0x87eb,
    "\x8f\xf7\xf9"=>0x87ed,
    "\x8f\xf7\xfa"=>0x8801,
    "\x8f\xf7\xfb"=>0x8803,
    "\x8f\xf7\xfc"=>0x880b,
    "\x8f\xf7\xfd"=>0x8813,
    "\x8f\xf7\xfe"=>0x8828,
    "\x8f\xf8\xa1"=>0x882e,
    "\x8f\xf8\xa2"=>0x8832,
    "\x8f\xf8\xa3"=>0x883c,
    "\x8f\xf8\xa4"=>0x460f,
    "\x8f\xf8\xa5"=>0x884a,
    "\x8f\xf8\xa6"=>0x8858,
    "\x8f\xf8\xa7"=>0x885f,
    "\x8f\xf8\xa8"=>0x8864,
    "\x8f\xf8\xa9"=>0x27615,
    "\x8f\xf8\xaa"=>0x27614,
    "\x8f\xf8\xab"=>0x8869,
    "\x8f\xf8\xac"=>0x27631,
    "\x8f\xf8\xad"=>0x886f,
    "\x8f\xf8\xae"=>0x88a0,
    "\x8f\xf8\xaf"=>0x88bc,
    "\x8f\xf8\xb0"=>0x88bd,
    "\x8f\xf8\xb1"=>0x88be,
    "\x8f\xf8\xb2"=>0x88c0,
    "\x8f\xf8\xb3"=>0x88d2,
    "\x8f\xf8\xb4"=>0x27693,
    "\x8f\xf8\xb5"=>0x88d1,
    "\x8f\xf8\xb6"=>0x88d3,
    "\x8f\xf8\xb7"=>0x88db,
    "\x8f\xf8\xb8"=>0x88f0,
    "\x8f\xf8\xb9"=>0x88f1,
    "\x8f\xf8\xba"=>0x4641,
    "\x8f\xf8\xbb"=>0x8901,
    "\x8f\xf8\xbc"=>0x2770e,
    "\x8f\xf8\xbd"=>0x8937,
    "\x8f\xf8\xbe"=>0x27723,
    "\x8f\xf8\xbf"=>0x8942,
    "\x8f\xf8\xc0"=>0x8945,
    "\x8f\xf8\xc1"=>0x8949,
    "\x8f\xf8\xc2"=>0x27752,
    "\x8f\xf8\xc3"=>0x4665,
    "\x8f\xf8\xc4"=>0x8962,
    "\x8f\xf8\xc5"=>0x8980,
    "\x8f\xf8\xc6"=>0x8989,
    "\x8f\xf8\xc7"=>0x8990,
    "\x8f\xf8\xc8"=>0x899f,
    "\x8f\xf8\xc9"=>0x89b0,
    "\x8f\xf8\xca"=>0x89b7,
    "\x8f\xf8\xcb"=>0x89d6,
    "\x8f\xf8\xcc"=>0x89d8,
    "\x8f\xf8\xcd"=>0x89eb,
    "\x8f\xf8\xce"=>0x46a1,
    "\x8f\xf8\xcf"=>0x89f1,
    "\x8f\xf8\xd0"=>0x89f3,
    "\x8f\xf8\xd1"=>0x89fd,
    "\x8f\xf8\xd2"=>0x89ff,
    "\x8f\xf8\xd3"=>0x46af,
    "\x8f\xf8\xd4"=>0x8a11,
    "\x8f\xf8\xd5"=>0x8a14,
    "\x8f\xf8\xd6"=>0x27985,
    "\x8f\xf8\xd7"=>0x8a21,
    "\x8f\xf8\xd8"=>0x8a35,
    "\x8f\xf8\xd9"=>0x8a3e,
    "\x8f\xf8\xda"=>0x8a45,
    "\x8f\xf8\xdb"=>0x8a4d,
    "\x8f\xf8\xdc"=>0x8a58,
    "\x8f\xf8\xdd"=>0x8aae,
    "\x8f\xf8\xde"=>0x8a90,
    "\x8f\xf8\xdf"=>0x8ab7,
    "\x8f\xf8\xe0"=>0x8abe,
    "\x8f\xf8\xe1"=>0x8ad7,
    "\x8f\xf8\xe2"=>0x8afc,
    "\x8f\xf8\xe3"=>0x27a84,
    "\x8f\xf8\xe4"=>0x8b0a,
    "\x8f\xf8\xe5"=>0x8b05,
    "\x8f\xf8\xe6"=>0x8b0d,
    "\x8f\xf8\xe7"=>0x8b1c,
    "\x8f\xf8\xe8"=>0x8b1f,
    "\x8f\xf8\xe9"=>0x8b2d,
    "\x8f\xf8\xea"=>0x8b43,
    "\x8f\xf8\xeb"=>0x470c,
    "\x8f\xf8\xec"=>0x8b51,
    "\x8f\xf8\xed"=>0x8b5e,
    "\x8f\xf8\xee"=>0x8b76,
    "\x8f\xf8\xef"=>0x8b7f,
    "\x8f\xf8\xf0"=>0x8b81,
    "\x8f\xf8\xf1"=>0x8b8b,
    "\x8f\xf8\xf2"=>0x8b94,
    "\x8f\xf8\xf3"=>0x8b95,
    "\x8f\xf8\xf4"=>0x8b9c,
    "\x8f\xf8\xf5"=>0x8b9e,
    "\x8f\xf8\xf6"=>0x8c39,
    "\x8f\xf8\xf7"=>0x27bb3,
    "\x8f\xf8\xf8"=>0x8c3d,
    "\x8f\xf8\xf9"=>0x27bbe,
    "\x8f\xf8\xfa"=>0x27bc7,
    "\x8f\xf8\xfb"=>0x8c45,
    "\x8f\xf8\xfc"=>0x8c47,
    "\x8f\xf8\xfd"=>0x8c4f,
    "\x8f\xf8\xfe"=>0x8c54,
    "\x8f\xf9\xa1"=>0x8c57,
    "\x8f\xf9\xa2"=>0x8c69,
    "\x8f\xf9\xa3"=>0x8c6d,
    "\x8f\xf9\xa4"=>0x8c73,
    "\x8f\xf9\xa5"=>0x27cb8,
    "\x8f\xf9\xa6"=>0x8c93,
    "\x8f\xf9\xa7"=>0x8c92,
    "\x8f\xf9\xa8"=>0x8c99,
    "\x8f\xf9\xa9"=>0x4764,
    "\x8f\xf9\xaa"=>0x8c9b,
    "\x8f\xf9\xab"=>0x8ca4,
    "\x8f\xf9\xac"=>0x8cd6,
    "\x8f\xf9\xad"=>0x8cd5,
    "\x8f\xf9\xae"=>0x8cd9,
    "\x8f\xf9\xaf"=>0x27da0,
    "\x8f\xf9\xb0"=>0x8cf0,
    "\x8f\xf9\xb1"=>0x8cf1,
    "\x8f\xf9\xb2"=>0x27e10,
    "\x8f\xf9\xb3"=>0x8d09,
    "\x8f\xf9\xb4"=>0x8d0e,
    "\x8f\xf9\xb5"=>0x8d6c,
    "\x8f\xf9\xb6"=>0x8d84,
    "\x8f\xf9\xb7"=>0x8d95,
    "\x8f\xf9\xb8"=>0x8da6,
    "\x8f\xf9\xb9"=>0x27fb7,
    "\x8f\xf9\xba"=>0x8dc6,
    "\x8f\xf9\xbb"=>0x8dc8,
    "\x8f\xf9\xbc"=>0x8dd9,
    "\x8f\xf9\xbd"=>0x8dec,
    "\x8f\xf9\xbe"=>0x8e0c,
    "\x8f\xf9\xbf"=>0x47fd,
    "\x8f\xf9\xc0"=>0x8dfd,
    "\x8f\xf9\xc1"=>0x8e06,
    "\x8f\xf9\xc2"=>0x2808a,
    "\x8f\xf9\xc3"=>0x8e14,
    "\x8f\xf9\xc4"=>0x8e16,
    "\x8f\xf9\xc5"=>0x8e21,
    "\x8f\xf9\xc6"=>0x8e22,
    "\x8f\xf9\xc7"=>0x8e27,
    "\x8f\xf9\xc8"=>0x280bb,
    "\x8f\xf9\xc9"=>0x4816,
    "\x8f\xf9\xca"=>0x8e36,
    "\x8f\xf9\xcb"=>0x8e39,
    "\x8f\xf9\xcc"=>0x8e4b,
    "\x8f\xf9\xcd"=>0x8e54,
    "\x8f\xf9\xce"=>0x8e62,
    "\x8f\xf9\xcf"=>0x8e6c,
    "\x8f\xf9\xd0"=>0x8e6d,
    "\x8f\xf9\xd1"=>0x8e6f,
    "\x8f\xf9\xd2"=>0x8e98,
    "\x8f\xf9\xd3"=>0x8e9e,
    "\x8f\xf9\xd4"=>0x8eae,
    "\x8f\xf9\xd5"=>0x8eb3,
    "\x8f\xf9\xd6"=>0x8eb5,
    "\x8f\xf9\xd7"=>0x8eb6,
    "\x8f\xf9\xd8"=>0x8ebb,
    "\x8f\xf9\xd9"=>0x28282,
    "\x8f\xf9\xda"=>0x8ed1,
    "\x8f\xf9\xdb"=>0x8ed4,
    "\x8f\xf9\xdc"=>0x484e,
    "\x8f\xf9\xdd"=>0x8ef9,
    "\x8f\xf9\xde"=>0x282f3,
    "\x8f\xf9\xdf"=>0x8f00,
    "\x8f\xf9\xe0"=>0x8f08,
    "\x8f\xf9\xe1"=>0x8f17,
    "\x8f\xf9\xe2"=>0x8f2b,
    "\x8f\xf9\xe3"=>0x8f40,
    "\x8f\xf9\xe4"=>0x8f4a,
    "\x8f\xf9\xe5"=>0x8f58,
    "\x8f\xf9\xe6"=>0x2840c,
    "\x8f\xf9\xe7"=>0x8fa4,
    "\x8f\xf9\xe8"=>0x8fb4,
    "\x8f\xf9\xe9"=>0xfa66,
    "\x8f\xf9\xea"=>0x8fb6,
    "\x8f\xf9\xeb"=>0x28455,
    "\x8f\xf9\xec"=>0x8fc1,
    "\x8f\xf9\xed"=>0x8fc6,
    "\x8f\xf9\xee"=>0xfa24,
    "\x8f\xf9\xef"=>0x8fca,
    "\x8f\xf9\xf0"=>0x8fcd,
    "\x8f\xf9\xf1"=>0x8fd3,
    "\x8f\xf9\xf2"=>0x8fd5,
    "\x8f\xf9\xf3"=>0x8fe0,
    "\x8f\xf9\xf4"=>0x8ff1,
    "\x8f\xf9\xf5"=>0x8ff5,
    "\x8f\xf9\xf6"=>0x8ffb,
    "\x8f\xf9\xf7"=>0x9002,
    "\x8f\xf9\xf8"=>0x900c,
    "\x8f\xf9\xf9"=>0x9037,
    "\x8f\xf9\xfa"=>0x2856b,
    "\x8f\xf9\xfb"=>0x9043,
    "\x8f\xf9\xfc"=>0x9044,
    "\x8f\xf9\xfd"=>0x905d,
    "\x8f\xf9\xfe"=>0x285c8,
    "\x8f\xfa\xa1"=>0x285c9,
    "\x8f\xfa\xa2"=>0x9085,
    "\x8f\xfa\xa3"=>0x908c,
    "\x8f\xfa\xa4"=>0x9090,
    "\x8f\xfa\xa5"=>0x961d,
    "\x8f\xfa\xa6"=>0x90a1,
    "\x8f\xfa\xa7"=>0x48b5,
    "\x8f\xfa\xa8"=>0x90b0,
    "\x8f\xfa\xa9"=>0x90b6,
    "\x8f\xfa\xaa"=>0x90c3,
    "\x8f\xfa\xab"=>0x90c8,
    "\x8f\xfa\xac"=>0x286d7,
    "\x8f\xfa\xad"=>0x90dc,
    "\x8f\xfa\xae"=>0x90df,
    "\x8f\xfa\xaf"=>0x286fa,
    "\x8f\xfa\xb0"=>0x90f6,
    "\x8f\xfa\xb1"=>0x90f2,
    "\x8f\xfa\xb2"=>0x9100,
    "\x8f\xfa\xb3"=>0x90eb,
    "\x8f\xfa\xb4"=>0x90fe,
    "\x8f\xfa\xb5"=>0x90ff,
    "\x8f\xfa\xb6"=>0x9104,
    "\x8f\xfa\xb7"=>0x9106,
    "\x8f\xfa\xb8"=>0x9118,
    "\x8f\xfa\xb9"=>0x911c,
    "\x8f\xfa\xba"=>0x911e,
    "\x8f\xfa\xbb"=>0x9137,
    "\x8f\xfa\xbc"=>0x9139,
    "\x8f\xfa\xbd"=>0x913a,
    "\x8f\xfa\xbe"=>0x9146,
    "\x8f\xfa\xbf"=>0x9147,
    "\x8f\xfa\xc0"=>0x9157,
    "\x8f\xfa\xc1"=>0x9159,
    "\x8f\xfa\xc2"=>0x9161,
    "\x8f\xfa\xc3"=>0x9164,
    "\x8f\xfa\xc4"=>0x9174,
    "\x8f\xfa\xc5"=>0x9179,
    "\x8f\xfa\xc6"=>0x9185,
    "\x8f\xfa\xc7"=>0x918e,
    "\x8f\xfa\xc8"=>0x91a8,
    "\x8f\xfa\xc9"=>0x91ae,
    "\x8f\xfa\xca"=>0x91b3,
    "\x8f\xfa\xcb"=>0x91b6,
    "\x8f\xfa\xcc"=>0x91c3,
    "\x8f\xfa\xcd"=>0x91c4,
    "\x8f\xfa\xce"=>0x91da,
    "\x8f\xfa\xcf"=>0x28949,
    "\x8f\xfa\xd0"=>0x28946,
    "\x8f\xfa\xd1"=>0x91ec,
    "\x8f\xfa\xd2"=>0x91ee,
    "\x8f\xfa\xd3"=>0x9201,
    "\x8f\xfa\xd4"=>0x920a,
    "\x8f\xfa\xd5"=>0x9216,
    "\x8f\xfa\xd6"=>0x9217,
    "\x8f\xfa\xd7"=>0x2896b,
    "\x8f\xfa\xd8"=>0x9233,
    "\x8f\xfa\xd9"=>0x9242,
    "\x8f\xfa\xda"=>0x9247,
    "\x8f\xfa\xdb"=>0x924a,
    "\x8f\xfa\xdc"=>0x924e,
    "\x8f\xfa\xdd"=>0x9251,
    "\x8f\xfa\xde"=>0x9256,
    "\x8f\xfa\xdf"=>0x9259,
    "\x8f\xfa\xe0"=>0x9260,
    "\x8f\xfa\xe1"=>0x9261,
    "\x8f\xfa\xe2"=>0x9265,
    "\x8f\xfa\xe3"=>0x9267,
    "\x8f\xfa\xe4"=>0x9268,
    "\x8f\xfa\xe5"=>0x28987,
    "\x8f\xfa\xe6"=>0x28988,
    "\x8f\xfa\xe7"=>0x927c,
    "\x8f\xfa\xe8"=>0x927d,
    "\x8f\xfa\xe9"=>0x927f,
    "\x8f\xfa\xea"=>0x9289,
    "\x8f\xfa\xeb"=>0x928d,
    "\x8f\xfa\xec"=>0x9297,
    "\x8f\xfa\xed"=>0x9299,
    "\x8f\xfa\xee"=>0x929f,
    "\x8f\xfa\xef"=>0x92a7,
    "\x8f\xfa\xf0"=>0x92ab,
    "\x8f\xfa\xf1"=>0x289ba,
    "\x8f\xfa\xf2"=>0x289bb,
    "\x8f\xfa\xf3"=>0x92b2,
    "\x8f\xfa\xf4"=>0x92bf,
    "\x8f\xfa\xf5"=>0x92c0,
    "\x8f\xfa\xf6"=>0x92c6,
    "\x8f\xfa\xf7"=>0x92ce,
    "\x8f\xfa\xf8"=>0x92d0,
    "\x8f\xfa\xf9"=>0x92d7,
    "\x8f\xfa\xfa"=>0x92d9,
    "\x8f\xfa\xfb"=>0x92e5,
    "\x8f\xfa\xfc"=>0x92e7,
    "\x8f\xfa\xfd"=>0x9311,
    "\x8f\xfa\xfe"=>0x28a1e,
    "\x8f\xfb\xa1"=>0x28a29,
    "\x8f\xfb\xa2"=>0x92f7,
    "\x8f\xfb\xa3"=>0x92f9,
    "\x8f\xfb\xa4"=>0x92fb,
    "\x8f\xfb\xa5"=>0x9302,
    "\x8f\xfb\xa6"=>0x930d,
    "\x8f\xfb\xa7"=>0x9315,
    "\x8f\xfb\xa8"=>0x931d,
    "\x8f\xfb\xa9"=>0x931e,
    "\x8f\xfb\xaa"=>0x9327,
    "\x8f\xfb\xab"=>0x9329,
    "\x8f\xfb\xac"=>0x28a71,
    "\x8f\xfb\xad"=>0x28a43,
    "\x8f\xfb\xae"=>0x9347,
    "\x8f\xfb\xaf"=>0x9351,
    "\x8f\xfb\xb0"=>0x9357,
    "\x8f\xfb\xb1"=>0x935a,
    "\x8f\xfb\xb2"=>0x936b,
    "\x8f\xfb\xb3"=>0x9371,
    "\x8f\xfb\xb4"=>0x9373,
    "\x8f\xfb\xb5"=>0x93a1,
    "\x8f\xfb\xb6"=>0x28a99,
    "\x8f\xfb\xb7"=>0x28acd,
    "\x8f\xfb\xb8"=>0x9388,
    "\x8f\xfb\xb9"=>0x938b,
    "\x8f\xfb\xba"=>0x938f,
    "\x8f\xfb\xbb"=>0x939e,
    "\x8f\xfb\xbc"=>0x93f5,
    "\x8f\xfb\xbd"=>0x28ae4,
    "\x8f\xfb\xbe"=>0x28add,
    "\x8f\xfb\xbf"=>0x93f1,
    "\x8f\xfb\xc0"=>0x93c1,
    "\x8f\xfb\xc1"=>0x93c7,
    "\x8f\xfb\xc2"=>0x93dc,
    "\x8f\xfb\xc3"=>0x93e2,
    "\x8f\xfb\xc4"=>0x93e7,
    "\x8f\xfb\xc5"=>0x9409,
    "\x8f\xfb\xc6"=>0x940f,
    "\x8f\xfb\xc7"=>0x9416,
    "\x8f\xfb\xc8"=>0x9417,
    "\x8f\xfb\xc9"=>0x93fb,
    "\x8f\xfb\xca"=>0x9432,
    "\x8f\xfb\xcb"=>0x9434,
    "\x8f\xfb\xcc"=>0x943b,
    "\x8f\xfb\xcd"=>0x9445,
    "\x8f\xfb\xce"=>0x28bc1,
    "\x8f\xfb\xcf"=>0x28bef,
    "\x8f\xfb\xd0"=>0x946d,
    "\x8f\xfb\xd1"=>0x946f,
    "\x8f\xfb\xd2"=>0x9578,
    "\x8f\xfb\xd3"=>0x9579,
    "\x8f\xfb\xd4"=>0x9586,
    "\x8f\xfb\xd5"=>0x958c,
    "\x8f\xfb\xd6"=>0x958d,
    "\x8f\xfb\xd7"=>0x28d10,
    "\x8f\xfb\xd8"=>0x95ab,
    "\x8f\xfb\xd9"=>0x95b4,
    "\x8f\xfb\xda"=>0x28d71,
    "\x8f\xfb\xdb"=>0x95c8,
    "\x8f\xfb\xdc"=>0x28dfb,
    "\x8f\xfb\xdd"=>0x28e1f,
    "\x8f\xfb\xde"=>0x962c,
    "\x8f\xfb\xdf"=>0x9633,
    "\x8f\xfb\xe0"=>0x9634,
    "\x8f\xfb\xe1"=>0x28e36,
    "\x8f\xfb\xe2"=>0x963c,
    "\x8f\xfb\xe3"=>0x9641,
    "\x8f\xfb\xe4"=>0x9661,
    "\x8f\xfb\xe5"=>0x28e89,
    "\x8f\xfb\xe6"=>0x9682,
    "\x8f\xfb\xe7"=>0x28eeb,
    "\x8f\xfb\xe8"=>0x969a,
    "\x8f\xfb\xe9"=>0x28f32,
    "\x8f\xfb\xea"=>0x49e7,
    "\x8f\xfb\xeb"=>0x96a9,
    "\x8f\xfb\xec"=>0x96af,
    "\x8f\xfb\xed"=>0x96b3,
    "\x8f\xfb\xee"=>0x96ba,
    "\x8f\xfb\xef"=>0x96bd,
    "\x8f\xfb\xf0"=>0x49fa,
    "\x8f\xfb\xf1"=>0x28ff8,
    "\x8f\xfb\xf2"=>0x96d8,
    "\x8f\xfb\xf3"=>0x96da,
    "\x8f\xfb\xf4"=>0x96dd,
    "\x8f\xfb\xf5"=>0x4a04,
    "\x8f\xfb\xf6"=>0x9714,
    "\x8f\xfb\xf7"=>0x9723,
    "\x8f\xfb\xf8"=>0x4a29,
    "\x8f\xfb\xf9"=>0x9736,
    "\x8f\xfb\xfa"=>0x9741,
    "\x8f\xfb\xfb"=>0x9747,
    "\x8f\xfb\xfc"=>0x9755,
    "\x8f\xfb\xfd"=>0x9757,
    "\x8f\xfb\xfe"=>0x975b,
    "\x8f\xfc\xa1"=>0x976a,
    "\x8f\xfc\xa2"=>0x292a0,
    "\x8f\xfc\xa3"=>0x292b1,
    "\x8f\xfc\xa4"=>0x9796,
    "\x8f\xfc\xa5"=>0x979a,
    "\x8f\xfc\xa6"=>0x979e,
    "\x8f\xfc\xa7"=>0x97a2,
    "\x8f\xfc\xa8"=>0x97b1,
    "\x8f\xfc\xa9"=>0x97b2,
    "\x8f\xfc\xaa"=>0x97be,
    "\x8f\xfc\xab"=>0x97cc,
    "\x8f\xfc\xac"=>0x97d1,
    "\x8f\xfc\xad"=>0x97d4,
    "\x8f\xfc\xae"=>0x97d8,
    "\x8f\xfc\xaf"=>0x97d9,
    "\x8f\xfc\xb0"=>0x97e1,
    "\x8f\xfc\xb1"=>0x97f1,
    "\x8f\xfc\xb2"=>0x9804,
    "\x8f\xfc\xb3"=>0x980d,
    "\x8f\xfc\xb4"=>0x980e,
    "\x8f\xfc\xb5"=>0x9814,
    "\x8f\xfc\xb6"=>0x9816,
    "\x8f\xfc\xb7"=>0x4abc,
    "\x8f\xfc\xb8"=>0x29490,
    "\x8f\xfc\xb9"=>0x9823,
    "\x8f\xfc\xba"=>0x9832,
    "\x8f\xfc\xbb"=>0x9833,
    "\x8f\xfc\xbc"=>0x9825,
    "\x8f\xfc\xbd"=>0x9847,
    "\x8f\xfc\xbe"=>0x9866,
    "\x8f\xfc\xbf"=>0x98ab,
    "\x8f\xfc\xc0"=>0x98ad,
    "\x8f\xfc\xc1"=>0x98b0,
    "\x8f\xfc\xc2"=>0x295cf,
    "\x8f\xfc\xc3"=>0x98b7,
    "\x8f\xfc\xc4"=>0x98b8,
    "\x8f\xfc\xc5"=>0x98bb,
    "\x8f\xfc\xc6"=>0x98bc,
    "\x8f\xfc\xc7"=>0x98bf,
    "\x8f\xfc\xc8"=>0x98c2,
    "\x8f\xfc\xc9"=>0x98c7,
    "\x8f\xfc\xca"=>0x98cb,
    "\x8f\xfc\xcb"=>0x98e0,
    "\x8f\xfc\xcc"=>0x2967f,
    "\x8f\xfc\xcd"=>0x98e1,
    "\x8f\xfc\xce"=>0x98e3,
    "\x8f\xfc\xcf"=>0x98e5,
    "\x8f\xfc\xd0"=>0x98ea,
    "\x8f\xfc\xd1"=>0x98f0,
    "\x8f\xfc\xd2"=>0x98f1,
    "\x8f\xfc\xd3"=>0x98f3,
    "\x8f\xfc\xd4"=>0x9908,
    "\x8f\xfc\xd5"=>0x4b3b,
    "\x8f\xfc\xd6"=>0x296f0,
    "\x8f\xfc\xd7"=>0x9916,
    "\x8f\xfc\xd8"=>0x9917,
    "\x8f\xfc\xd9"=>0x29719,
    "\x8f\xfc\xda"=>0x991a,
    "\x8f\xfc\xdb"=>0x991b,
    "\x8f\xfc\xdc"=>0x991c,
    "\x8f\xfc\xdd"=>0x29750,
    "\x8f\xfc\xde"=>0x9931,
    "\x8f\xfc\xdf"=>0x9932,
    "\x8f\xfc\xe0"=>0x9933,
    "\x8f\xfc\xe1"=>0x993a,
    "\x8f\xfc\xe2"=>0x993b,
    "\x8f\xfc\xe3"=>0x993c,
    "\x8f\xfc\xe4"=>0x9940,
    "\x8f\xfc\xe5"=>0x9941,
    "\x8f\xfc\xe6"=>0x9946,
    "\x8f\xfc\xe7"=>0x994d,
    "\x8f\xfc\xe8"=>0x994e,
    "\x8f\xfc\xe9"=>0x995c,
    "\x8f\xfc\xea"=>0x995f,
    "\x8f\xfc\xeb"=>0x9960,
    "\x8f\xfc\xec"=>0x99a3,
    "\x8f\xfc\xed"=>0x99a6,
    "\x8f\xfc\xee"=>0x99b9,
    "\x8f\xfc\xef"=>0x99bd,
    "\x8f\xfc\xf0"=>0x99bf,
    "\x8f\xfc\xf1"=>0x99c3,
    "\x8f\xfc\xf2"=>0x99c9,
    "\x8f\xfc\xf3"=>0x99d4,
    "\x8f\xfc\xf4"=>0x99d9,
    "\x8f\xfc\xf5"=>0x99de,
    "\x8f\xfc\xf6"=>0x298c6,
    "\x8f\xfc\xf7"=>0x99f0,
    "\x8f\xfc\xf8"=>0x99f9,
    "\x8f\xfc\xf9"=>0x99fc,
    "\x8f\xfc\xfa"=>0x9a0a,
    "\x8f\xfc\xfb"=>0x9a11,
    "\x8f\xfc\xfc"=>0x9a16,
    "\x8f\xfc\xfd"=>0x9a1a,
    "\x8f\xfc\xfe"=>0x9a20,
    "\x8f\xfd\xa1"=>0x9a31,
    "\x8f\xfd\xa2"=>0x9a36,
    "\x8f\xfd\xa3"=>0x9a44,
    "\x8f\xfd\xa4"=>0x9a4c,
    "\x8f\xfd\xa5"=>0x9a58,
    "\x8f\xfd\xa6"=>0x4bc2,
    "\x8f\xfd\xa7"=>0x9aaf,
    "\x8f\xfd\xa8"=>0x4bca,
    "\x8f\xfd\xa9"=>0x9ab7,
    "\x8f\xfd\xaa"=>0x4bd2,
    "\x8f\xfd\xab"=>0x9ab9,
    "\x8f\xfd\xac"=>0x29a72,
    "\x8f\xfd\xad"=>0x9ac6,
    "\x8f\xfd\xae"=>0x9ad0,
    "\x8f\xfd\xaf"=>0x9ad2,
    "\x8f\xfd\xb0"=>0x9ad5,
    "\x8f\xfd\xb1"=>0x4be8,
    "\x8f\xfd\xb2"=>0x9adc,
    "\x8f\xfd\xb3"=>0x9ae0,
    "\x8f\xfd\xb4"=>0x9ae5,
    "\x8f\xfd\xb5"=>0x9ae9,
    "\x8f\xfd\xb6"=>0x9b03,
    "\x8f\xfd\xb7"=>0x9b0c,
    "\x8f\xfd\xb8"=>0x9b10,
    "\x8f\xfd\xb9"=>0x9b12,
    "\x8f\xfd\xba"=>0x9b16,
    "\x8f\xfd\xbb"=>0x9b1c,
    "\x8f\xfd\xbc"=>0x9b2b,
    "\x8f\xfd\xbd"=>0x9b33,
    "\x8f\xfd\xbe"=>0x9b3d,
    "\x8f\xfd\xbf"=>0x4c20,
    "\x8f\xfd\xc0"=>0x9b4b,
    "\x8f\xfd\xc1"=>0x9b63,
    "\x8f\xfd\xc2"=>0x9b65,
    "\x8f\xfd\xc3"=>0x9b6b,
    "\x8f\xfd\xc4"=>0x9b6c,
    "\x8f\xfd\xc5"=>0x9b73,
    "\x8f\xfd\xc6"=>0x9b76,
    "\x8f\xfd\xc7"=>0x9b77,
    "\x8f\xfd\xc8"=>0x9ba6,
    "\x8f\xfd\xc9"=>0x9bac,
    "\x8f\xfd\xca"=>0x9bb1,
    "\x8f\xfd\xcb"=>0x29ddb,
    "\x8f\xfd\xcc"=>0x29e3d,
    "\x8f\xfd\xcd"=>0x9bb2,
    "\x8f\xfd\xce"=>0x9bb8,
    "\x8f\xfd\xcf"=>0x9bbe,
    "\x8f\xfd\xd0"=>0x9bc7,
    "\x8f\xfd\xd1"=>0x9bf3,
    "\x8f\xfd\xd2"=>0x9bd8,
    "\x8f\xfd\xd3"=>0x9bdd,
    "\x8f\xfd\xd4"=>0x9be7,
    "\x8f\xfd\xd5"=>0x9bea,
    "\x8f\xfd\xd6"=>0x9beb,
    "\x8f\xfd\xd7"=>0x9bef,
    "\x8f\xfd\xd8"=>0x9bee,
    "\x8f\xfd\xd9"=>0x29e15,
    "\x8f\xfd\xda"=>0x9bfa,
    "\x8f\xfd\xdb"=>0x29e8a,
    "\x8f\xfd\xdc"=>0x9bf7,
    "\x8f\xfd\xdd"=>0x29e49,
    "\x8f\xfd\xde"=>0x9c16,
    "\x8f\xfd\xdf"=>0x9c18,
    "\x8f\xfd\xe0"=>0x9c19,
    "\x8f\xfd\xe1"=>0x9c1a,
    "\x8f\xfd\xe2"=>0x9c1d,
    "\x8f\xfd\xe3"=>0x9c22,
    "\x8f\xfd\xe4"=>0x9c27,
    "\x8f\xfd\xe5"=>0x9c29,
    "\x8f\xfd\xe6"=>0x9c2a,
    "\x8f\xfd\xe7"=>0x29ec4,
    "\x8f\xfd\xe8"=>0x9c31,
    "\x8f\xfd\xe9"=>0x9c36,
    "\x8f\xfd\xea"=>0x9c37,
    "\x8f\xfd\xeb"=>0x9c45,
    "\x8f\xfd\xec"=>0x9c5c,
    "\x8f\xfd\xed"=>0x29ee9,
    "\x8f\xfd\xee"=>0x9c49,
    "\x8f\xfd\xef"=>0x9c4a,
    "\x8f\xfd\xf0"=>0x29edb,
    "\x8f\xfd\xf1"=>0x9c54,
    "\x8f\xfd\xf2"=>0x9c58,
    "\x8f\xfd\xf3"=>0x9c5b,
    "\x8f\xfd\xf4"=>0x9c5d,
    "\x8f\xfd\xf5"=>0x9c5f,
    "\x8f\xfd\xf6"=>0x9c69,
    "\x8f\xfd\xf7"=>0x9c6a,
    "\x8f\xfd\xf8"=>0x9c6b,
    "\x8f\xfd\xf9"=>0x9c6d,
    "\x8f\xfd\xfa"=>0x9c6e,
    "\x8f\xfd\xfb"=>0x9c70,
    "\x8f\xfd\xfc"=>0x9c72,
    "\x8f\xfd\xfd"=>0x9c75,
    "\x8f\xfd\xfe"=>0x9c7a,
    "\x8f\xfe\xa1"=>0x9ce6,
    "\x8f\xfe\xa2"=>0x9cf2,
    "\x8f\xfe\xa3"=>0x9d0b,
    "\x8f\xfe\xa4"=>0x9d02,
    "\x8f\xfe\xa5"=>0x29fce,
    "\x8f\xfe\xa6"=>0x9d11,
    "\x8f\xfe\xa7"=>0x9d17,
    "\x8f\xfe\xa8"=>0x9d18,
    "\x8f\xfe\xa9"=>0x2a02f,
    "\x8f\xfe\xaa"=>0x4cc4,
    "\x8f\xfe\xab"=>0x2a01a,
    "\x8f\xfe\xac"=>0x9d32,
    "\x8f\xfe\xad"=>0x4cd1,
    "\x8f\xfe\xae"=>0x9d42,
    "\x8f\xfe\xaf"=>0x9d4a,
    "\x8f\xfe\xb0"=>0x9d5f,
    "\x8f\xfe\xb1"=>0x9d62,
    "\x8f\xfe\xb2"=>0x2a0f9,
    "\x8f\xfe\xb3"=>0x9d69,
    "\x8f\xfe\xb4"=>0x9d6b,
    "\x8f\xfe\xb5"=>0x2a082,
    "\x8f\xfe\xb6"=>0x9d73,
    "\x8f\xfe\xb7"=>0x9d76,
    "\x8f\xfe\xb8"=>0x9d77,
    "\x8f\xfe\xb9"=>0x9d7e,
    "\x8f\xfe\xba"=>0x9d84,
    "\x8f\xfe\xbb"=>0x9d8d,
    "\x8f\xfe\xbc"=>0x9d99,
    "\x8f\xfe\xbd"=>0x9da1,
    "\x8f\xfe\xbe"=>0x9dbf,
    "\x8f\xfe\xbf"=>0x9db5,
    "\x8f\xfe\xc0"=>0x9db9,
    "\x8f\xfe\xc1"=>0x9dbd,
    "\x8f\xfe\xc2"=>0x9dc3,
    "\x8f\xfe\xc3"=>0x9dc7,
    "\x8f\xfe\xc4"=>0x9dc9,
    "\x8f\xfe\xc5"=>0x9dd6,
    "\x8f\xfe\xc6"=>0x9dda,
    "\x8f\xfe\xc7"=>0x9ddf,
    "\x8f\xfe\xc8"=>0x9de0,
    "\x8f\xfe\xc9"=>0x9de3,
    "\x8f\xfe\xca"=>0x9df4,
    "\x8f\xfe\xcb"=>0x4d07,
    "\x8f\xfe\xcc"=>0x9e0a,
    "\x8f\xfe\xcd"=>0x9e02,
    "\x8f\xfe\xce"=>0x9e0d,
    "\x8f\xfe\xcf"=>0x9e19,
    "\x8f\xfe\xd0"=>0x9e1c,
    "\x8f\xfe\xd1"=>0x9e1d,
    "\x8f\xfe\xd2"=>0x9e7b,
    "\x8f\xfe\xd3"=>0x22218,
    "\x8f\xfe\xd4"=>0x9e80,
    "\x8f\xfe\xd5"=>0x9e85,
    "\x8f\xfe\xd6"=>0x9e9b,
    "\x8f\xfe\xd7"=>0x9ea8,
    "\x8f\xfe\xd8"=>0x2a38c,
    "\x8f\xfe\xd9"=>0x9ebd,
    "\x8f\xfe\xda"=>0x2a437,
    "\x8f\xfe\xdb"=>0x9edf,
    "\x8f\xfe\xdc"=>0x9ee7,
    "\x8f\xfe\xdd"=>0x9eee,
    "\x8f\xfe\xde"=>0x9eff,
    "\x8f\xfe\xdf"=>0x9f02,
    "\x8f\xfe\xe0"=>0x4d77,
    "\x8f\xfe\xe1"=>0x9f03,
    "\x8f\xfe\xe2"=>0x9f17,
    "\x8f\xfe\xe3"=>0x9f19,
    "\x8f\xfe\xe4"=>0x9f2f,
    "\x8f\xfe\xe5"=>0x9f37,
    "\x8f\xfe\xe6"=>0x9f3a,
    "\x8f\xfe\xe7"=>0x9f3d,
    "\x8f\xfe\xe8"=>0x9f41,
    "\x8f\xfe\xe9"=>0x9f45,
    "\x8f\xfe\xea"=>0x9f46,
    "\x8f\xfe\xeb"=>0x9f53,
    "\x8f\xfe\xec"=>0x9f55,
    "\x8f\xfe\xed"=>0x9f58,
    "\x8f\xfe\xee"=>0x2a5f1,
    "\x8f\xfe\xef"=>0x9f5d,
    "\x8f\xfe\xf0"=>0x2a602,
    "\x8f\xfe\xf1"=>0x9f69,
    "\x8f\xfe\xf2"=>0x2a61a,
    "\x8f\xfe\xf3"=>0x9f6d,
    "\x8f\xfe\xf4"=>0x9f70,
    "\x8f\xfe\xf5"=>0x9f75,
    "\x8f\xfe\xf6"=>0x2a6b2,
  }

  UCS_EUCJIS2004_MAP = {
    0x00a0=>"\xa9\xa2",
    0x00a1=>"\xa9\xa3",
    0x00a4=>"\xa9\xa4",
    0x00a6=>"\xa9\xa5",
    0x00a9=>"\xa9\xa6",
    0x00aa=>"\xa9\xa7",
    0x00ab=>"\xa9\xa8",
    0x00ad=>"\xa9\xa9",
    0x00ae=>"\xa9\xaa",
    0x00af=>"\xa9\xab",
    0x00b2=>"\xa9\xac",
    0x00b3=>"\xa9\xad",
    0x00b7=>"\xa9\xae",
    0x00b8=>"\xa9\xaf",
    0x00b9=>"\xa9\xb0",
    0x00ba=>"\xa9\xb1",
    0x00bb=>"\xa9\xb2",
    0x00bc=>"\xa9\xb3",
    0x00bd=>"\xa9\xb4",
    0x00be=>"\xa9\xb5",
    0x00bf=>"\xa9\xb6",
    0x00c0=>"\xa9\xb7",
    0x00c1=>"\xa9\xb8",
    0x00c2=>"\xa9\xb9",
    0x00c3=>"\xa9\xba",
    0x00c4=>"\xa9\xbb",
    0x00c5=>"\xa9\xbc",
    0x00c6=>"\xa9\xbd",
    0x00c7=>"\xa9\xbe",
    0x00c8=>"\xa9\xbf",
    0x00c9=>"\xa9\xc0",
    0x00ca=>"\xa9\xc1",
    0x00cb=>"\xa9\xc2",
    0x00cc=>"\xa9\xc3",
    0x00cd=>"\xa9\xc4",
    0x00ce=>"\xa9\xc5",
    0x00cf=>"\xa9\xc6",
    0x00d0=>"\xa9\xc7",
    0x00d1=>"\xa9\xc8",
    0x00d2=>"\xa9\xc9",
    0x00d3=>"\xa9\xca",
    0x00d4=>"\xa9\xcb",
    0x00d5=>"\xa9\xcc",
    0x00d6=>"\xa9\xcd",
    0x00d8=>"\xa9\xce",
    0x00d9=>"\xa9\xcf",
    0x00da=>"\xa9\xd0",
    0x00db=>"\xa9\xd1",
    0x00dc=>"\xa9\xd2",
    0x00dd=>"\xa9\xd3",
    0x00de=>"\xa9\xd4",
    0x00df=>"\xa9\xd5",
    0x00e0=>"\xa9\xd6",
    0x00e1=>"\xa9\xd7",
    0x00e2=>"\xa9\xd8",
    0x00e3=>"\xa9\xd9",
    0x00e4=>"\xa9\xda",
    0x00e5=>"\xa9\xdb",
    0x00e6=>"\xa9\xdc",
#    0x00e6=>"\xa9\xc4", # U+0300
    0x00e7=>"\xa9\xdd",
    0x00e8=>"\xa9\xde",
    0x00e9=>"\xa9\xdf",
    0x00ea=>"\xa9\xe0",
    0x00eb=>"\xa9\xe1",
    0x00ec=>"\xa9\xe2",
    0x00ed=>"\xa9\xe3",
    0x00ee=>"\xa9\xe4",
    0x00ef=>"\xa9\xe5",
    0x00f0=>"\xa9\xe6",
    0x00f1=>"\xa9\xe7",
    0x00f2=>"\xa9\xe8",
    0x00f3=>"\xa9\xe9",
    0x00f4=>"\xa9\xea",
    0x00f5=>"\xa9\xeb",
    0x00f6=>"\xa9\xec",
    0x00f8=>"\xa9\xed",
    0x00f9=>"\xa9\xee",
    0x00fa=>"\xa9\xef",
    0x00fb=>"\xa9\xf0",
    0x00fc=>"\xa9\xf1",
    0x00fd=>"\xa9\xf2",
    0x00fe=>"\xa9\xf3",
    0x00ff=>"\xa9\xf4",
    0x0100=>"\xa9\xf5",
    0x0101=>"\xa9\xfa",
    0x0102=>"\xaa\xba",
    0x0103=>"\xaa\xc9",
    0x0104=>"\xaa\xa1",
    0x0105=>"\xaa\xac",
    0x0106=>"\xaa\xbc",
    0x0107=>"\xaa\xcb",
    0x0108=>"\xaa\xd9",
    0x0109=>"\xaa\xdf",
    0x010a=>"",
    0x010b=>"",
    0x010c=>"\xaa\xbd",
    0x010d=>"\xaa\xcc",
    0x010e=>"\xaa\xc0",
    0x010f=>"\xaa\xcf",
    0x0110=>"",
    0x0111=>"\xaa\xd0",
    0x0112=>"\xa9\xf8",
    0x0113=>"\xa9\xfd",
    0x0116=>"",
    0x0117=>"",
    0x0118=>"\xaa\xbe",
    0x0119=>"\xaa\xcd",
    0x011a=>"\xaa\xbf",
    0x011b=>"\xaa\xce",
    0x011c=>"\xaa\xda",
    0x011d=>"\xaa\xe0",
    0x011e=>"",
    0x011f=>"",
    0x0120=>"",
    0x0121=>"",
    0x0122=>"",
    0x0124=>"\xaa\xdb",
    0x0125=>"\xaa\xe1",
    0x0126=>"",
    0x0127=>"\xaa\xfd",
    0x0128=>"",
    0x0129=>"",
    0x012a=>"\xa9\xf6",
    0x012b=>"\xa9\xfb",
    0x012e=>"",
    0x012f=>"",
    0x0130=>"",
    0x0131=>"",
    0x0132=>"",
    0x0133=>"",
    0x0134=>"\xaa\xdc",
    0x0135=>"\xaa\xe2",
    0x0136=>"",
    0x0137=>"",
    0x0138=>"",
    0x0139=>"\xaa\xbb",
    0x013a=>"\xaa\xca",
    0x013b=>"",
    0x013c=>"",
    0x013d=>"\xaa\xa4",
    0x013e=>"\xaa\xaf",
    0x013f=>"",
    0x0140=>"",
    0x0141=>"\xaa\xa3",
    0x0142=>"\xaa\xae",
    0x0143=>"\xaa\xc1",
    0x0144=>"\xaa\xd1",
    0x0145=>"",
    0x0146=>"",
    0x0147=>"\xaa\xc2",
    0x0148=>"\xaa\xd2",
    0x0149=>"",
    0x014a=>"",
    0x014b=>"\xaa\xfa",
    0x014c=>"\xa9\xf9",
    0x014d=>"\xa9\xfe",
    0x0150=>"\xaa\xc3",
    0x0151=>"\xaa\xd3",
    0x0152=>"\xab\xab",
    0x0153=>"\xab\xaa",
    0x0154=>"\xaa\xb9",
    0x0155=>"\xaa\xc8",
    0x0156=>"",
    0x0157=>"",
    0x0158=>"\xaa\xc4",
    0x0159=>"\xaa\xd4",
    0x015a=>"\xaa\xa5",
    0x015b=>"\xaa\xb0",
    0x015c=>"\xaa\xdd",
    0x015d=>"\xaa\xe3",
    0x015e=>"\xaa\xa7",
    0x015f=>"\xaa\xb3",
    0x0160=>"\xaa\xa6",
    0x0161=>"\xaa\xb2",
    0x0162=>"\xaa\xc7",
    0x0163=>"\xaa\xd7",
    0x0164=>"\xaa\xa8",
    0x0165=>"\xaa\xb4",
    0x0166=>"",
    0x0167=>"",
    0x0168=>"",
    0x0169=>"",
    0x016a=>"\xa9\xf7",
    0x016b=>"\xa9\xfc",
    0x016c=>"\xaa\xde",
    0x016d=>"\xaa\xe4",
    0x016e=>"\xaa\xc5",
    0x016f=>"\xaa\xd5",
    0x0170=>"\xaa\xc6",
    0x0171=>"\xaa\xd6",
    0x0172=>"",
    0x0173=>"",
    0x0174=>"",
    0x0175=>"",
    0x0176=>"",
    0x0177=>"",
    0x0178=>"",
    0x0179=>"\xaa\xa9",
    0x017a=>"\xaa\xb5",
    0x017b=>"\xaa\xab",
    0x017c=>"\xaa\xb8",
    0x017d=>"\xaa\xaa",
    0x017e=>"\xaa\xb7",
    0x0193=>"\xab\xa9",
    0x01c2=>"\xab\xa4",
    0x01cd=>"\xa8\xef",
    0x01ce=>"\xa8\xf0",
    0x01cf=>"",
    0x01d0=>"\xa8\xf1",
    0x01d1=>"\xa8\xf6",
    0x01d2=>"\xa8\xf7",
    0x01d3=>"",
    0x01d4=>"\xa8\xf8",
    0x01d5=>"",
    0x01d6=>"\xa8\xf9",
    0x01d7=>"",
    0x01d8=>"\xa8\xfa",
    0x01d9=>"",
    0x01da=>"\xa8\xfb",
    0x01db=>"",
    0x01dc=>"\xa8\xfc",
    0x01f5=>"",
    0x01f8=>"\xa8\xf4",
    0x01f9=>"\xa8\xf5",
    0x01fd=>"\xab\xc5",
    0x0250=>"\xab\xb3",
    0x0251=>"\xab\xb9",
    0x0252=>"\xab\xba",
    0x0253=>"\xab\xa5",
    0x0254=>"\xab\xb8",
#    0x0254=>"\xab\xc8", # U+0300
#    0x0254=>"\xab\xc9", # U+0301
    0x0255=>"\xab\xbf",
    0x0256=>"\xaa\xee",
    0x0257=>"\xab\xa6",
    0x0258=>"\xab\xae",
    0x0259=>"\xab\xb0",
#    0x0259=>"\xab\xcc", # U+0300
#    0x0259=>"\xab\xcd", # U+0301
    0x025a=>"\xab\xc3",
#    0x025a=>"\xab\xce", # U+0300
#    0x025a=>"\xab\xcf", # U+0301
    0x025c=>"\xab\xb1",
    0x025e=>"\xab\xb2",
    0x025f=>"\xaa\xf5",
    0x0260=>"\xab\xa8",
    0x0261=>"\xaa\xf9",
    0x0264=>"\xab\xb6",
    0x0265=>"\xab\xbc",
    0x0266=>"\xab\xa2",
    0x0267=>"\xab\xc2",
    0x0268=>"\xab\xac",
    0x026c=>"\xaa\xea",
    0x026d=>"\xaa\xf4",
    0x026e=>"\xaa\xeb",
    0x026f=>"\xab\xb4",
    0x0270=>"\xaa\xfb",
    0x0271=>"\xaa\xe5",
    0x0272=>"\xaa\xf6",
    0x0273=>"\xaa\xef",
    0x0275=>"\xab\xaf",
    0x0279=>"\xaa\xec",
    0x027a=>"\xab\xc1",
    0x027b=>"\xaa\xf3",
    0x027d=>"\xaa\xf0",
    0x027e=>"\xaa\xe7",
    0x0281=>"\xaa\xfc",
    0x0282=>"\xaa\xf1",
    0x0283=>"\xaa\xe8",
    0x0284=>"\xab\xa7",
    0x0288=>"\xaa\xed",
    0x0289=>"\xab\xad",
    0x028a=>"\xab\xb5",
    0x028b=>"\xaa\xe6",
    0x028c=>"\xab\xb7",
#    0x028c=>"\xab\xca", # U+0300
#    0x028c=>"\xab\xcb", # U+0301
    0x028d=>"\xab\xbb",
    0x028e=>"\xaa\xf8",
    0x0290=>"\xaa\xf2",
    0x0291=>"\xab\xc0",
    0x0292=>"\xaa\xe9",
    0x0294=>"\xab\xa1",
    0x0295=>"\xaa\xfe",
    0x0298=>"\xab\xa3",
    0x029d=>"\xaa\xf7",
    0x02a1=>"\xab\xbe",
    0x02a2=>"\xab\xbd",
    0x02c7=>"\xaa\xb1",
    0x02c8=>"\xab\xd3",
    0x02cc=>"\xab\xd4",
    0x02d0=>"\xab\xd5",
    0x02d1=>"\xab\xd6",
    0x02d8=>"\xaa\xa2",
    0x02d9=>"\xaa\xd8",
    0x02da=>"",
    0x02db=>"\xaa\xad",
    0x02dd=>"\xaa\xb6",
    0x02de=>"\xab\xf1",
    0x02e5=>"\xab\xe0",
#    0x02e5=>"\xab\xe6", # U+02E9
    0x02e6=>"\xab\xe1",
    0x02e7=>"\xab\xe2",
    0x02e8=>"\xab\xe3",
    0x02e9=>"\xab\xe4",
#    0x02e9=>"\xab\xe5", # U+02E5
    0x0300=>"\xab\xdc",
    0x0301=>"\xab\xda",
    0x0302=>"\xab\xdf",
    0x0303=>"\xab\xfd",
    0x0304=>"\xab\xdb",
    0x0306=>"\xab\xd7",
    0x0308=>"\xab\xed",
    0x030b=>"\xab\xd9",
    0x030c=>"\xab\xde",
    0x030f=>"\xab\xdd",
    0x0318=>"\xab\xf8",
    0x0319=>"\xab\xf9",
    0x031a=>"\xab\xfe",
    0x031c=>"\xab\xea",
    0x031d=>"\xab\xf6",
    0x031e=>"\xab\xf7",
    0x031f=>"\xab\xeb",
    0x0320=>"\xab\xec",
    0x0324=>"\xab\xf2",
    0x0325=>"\xab\xe7",
    0x0329=>"\xab\xef",
    0x032a=>"\xab\xfa",
    0x032c=>"\xab\xe8",
    0x032f=>"\xab\xf0",
    0x0330=>"\xab\xf3",
    0x0334=>"\xab\xf5",
    0x0339=>"\xab\xe9",
    0x033a=>"\xab\xfb",
    0x033b=>"\xab\xfc",
    0x033c=>"\xab\xf4",
    0x033d=>"\xab\xee",
    0x0361=>"\xab\xd2",
    0x0384=>"",
    0x0385=>"",
    0x0386=>"",
    0x0388=>"",
    0x0389=>"",
    0x038a=>"",
    0x038c=>"",
    0x038e=>"",
    0x038f=>"",
    0x0390=>"",
    0x03aa=>"",
    0x03ab=>"",
    0x03ac=>"",
    0x03ad=>"",
    0x03ae=>"",
    0x03af=>"",
    0x03b0=>"",
    0x03c2=>"\xa6\xd9",
    0x03ca=>"",
    0x03cb=>"",
    0x03cc=>"",
    0x03cd=>"",
    0x03ce=>"",
    0x0402=>"",
    0x0403=>"",
    0x0404=>"",
    0x0405=>"",
    0x0406=>"",
    0x0407=>"",
    0x0408=>"",
    0x0409=>"",
    0x040a=>"",
    0x040b=>"",
    0x040c=>"",
    0x040e=>"",
    0x040f=>"",
    0x0452=>"",
    0x0453=>"",
    0x0454=>"",
    0x0455=>"",
    0x0456=>"",
    0x0457=>"",
    0x0458=>"",
    0x0459=>"",
    0x045a=>"",
    0x045b=>"",
    0x045c=>"",
    0x045e=>"",
    0x045f=>"",
    0x1e3e=>"\xa8\xf2",
    0x1e3f=>"\xa8\xf3",
    0x1f70=>"\xab\xc6",
    0x1f71=>"\xab\xc7",
    0x1f72=>"\xab\xd0",
    0x1f73=>"\xab\xd1",
    0x2013=>"\xa3\xfc",
    0x2022=>"\xa3\xc0",
    0x203c=>"\xa8\xeb",
    0x203f=>"\xab\xd8",
    0x2042=>"\xac\xfe",
    0x2047=>"\xa8\xec",
    0x2048=>"\xa8\xed",
    0x2049=>"\xa8\xee",
    0x2051=>"\xac\xfd",
    0x20ac=>"\xa9\xa1",
    0x210f=>"\xa3\xdd",
    0x2113=>"\xa3\xdf",
    0x2116=>"\xad\xe2",
    0x2121=>"\xad\xe4",
    0x2122=>"",
    0x2127=>"\xa3\xe0",
    0x2135=>"\xa3\xdc",
    0x2153=>"\xa7\xf8",
    0x2154=>"\xa7\xf9",
    0x2155=>"\xa7\xfa",
    0x2160=>"\xad\xb5",
    0x2161=>"\xad\xb6",
    0x2162=>"\xad\xb7",
    0x2163=>"\xad\xb8",
    0x2164=>"\xad\xb9",
    0x2165=>"\xad\xba",
    0x2166=>"\xad\xbb",
    0x2167=>"\xad\xbc",
    0x2168=>"\xad\xbd",
    0x2169=>"\xad\xbe",
    0x216a=>"\xad\xbf",
    0x216b=>"\xad\xd7",
    0x2170=>"\xac\xb5",
    0x2171=>"\xac\xb6",
    0x2172=>"\xac\xb7",
    0x2173=>"\xac\xb8",
    0x2174=>"\xac\xb9",
    0x2175=>"\xac\xba",
    0x2176=>"\xac\xbb",
    0x2177=>"\xac\xbc",
    0x2178=>"\xac\xbd",
    0x2179=>"\xac\xbe",
    0x217a=>"\xac\xbf",
    0x217b=>"\xac\xc0",
    0x2194=>"\xa2\xf1",
    0x2196=>"\xa3\xa7",
    0x2197=>"\xa3\xa5",
    0x2198=>"\xa3\xa6",
    0x2199=>"\xa3\xa8",
    0x21c4=>"\xa3\xa9",
    0x21e6=>"\xa3\xab",
    0x21e7=>"\xa3\xac",
    0x21e8=>"\xa3\xaa",
    0x21e9=>"\xa3\xad",
    0x2205=>"\xa2\xc7",
    0x2209=>"\xa2\xc6",
    0x2213=>"\xa3\xdb",
    0x221f=>"\xad\xf8",
    0x2225=>"\xa2\xd4",
    0x2226=>"\xa2\xd5",
    0x222e=>"\xad\xf3",
    0x2243=>"\xa2\xec",
    0x2245=>"\xa2\xed",
    0x2248=>"\xa2\xee",
    0x2262=>"\xa2\xeb",
    0x2276=>"\xa2\xef",
    0x2277=>"\xa2\xf0",
    0x2284=>"\xa2\xc2",
    0x2285=>"\xa2\xc3",
    0x228a=>"\xa2\xc4",
    0x228b=>"\xa2\xc5",
    0x2295=>"\xa2\xd1",
    0x2296=>"\xa2\xd2",
    0x2297=>"\xa2\xd3",
    0x2299=>"\xa3\xba",
    0x22bf=>"\xad\xf9",
    0x22da=>"\xa7\xf6",
    0x22db=>"\xa7\xf7",
    0x2305=>"\xa2\xc8",
    0x2306=>"\xa2\xc9",
    0x2318=>"\xa7\xfc",
    0x23be=>"\xa7\xc2",
    0x23bf=>"\xa7\xc3",
    0x23c0=>"\xa7\xc4",
    0x23c1=>"\xa7\xc5",
    0x23c2=>"\xa7\xc6",
    0x23c3=>"\xa7\xc7",
    0x23c4=>"\xa7\xc8",
    0x23c5=>"\xa7\xc9",
    0x23c6=>"\xa7\xca",
    0x23c7=>"\xa7\xcb",
    0x23c8=>"\xa7\xcc",
    0x23c9=>"\xa7\xcd",
    0x23ca=>"\xa7\xce",
    0x23cb=>"\xa7\xcf",
    0x23cc=>"\xa7\xd0",
    0x23ce=>"\xa7\xfe",
    0x2423=>"\xa7\xfd",
    0x2460=>"\xad\xa1",
    0x2461=>"\xad\xa2",
    0x2462=>"\xad\xa3",
    0x2463=>"\xad\xa4",
    0x2464=>"\xad\xa5",
    0x2465=>"\xad\xa6",
    0x2466=>"\xad\xa7",
    0x2467=>"\xad\xa8",
    0x2468=>"\xad\xa9",
    0x2469=>"\xad\xaa",
    0x246a=>"\xad\xab",
    0x246b=>"\xad\xac",
    0x246c=>"\xad\xad",
    0x246d=>"\xad\xae",
    0x246e=>"\xad\xaf",
    0x246f=>"\xad\xb0",
    0x2470=>"\xad\xb1",
    0x2471=>"\xad\xb2",
    0x2472=>"\xad\xb3",
    0x2473=>"\xad\xb4",
    0x24d0=>"\xac\xc1",
    0x24d1=>"\xac\xc2",
    0x24d2=>"\xac\xc3",
    0x24d3=>"\xac\xc4",
    0x24d4=>"\xac\xc5",
    0x24d5=>"\xac\xc6",
    0x24d6=>"\xac\xc7",
    0x24d7=>"\xac\xc8",
    0x24d8=>"\xac\xc9",
    0x24d9=>"\xac\xca",
    0x24da=>"\xac\xcb",
    0x24db=>"\xac\xcc",
    0x24dc=>"\xac\xcd",
    0x24dd=>"\xac\xce",
    0x24de=>"\xac\xcf",
    0x24df=>"\xac\xd0",
    0x24e0=>"\xac\xd1",
    0x24e1=>"\xac\xd2",
    0x24e2=>"\xac\xd3",
    0x24e3=>"\xac\xd4",
    0x24e4=>"\xac\xd5",
    0x24e5=>"\xac\xd6",
    0x24e6=>"\xac\xd7",
    0x24e7=>"\xac\xd8",
    0x24e8=>"\xac\xd9",
    0x24e9=>"\xac\xda",
    0x24eb=>"\xac\xab",
    0x24ec=>"\xac\xac",
    0x24ed=>"\xac\xad",
    0x24ee=>"\xac\xae",
    0x24ef=>"\xac\xaf",
    0x24f0=>"\xac\xb0",
    0x24f1=>"\xac\xb1",
    0x24f2=>"\xac\xb2",
    0x24f3=>"\xac\xb3",
    0x24f4=>"\xac\xb4",
    0x24f5=>"\xa6\xda",
    0x24f6=>"\xa6\xdb",
    0x24f7=>"\xa6\xdc",
    0x24f8=>"\xa6\xdd",
    0x24f9=>"\xa6\xde",
    0x24fa=>"\xa6\xdf",
    0x24fb=>"\xa6\xe0",
    0x24fc=>"\xa6\xe1",
    0x24fd=>"\xa6\xe2",
    0x24fe=>"\xa6\xe3",
    0x25b1=>"\xa6\xed",
    0x25b6=>"\xa3\xa2",
    0x25b7=>"\xa3\xa1",
    0x25c0=>"\xa3\xa4",
    0x25c1=>"\xa3\xa3",
    0x25c9=>"\xa3\xbb",
    0x25d0=>"\xa8\xe7",
    0x25d1=>"\xa8\xe8",
    0x25d2=>"\xa8\xe9",
    0x25d3=>"\xa8\xea",
    0x25e6=>"\xa3\xbf",
    0x2600=>"\xa6\xe8",
    0x2601=>"\xa6\xe9",
    0x2602=>"\xa6\xea",
    0x2603=>"\xa6\xeb",
    0x260e=>"\xa6\xe7",
    0x2616=>"\xa6\xe4",
    0x2617=>"\xa6\xe5",
    0x261e=>"\xad\xfe",
    0x2660=>"\xa6\xba",
    0x2661=>"\xa6\xbd",
    0x2662=>"\xa6\xbb",
    0x2663=>"\xa6\xc0",
    0x2664=>"\xa6\xb9",
    0x2665=>"\xa6\xbe",
    0x2666=>"\xa6\xbc",
    0x2667=>"\xa6\xbf",
    0x2668=>"\xa6\xec",
    0x2669=>"\xa2\xfd",
    0x266b=>"\xa2\xfb",
    0x266c=>"\xa2\xfc",
    0x266e=>"\xa2\xfa",
    0x2713=>"\xa7\xfb",
    0x2756=>"\xad\xfd",
    0x2776=>"\xac\xa1",
    0x2777=>"\xac\xa2",
    0x2778=>"\xac\xa3",
    0x2779=>"\xac\xa4",
    0x277a=>"\xac\xa5",
    0x277b=>"\xac\xa6",
    0x277c=>"\xac\xa7",
    0x277d=>"\xac\xa8",
    0x277e=>"\xac\xa9",
    0x277f=>"\xac\xaa",
    0x2934=>"\xa3\xae",
    0x2935=>"\xa3\xaf",
    0x29fa=>"\xa3\xfd",
    0x29fb=>"\xa3\xfe",
    0x3016=>"\xa2\xda",
    0x3017=>"\xa2\xdb",
    0x3018=>"\xa2\xd8",
    0x3019=>"\xa2\xd9",
    0x301d=>"\xad\xe0",
    0x301f=>"\xad\xe1",
    0x3020=>"\xa6\xe6",
    0x3033=>"\xa2\xb3",
    0x3034=>"\xa2\xb4",
    0x3035=>"\xa2\xb5",
    0x303b=>"\xa2\xb6",
    0x303c=>"\xa2\xb7",
    0x303d=>"\xa3\xbc",
#    0x304b=>"\xa4\xf7", # U+309A
#    0x304d=>"\xa4\xf8", # U+309A
#    0x304f=>"\xa4\xf9", # U+309A
#    0x3051=>"\xa4\xfa", # U+309A
#    0x3053=>"\xa4\xfb", # U+309A
#    0x30ab=>"\xa5\xf7", # U+309A
#    0x30ad=>"\xa5\xf8", # U+309A
#    0x30af=>"\xa5\xf9", # U+309A
#    0x30b1=>"\xa5\xfa", # U+309A
#    0x30b3=>"\xa5\xfb", # U+309A
#    0x30bb=>"\xa5\xfc", # U+309A
#    0x30c4=>"\xa5\xfd", # U+309A
#    0x30c8=>"\xa5\xfe", # U+309A
    0x3094=>"\xa4\xf4",
    0x3095=>"\xa4\xf5",
    0x3096=>"\xa4\xf6",
    0x309f=>"\xa2\xb9",
    0x30a0=>"\xa3\xfb",
    0x30f7=>"\xa7\xf2",
    0x30f8=>"\xa7\xf3",
    0x30f9=>"\xa7\xf4",
    0x30fa=>"\xa7\xf5",
    0x30ff=>"\xa2\xb8",
    0x31f0=>"\xa6\xee",
    0x31f1=>"\xa6\xef",
    0x31f2=>"\xa6\xf0",
    0x31f3=>"\xa6\xf1",
    0x31f4=>"\xa6\xf2",
    0x31f5=>"\xa6\xf3",
    0x31f6=>"\xa6\xf4",
    0x31f7=>"\xa6\xf5",
#    0x31f7=>"\xa6\xf8", # U+309A
    0x31f8=>"\xa6\xf6",
    0x31f9=>"\xa6\xf7",
    0x31fa=>"\xa6\xf9",
    0x31fb=>"\xa6\xfa",
    0x31fc=>"\xa6\xfb",
    0x31fd=>"\xa6\xfc",
    0x31fe=>"\xa6\xfd",
    0x31ff=>"\xa6\xfe",
    0x3231=>"\xad\xea",
    0x3232=>"\xad\xeb",
    0x3239=>"\xad\xec",
    0x3251=>"\xa8\xc1",
    0x3252=>"\xa8\xc2",
    0x3253=>"\xa8\xc3",
    0x3254=>"\xa8\xc4",
    0x3255=>"\xa8\xc5",
    0x3256=>"\xa8\xc6",
    0x3257=>"\xa8\xc7",
    0x3258=>"\xa8\xc8",
    0x3259=>"\xa8\xc9",
    0x325a=>"\xa8\xca",
    0x325b=>"\xa8\xcb",
    0x325c=>"\xa8\xcc",
    0x325d=>"\xa8\xcd",
    0x325e=>"\xa8\xce",
    0x325f=>"\xa8\xcf",
    0x32a4=>"\xad\xe5",
    0x32a5=>"\xad\xe6",
    0x32a6=>"\xad\xe7",
    0x32a7=>"\xad\xe8",
    0x32a8=>"\xad\xe9",
    0x32b1=>"\xa8\xd0",
    0x32b2=>"\xa8\xd1",
    0x32b3=>"\xa8\xd2",
    0x32b4=>"\xa8\xd3",
    0x32b5=>"\xa8\xd4",
    0x32b6=>"\xa8\xd5",
    0x32b7=>"\xa8\xd6",
    0x32b8=>"\xa8\xd7",
    0x32b9=>"\xa8\xd8",
    0x32ba=>"\xa8\xd9",
    0x32bb=>"\xa8\xda",
    0x32bc=>"\xa8\xdb",
    0x32bd=>"\xa8\xdc",
    0x32be=>"\xa8\xdd",
    0x32bf=>"\xa8\xde",
    0x32d0=>"\xac\xdb",
    0x32d1=>"\xac\xdc",
    0x32d2=>"\xac\xdd",
    0x32d3=>"\xac\xde",
    0x32d4=>"\xac\xdf",
    0x32d5=>"\xac\xe0",
    0x32d6=>"\xac\xe1",
    0x32d7=>"\xac\xe2",
    0x32d8=>"\xac\xe3",
    0x32d9=>"\xac\xe4",
    0x32da=>"\xac\xe5",
    0x32db=>"\xac\xe6",
    0x32dc=>"\xac\xe7",
    0x32dd=>"\xac\xe8",
    0x32de=>"\xac\xe9",
    0x32df=>"\xac\xea",
    0x32e0=>"\xac\xeb",
    0x32e1=>"\xac\xec",
    0x32e2=>"\xac\xed",
    0x32e3=>"\xac\xee",
    0x32e5=>"\xac\xf1",
    0x32e9=>"\xac\xf0",
    0x32ec=>"\xac\xf3",
    0x32ed=>"\xac\xf2",
    0x32fa=>"\xac\xef",
    0x3303=>"\xad\xc6",
    0x330d=>"\xad\xca",
    0x3314=>"\xad\xc1",
    0x3318=>"\xad\xc4",
    0x3322=>"\xad\xc2",
    0x3323=>"\xad\xcc",
    0x3326=>"\xad\xcb",
    0x3327=>"\xad\xc5",
    0x332b=>"\xad\xcd",
    0x3336=>"\xad\xc7",
    0x333b=>"\xad\xcf",
    0x3349=>"\xad\xc0",
    0x334a=>"\xad\xce",
    0x334d=>"\xad\xc3",
    0x3351=>"\xad\xc8",
    0x3357=>"\xad\xc9",
    0x337b=>"\xad\xdf",
    0x337c=>"\xad\xef",
    0x337d=>"\xad\xee",
    0x337e=>"\xad\xed",
    0x338e=>"\xad\xd3",
    0x338f=>"\xad\xd4",
    0x339c=>"\xad\xd0",
    0x339d=>"\xad\xd1",
    0x339e=>"\xad\xd2",
    0x33a1=>"\xad\xd6",
    0x33c4=>"\xad\xd5",
    0x33cb=>"\xa3\xde",
    0x33cd=>"\xad\xe3",
    0x3402=>"\xae\xa3",
    0x3406=>"\x8f\xa1\xad",
    0x342c=>"\x8f\xa1\xb2",
    0x342e=>"\x8f\xa1\xb3",
    0x3468=>"\x8f\xa1\xde",
    0x346a=>"\x8f\xa1\xd6",
    0x3492=>"\x8f\xa1\xfe",
    0x34b5=>"\xae\xd3",
    0x34bc=>"\x8f\xa3\xab",
    0x34c1=>"\x8f\xf4\xe8",
    0x34c7=>"\x8f\xa3\xaf",
    0x34db=>"\xae\xdb",
    0x351f=>"\x8f\xa3\xc8",
    0x355d=>"\x8f\xa3\xdd",
    0x355e=>"\x8f\xa3\xde",
    0x3563=>"\x8f\xa3\xe1",
    0x356e=>"\x8f\xa3\xe7",
    0x35a6=>"\x8f\xa4\xa3",
    0x35a8=>"\x8f\xa4\xa6",
    0x35c5=>"\x8f\xa4\xaf",
    0x35da=>"\x8f\xa4\xb8",
    0x35f4=>"\x8f\xa4\xc2",
    0x3605=>"\x8f\xa4\xca",
    0x364a=>"\x8f\xa4\xf9",
    0x3691=>"\x8f\xa5\xbf",
    0x3696=>"\x8f\xa5\xc3",
    0x3699=>"\x8f\xa5\xc1",
    0x36cf=>"\x8f\xa5\xd7",
    0x3761=>"\x8f\xa8\xa3",
    0x3762=>"\x8f\xa8\xa5",
    0x376b=>"\x8f\xa8\xa9",
    0x376c=>"\x8f\xa8\xa8",
    0x3775=>"\x8f\xa8\xac",
    0x378d=>"\xcf\xdf",
    0x37c1=>"\x8f\xa8\xbe",
    0x37e2=>"\xcf\xef",
    0x37e8=>"\x8f\xa8\xd6",
    0x37f4=>"\x8f\xa8\xd9",
    0x37fd=>"\x8f\xa8\xdc",
    0x3800=>"\x8f\xa8\xde",
    0x382f=>"\x8f\xa8\xef",
    0x3836=>"\x8f\xa8\xf1",
    0x3840=>"\x8f\xa8\xf4",
    0x385c=>"\x8f\xa8\xf9",
    0x3861=>"\x8f\xa8\xfb",
    0x38fa=>"\x8f\xac\xbb",
    0x3917=>"\x8f\xac\xc6",
    0x391a=>"\x8f\xac\xca",
    0x396f=>"\x8f\xac\xe0",
    0x3a6e=>"\x8f\xad\xdb",
    0x3a73=>"\x8f\xad\xdf",
    0x3ad6=>"\x8f\xad\xf1",
    0x3ad7=>"\x8f\xae\xb6",
    0x3aea=>"\x8f\xad\xfc",
    0x3b0e=>"\x8f\xae\xae",
    0x3b1a=>"\x8f\xae\xb2",
    0x3b1c=>"\x8f\xae\xb4",
    0x3b22=>"\xf5\xc9",
    0x3b6d=>"\x8f\xae\xed",
    0x3b77=>"\x8f\xae\xe5",
    0x3b87=>"\x8f\xaf\xa8",
    0x3b88=>"\x8f\xaf\xa9",
    0x3b8d=>"\x8f\xaf\xac",
    0x3ba4=>"\x8f\xaf\xb4",
    0x3bb6=>"\xf5\xfe",
    0x3bc3=>"\xf6\xa1",
    0x3bcd=>"\x8f\xaf\xc8",
    0x3bf0=>"\x8f\xaf\xdd",
    0x3c0f=>"\xf6\xba",
    0x3c26=>"\x8f\xaf\xf7",
    0x3cc3=>"\x8f\xee\xbb",
    0x3cd2=>"\x8f\xee\xc2",
    0x3d11=>"\x8f\xee\xf1",
    0x3d1e=>"\x8f\xee\xfe",
    0x3d64=>"\x8f\xef\xc0",
    0x3d9a=>"\x8f\xef\xd4",
    0x3dc0=>"\x8f\xef\xf0",
    0x3dd4=>"\x8f\xef\xf7",
    0x3e05=>"\x8f\xf0\xa8",
    0x3e3f=>"\xf7\xe6",
    0x3e60=>"\x8f\xf0\xbf",
    0x3e66=>"\x8f\xf0\xc1",
    0x3e68=>"\x8f\xf0\xc2",
    0x3e83=>"\x8f\xf0\xc9",
    0x3e94=>"\x8f\xf0\xd0",
    0x3f57=>"\x8f\xf1\xb4",
    0x3f72=>"\xf8\xcd",
    0x3f75=>"\x8f\xf1\xc6",
    0x3f77=>"\x8f\xf1\xc8",
    0x3fae=>"\x8f\xf1\xdc",
    0x3fc9=>"\x8f\xf1\xe7",
    0x3fd7=>"\x8f\xf1\xec",
    0x4039=>"\x8f\xf2\xa2",
    0x4058=>"\x8f\xf2\xad",
    0x4093=>"\x8f\xf2\xb9",
    0x4105=>"\x8f\xf2\xe4",
    0x4148=>"\x8f\xf2\xf4",
    0x414f=>"\x8f\xf2\xf7",
    0x4163=>"\x8f\xf2\xfd",
    0x41b4=>"\x8f\xf3\xb3",
    0x41bf=>"\x8f\xf3\xb7",
    0x41e6=>"\x8f\xf3\xc7",
    0x41ee=>"\x8f\xf3\xcb",
    0x41f3=>"\x8f\xf3\xc8",
    0x4207=>"\x8f\xf3\xd3",
    0x420e=>"\x8f\xf3\xd7",
    0x4264=>"\xf9\xed",
    0x42c6=>"\x8f\xf4\xab",
    0x42d6=>"\x8f\xf4\xb6",
    0x42dd=>"\x8f\xf4\xbb",
    0x4302=>"\x8f\xf4\xce",
    0x432b=>"\x8f\xf4\xdd",
    0x4343=>"\x8f\xf4\xe1",
    0x43ee=>"\x8f\xf5\xbe",
    0x43f0=>"\x8f\xf5\xc2",
    0x4408=>"\x8f\xf5\xc8",
    0x4417=>"\x8f\xf5\xca",
    0x441c=>"\x8f\xf5\xcc",
    0x4422=>"\x8f\xf5\xcf",
    0x4453=>"\xfa\xd9",
    0x445b=>"\xfa\xda",
    0x4476=>"\x8f\xf5\xec",
    0x447a=>"\x8f\xf5\xee",
    0x4491=>"\x8f\xf5\xf7",
    0x44b3=>"\x8f\xf6\xb5",
    0x44be=>"\x8f\xf6\xb2",
    0x44d4=>"\x8f\xf6\xb4",
    0x4508=>"\x8f\xf6\xd9",
    0x450d=>"\x8f\xf6\xd4",
    0x4525=>"\x8f\xf6\xed",
    0x4543=>"\x8f\xf6\xee",
    0x459d=>"\xfb\xd1",
    0x45b8=>"\x8f\xf7\xcf",
    0x45e5=>"\x8f\xf7\xec",
    0x45ea=>"\xfb\xe0",
    0x460f=>"\x8f\xf8\xa4",
    0x4641=>"\x8f\xf8\xba",
    0x4665=>"\x8f\xf8\xc3",
    0x46a1=>"\x8f\xf8\xce",
    0x46af=>"\x8f\xf8\xd3",
    0x470c=>"\x8f\xf8\xeb",
    0x4764=>"\x8f\xf9\xa9",
    0x47fd=>"\x8f\xf9\xbf",
    0x4816=>"\x8f\xf9\xc9",
    0x4844=>"\xfc\xcb",
    0x484e=>"\x8f\xf9\xdc",
    0x48b5=>"\x8f\xfa\xa7",
    0x49b0=>"\xfd\xd8",
    0x49e7=>"\x8f\xfb\xea",
    0x49fa=>"\x8f\xfb\xf0",
    0x4a04=>"\x8f\xfb\xf5",
    0x4a29=>"\x8f\xfb\xf8",
    0x4abc=>"\x8f\xfc\xb7",
    0x4b3b=>"\x8f\xfc\xd5",
    0x4bc2=>"\x8f\xfd\xa6",
    0x4bca=>"\x8f\xfd\xa8",
    0x4bd2=>"\x8f\xfd\xaa",
    0x4be8=>"\x8f\xfd\xb1",
    0x4c17=>"\xfe\xbe",
    0x4c20=>"\x8f\xfd\xbf",
    0x4cc4=>"\x8f\xfe\xaa",
    0x4cd1=>"\x8f\xfe\xad",
    0x4d07=>"\x8f\xfe\xcb",
    0x4d77=>"\x8f\xfe\xe0",
    0x4e02=>"\x8f\xa1\xa2",
    0x4e04=>"",
    0x4e05=>"",
    0x4e0c=>"",
    0x4e0f=>"\x8f\xa1\xa3",
    0x4e12=>"\x8f\xa1\xa4",
    0x4e1f=>"",
    0x4e23=>"",
    0x4e24=>"",
    0x4e28=>"\xae\xa4",
    0x4e29=>"\x8f\xa1\xa5",
    0x4e2b=>"\x8f\xa1\xa6",
    0x4e2c=>"\x8f\xf0\xae",
    0x4e2e=>"\x8f\xa1\xa7",
    0x4e2f=>"\xae\xa5",
    0x4e30=>"\xae\xa6",
    0x4e35=>"",
    0x4e40=>"\x8f\xa1\xa8",
    0x4e41=>"",
    0x4e44=>"",
    0x4e47=>"\x8f\xa1\xa9",
    0x4e48=>"\x8f\xa1\xaa",
    0x4e51=>"\x8f\xa1\xac",
    0x4e5a=>"\x8f\xa1\xaf",
    0x4e5c=>"",
    0x4e63=>"",
    0x4e68=>"",
    0x4e69=>"\x8f\xa1\xb0",
    0x4e74=>"",
    0x4e75=>"",
    0x4e79=>"",
    0x4e7f=>"",
    0x4e8d=>"\xae\xa7",
    0x4e96=>"",
    0x4e97=>"",
    0x4e9d=>"\x8f\xa1\xb1",
    0x4eaf=>"",
    0x4eb9=>"\x8f\xa1\xb4",
    0x4ebb=>"\x8f\xa1\xb5",
    0x4ebc=>"\x8f\xa1\xb7",
    0x4ec3=>"\x8f\xa1\xb8",
    0x4ec8=>"\x8f\xa1\xb9",
    0x4ed0=>"\x8f\xa1\xba",
    0x4eda=>"\x8f\xa1\xbc",
    0x4edb=>"",
    0x4ee0=>"",
    0x4ee1=>"\xae\xa8",
    0x4ee2=>"",
    0x4ee8=>"",
    0x4eeb=>"\x8f\xa1\xbb",
    0x4eef=>"",
    0x4ef1=>"\x8f\xa1\xbd",
    0x4ef3=>"",
    0x4ef5=>"\x8f\xa1\xbe",
    0x4efd=>"\xae\xa9",
    0x4efe=>"",
    0x4eff=>"\xae\xaa",
    0x4f00=>"\x8f\xa1\xbf",
    0x4f02=>"",
    0x4f03=>"\xae\xab",
    0x4f08=>"",
    0x4f0b=>"\xae\xac",
    0x4f0c=>"",
    0x4f12=>"",
    0x4f15=>"",
    0x4f16=>"\x8f\xa1\xc0",
    0x4f17=>"",
    0x4f19=>"",
    0x4f2e=>"",
    0x4f31=>"",
    0x4f33=>"",
    0x4f35=>"",
    0x4f37=>"\x8f\xa1\xc2",
    0x4f39=>"",
    0x4f3b=>"",
    0x4f3e=>"\x8f\xa1\xc3",
    0x4f40=>"",
    0x4f42=>"",
    0x4f48=>"\xae\xae",
    0x4f49=>"\xae\xaf",
    0x4f4b=>"",
    0x4f4c=>"",
    0x4f52=>"",
    0x4f54=>"\x8f\xa1\xc4",
    0x4f56=>"\xae\xb0",
    0x4f58=>"\x8f\xa1\xc5",
    0x4f5f=>"\xae\xb1",
    0x4f60=>"\xae\xad",
    0x4f63=>"",
    0x4f64=>"\x8f\xa1\xc1",
    0x4f6a=>"\xae\xb2",
    0x4f6c=>"\xae\xb3",
    0x4f6e=>"",
    0x4f71=>"",
    0x4f77=>"\x8f\xa1\xc7",
    0x4f78=>"\x8f\xa1\xc8",
    0x4f79=>"",
    0x4f7a=>"\x8f\xa1\xc9",
    0x4f7d=>"\x8f\xa1\xca",
    0x4f7e=>"\xae\xb4",
    0x4f81=>"",
    0x4f82=>"\x8f\xa1\xcb",
    0x4f84=>"",
    0x4f85=>"\x8f\xa1\xcc",
    0x4f89=>"",
    0x4f8a=>"\xae\xb5",
    0x4f8c=>"",
    0x4f8e=>"",
    0x4f90=>"",
    0x4f92=>"\x8f\xa1\xcd",
    0x4f93=>"",
    0x4f94=>"\xae\xb6",
    0x4f97=>"\xae\xb7",
    0x4f99=>"",
    0x4f9a=>"\x8f\xa1\xce",
    0x4f9e=>"",
    0x4f9f=>"",
    0x4fb2=>"\x8f\xa1\xd0",
    0x4fb7=>"",
    0x4fb9=>"",
    0x4fbb=>"",
    0x4fbc=>"",
    0x4fbd=>"",
    0x4fbe=>"\x8f\xa1\xd1",
    0x4fc0=>"",
    0x4fc1=>"",
    0x4fc5=>"\x8f\xa1\xd2",
    0x4fc6=>"",
    0x4fc8=>"",
    0x4fc9=>"\xae\xb9",
    0x4fcb=>"\x8f\xa1\xd3",
    0x4fcc=>"",
    0x4fcd=>"",
    0x4fcf=>"\x8f\xa1\xd4",
    0x4fd2=>"\x8f\xa1\xd5",
    0x4fdc=>"",
    0x4fe0=>"\xae\xba",
    0x4fe2=>"",
    0x4fe6=>"\x8f\xa1\xcf",
    0x4ff0=>"",
    0x4ff1=>"\xae\xa1", # [2004]
    0x4ff2=>"\x8f\xa1\xd7",
    0x4ffc=>"",
    0x4ffd=>"",
    0x4fff=>"",
    0x5000=>"\x8f\xa1\xd8",
    0x5001=>"\xae\xbb",
    0x5002=>"\xae\xbc",
    0x5004=>"",
    0x5007=>"",
    0x500a=>"",
    0x500c=>"",
    0x500e=>"\xae\xbd",
    0x5010=>"\x8f\xa1\xd9",
    0x5013=>"\x8f\xa1\xda",
    0x5017=>"",
    0x5018=>"\xae\xbe",
    0x501b=>"",
    0x501c=>"\x8f\xa1\xdb",
    0x501d=>"",
    0x501e=>"\x8f\xa1\xdc",
    0x5022=>"\x8f\xa1\xdd",
    0x5027=>"\xae\xbf",
    0x502e=>"\xae\xc0",
    0x5030=>"",
    0x5032=>"",
    0x5033=>"",
    0x5035=>"",
    0x503b=>"\xae\xc2",
    0x5040=>"\xae\xc1",
    0x5041=>"\xae\xc3",
    0x5042=>"\x8f\xa1\xdf",
    0x5045=>"",
    0x5046=>"\x8f\xa1\xe0",
    0x504a=>"",
    0x504c=>"",
    0x504e=>"\x8f\xa1\xe1",
    0x5051=>"",
    0x5052=>"",
    0x5053=>"\x8f\xa1\xe2",
    0x5057=>"\x8f\xa1\xe3",
    0x5059=>"",
    0x505f=>"",
    0x5060=>"",
    0x5062=>"",
    0x5063=>"\x8f\xa1\xe4",
    0x5066=>"\x8f\xa1\xe5",
    0x5067=>"",
    0x506a=>"\x8f\xa1\xe6",
    0x506d=>"",
    0x5070=>"\x8f\xa1\xe7",
    0x5071=>"",
    0x5081=>"",
    0x5083=>"",
    0x5084=>"",
    0x5086=>"",
    0x5088=>"\x8f\xa1\xe9",
    0x508a=>"",
    0x508e=>"",
    0x508f=>"",
    0x5090=>"",
    0x5092=>"\x8f\xa1\xea",
    0x5093=>"\x8f\xa1\xeb",
    0x5094=>"\xae\xc4",
    0x5095=>"\x8f\xa1\xec",
    0x5096=>"\x8f\xa1\xed",
    0x509b=>"",
    0x509c=>"\x8f\xa1\xee",
    0x509e=>"",
    0x509f=>"",
    0x50a0=>"",
    0x50a1=>"",
    0x50a2=>"",
    0x50a3=>"\x8f\xa1\xe8",
    0x50aa=>"\x8f\xa1\xef",
    0x50af=>"",
    0x50b0=>"",
    0x50b1=>"\x8f\xa1\xf1",
    0x50b9=>"",
    0x50ba=>"\x8f\xa1\xf2",
    0x50bb=>"\x8f\xa1\xf3",
    0x50bd=>"",
    0x50c0=>"",
    0x50c3=>"",
    0x50c4=>"\x8f\xa1\xf4",
    0x50c7=>"\x8f\xa1\xf5",
    0x50cc=>"\xae\xc5",
    0x50ce=>"\x8f\xa1\xf8",
    0x50d0=>"\xae\xc7",
    0x50d3=>"",
    0x50d4=>"\x8f\xa1\xfa",
    0x50d8=>"",
    0x50d9=>"\x8f\xa1\xfb",
    0x50dc=>"",
    0x50dd=>"",
    0x50df=>"",
    0x50e1=>"\x8f\xa1\xfc",
    0x50e2=>"",
    0x50e4=>"",
    0x50e6=>"\xae\xc8",
    0x50e8=>"",
    0x50e9=>"\x8f\xa1\xfd",
    0x50ef=>"",
    0x50f1=>"",
    0x50f2=>"\xae\xc6",
    0x50f3=>"\x8f\xa1\xf6",
    0x50f6=>"",
    0x50fa=>"",
    0x50fe=>"",
    0x5103=>"\xae\xcb",
    0x5106=>"\xae\xca",
    0x5107=>"",
    0x5108=>"\x8f\xa3\xa1",
    0x510b=>"\xae\xcc",
    0x510c=>"",
    0x510d=>"",
    0x510e=>"",
    0x5110=>"",
    0x5117=>"\x8f\xa3\xa3",
    0x5119=>"",
    0x511b=>"\x8f\xa3\xa4",
    0x511c=>"",
    0x511d=>"",
    0x511e=>"\xae\xcd",
    0x5123=>"",
    0x5127=>"",
    0x5128=>"",
    0x512c=>"",
    0x512d=>"",
    0x512f=>"",
    0x5131=>"",
    0x5133=>"",
    0x5134=>"",
    0x5135=>"\xae\xce",
    0x5138=>"",
    0x5139=>"",
    0x5142=>"",
    0x514a=>"\xae\xcf",
    0x514f=>"",
    0x5153=>"",
    0x5155=>"\xae\xd1",
    0x5157=>"\xae\xd2",
    0x5158=>"",
    0x515f=>"",
    0x5160=>"\x8f\xa3\xa6",
    0x5164=>"",
    0x5166=>"",
    0x5173=>"\x8f\xa3\xa8",
    0x517b=>"\x8f\xf4\xf4",
    0x517e=>"",
    0x5183=>"\x8f\xa3\xa9",
    0x5184=>"",
    0x518b=>"\x8f\xa3\xaa",
    0x518e=>"",
    0x5198=>"\x8f\xa3\xac",
    0x519d=>"\xae\xd4",
    0x51a1=>"",
    0x51a3=>"\x8f\xa3\xad",
    0x51ad=>"\x8f\xa3\xae",
    0x51b8=>"",
    0x51ba=>"",
    0x51bc=>"\x8f\xa3\xb0",
    0x51be=>"",
    0x51bf=>"",
    0x51c2=>"",
    0x51c3=>"\xae\xd5",
    0x51c8=>"",
    0x51ca=>"\xae\xd6",
    0x51cf=>"",
    0x51d1=>"",
    0x51d2=>"",
    0x51d3=>"",
    0x51d5=>"",
    0x51d8=>"",
    0x51de=>"\xae\xd7",
    0x51e2=>"\xae\xd8",
    0x51e5=>"",
    0x51ee=>"\xae\xd9",
    0x51f2=>"",
    0x51f3=>"\x8f\xa3\xb3",
    0x51f4=>"\x8f\xa3\xb4",
    0x51f7=>"",
    0x5201=>"\xae\xda",
    0x5202=>"\x8f\xa3\xb5",
    0x5205=>"",
    0x5212=>"\x8f\xa3\xb6",
    0x5213=>"\xae\xdc",
    0x5215=>"\xae\xdd",
    0x5216=>"\x8f\xa3\xb7",
    0x5218=>"",
    0x5222=>"",
    0x5228=>"",
    0x5231=>"",
    0x5232=>"",
    0x5235=>"",
    0x523c=>"",
    0x5245=>"",
    0x5249=>"\xae\xde",
    0x5255=>"\x8f\xa3\xb9",
    0x5257=>"\xae\xdf",
    0x5258=>"",
    0x525a=>"",
    0x525c=>"\x8f\xa3\xba",
    0x525d=>"\xaf\xfe", # [2004]
    0x525f=>"",
    0x5260=>"",
    0x5261=>"\xae\xe0",
    0x5266=>"",
    0x526c=>"\x8f\xa3\xbb",
    0x526e=>"",
    0x5277=>"\x8f\xa3\xbc",
    0x5278=>"",
    0x5279=>"",
    0x5280=>"",
    0x5282=>"\x8f\xa3\xbe",
    0x5284=>"\x8f\xa3\xbd",
    0x5285=>"",
    0x528a=>"",
    0x528c=>"",
    0x5293=>"\xae\xe1",
    0x5295=>"",
    0x5296=>"",
    0x5297=>"",
    0x5298=>"\x8f\xa3\xc0",
    0x529a=>"",
    0x529c=>"",
    0x52a4=>"\x8f\xa3\xc2",
    0x52a5=>"",
    0x52a6=>"\x8f\xa3\xc3",
    0x52a7=>"",
    0x52af=>"\x8f\xa3\xc4",
    0x52b0=>"",
    0x52b6=>"",
    0x52b7=>"",
    0x52b8=>"",
    0x52ba=>"\x8f\xa3\xc5",
    0x52bb=>"\x8f\xa3\xc6",
    0x52bd=>"",
    0x52c0=>"",
    0x52c4=>"",
    0x52c6=>"",
    0x52c8=>"\xae\xe2",
    0x52ca=>"\x8f\xa3\xc7",
    0x52cc=>"\xae\xe4",
    0x52cf=>"",
    0x52d0=>"\xae\xe5",
    0x52d1=>"\x8f\xa3\xc9",
    0x52d4=>"",
    0x52d6=>"\xae\xe6",
    0x52db=>"\xae\xe7",
    0x52dc=>"",
    0x52e1=>"",
    0x52e5=>"",
    0x52e8=>"",
    0x52e9=>"",
    0x52ea=>"",
    0x52ec=>"",
    0x52f0=>"\xae\xe9",
    0x52f1=>"",
    0x52f4=>"",
    0x52f6=>"",
    0x52f7=>"\x8f\xa3\xcb",
    0x52fb=>"\xae\xea",
    0x5300=>"\xae\xeb",
    0x5303=>"",
    0x5307=>"\xae\xec",
    0x530a=>"\x8f\xa3\xcc",
    0x530b=>"\x8f\xa3\xcd",
    0x530c=>"",
    0x5311=>"",
    0x5313=>"",
    0x5318=>"",
    0x531b=>"",
    0x531c=>"\xae\xed",
    0x531e=>"",
    0x531f=>"",
    0x5324=>"\x8f\xa3\xce",
    0x5325=>"",
    0x5327=>"",
    0x5328=>"",
    0x5329=>"",
    0x532b=>"",
    0x532c=>"",
    0x532d=>"",
    0x5330=>"",
    0x5332=>"",
    0x5335=>"\x8f\xa3\xcf",
    0x533c=>"",
    0x533d=>"",
    0x533e=>"\x8f\xa3\xd0",
    0x5342=>"\x8f\xa3\xd1",
    0x534b=>"",
    0x534c=>"",
    0x5359=>"",
    0x535b=>"",
    0x5361=>"\xae\xef",
    0x5363=>"\xae\xf0",
    0x5365=>"",
    0x5367=>"\x8f\xa3\xd4",
    0x536c=>"\x8f\xa3\xd5",
    0x536d=>"",
    0x5372=>"",
    0x5379=>"",
    0x537a=>"\x8f\xa3\xd6",
    0x537d=>"\xae\xf1",
    0x537e=>"",
    0x5383=>"",
    0x5387=>"",
    0x5388=>"",
    0x538e=>"",
    0x5393=>"\xae\xf2",
    0x5394=>"",
    0x5399=>"",
    0x539d=>"\xae\xf3",
    0x53a1=>"",
    0x53a4=>"\x8f\xa3\xd7",
    0x53aa=>"",
    0x53ab=>"",
    0x53af=>"",
    0x53b2=>"\xae\xf4",
    0x53b4=>"\x8f\xa3\xd8",
    0x53b5=>"",
    0x53b7=>"\x8f\xa3\xda",
    0x53b8=>"",
    0x53ba=>"",
    0x53bd=>"",
    0x53c0=>"\x8f\xa3\xdb",
    0x53c5=>"",
    0x53cf=>"",
    0x53d2=>"",
    0x53d3=>"",
    0x53d5=>"\x8f\xa3\xdf",
    0x53da=>"\x8f\xa3\xe0",
    0x53dd=>"",
    0x53de=>"",
    0x53e0=>"",
    0x53e6=>"",
    0x53e7=>"",
    0x53f4=>"\x8f\xa3\xe2",
    0x53f5=>"\x8f\xa3\xe3",
    0x5402=>"",
    0x5412=>"\xae\xf5",
    0x5413=>"",
    0x541a=>"",
    0x541e=>"\xcf\xfe", # [2004]
    0x5421=>"",
    0x5424=>"\x8f\xa3\xe5",
    0x5427=>"\xae\xf6",
    0x5428=>"\x8f\xa3\xe6",
    0x542a=>"",
    0x542f=>"",
    0x5431=>"",
    0x5434=>"",
    0x5435=>"",
    0x5443=>"\x8f\xa3\xe8",
    0x5444=>"",
    0x5447=>"",
    0x544d=>"\xae\xf7",
    0x544f=>"",
    0x5455=>"\x8f\xa3\xe4",
    0x545e=>"",
    0x5462=>"\x8f\xa3\xe9",
    0x5464=>"",
    0x5466=>"\x8f\xa3\xea",
    0x5467=>"",
    0x5469=>"",
    0x546b=>"\xae\xf9",
    0x546c=>"\x8f\xa3\xeb",
    0x546d=>"",
    0x546e=>"",
    0x5474=>"\xae\xfa",
    0x547f=>"\xae\xfb",
    0x5481=>"",
    0x5483=>"",
    0x5485=>"",
    0x5488=>"\xae\xfc",
    0x5489=>"",
    0x548a=>"\x8f\xa3\xec",
    0x548d=>"\x8f\xa3\xed",
    0x5491=>"",
    0x5495=>"\x8f\xa3\xee",
    0x5496=>"\xae\xfd",
    0x549c=>"\xae\xf8",
    0x549f=>"",
    0x54a0=>"\x8f\xa3\xef",
    0x54a1=>"\xae\xfe",
    0x54a6=>"\x8f\xa3\xf0",
    0x54a7=>"",
    0x54a9=>"\xaf\xa1",
    0x54aa=>"",
    0x54ad=>"\x8f\xa3\xf1",
    0x54ae=>"\x8f\xa3\xf2",
    0x54b1=>"",
    0x54b7=>"\x8f\xa3\xf3",
    0x54b9=>"",
    0x54ba=>"\x8f\xa3\xf4",
    0x54bb=>"",
    0x54bf=>"\x8f\xa3\xf5",
    0x54c3=>"\x8f\xa3\xf6",
    0x54c6=>"\xaf\xa2",
    0x54ca=>"",
    0x54cd=>"",
    0x54ce=>"",
    0x54e0=>"",
    0x54ea=>"",
    0x54ec=>"\x8f\xa3\xf8",
    0x54ef=>"\x8f\xa3\xf9",
    0x54f1=>"\x8f\xa3\xfa",
    0x54f3=>"\x8f\xa3\xfb",
    0x54f6=>"",
    0x54fc=>"",
    0x54fe=>"",
    0x54ff=>"\xaf\xa3",
    0x5500=>"\x8f\xa3\xfc",
    0x5501=>"\x8f\xa3\xfd",
    0x5505=>"",
    0x5508=>"",
    0x5509=>"\x8f\xa3\xfe",
    0x550c=>"",
    0x550d=>"",
    0x550e=>"\xaf\xa4",
    0x5515=>"",
    0x552a=>"",
    0x552b=>"\xaf\xa5",
    0x5532=>"",
    0x5535=>"\xaf\xa6",
    0x5536=>"",
    0x553b=>"",
    0x553c=>"\x8f\xa4\xa1",
    0x553d=>"",
    0x5541=>"\x8f\xa4\xa2",
    0x5547=>"\x8f\xa4\xa4",
    0x5549=>"",
    0x554a=>"\x8f\xa4\xa5",
    0x554d=>"",
    0x5550=>"\xaf\xa7",
    0x5551=>"",
    0x5558=>"",
    0x555a=>"",
    0x555b=>"",
    0x555e=>"\xaf\xa8",
    0x5560=>"\x8f\xa4\xa7",
    0x5561=>"\x8f\xa4\xa8",
    0x5564=>"\x8f\xa4\xa9",
    0x5566=>"",
    0x557d=>"\x8f\xa4\xab",
    0x557f=>"",
    0x5581=>"\xaf\xa9",
    0x5582=>"\x8f\xa4\xac",
    0x5586=>"\xaf\xaa",
    0x5588=>"\x8f\xa4\xad",
    0x558e=>"\xaf\xab",
    0x558f=>"",
    0x5591=>"\x8f\xa4\xae",
    0x5592=>"",
    0x5593=>"",
    0x5594=>"",
    0x5597=>"",
    0x55a3=>"",
    0x55a4=>"",
    0x55ad=>"\xaf\xad",
    0x55b2=>"",
    0x55bf=>"\x8f\xa4\xb3",
    0x55c1=>"",
    0x55c3=>"",
    0x55c6=>"",
    0x55c9=>"\x8f\xa4\xb4",
    0x55cb=>"",
    0x55cc=>"\x8f\xa4\xb5",
    0x55ce=>"\xaf\xae",
    0x55d1=>"\x8f\xa4\xb6",
    0x55d2=>"\x8f\xa4\xb0",
    0x55d3=>"",
    0x55d7=>"",
    0x55d8=>"",
    0x55db=>"",
    0x55dd=>"\x8f\xa4\xb7",
    0x55de=>"",
    0x55e2=>"\x8f\xa4\xb9",
    0x55e9=>"\x8f\xa4\xbb",
    0x55f6=>"",
    0x55ff=>"",
    0x5605=>"",
    0x5607=>"\x8f\xa4\xbe",
    0x5608=>"\xaf\xb0",
    0x560a=>"",
    0x560d=>"",
    0x560e=>"\xaf\xb1",
    0x560f=>"",
    0x5610=>"\x8f\xa4\xbf",
    0x5611=>"",
    0x5612=>"",
    0x5619=>"",
    0x5628=>"\x8f\xa4\xbc",
    0x562c=>"",
    0x5630=>"\x8f\xa4\xc0",
    0x5633=>"",
    0x5635=>"",
    0x5637=>"\x8f\xa4\xc1",
    0x5639=>"",
    0x563b=>"\xaf\xb2",
    0x563c=>"",
    0x563d=>"\x8f\xa4\xc3",
    0x563f=>"\x8f\xa4\xc4",
    0x5640=>"\x8f\xa4\xc5",
    0x5641=>"",
    0x5643=>"",
    0x5644=>"",
    0x5646=>"",
    0x5647=>"\x8f\xa4\xc6",
    0x5649=>"\xaf\xb3",
    0x564b=>"",
    0x564d=>"",
    0x564f=>"",
    0x5653=>"\xf4\xa7", # [2004]
    0x5654=>"",
    0x565e=>"\x8f\xa4\xc7",
    0x5660=>"\x8f\xa4\xc8",
    0x5661=>"",
    0x5662=>"",
    0x5663=>"",
    0x5666=>"\xaf\xb5",
    0x5669=>"",
    0x566d=>"\x8f\xa4\xc9",
    0x566f=>"\xaf\xb7",
    0x5671=>"\xaf\xb8",
    0x5672=>"\xaf\xb9",
    0x5675=>"",
    0x5676=>"\xaf\xb4",
    0x5684=>"",
    0x5685=>"",
    0x5688=>"\x8f\xa4\xcb",
    0x568b=>"",
    0x568c=>"\x8f\xa4\xcc",
    0x5695=>"\x8f\xa4\xcd",
    0x5699=>"\xaf\xba",
    0x569a=>"\x8f\xa4\xce",
    0x569d=>"\x8f\xa4\xcf",
    0x569e=>"\xaf\xbb",
    0x569f=>"",
    0x56a6=>"",
    0x56a7=>"",
    0x56a8=>"\x8f\xa4\xd0",
    0x56a9=>"\xaf\xbc",
    0x56ab=>"",
    0x56ac=>"\xaf\xbd",
    0x56ad=>"\x8f\xa4\xd1",
    0x56b1=>"",
    0x56b2=>"\x8f\xa4\xd2",
    0x56b3=>"\xaf\xbe",
    0x56b7=>"",
    0x56be=>"",
    0x56c5=>"\x8f\xa4\xd3",
    0x56c9=>"\xaf\xbf",
    0x56ca=>"\xaf\xc0",
    0x56cb=>"",
    0x56cc=>"",
    0x56cd=>"\x8f\xa4\xd4",
    0x56cf=>"",
    0x56d0=>"",
    0x56d9=>"",
    0x56dc=>"",
    0x56dd=>"",
    0x56df=>"\x8f\xa4\xd5",
    0x56e1=>"",
    0x56e4=>"",
    0x56e5=>"",
    0x56e6=>"",
    0x56e7=>"",
    0x56e8=>"\x8f\xa4\xd6",
    0x56eb=>"",
    0x56ed=>"",
    0x56f1=>"",
    0x56f6=>"\x8f\xa4\xd7",
    0x56f7=>"\x8f\xa4\xd8",
    0x5701=>"",
    0x5702=>"",
    0x5707=>"",
    0x570a=>"\xaf\xc1",
    0x570c=>"",
    0x5711=>"",
    0x5715=>"\x8f\xa4\xda",
    0x571a=>"",
    0x571b=>"",
    0x571d=>"",
    0x5720=>"",
    0x5721=>"\xaf\xc3",
    0x5722=>"",
    0x5723=>"\x8f\xa4\xdb",
    0x5724=>"",
    0x5725=>"",
    0x5729=>"\x8f\xa4\xdd",
    0x572a=>"",
    0x572c=>"",
    0x572e=>"",
    0x572f=>"\xaf\xc4",
    0x5733=>"\xaf\xc5",
    0x5734=>"\xaf\xc6",
    0x573d=>"",
    0x573e=>"",
    0x573f=>"",
    0x5745=>"\x8f\xa4\xdf",
    0x5746=>"\x8f\xa4\xe0",
    0x574c=>"\x8f\xa4\xe1",
    0x574d=>"\x8f\xa4\xe2",
    0x5752=>"",
    0x5762=>"",
    0x5765=>"",
    0x5767=>"",
    0x5768=>"\x8f\xa4\xe4",
    0x576b=>"",
    0x576d=>"",
    0x576e=>"",
    0x576f=>"\x8f\xa4\xe5",
    0x5770=>"\xaf\xc7",
    0x5771=>"",
    0x5773=>"\x8f\xa4\xe6",
    0x5774=>"\x8f\xa4\xe7",
    0x5775=>"\x8f\xa4\xe8",
    0x5777=>"\xaf\xc8",
    0x5779=>"",
    0x577a=>"",
    0x577b=>"\x8f\xa4\xe9",
    0x577c=>"\xaf\xc9",
    0x577e=>"",
    0x5781=>"",
    0x5783=>"",
    0x578c=>"",
    0x5794=>"",
    0x5795=>"",
    0x5797=>"",
    0x5799=>"",
    0x579a=>"\x8f\xa4\xed",
    0x579c=>"\xaf\xca",
    0x579d=>"\x8f\xa4\xee",
    0x579e=>"\x8f\xa4\xef",
    0x579f=>"",
    0x57a1=>"",
    0x57a7=>"",
    0x57a8=>"\x8f\xa4\xf0",
    0x57a9=>"",
    0x57ac=>"\x8f\xa4\xec",
    0x57b8=>"\xaf\xcd",
    0x57bd=>"",
    0x57c7=>"\xaf\xce",
    0x57c8=>"\xaf\xcf",
    0x57cc=>"\x8f\xa4\xf3",
    0x57cf=>"\xaf\xd0",
    0x57d5=>"",
    0x57d7=>"\x8f\xa4\xf1",
    0x57dd=>"",
    0x57de=>"\x8f\xa4\xf6",
    0x57e1=>"",
    0x57e4=>"\xaf\xd1",
    0x57e6=>"\x8f\xa4\xf7",
    0x57e7=>"",
    0x57e9=>"",
    0x57ed=>"\xaf\xd2",
    0x57f0=>"\x8f\xa4\xf8",
    0x57f5=>"\xaf\xd3",
    0x57f6=>"\xaf\xd4",
    0x57f8=>"\x8f\xa4\xfa",
    0x57fb=>"\x8f\xa4\xfb",
    0x57fd=>"\x8f\xa4\xfc",
    0x57fe=>"",
    0x57ff=>"\xaf\xd5",
    0x5803=>"",
    0x5804=>"\x8f\xa4\xfd",
    0x5808=>"",
    0x5809=>"\xaf\xd6",
    0x580c=>"",
    0x580d=>"",
    0x581b=>"",
    0x581e=>"\x8f\xa4\xfe",
    0x581f=>"",
    0x5820=>"\x8f\xa5\xa1",
    0x5826=>"",
    0x5827=>"\x8f\xa5\xa2",
    0x582d=>"",
    0x5832=>"\x8f\xa5\xa3",
    0x5839=>"\x8f\xa5\xa4",
    0x583f=>"",
    0x5849=>"\x8f\xa5\xa6",
    0x584c=>"\x8f\xa5\xa7",
    0x584d=>"",
    0x584f=>"",
    0x5850=>"",
    0x5855=>"",
    0x585f=>"",
    0x5861=>"\xaf\xd8",
    0x5864=>"\xaf\xd9",
    0x5867=>"\x8f\xa5\xa8",
    0x5868=>"",
    0x5878=>"",
    0x587c=>"\xaf\xdb",
    0x587f=>"",
    0x5880=>"",
    0x5881=>"",
    0x5887=>"",
    0x5888=>"",
    0x5889=>"\xaf\xdc",
    0x588a=>"\x8f\xa5\xa9",
    0x588b=>"\x8f\xa5\xaa",
    0x588c=>"",
    0x588d=>"\x8f\xa5\xab",
    0x588f=>"\x8f\xa5\xac",
    0x5890=>"\x8f\xa5\xad",
    0x5894=>"\x8f\xa5\xae",
    0x5896=>"",
    0x589d=>"\x8f\xa5\xaf",
    0x589e=>"\xaf\xdd",
    0x58a0=>"",
    0x58a1=>"",
    0x58a2=>"",
    0x58a6=>"",
    0x58a9=>"\xaf\xdf",
    0x58aa=>"\x8f\xa5\xb0",
    0x58b1=>"\x8f\xa5\xb1",
    0x58b2=>"",
    0x58bc=>"",
    0x58c2=>"",
    0x58c3=>"\x8f\xa5\xb3",
    0x58c4=>"",
    0x58c8=>"",
    0x58cd=>"\x8f\xa5\xb4",
    0x58ce=>"\xaf\xe2",
    0x58d0=>"",
    0x58d2=>"\xaf\xe1",
    0x58d4=>"\xaf\xe3",
    0x58d6=>"",
    0x58da=>"\xaf\xe4",
    0x58dd=>"",
    0x58e0=>"\xaf\xe5",
    0x58e1=>"",
    0x58e2=>"\x8f\xa5\xb5",
    0x58e9=>"\xaf\xe6",
    0x58f3=>"\x8f\xa5\xb6",
    0x58f4=>"\x8f\xa5\xb7",
    0x5905=>"\x8f\xa5\xb8",
    0x5906=>"\x8f\xa5\xb9",
    0x590b=>"\x8f\xa5\xba",
    0x590c=>"\xaf\xe7",
    0x590d=>"\x8f\xa5\xbb",
    0x5912=>"",
    0x5913=>"",
    0x5914=>"\x8f\xa5\xbc",
    0x591d=>"",
    0x5921=>"",
    0x5923=>"",
    0x5924=>"\x8f\xa5\xbd",
    0x5928=>"",
    0x592f=>"",
    0x5930=>"",
    0x5933=>"",
    0x5935=>"",
    0x5936=>"",
    0x593d=>"\x8f\xa5\xc0",
    0x593f=>"",
    0x5943=>"",
    0x5946=>"\x8f\xa5\xc2",
    0x5952=>"",
    0x5953=>"",
    0x5959=>"",
    0x595b=>"\x8f\xa5\xc5",
    0x595d=>"\xaf\xe9",
    0x595e=>"",
    0x595f=>"\x8f\xa5\xc6",
    0x5961=>"",
    0x5963=>"",
    0x596b=>"",
    0x596d=>"\xaf\xea",
    0x596f=>"",
    0x5972=>"",
    0x5975=>"\x8f\xa5\xc8",
    0x5976=>"\x8f\xa5\xc9",
    0x5979=>"",
    0x597b=>"",
    0x597c=>"\x8f\xa5\xca",
    0x598b=>"\xaf\xeb",
    0x598c=>"",
    0x598e=>"",
    0x5992=>"\xaf\xec",
    0x5995=>"",
    0x5997=>"",
    0x599f=>"\x8f\xa5\xcb",
    0x59a4=>"\xaf\xed",
    0x59a7=>"",
    0x59ad=>"",
    0x59ae=>"\x8f\xa5\xcc",
    0x59af=>"",
    0x59b0=>"",
    0x59b3=>"",
    0x59b7=>"",
    0x59ba=>"",
    0x59bc=>"\x8f\xa5\xcd",
    0x59c1=>"",
    0x59c3=>"\xaf\xee",
    0x59c4=>"",
    0x59c8=>"\x8f\xa5\xce",
    0x59ca=>"",
    0x59cd=>"\x8f\xa5\xcf",
    0x59d2=>"\xaf\xef",
    0x59dd=>"\xaf\xf0",
    0x59de=>"\x8f\xa5\xd0",
    0x59df=>"",
    0x59e3=>"\x8f\xa5\xd1",
    0x59e4=>"\x8f\xa5\xd2",
    0x59e7=>"\x8f\xa5\xd3",
    0x59ee=>"\x8f\xa5\xd4",
    0x59ef=>"",
    0x59f1=>"",
    0x59f2=>"",
    0x59f4=>"",
    0x59f7=>"",
    0x59f8=>"\xfe\xfa", # [2004]
    0x5a00=>"",
    0x5a04=>"",
    0x5a0c=>"\x8f\xa5\xd8",
    0x5a0d=>"\x8f\xa5\xd9",
    0x5a0e=>"",
    0x5a12=>"",
    0x5a13=>"\xaf\xf1",
    0x5a17=>"\x8f\xa5\xda",
    0x5a1e=>"",
    0x5a23=>"\xaf\xf2",
    0x5a24=>"",
    0x5a27=>"\x8f\xa5\xdb",
    0x5a28=>"",
    0x5a2a=>"",
    0x5a2d=>"\x8f\xa5\xdc",
    0x5a30=>"",
    0x5a44=>"",
    0x5a45=>"",
    0x5a47=>"",
    0x5a48=>"",
    0x5a4c=>"",
    0x5a50=>"",
    0x5a55=>"\x8f\xa5\xdd",
    0x5a5e=>"",
    0x5a63=>"",
    0x5a65=>"\x8f\xa5\xde",
    0x5a67=>"\xaf\xf3",
    0x5a6d=>"\xaf\xf4",
    0x5a77=>"\xaf\xf5",
    0x5a7a=>"\x8f\xa5\xdf",
    0x5a7b=>"",
    0x5a7e=>"\xaf\xf6",
    0x5a84=>"\xaf\xf7",
    0x5a8b=>"\x8f\xa5\xe0",
    0x5a90=>"",
    0x5a93=>"",
    0x5a96=>"",
    0x5a99=>"",
    0x5a9c=>"\x8f\xa5\xe1",
    0x5a9e=>"\xaf\xf8",
    0x5a9f=>"\x8f\xa5\xe2",
    0x5aa0=>"\x8f\xa5\xe3",
    0x5aa2=>"\x8f\xa5\xe4",
    0x5aa7=>"\xaf\xf9",
    0x5aac=>"",
    0x5ab1=>"\x8f\xa5\xe5",
    0x5ab2=>"",
    0x5ab3=>"\x8f\xa5\xe6",
    0x5ab5=>"\x8f\xa5\xe7",
    0x5ab8=>"",
    0x5aba=>"\x8f\xa5\xe8",
    0x5abb=>"",
    0x5abf=>"\x8f\xa5\xe9",
    0x5ac4=>"\xaf\xfa",
    0x5ac6=>"",
    0x5ac8=>"",
    0x5acf=>"",
    0x5ada=>"\x8f\xa5\xea",
    0x5adc=>"\x8f\xa5\xeb",
    0x5ae0=>"\x8f\xa5\xec",
    0x5ae5=>"\x8f\xa5\xed",
    0x5aea=>"",
    0x5aee=>"\x8f\xa5\xef",
    0x5af0=>"\x8f\xa5\xee",
    0x5af5=>"\x8f\xa5\xf0",
    0x5af6=>"",
    0x5afd=>"",
    0x5b00=>"\x8f\xa5\xf1",
    0x5b01=>"",
    0x5b08=>"\x8f\xa5\xf2",
    0x5b17=>"\x8f\xa5\xf3",
    0x5b19=>"\xaf\xfc",
    0x5b1b=>"",
    0x5b1d=>"",
    0x5b21=>"",
    0x5b25=>"\xaf\xfd",
    0x5b2d=>"\x8f\xa5\xf5",
    0x5b34=>"\x8f\xa5\xf4",
    0x5b38=>"",
    0x5b41=>"\xcf\xd5",
    0x5b4b=>"",
    0x5b4c=>"\x8f\xa5\xf6",
    0x5b52=>"\x8f\xa5\xf7",
    0x5b56=>"\xcf\xd6",
    0x5b5e=>"",
    0x5b68=>"\x8f\xa5\xf8",
    0x5b6e=>"",
    0x5b6f=>"\x8f\xa5\xf9",
    0x5b7c=>"\x8f\xa5\xfa",
    0x5b7d=>"\xcf\xd7",
    0x5b7e=>"",
    0x5b7f=>"\x8f\xa5\xfb",
    0x5b81=>"\x8f\xa5\xfc",
    0x5b84=>"\x8f\xa5\xfd",
    0x5b86=>"",
    0x5b8a=>"",
    0x5b8e=>"",
    0x5b90=>"",
    0x5b91=>"",
    0x5b93=>"\xcf\xd8",
    0x5b94=>"",
    0x5b96=>"\x8f\xa8\xa1",
    0x5ba8=>"",
    0x5ba9=>"",
    0x5bac=>"\x8f\xa8\xa2",
    0x5bad=>"",
    0x5baf=>"",
    0x5bb1=>"",
    0x5bb2=>"",
    0x5bb7=>"",
    0x5bba=>"",
    0x5bbc=>"",
    0x5bc0=>"\x8f\xa8\xa4",
    0x5bc1=>"",
    0x5bcd=>"",
    0x5bce=>"\x8f\xa8\xa6",
    0x5bcf=>"",
    0x5bd6=>"\x8f\xa8\xa7",
    0x5bd7=>"",
    0x5bd8=>"\xcf\xd9",
    0x5bd9=>"",
    0x5bda=>"",
    0x5be0=>"",
    0x5bec=>"\xcf\xda",
    0x5bef=>"",
    0x5bf1=>"\x8f\xa8\xaa",
    0x5bf4=>"",
    0x5bfd=>"\x8f\xa8\xab",
    0x5c03=>"\x8f\xa8\xad",
    0x5c0c=>"",
    0x5c12=>"\xcf\xdb",
    0x5c17=>"",
    0x5c1e=>"\xcf\xdc",
    0x5c1f=>"",
    0x5c23=>"\xcf\xdd",
    0x5c26=>"",
    0x5c29=>"\x8f\xa8\xae",
    0x5c2b=>"\xcf\xde",
    0x5c2c=>"",
    0x5c2e=>"",
    0x5c30=>"\x8f\xa8\xaf",
    0x5c32=>"",
    0x5c35=>"",
    0x5c36=>"",
    0x5c59=>"",
    0x5c5a=>"",
    0x5c5b=>"\xfe\xfb", # [2004]
    0x5c5c=>"",
    0x5c5f=>"\x8f\xa8\xb1",
    0x5c62=>"\xcf\xe0",
    0x5c63=>"\x8f\xa8\xb2",
    0x5c67=>"\x8f\xa8\xb3",
    0x5c68=>"\x8f\xa8\xb4",
    0x5c69=>"\x8f\xa8\xb5",
    0x5c6d=>"",
    0x5c70=>"\x8f\xa8\xb6",
    0x5c74=>"",
    0x5c75=>"",
    0x5c7a=>"\xcf\xe4",
    0x5c7b=>"",
    0x5c7c=>"\x8f\xa8\xb9",
    0x5c7d=>"",
    0x5c87=>"",
    0x5c88=>"\x8f\xa8\xbc",
    0x5c8a=>"\x8f\xa8\xbd",
    0x5c8f=>"\xcf\xe5",
    0x5c92=>"",
    0x5c9d=>"",
    0x5c9f=>"\xcf\xe6",
    0x5ca0=>"\x8f\xa8\xc1",
    0x5ca2=>"\x8f\xa8\xc2",
    0x5ca3=>"\xcf\xe7",
    0x5ca6=>"\x8f\xa8\xc3",
    0x5ca7=>"\x8f\xa8\xc4",
    0x5caa=>"\xcf\xe8",
    0x5cad=>"\x8f\xa8\xc6",
    0x5cb2=>"",
    0x5cb4=>"",
    0x5cb5=>"\x8f\xa8\xc7",
    0x5cba=>"\xcf\xe9",
    0x5cc9=>"\x8f\xa8\xc9",
    0x5ccb=>"\xcf\xea",
    0x5cd0=>"\xcf\xeb",
    0x5cd2=>"\xcf\xec",
    0x5cd7=>"",
    0x5cdd=>"",
    0x5cee=>"",
    0x5cf1=>"",
    0x5cf2=>"",
    0x5cf4=>"\xcf\xed",
    0x5d01=>"",
    0x5d06=>"\x8f\xa8\xcc",
    0x5d0d=>"\xcf\xf0",
    0x5d10=>"\x8f\xa8\xcd",
    0x5d12=>"",
    0x5d1d=>"\x8f\xa8\xcf",
    0x5d20=>"\x8f\xa8\xd0",
    0x5d23=>"",
    0x5d24=>"\x8f\xa8\xd1",
    0x5d26=>"\x8f\xa8\xd2",
    0x5d27=>"\xcf\xf1",
    0x5d2b=>"\x8f\xa8\xce",
    0x5d31=>"\x8f\xa8\xd3",
    0x5d34=>"",
    0x5d39=>"\x8f\xa8\xd4",
    0x5d3d=>"",
    0x5d3f=>"",
    0x5d42=>"\x8f\xa8\xd5",
    0x5d43=>"",
    0x5d46=>"\xcf\xf3",
    0x5d47=>"\xcf\xf4",
    0x5d48=>"",
    0x5d4a=>"\xcf\xf6",
    0x5d51=>"",
    0x5d53=>"\xcf\xf5",
    0x5d55=>"",
    0x5d59=>"",
    0x5d5f=>"",
    0x5d60=>"",
    0x5d61=>"\x8f\xa8\xd7",
    0x5d62=>"",
    0x5d64=>"",
    0x5d6a=>"\x8f\xa8\xd8",
    0x5d6d=>"\xcf\xf7",
    0x5d70=>"\x8f\xa8\xda",
    0x5d79=>"",
    0x5d7a=>"",
    0x5d7e=>"",
    0x5d7f=>"",
    0x5d81=>"\xcf\xf8",
    0x5d83=>"",
    0x5d88=>"\x8f\xa8\xdd",
    0x5d8a=>"",
    0x5d92=>"\x8f\xa8\xdf",
    0x5d93=>"",
    0x5d94=>"\x8f\xa8\xe0",
    0x5d95=>"",
    0x5d97=>"\x8f\xa8\xe1",
    0x5d99=>"\x8f\xa8\xe2",
    0x5d9b=>"",
    0x5d9f=>"",
    0x5da0=>"\xcf\xf9",
    0x5da4=>"\xcf\xfa",
    0x5da7=>"\xcf\xfb",
    0x5dab=>"",
    0x5db0=>"\x8f\xa8\xe3",
    0x5db2=>"\x8f\xa8\xe4",
    0x5db4=>"\x8f\xa8\xe5",
    0x5db8=>"\xcf\xfc",
    0x5db9=>"\x8f\xa8\xe7",
    0x5dc3=>"",
    0x5dc7=>"",
    0x5dcb=>"\xcf\xfd",
    0x5dce=>"",
    0x5dd0=>"",
    0x5dd1=>"\x8f\xa8\xe8",
    0x5dd7=>"\x8f\xa8\xe9",
    0x5dd8=>"\x8f\xa8\xea",
    0x5dd9=>"",
    0x5de0=>"\x8f\xa8\xeb",
    0x5de2=>"\xf4\xa8",
    0x5de4=>"\x8f\xa8\xed",
    0x5de9=>"\x8f\xa8\xee",
    0x5df8=>"",
    0x5df9=>"",
    0x5e00=>"\x8f\xa8\xf0",
    0x5e07=>"",
    0x5e0d=>"",
    0x5e12=>"\x8f\xa8\xf2",
    0x5e14=>"\xf4\xa9",
    0x5e15=>"\x8f\xa8\xf3",
    0x5e18=>"\xf4\xaa",
    0x5e1f=>"\x8f\xa8\xf5",
    0x5e20=>"",
    0x5e28=>"",
    0x5e2e=>"\x8f\xa8\xf6",
    0x5e32=>"",
    0x5e35=>"",
    0x5e3e=>"\x8f\xa8\xf7",
    0x5e49=>"\x8f\xa8\xf8",
    0x5e4b=>"",
    0x5e50=>"",
    0x5e51=>"",
    0x5e56=>"\x8f\xa8\xfa",
    0x5e58=>"\xf4\xab",
    0x5e5b=>"",
    0x5e5c=>"",
    0x5e5e=>"\xf4\xac",
    0x5e68=>"",
    0x5e6a=>"",
    0x5e6b=>"\x8f\xa8\xfc",
    0x5e6c=>"\x8f\xa8\xfd",
    0x5e6d=>"\x8f\xa8\xfe",
    0x5e6e=>"\x8f\xac\xa1",
    0x5e70=>"",
    0x5e77=>"\xfe\xfc", # [2004]
    0x5e80=>"",
    0x5e8b=>"",
    0x5e8e=>"",
    0x5ea2=>"",
    0x5ea4=>"",
    0x5ea5=>"\x8f\xac\xa3",
    0x5ea8=>"",
    0x5eaa=>"\x8f\xac\xa4",
    0x5eac=>"\x8f\xac\xa5",
    0x5eb1=>"",
    0x5eb3=>"",
    0x5eb9=>"\x8f\xac\xa6",
    0x5ebd=>"",
    0x5ebe=>"\xf4\xad",
    0x5ebf=>"\x8f\xac\xa7",
    0x5ec6=>"\x8f\xac\xa8",
    0x5ecb=>"\xf4\xaf",
    0x5ecc=>"",
    0x5ece=>"",
    0x5ed1=>"",
    0x5ed2=>"\x8f\xac\xa9",
    0x5ed4=>"",
    0x5ed5=>"",
    0x5ed9=>"\x8f\xac\xaa",
    0x5edc=>"",
    0x5ede=>"",
    0x5ee5=>"",
    0x5eeb=>"",
    0x5ef9=>"\xf4\xb0",
    0x5efd=>"\x8f\xac\xac",
    0x5f00=>"\xf4\xb1",
    0x5f02=>"\xf4\xb2",
    0x5f06=>"",
    0x5f07=>"\xf4\xb3",
    0x5f08=>"\x8f\xac\xad",
    0x5f0e=>"\x8f\xac\xae",
    0x5f19=>"",
    0x5f1c=>"\x8f\xac\xaf",
    0x5f1d=>"\xf4\xb4",
    0x5f1e=>"\x8f\xac\xb1",
    0x5f21=>"",
    0x5f22=>"",
    0x5f23=>"\xf4\xb5",
    0x5f24=>"",
    0x5f28=>"",
    0x5f2b=>"",
    0x5f2c=>"",
    0x5f2e=>"",
    0x5f30=>"",
    0x5f34=>"\xf4\xb6",
    0x5f36=>"\xf4\xb7",
    0x5f3b=>"",
    0x5f3d=>"\xf4\xb8",
    0x5f3f=>"",
    0x5f40=>"\xf4\xb9",
    0x5f44=>"",
    0x5f45=>"\xf4\xba",
    0x5f47=>"\x8f\xac\xb2",
    0x5f4d=>"",
    0x5f50=>"",
    0x5f54=>"\xf4\xbb",
    0x5f58=>"\xf4\xbc",
    0x5f5b=>"",
    0x5f60=>"",
    0x5f63=>"\x8f\xac\xb3",
    0x5f64=>"\xf4\xbd",
    0x5f67=>"\xf4\xbe",
    0x5f6f=>"",
    0x5f72=>"\x8f\xac\xb4",
    0x5f74=>"",
    0x5f75=>"",
    0x5f78=>"",
    0x5f7a=>"",
    0x5f7d=>"\xf4\xbf",
    0x5f7e=>"\x8f\xac\xb5",
    0x5f89=>"\xf4\xc0",
    0x5f8d=>"",
    0x5f8f=>"\x8f\xac\xb6",
    0x5f96=>"",
    0x5f9c=>"\xf4\xc1",
    0x5f9d=>"",
    0x5fa2=>"\x8f\xac\xb7",
    0x5fa4=>"\x8f\xac\xb8",
    0x5fa7=>"\xf4\xc2",
    0x5fab=>"",
    0x5fac=>"",
    0x5faf=>"\xf4\xc3",
    0x5fb0=>"",
    0x5fb1=>"",
    0x5fb5=>"\xf4\xc4",
    0x5fb7=>"\xf4\xc5",
    0x5fb8=>"\x8f\xac\xb9",
    0x5fc4=>"\x8f\xac\xba",
    0x5fc7=>"\x8f\xac\xbc",
    0x5fc8=>"",
    0x5fc9=>"\xf4\xc6",
    0x5fcb=>"\x8f\xac\xbd",
    0x5fd0=>"",
    0x5fd1=>"",
    0x5fd2=>"\x8f\xac\xbe",
    0x5fd3=>"\x8f\xac\xbf",
    0x5fd4=>"\x8f\xac\xc0",
    0x5fde=>"\xf4\xc7",
    0x5fe1=>"\xf4\xc8",
    0x5fe2=>"\x8f\xac\xc1",
    0x5fe8=>"",
    0x5fe9=>"\xf4\xc9",
    0x5fea=>"",
    0x5fec=>"",
    0x5fed=>"",
    0x5fee=>"\x8f\xac\xc2",
    0x5fef=>"\x8f\xac\xc3",
    0x5ff2=>"",
    0x5ff3=>"\x8f\xac\xc4",
    0x5ff6=>"",
    0x5ffa=>"",
    0x5ffc=>"\x8f\xac\xc5",
    0x6007=>"",
    0x600a=>"",
    0x600d=>"\xf4\xca",
    0x6013=>"",
    0x6014=>"\xf4\xcb",
    0x6017=>"\x8f\xac\xc7",
    0x6018=>"\xf4\xcc",
    0x601a=>"",
    0x601f=>"",
    0x6022=>"\x8f\xac\xc8",
    0x6024=>"\x8f\xac\xc9",
    0x602d=>"",
    0x6033=>"\xf4\xcd",
    0x6035=>"\xf4\xce",
    0x6040=>"",
    0x6047=>"\xf4\xcf",
    0x6048=>"",
    0x6049=>"",
    0x604c=>"\x8f\xac\xcb",
    0x6051=>"",
    0x6054=>"",
    0x6056=>"",
    0x6057=>"",
    0x605d=>"",
    0x6061=>"",
    0x6067=>"",
    0x6071=>"",
    0x607e=>"",
    0x607f=>"\x8f\xac\xcc",
    0x6082=>"",
    0x6086=>"",
    0x6088=>"",
    0x608a=>"\x8f\xac\xcd",
    0x608e=>"",
    0x6091=>"",
    0x6093=>"",
    0x6095=>"\x8f\xac\xce",
    0x6098=>"",
    0x609d=>"\xf4\xd1",
    0x609e=>"\xf4\xd2",
    0x60a2=>"",
    0x60a4=>"",
    0x60a5=>"",
    0x60a8=>"\x8f\xac\xcf",
    0x60b0=>"\x8f\xac\xd1",
    0x60b1=>"\x8f\xac\xd2",
    0x60b7=>"",
    0x60bb=>"",
    0x60be=>"\x8f\xac\xd3",
    0x60c2=>"",
    0x60c4=>"",
    0x60c8=>"\x8f\xac\xd4",
    0x60c9=>"",
    0x60ca=>"",
    0x60cb=>"\xf4\xd3",
    0x60ce=>"",
    0x60cf=>"",
    0x60d4=>"\xf4\xd4",
    0x60d5=>"\xf4\xd5",
    0x60d9=>"\x8f\xac\xd5",
    0x60db=>"\x8f\xac\xd6",
    0x60dd=>"\xf4\xd6",
    0x60de=>"",
    0x60e2=>"",
    0x60e5=>"",
    0x60ee=>"\x8f\xac\xd7",
    0x60f2=>"\x8f\xac\xd8",
    0x60f5=>"\x8f\xac\xd9",
    0x60f8=>"\xf4\xd7",
    0x60fc=>"",
    0x60fd=>"",
    0x6102=>"",
    0x6107=>"",
    0x610a=>"",
    0x610c=>"",
    0x6110=>"\x8f\xac\xda",
    0x6111=>"",
    0x6112=>"\x8f\xac\xdb",
    0x6113=>"\x8f\xac\xdc",
    0x6114=>"",
    0x6116=>"",
    0x6117=>"",
    0x6119=>"\x8f\xac\xdd",
    0x611c=>"\xf4\xd8",
    0x611e=>"\x8f\xac\xde",
    0x6122=>"",
    0x612a=>"",
    0x612b=>"\xf4\xd9",
    0x6130=>"\xf4\xda",
    0x6131=>"",
    0x6135=>"",
    0x6136=>"",
    0x6137=>"\xf4\xdb",
    0x6139=>"",
    0x613a=>"\x8f\xac\xdf",
    0x6141=>"\x8f\xac\xe1",
    0x6145=>"",
    0x6146=>"\x8f\xac\xe2",
    0x6149=>"",
    0x615e=>"",
    0x6160=>"\x8f\xac\xe3",
    0x616c=>"",
    0x6172=>"",
    0x6178=>"",
    0x617b=>"",
    0x617c=>"\x8f\xac\xe4",
    0x617f=>"",
    0x6180=>"",
    0x6181=>"",
    0x6183=>"",
    0x6184=>"",
    0x618b=>"",
    0x618d=>"\xf4\xdd",
    0x6192=>"\x8f\xac\xe6",
    0x6193=>"\x8f\xac\xe7",
    0x6197=>"\x8f\xac\xe8",
    0x6198=>"\x8f\xac\xe9",
    0x619c=>"",
    0x619d=>"",
    0x619f=>"",
    0x61a0=>"",
    0x61a5=>"\x8f\xac\xea",
    0x61a8=>"\x8f\xac\xeb",
    0x61aa=>"",
    0x61ad=>"\x8f\xac\xec",
    0x61b8=>"",
    0x61b9=>"\xf4\xe0",
    0x61bc=>"\xf4\xdf",
    0x61c0=>"",
    0x61c1=>"",
    0x61c2=>"",
    0x61ce=>"",
    0x61cf=>"",
    0x61d5=>"\x8f\xac\xee",
    0x61dc=>"",
    0x61dd=>"\x8f\xac\xef",
    0x61de=>"",
    0x61df=>"\x8f\xac\xf0",
    0x61e1=>"",
    0x61e2=>"",
    0x61e5=>"",
    0x61e7=>"",
    0x61e9=>"",
    0x61ec=>"",
    0x61ed=>"",
    0x61ef=>"",
    0x61f5=>"\x8f\xac\xf1",
    0x6201=>"",
    0x6203=>"",
    0x6204=>"",
    0x6207=>"",
    0x6213=>"",
    0x6215=>"\x8f\xac\xf3",
    0x621c=>"",
    0x6220=>"",
    0x6222=>"\xf4\xe2",
    0x6223=>"\x8f\xac\xf4",
    0x6227=>"",
    0x6229=>"\x8f\xac\xf5",
    0x622b=>"",
    0x6239=>"",
    0x623d=>"",
    0x623e=>"\xf4\xe3",
    0x6242=>"",
    0x6243=>"\xf4\xe4",
    0x6244=>"",
    0x6246=>"\x8f\xac\xf6",
    0x624c=>"\x8f\xac\xf7",
    0x6250=>"",
    0x6251=>"\x8f\xac\xf8",
    0x6252=>"\x8f\xac\xf9",
    0x6254=>"",
    0x6256=>"\xf4\xe5",
    0x625a=>"\xf4\xe6",
    0x625c=>"",
    0x6261=>"\x8f\xac\xfa",
    0x6264=>"\x8f\xac\xfb",
    0x626d=>"\x8f\xac\xfd",
    0x626f=>"\xf4\xe7",
    0x6273=>"\x8f\xac\xfe",
    0x627a=>"",
    0x627b=>"\x8f\xac\xfc",
    0x627d=>"",
    0x6285=>"\xf4\xe8",
    0x628d=>"",
    0x628e=>"",
    0x628f=>"",
    0x6290=>"",
    0x6299=>"\x8f\xad\xa1",
    0x62a6=>"\x8f\xad\xa2",
    0x62a8=>"",
    0x62b3=>"",
    0x62b6=>"",
    0x62b7=>"",
    0x62ba=>"",
    0x62be=>"",
    0x62bf=>"",
    0x62c4=>"\xf4\xe9",
    0x62ce=>"",
    0x62d5=>"\x8f\xad\xa3",
    0x62d6=>"\xf4\xea",
    0x62da=>"",
    0x62ea=>"",
    0x62f2=>"",
    0x62f4=>"",
    0x62fc=>"\xf4\xeb",
    0x62fd=>"\x8f\xad\xa5",
    0x6303=>"\x8f\xad\xa6",
    0x6304=>"",
    0x630a=>"\xf4\xec",
    0x630b=>"",
    0x630d=>"\x8f\xad\xa7",
    0x6310=>"\x8f\xad\xa8",
    0x6313=>"",
    0x6316=>"",
    0x6318=>"\xf4\xed",
    0x6329=>"",
    0x632a=>"",
    0x632d=>"",
    0x6332=>"\x8f\xad\xab",
    0x6335=>"\x8f\xad\xac",
    0x6336=>"",
    0x6339=>"\xf4\xee",
    0x633b=>"\x8f\xad\xad",
    0x633c=>"\x8f\xad\xae",
    0x6341=>"\x8f\xad\xaf",
    0x6342=>"",
    0x6343=>"\xf4\xef",
    0x6344=>"\x8f\xad\xb0",
    0x6346=>"",
    0x634a=>"",
    0x634b=>"",
    0x634e=>"\x8f\xad\xb1",
    0x6352=>"",
    0x6353=>"",
    0x6354=>"",
    0x6358=>"",
    0x6359=>"\x8f\xad\xb3",
    0x635b=>"",
    0x6365=>"\xf4\xf0",
    0x6366=>"",
    0x636c=>"\x8f\xad\xb6",
    0x636d=>"",
    0x6371=>"",
    0x6374=>"",
    0x6375=>"",
    0x6378=>"",
    0x637c=>"\xf4\xf1",
    0x637d=>"",
    0x637f=>"",
    0x6382=>"",
    0x6384=>"\x8f\xad\xb7",
    0x6387=>"",
    0x638a=>"",
    0x6390=>"",
    0x6394=>"\x8f\xad\xba",
    0x6395=>"",
    0x6399=>"\x8f\xad\xb8",
    0x639a=>"",
    0x639e=>"",
    0x63a4=>"",
    0x63a6=>"",
    0x63ad=>"",
    0x63ae=>"",
    0x63af=>"",
    0x63bd=>"\x8f\xad\xbb",
    0x63c1=>"",
    0x63c5=>"",
    0x63c8=>"",
    0x63ce=>"",
    0x63d1=>"",
    0x63d3=>"",
    0x63d4=>"\x8f\xad\xbd",
    0x63d5=>"\x8f\xad\xbe",
    0x63dc=>"\x8f\xad\xbf",
    0x63e0=>"\x8f\xad\xc0",
    0x63e5=>"\xf4\xf2",
    0x63ea=>"",
    0x63eb=>"\x8f\xad\xc1",
    0x63ec=>"\x8f\xad\xc2",
    0x63ed=>"\xf4\xf3",
    0x63f2=>"\x8f\xad\xc3",
    0x63f3=>"",
    0x63f5=>"\xf4\xf4",
    0x63f7=>"\x8f\xad\xbc",
    0x63f8=>"",
    0x63f9=>"",
    0x6409=>"\x8f\xad\xc4",
    0x640a=>"",
    0x6410=>"\xf4\xf5",
    0x6412=>"",
    0x6414=>"\xf4\xf6",
    0x6418=>"",
    0x641e=>"\x8f\xad\xc5",
    0x6420=>"",
    0x6422=>"\xf4\xf7",
    0x6424=>"",
    0x6425=>"\x8f\xad\xc6",
    0x6429=>"\x8f\xad\xc7",
    0x642a=>"",
    0x642f=>"\x8f\xad\xc8",
    0x6430=>"",
    0x6435=>"",
    0x643d=>"",
    0x643f=>"",
    0x644b=>"",
    0x644f=>"",
    0x6451=>"\xf4\xf9",
    0x6452=>"",
    0x6453=>"",
    0x6454=>"",
    0x645a=>"\x8f\xad\xc9",
    0x645b=>"\x8f\xad\xca",
    0x645c=>"",
    0x645d=>"\x8f\xad\xcb",
    0x645f=>"",
    0x6460=>"\xf4\xfa",
    0x6461=>"",
    0x6463=>"",
    0x646d=>"\xf4\xfb",
    0x6473=>"\x8f\xad\xcc",
    0x6474=>"",
    0x6479=>"\xf4\xf8",
    0x647b=>"",
    0x647d=>"\x8f\xad\xcd",
    0x6485=>"",
    0x6487=>"\x8f\xad\xce",
    0x648f=>"",
    0x6490=>"",
    0x6491=>"\x8f\xad\xcf",
    0x6498=>"",
    0x6499=>"",
    0x649b=>"",
    0x649d=>"\x8f\xad\xd0",
    0x649f=>"\x8f\xad\xd1",
    0x64a1=>"",
    0x64a3=>"",
    0x64a6=>"",
    0x64a8=>"",
    0x64ac=>"",
    0x64b3=>"",
    0x64bd=>"",
    0x64be=>"\xf4\xfd",
    0x64bf=>"\xf4\xfe",
    0x64c4=>"\xf5\xa1",
    0x64c9=>"",
    0x64ca=>"\xf5\xa2",
    0x64cb=>"\x8f\xad\xd2",
    0x64cc=>"\x8f\xad\xd3",
    0x64ce=>"\xf4\xfc",
    0x64d0=>"\xf5\xa3",
    0x64d1=>"",
    0x64d5=>"\x8f\xad\xd4",
    0x64d7=>"\x8f\xad\xd5",
    0x64e4=>"\x8f\xad\xd7",
    0x64e5=>"\x8f\xad\xd8",
    0x64e9=>"",
    0x64ea=>"",
    0x64ed=>"",
    0x64f0=>"",
    0x64f5=>"",
    0x64f7=>"\xf5\xa4",
    0x64fb=>"\xf5\xa5",
    0x64ff=>"\x8f\xad\xd9",
    0x6501=>"",
    0x6504=>"\x8f\xad\xda",
    0x6508=>"",
    0x6509=>"",
    0x650a=>"",
    0x650f=>"\x8f\xad\xdc",
    0x6513=>"",
    0x6514=>"\x8f\xad\xdd",
    0x6516=>"\x8f\xad\xde",
    0x6519=>"",
    0x651b=>"",
    0x651e=>"\x8f\xad\xe0",
    0x651f=>"",
    0x6522=>"\xf5\xa6",
    0x6526=>"",
    0x6529=>"\xf5\xa7",
    0x652e=>"",
    0x6531=>"",
    0x6532=>"\x8f\xad\xe1",
    0x653a=>"",
    0x653c=>"",
    0x653d=>"",
    0x6543=>"",
    0x6544=>"\x8f\xad\xe2",
    0x6547=>"",
    0x6549=>"",
    0x6550=>"",
    0x6552=>"",
    0x6554=>"\x8f\xad\xe3",
    0x655f=>"",
    0x6560=>"",
    0x6567=>"\xf5\xa9",
    0x656b=>"\x8f\xad\xe4",
    0x657a=>"\x8f\xad\xe5",
    0x657d=>"",
    0x6581=>"\x8f\xad\xe6",
    0x6584=>"\x8f\xad\xe7",
    0x6585=>"\x8f\xad\xe8",
    0x658a=>"\x8f\xad\xe9",
    0x6592=>"",
    0x6595=>"",
    0x6598=>"",
    0x659d=>"\xf5\xaa",
    0x65a0=>"",
    0x65a3=>"",
    0x65a6=>"",
    0x65ae=>"",
    0x65b2=>"\x8f\xad\xea",
    0x65b3=>"",
    0x65b4=>"",
    0x65b5=>"\x8f\xad\xeb",
    0x65b8=>"\x8f\xad\xec",
    0x65bf=>"\x8f\xad\xed",
    0x65c2=>"\x8f\xad\xee",
    0x65c8=>"",
    0x65c9=>"\x8f\xad\xef",
    0x65ce=>"",
    0x65d0=>"",
    0x65d4=>"\x8f\xad\xf0",
    0x65d6=>"",
    0x65d8=>"",
    0x65df=>"",
    0x65f0=>"",
    0x65f2=>"\x8f\xad\xf2",
    0x65f4=>"",
    0x65f5=>"",
    0x65f9=>"\x8f\xad\xf3",
    0x65fc=>"\x8f\xad\xf4",
    0x65fe=>"",
    0x65ff=>"",
    0x6600=>"\xf5\xac",
    0x6604=>"\x8f\xad\xf5",
    0x6608=>"\x8f\xad\xf6",
    0x6609=>"\xf5\xad",
    0x660d=>"",
    0x6611=>"",
    0x6612=>"",
    0x6615=>"\xf5\xae",
    0x6616=>"",
    0x661d=>"",
    0x661e=>"\xf5\xaf",
    0x6621=>"\x8f\xad\xf7",
    0x6622=>"\xf5\xb1",
    0x6623=>"",
    0x6624=>"\xf5\xb2",
    0x6626=>"",
    0x6629=>"",
    0x662a=>"\x8f\xad\xf8",
    0x662b=>"\xf5\xb3",
    0x662c=>"",
    0x662e=>"",
    0x6630=>"\xf5\xb4",
    0x6631=>"\xf5\xb5",
    0x6633=>"\xf5\xb6",
    0x6637=>"",
    0x6639=>"",
    0x663a=>"\xf5\xb0",
    0x6640=>"",
    0x6645=>"\x8f\xad\xf9",
    0x6646=>"",
    0x6648=>"\xf5\xb8",
    0x664a=>"",
    0x664c=>"\xf5\xb9",
    0x664e=>"\x8f\xad\xfb",
    0x6651=>"\x8f\xad\xfa",
    0x6657=>"\x8f\xad\xfe",
    0x6658=>"",
    0x6659=>"\xf5\xbb",
    0x665a=>"\xf5\xbc",
    0x665b=>"\x8f\xae\xa1",
    0x665c=>"",
    0x6660=>"",
    0x6661=>"\xf5\xbd",
    0x6663=>"\x8f\xae\xa2",
    0x6665=>"\xf5\xbe",
    0x666a=>"\x8f\xae\xa5",
    0x666b=>"\x8f\xae\xa6",
    0x666c=>"\x8f\xae\xa7",
    0x666d=>"\x8f\xae\xa8",
    0x6673=>"\xf5\xbf",
    0x6675=>"",
    0x6677=>"\xf5\xc0",
    0x6678=>"\xf5\xc1",
    0x6679=>"",
    0x667b=>"\x8f\xae\xa9",
    0x667c=>"",
    0x667e=>"",
    0x667f=>"",
    0x6680=>"\x8f\xae\xaa",
    0x668b=>"",
    0x668c=>"",
    0x668d=>"\xf5\xc2",
    0x6690=>"\x8f\xae\xab",
    0x6692=>"\x8f\xae\xac",
    0x6699=>"\x8f\xae\xad",
    0x669a=>"",
    0x669b=>"",
    0x669c=>"",
    0x669f=>"",
    0x66a0=>"\xf5\xc4",
    0x66a4=>"",
    0x66ad=>"\x8f\xae\xaf",
    0x66b1=>"\x8f\xae\xb0",
    0x66b2=>"\xf5\xc5",
    0x66b5=>"\x8f\xae\xb1",
    0x66bb=>"\xf5\xc6",
    0x66bf=>"\x8f\xae\xb3",
    0x66c0=>"",
    0x66c2=>"",
    0x66c3=>"",
    0x66c6=>"\xf5\xc7",
    0x66c8=>"\xf5\xc8",
    0x66cc=>"",
    0x66ce=>"",
    0x66cf=>"",
    0x66d4=>"",
    0x66db=>"\xf5\xca",
    0x66df=>"",
    0x66e8=>"\xf5\xcb",
    0x66eb=>"",
    0x66ec=>"\x8f\xae\xb5",
    0x66ee=>"",
    0x66fa=>"\xf5\xcc",
    0x66fb=>"\xf5\xb7",
    0x6701=>"\x8f\xae\xb7",
    0x6705=>"\x8f\xae\xb8",
    0x6707=>"",
    0x670e=>"",
    0x6712=>"\x8f\xae\xb9",
    0x6713=>"\xf5\xcd",
    0x6719=>"\x8f\xae\xbb",
    0x671c=>"",
    0x6720=>"",
    0x6722=>"",
    0x6733=>"\xf5\xcf",
    0x673e=>"",
    0x6745=>"",
    0x6747=>"\xf5\xd1",
    0x6748=>"\xf5\xd2",
    0x674c=>"\x8f\xae\xbe",
    0x674d=>"\x8f\xae\xbf",
    0x6754=>"\x8f\xae\xc0",
    0x6755=>"",
    0x675d=>"\x8f\xae\xc1",
    0x6766=>"\xf5\xd0",
    0x676c=>"",
    0x676e=>"",
    0x6774=>"\x8f\xae\xc5",
    0x6776=>"\x8f\xae\xc6",
    0x677b=>"\xf5\xd3",
    0x6781=>"\xf5\xd4",
    0x6784=>"",
    0x678e=>"",
    0x678f=>"",
    0x6791=>"",
    0x6792=>"\x8f\xae\xc8",
    0x6793=>"\xf5\xd5",
    0x6796=>"",
    0x6798=>"\xf5\xd6",
    0x6799=>"",
    0x679b=>"\xf5\xd7",
    0x67b0=>"\x8f\xae\xcc",
    0x67b1=>"",
    0x67b2=>"\x8f\xae\xcd",
    0x67b5=>"",
    0x67bb=>"\xf5\xd8",
    0x67bc=>"",
    0x67bd=>"",
    0x67c0=>"\xf5\xda",
    0x67c2=>"",
    0x67c3=>"\x8f\xae\xce",
    0x67c5=>"",
    0x67c8=>"\x8f\xae\xcf",
    0x67c9=>"",
    0x67d2=>"\x8f\xae\xd0",
    0x67d7=>"\xf5\xdb",
    0x67d9=>"\x8f\xae\xd1",
    0x67db=>"\x8f\xae\xd2",
    0x67dc=>"",
    0x67e1=>"",
    0x67e6=>"",
    0x67f0=>"\x8f\xae\xd3",
    0x67f2=>"",
    0x67f6=>"",
    0x67f7=>"\x8f\xae\xd4",
    0x67f9=>"\xf5\xd9",
    0x67fc=>"\xf5\xdc",
    0x6801=>"\xf5\xdd",
    0x6810=>"\x8f\xae\xcb",
    0x6814=>"",
    0x6818=>"\x8f\xae\xd8",
    0x6819=>"",
    0x681d=>"\xf5\xdf",
    0x681f=>"\x8f\xae\xd9",
    0x6827=>"",
    0x6828=>"",
    0x682c=>"\xf5\xe0",
    0x682d=>"\x8f\xae\xda",
    0x682f=>"",
    0x6830=>"",
    0x6831=>"\xf5\xe1",
    0x6833=>"\x8f\xae\xdc",
    0x683b=>"\x8f\xae\xdd",
    0x683e=>"\x8f\xae\xde",
    0x683f=>"",
    0x6844=>"\x8f\xae\xdf",
    0x6845=>"\x8f\xae\xe0",
    0x6849=>"\x8f\xae\xe1",
    0x684a=>"",
    0x684c=>"\x8f\xae\xe2",
    0x6852=>"\xf5\xde",
    0x6855=>"\x8f\xae\xe3",
    0x6857=>"\x8f\xae\xe4",
    0x6858=>"",
    0x685b=>"\xf5\xe2",
    0x686b=>"\x8f\xae\xe6",
    0x686e=>"\x8f\xae\xe7",
    0x686f=>"",
    0x6870=>"",
    0x6871=>"",
    0x6872=>"\xf5\xe3",
    0x6875=>"\xf5\xe4",
    0x6879=>"",
    0x687a=>"\x8f\xae\xe8",
    0x687b=>"",
    0x687c=>"\x8f\xae\xe9",
    0x6882=>"\x8f\xae\xea",
    0x6884=>"",
    0x6886=>"",
    0x6888=>"",
    0x6890=>"\x8f\xae\xeb",
    0x6896=>"\x8f\xae\xec",
    0x6898=>"\x8f\xae\xee",
    0x6899=>"\x8f\xae\xef",
    0x689a=>"\x8f\xae\xf0",
    0x689c=>"\x8f\xae\xf1",
    0x68a1=>"",
    0x68a3=>"\xf5\xe6",
    0x68a5=>"\xf5\xe7",
    0x68a9=>"",
    0x68aa=>"\x8f\xae\xf2",
    0x68ab=>"\x8f\xae\xf3",
    0x68ae=>"",
    0x68b2=>"\xf5\xe8",
    0x68b4=>"\x8f\xae\xf4",
    0x68bb=>"\x8f\xae\xf5",
    0x68c3=>"\x8f\xae\xfa",
    0x68c5=>"\x8f\xae\xfb",
    0x68c8=>"\xf5\xe9",
    0x68cc=>"\x8f\xae\xfc",
    0x68cf=>"\x8f\xae\xfd",
    0x68d0=>"\xf5\xea",
    0x68d1=>"",
    0x68d3=>"",
    0x68d6=>"\x8f\xae\xfe",
    0x68d9=>"\x8f\xaf\xa1",
    0x68dc=>"",
    0x68dd=>"",
    0x68e4=>"\x8f\xaf\xa2",
    0x68e5=>"\x8f\xaf\xa3",
    0x68e8=>"\xf5\xeb",
    0x68ea=>"",
    0x68eb=>"",
    0x68ec=>"\x8f\xaf\xa4",
    0x68ed=>"\xf5\xec",
    0x68f0=>"\xf5\xed",
    0x68f1=>"\xf5\xee",
    0x68f5=>"",
    0x68f6=>"",
    0x68f7=>"\x8f\xaf\xa5",
    0x68fb=>"\x8f\xae\xf6",
    0x68fc=>"\xf5\xef",
    0x68fd=>"",
    0x6903=>"\x8f\xaf\xa6",
    0x6906=>"",
    0x6907=>"\x8f\xaf\xa7",
    0x6909=>"",
    0x690a=>"\xf5\xf0",
    0x6910=>"",
    0x6911=>"",
    0x6913=>"",
    0x6916=>"",
    0x6917=>"",
    0x6931=>"",
    0x6933=>"",
    0x6935=>"\xf5\xf3",
    0x6938=>"",
    0x693b=>"\x8f\xaf\xab",
    0x6942=>"\xf5\xf4",
    0x6945=>"",
    0x6946=>"\x8f\xaf\xad",
    0x6949=>"\xf5\xf1",
    0x694e=>"",
    0x6957=>"\xf5\xf5",
    0x695b=>"",
    0x6963=>"\xf5\xf6",
    0x6964=>"\xf5\xf7",
    0x6965=>"",
    0x6966=>"",
    0x6968=>"\xf5\xf8",
    0x6969=>"\x8f\xaf\xae",
    0x696c=>"\x8f\xaf\xaf",
    0x6970=>"",
    0x6971=>"",
    0x6972=>"\x8f\xaf\xb0",
    0x697a=>"\x8f\xaf\xb1",
    0x697b=>"",
    0x697f=>"\x8f\xaf\xb2",
    0x6980=>"\xf5\xf9",
    0x698d=>"",
    0x6992=>"\x8f\xaf\xb3",
    0x6996=>"\x8f\xaf\xb5",
    0x6998=>"\x8f\xaf\xb6",
    0x69a1=>"",
    0x69a5=>"\xf5\xfb",
    0x69a6=>"\x8f\xaf\xb7",
    0x69a8=>"",
    0x69ab=>"",
    0x69ad=>"\xf5\xfc",
    0x69af=>"",
    0x69b0=>"\x8f\xaf\xb8",
    0x69b7=>"\x8f\xaf\xb9",
    0x69b8=>"",
    0x69ba=>"\x8f\xaf\xba",
    0x69bc=>"\x8f\xaf\xbb",
    0x69c0=>"\x8f\xaf\xbc",
    0x69c5=>"",
    0x69c8=>"",
    0x69cf=>"\xf5\xfd",
    0x69d1=>"\x8f\xaf\xbd",
    0x69d6=>"\x8f\xaf\xbe",
    0x69d7=>"",
    0x69e2=>"\xf6\xa2",
    0x69e3=>"\x8f\xaf\xc4",
    0x69e5=>"",
    0x69e9=>"\xf6\xa3",
    0x69ea=>"\xf6\xa4",
    0x69ee=>"\x8f\xaf\xc5",
    0x69ef=>"\x8f\xaf\xc6",
    0x69f1=>"",
    0x69f3=>"\x8f\xaf\xc7",
    0x69f4=>"\x8f\xaf\xc9",
    0x69f5=>"\xf6\xa5",
    0x69f6=>"\xf6\xa6",
    0x69fe=>"\x8f\xaf\xca",
    0x6a00=>"",
    0x6a01=>"",
    0x6a03=>"",
    0x6a0f=>"\xf6\xa7",
    0x6a11=>"\x8f\xaf\xcb",
    0x6a15=>"\xf6\xa8",
    0x6a1a=>"\x8f\xaf\xcc",
    0x6a1d=>"\x8f\xaf\xcd",
    0x6a20=>"",
    0x6a24=>"",
    0x6a28=>"",
    0x6a30=>"\x8f\xaf\xc1",
    0x6a32=>"\x8f\xaf\xcf",
    0x6a33=>"\x8f\xaf\xd0",
    0x6a34=>"\x8f\xaf\xd1",
    0x6a37=>"",
    0x6a3b=>"\xf6\xaa",
    0x6a3e=>"\xf6\xab",
    0x6a3f=>"\x8f\xaf\xd2",
    0x6a45=>"\xf6\xac",
    0x6a46=>"\x8f\xaf\xd3",
    0x6a49=>"\x8f\xaf\xd4",
    0x6a4a=>"",
    0x6a4e=>"\x8f\xaf\xd6",
    0x6a50=>"\xf6\xad",
    0x6a51=>"",
    0x6a52=>"\x8f\xaf\xd7",
    0x6a55=>"",
    0x6a56=>"\xf6\xae",
    0x6a5b=>"\xf6\xaf",
    0x6a64=>"\x8f\xaf\xd8",
    0x6a67=>"",
    0x6a6a=>"",
    0x6a6b=>"\xf6\xb0",
    0x6a71=>"",
    0x6a73=>"\xf6\xb1",
    0x6a7a=>"\x8f\xaf\xd5",
    0x6a7e=>"\x8f\xaf\xda",
    0x6a81=>"",
    0x6a83=>"\x8f\xaf\xdb",
    0x6a86=>"",
    0x6a87=>"",
    0x6a89=>"\xf6\xb3",
    0x6a8b=>"\x8f\xaf\xdc",
    0x6a91=>"\x8f\xaf\xde",
    0x6a94=>"\xf6\xb4",
    0x6a9b=>"",
    0x6a9d=>"\xf6\xb5",
    0x6a9e=>"\xf6\xb6",
    0x6a9f=>"\x8f\xaf\xdf",
    0x6aa1=>"\x8f\xaf\xe0",
    0x6aa5=>"\xf6\xb7",
    0x6aab=>"\x8f\xaf\xe2",
    0x6aaf=>"",
    0x6ab0=>"",
    0x6ab1=>"",
    0x6ab4=>"",
    0x6abd=>"\x8f\xaf\xe3",
    0x6abe=>"",
    0x6abf=>"",
    0x6ac6=>"\x8f\xaf\xe4",
    0x6ac8=>"",
    0x6ac9=>"",
    0x6acc=>"",
    0x6ad0=>"\x8f\xaf\xe6",
    0x6ad4=>"\x8f\xaf\xe5",
    0x6ad5=>"",
    0x6ad6=>"",
    0x6adc=>"\x8f\xaf\xe7",
    0x6add=>"\x8f\xaf\xe8",
    0x6ae4=>"\xf6\xb8",
    0x6ae7=>"\xf6\xb9",
    0x6aec=>"\x8f\xaf\xeb",
    0x6af0=>"",
    0x6af1=>"\x8f\xaf\xec",
    0x6af2=>"\x8f\xaf\xed",
    0x6af3=>"\x8f\xaf\xee",
    0x6afc=>"",
    0x6afd=>"\x8f\xaf\xef",
    0x6b02=>"",
    0x6b03=>"",
    0x6b06=>"",
    0x6b07=>"",
    0x6b09=>"",
    0x6b0b=>"\x8f\xaf\xf1",
    0x6b0f=>"\x8f\xaf\xf2",
    0x6b10=>"\x8f\xaf\xf3",
    0x6b11=>"\x8f\xaf\xf4",
    0x6b17=>"\x8f\xaf\xf6",
    0x6b1b=>"\xf6\xbc",
    0x6b1e=>"\xf6\xbd",
    0x6b24=>"",
    0x6b28=>"",
    0x6b2b=>"",
    0x6b2c=>"\xf6\xbe",
    0x6b2f=>"\x8f\xaf\xf8",
    0x6b35=>"\xf6\xbf",
    0x6b36=>"",
    0x6b3b=>"",
    0x6b3f=>"",
    0x6b46=>"\xf6\xc0",
    0x6b4a=>"\x8f\xaf\xf9",
    0x6b4d=>"",
    0x6b52=>"",
    0x6b56=>"\xf6\xc1",
    0x6b58=>"\x8f\xaf\xfa",
    0x6b5d=>"",
    0x6b60=>"\xf6\xc2",
    0x6b65=>"\xf6\xc3",
    0x6b67=>"\xf6\xc4",
    0x6b6b=>"",
    0x6b6c=>"\x8f\xaf\xfb",
    0x6b6e=>"",
    0x6b70=>"",
    0x6b75=>"\x8f\xaf\xfc",
    0x6b77=>"\xf6\xc5",
    0x6b7a=>"\x8f\xaf\xfd",
    0x6b7d=>"",
    0x6b7e=>"",
    0x6b81=>"\x8f\xaf\xfe",
    0x6b82=>"\xf6\xc6",
    0x6b85=>"",
    0x6b97=>"",
    0x6b9b=>"\x8f\xee\xa1",
    0x6b9f=>"",
    0x6ba0=>"",
    0x6ba2=>"",
    0x6ba3=>"",
    0x6ba8=>"",
    0x6ba9=>"\xf6\xc7",
    0x6bac=>"",
    0x6bad=>"\xf6\xc8",
    0x6bae=>"\x8f\xee\xa2",
    0x6bb0=>"",
    0x6bb8=>"",
    0x6bb9=>"",
    0x6bbd=>"\x8f\xee\xa4",
    0x6bbe=>"\x8f\xee\xa5",
    0x6bc3=>"",
    0x6bc4=>"",
    0x6bc7=>"\x8f\xee\xa6",
    0x6bc8=>"\x8f\xee\xa7",
    0x6bc9=>"\x8f\xee\xa8",
    0x6bcc=>"",
    0x6bcf=>"\xf6\xca",
    0x6bd6=>"\xf6\xcb",
    0x6bd7=>"\xf6\xcc",
    0x6bda=>"\x8f\xee\xa9",
    0x6be1=>"",
    0x6be3=>"",
    0x6be6=>"\x8f\xee\xaa",
    0x6be7=>"\x8f\xee\xab",
    0x6bee=>"\x8f\xee\xac",
    0x6bf1=>"\x8f\xee\xad",
    0x6bf7=>"",
    0x6bf9=>"",
    0x6bff=>"\xf6\xcd",
    0x6c02=>"\x8f\xee\xae",
    0x6c04=>"",
    0x6c05=>"\xf6\xce",
    0x6c09=>"",
    0x6c0a=>"\x8f\xee\xaf",
    0x6c0d=>"",
    0x6c0e=>"\x8f\xee\xb0",
    0x6c10=>"\xf6\xcf",
    0x6c12=>"",
    0x6c19=>"",
    0x6c1f=>"",
    0x6c26=>"",
    0x6c27=>"",
    0x6c28=>"",
    0x6c2c=>"",
    0x6c2e=>"",
    0x6c33=>"\xf6\xd0",
    0x6c35=>"\x8f\xee\xb1",
    0x6c36=>"\x8f\xee\xb2",
    0x6c3a=>"\x8f\xee\xb3",
    0x6c3b=>"",
    0x6c3f=>"\x8f\xee\xb5",
    0x6c4a=>"",
    0x6c4b=>"",
    0x6c4d=>"\x8f\xee\xb6",
    0x6c4f=>"",
    0x6c52=>"",
    0x6c54=>"",
    0x6c59=>"\xf6\xd1",
    0x6c5b=>"\x8f\xee\xb7",
    0x6c5c=>"\xf6\xd2",
    0x6c67=>"\x8f\xee\xcf",
    0x6c6b=>"",
    0x6c6d=>"\x8f\xee\xb8",
    0x6c6f=>"",
    0x6c74=>"\xf6\xd4",
    0x6c76=>"\xf6\xd5",
    0x6c78=>"",
    0x6c79=>"",
    0x6c7b=>"",
    0x6c84=>"\x8f\xee\xb9",
    0x6c85=>"\xf6\xd6",
    0x6c86=>"\xf6\xd7",
    0x6c87=>"",
    0x6c89=>"\x8f\xee\xba",
    0x6c94=>"\x8f\xee\xbc",
    0x6c95=>"\x8f\xee\xbd",
    0x6c97=>"\x8f\xee\xbe",
    0x6c98=>"\xf6\xd8",
    0x6c9c=>"\xf6\xd9",
    0x6c9f=>"",
    0x6caa=>"\xf6\xd3",
    0x6cad=>"\x8f\xee\xbf",
    0x6cb0=>"",
    0x6cb2=>"",
    0x6cb4=>"",
    0x6cc2=>"\x8f\xee\xc0",
    0x6cc6=>"\xf6\xdb",
    0x6ccd=>"",
    0x6ccf=>"",
    0x6cd0=>"\x8f\xee\xc1",
    0x6cd1=>"",
    0x6cd2=>"",
    0x6cd4=>"\xf6\xdc",
    0x6cd6=>"\x8f\xee\xc3",
    0x6cda=>"\x8f\xee\xc4",
    0x6cdc=>"\x8f\xee\xc5",
    0x6ce0=>"\xf6\xdd",
    0x6ce7=>"",
    0x6ce9=>"\x8f\xee\xc6",
    0x6ceb=>"\xf6\xde",
    0x6cec=>"\x8f\xee\xc7",
    0x6ced=>"\x8f\xee\xc8",
    0x6cee=>"\xf6\xdf",
    0x6cf2=>"",
    0x6cf4=>"",
    0x6cfb=>"\xf6\xda",
    0x6d00=>"\x8f\xee\xca",
    0x6d04=>"\xf6\xe1",
    0x6d07=>"",
    0x6d0a=>"\x8f\xee\xcb",
    0x6d0e=>"\xf6\xe2",
    0x6d0f=>"",
    0x6d11=>"",
    0x6d13=>"",
    0x6d1a=>"",
    0x6d24=>"\x8f\xee\xcc",
    0x6d26=>"\x8f\xee\xcd",
    0x6d27=>"\x8f\xee\xce",
    0x6d28=>"",
    0x6d2e=>"\xf6\xe3",
    0x6d2f=>"\x8f\xee\xd0",
    0x6d31=>"\xf6\xe4",
    0x6d34=>"\x8f\xee\xe5",
    0x6d39=>"\xf6\xe5",
    0x6d3c=>"\x8f\xee\xd1",
    0x6d3f=>"\xf6\xe6",
    0x6d57=>"",
    0x6d58=>"\xf6\xe7",
    0x6d5b=>"\x8f\xee\xd2",
    0x6d5e=>"\x8f\xee\xd3",
    0x6d5f=>"",
    0x6d60=>"\x8f\xee\xd4",
    0x6d61=>"",
    0x6d65=>"\xf6\xe8",
    0x6d67=>"",
    0x6d6f=>"",
    0x6d70=>"\x8f\xee\xd5",
    0x6d7c=>"",
    0x6d80=>"\x8f\xee\xd6",
    0x6d81=>"\x8f\xee\xd7",
    0x6d82=>"\xf6\xea",
    0x6d87=>"\xf6\xeb",
    0x6d89=>"\xf6\xec",
    0x6d8a=>"\x8f\xee\xd8",
    0x6d8d=>"\x8f\xee\xd9",
    0x6d91=>"\x8f\xee\xda",
    0x6d92=>"",
    0x6d94=>"\xf6\xed",
    0x6d96=>"",
    0x6d97=>"",
    0x6d98=>"\x8f\xee\xdb",
    0x6daa=>"\xf6\xee",
    0x6dab=>"\x8f\xee\xe1",
    0x6dac=>"\xf6\xef",
    0x6dae=>"\x8f\xee\xe2",
    0x6db4=>"\x8f\xee\xe3",
    0x6db7=>"",
    0x6db9=>"",
    0x6dbd=>"",
    0x6dbf=>"\xf6\xf0",
    0x6dc2=>"\x8f\xee\xe4",
    0x6dc4=>"\xf6\xf1",
    0x6dc8=>"\x8f\xee\xe6",
    0x6dca=>"",
    0x6dce=>"\x8f\xee\xe7",
    0x6dcf=>"\x8f\xee\xe8",
    0x6dd0=>"\x8f\xee\xe9",
    0x6dd6=>"\xf6\xf2",
    0x6dda=>"\xf6\xf3",
    0x6ddb=>"\xf6\xf4",
    0x6ddd=>"\xf6\xf5",
    0x6ddf=>"\x8f\xee\xea",
    0x6de0=>"",
    0x6de2=>"",
    0x6de5=>"",
    0x6de9=>"\x8f\xee\xeb",
    0x6def=>"",
    0x6df0=>"",
    0x6df4=>"",
    0x6df6=>"\x8f\xee\xec",
    0x6dfc=>"\xf6\xf6",
    0x6e00=>"",
    0x6e04=>"",
    0x6e17=>"\x8f\xee\xdd",
    0x6e1e=>"\x8f\xee\xee",
    0x6e22=>"\x8f\xee\xef",
    0x6e27=>"\x8f\xee\xf0",
    0x6e32=>"\x8f\xee\xf2",
    0x6e34=>"\xf6\xf8",
    0x6e36=>"\x8f\xee\xed",
    0x6e39=>"",
    0x6e3b=>"",
    0x6e3c=>"\x8f\xee\xf3",
    0x6e44=>"\xf6\xf9",
    0x6e45=>"",
    0x6e48=>"\x8f\xee\xf4",
    0x6e49=>"\x8f\xee\xf5",
    0x6e4b=>"\x8f\xee\xf6",
    0x6e4c=>"\x8f\xee\xf7",
    0x6e4f=>"\x8f\xee\xf8",
    0x6e51=>"\x8f\xee\xf9",
    0x6e52=>"",
    0x6e53=>"\x8f\xee\xfa",
    0x6e54=>"\x8f\xee\xfb",
    0x6e57=>"\x8f\xee\xfc",
    0x6e5c=>"\xf6\xfa",
    0x6e5d=>"",
    0x6e5e=>"\xf6\xfb",
    0x6e62=>"",
    0x6e63=>"\x8f\xee\xfd",
    0x6e68=>"",
    0x6e73=>"",
    0x6e7b=>"",
    0x6e7d=>"",
    0x6e8d=>"",
    0x6e93=>"\x8f\xef\xa1",
    0x6e99=>"",
    0x6ea0=>"",
    0x6ea7=>"\x8f\xef\xa2",
    0x6eab=>"\xf6\xfc",
    0x6ead=>"",
    0x6eae=>"",
    0x6eb1=>"\xf6\xfd",
    0x6eb3=>"",
    0x6eb4=>"\x8f\xef\xa3",
    0x6ebb=>"",
    0x6ebf=>"\x8f\xef\xa4",
    0x6ec0=>"",
    0x6ec1=>"\xf6\xfe",
    0x6ec3=>"\x8f\xef\xa5",
    0x6ec7=>"\xf7\xa1",
    0x6ec8=>"",
    0x6eca=>"\x8f\xef\xa6",
    0x6ecd=>"",
    0x6ece=>"\xf7\xa2",
    0x6ecf=>"",
    0x6ed9=>"\x8f\xef\xa7",
    0x6eeb=>"\x8f\xef\xa9",
    0x6eed=>"",
    0x6eee=>"",
    0x6ef9=>"\x8f\xef\xaa",
    0x6efb=>"\x8f\xef\xab",
    0x6efd=>"",
    0x6f04=>"",
    0x6f08=>"",
    0x6f0a=>"\x8f\xef\xac",
    0x6f0c=>"\x8f\xef\xad",
    0x6f0d=>"",
    0x6f10=>"\xf7\xa3",
    0x6f16=>"",
    0x6f18=>"\x8f\xef\xae",
    0x6f1a=>"\xf7\xa4",
    0x6f1b=>"",
    0x6f25=>"\x8f\xef\xaf",
    0x6f26=>"",
    0x6f29=>"",
    0x6f2a=>"\xf7\xa6",
    0x6f2d=>"",
    0x6f2f=>"\xf7\xa7",
    0x6f30=>"",
    0x6f33=>"\xf7\xa8",
    0x6f35=>"\x8f\xef\xa8",
    0x6f36=>"\x8f\xef\xb0",
    0x6f3b=>"",
    0x6f3c=>"\x8f\xef\xb1",
    0x6f4f=>"",
    0x6f51=>"\xf7\xa9",
    0x6f52=>"\x8f\xef\xb3",
    0x6f53=>"",
    0x6f57=>"\x8f\xef\xb4",
    0x6f59=>"\xf7\xaa",
    0x6f5a=>"\x8f\xef\xb5",
    0x6f5d=>"",
    0x6f5e=>"\xf7\xab",
    0x6f60=>"\x8f\xef\xb6",
    0x6f61=>"\xf7\xac",
    0x6f62=>"\xf7\xad",
    0x6f68=>"\x8f\xef\xb7",
    0x6f6c=>"",
    0x6f7d=>"\x8f\xef\xb9",
    0x6f7e=>"\xf7\xae",
    0x6f83=>"",
    0x6f87=>"",
    0x6f88=>"\xf7\xaf",
    0x6f8b=>"",
    0x6f8c=>"\xf7\xb0",
    0x6f8d=>"\xf7\xb1",
    0x6f90=>"\x8f\xef\xba",
    0x6f92=>"",
    0x6f93=>"",
    0x6f94=>"\xf7\xb2",
    0x6f96=>"\x8f\xef\xbb",
    0x6f98=>"\x8f\xef\xb8",
    0x6f9a=>"",
    0x6f9f=>"\x8f\xef\xbd",
    0x6fa0=>"\xf7\xb3",
    0x6fa5=>"\x8f\xef\xbe",
    0x6fa6=>"",
    0x6fa7=>"\xf7\xb4",
    0x6fa8=>"",
    0x6fae=>"",
    0x6faf=>"\x8f\xef\xbf",
    0x6fb0=>"",
    0x6fb5=>"\x8f\xef\xc1",
    0x6fb6=>"\xf7\xb5",
    0x6fbc=>"\xf7\xb6",
    0x6fbe=>"\x8f\xef\xbc",
    0x6fc5=>"",
    0x6fc7=>"\xf7\xb7",
    0x6fc8=>"\x8f\xef\xc2",
    0x6fc9=>"\x8f\xef\xc3",
    0x6fca=>"\xf7\xb8",
    0x6fda=>"\x8f\xef\xc4",
    0x6fde=>"\x8f\xef\xc5",
    0x6fe8=>"",
    0x6fe9=>"\x8f\xef\xc6",
    0x6ff0=>"\xf7\xba",
    0x6ff5=>"\xf7\xbb",
    0x6ff9=>"\xf7\xb9",
    0x6ffc=>"\x8f\xef\xc8",
    0x6ffd=>"",
    0x7000=>"\x8f\xef\xc9",
    0x7005=>"\xf7\xbc",
    0x7006=>"\xf7\xbd",
    0x7007=>"\x8f\xef\xca",
    0x700a=>"\x8f\xef\xcb",
    0x700d=>"",
    0x7017=>"",
    0x7020=>"",
    0x7023=>"\x8f\xef\xcc",
    0x7028=>"\xf7\xbe",
    0x702f=>"",
    0x7034=>"",
    0x7037=>"",
    0x7039=>"\x8f\xef\xce",
    0x703a=>"\x8f\xef\xcf",
    0x703c=>"\x8f\xef\xd0",
    0x7043=>"\x8f\xef\xd1",
    0x7044=>"",
    0x7047=>"\x8f\xef\xd2",
    0x7048=>"",
    0x7049=>"",
    0x704a=>"\xf7\xbf",
    0x704b=>"\x8f\xef\xd3",
    0x704e=>"\xf7\xc2",
    0x7054=>"\x8f\xef\xd5",
    0x7055=>"",
    0x705d=>"\xf7\xc0",
    0x705e=>"\xf7\xc1",
    0x7064=>"\xf7\xc3",
    0x7065=>"\x8f\xef\xd6",
    0x7069=>"\x8f\xef\xd7",
    0x706c=>"\x8f\xef\xd8",
    0x706e=>"\x8f\xef\xd9",
    0x7075=>"\xf7\xc4",
    0x7076=>"\x8f\xef\xda",
    0x707e=>"\x8f\xef\xdb",
    0x7081=>"\x8f\xef\xdc",
    0x7085=>"\xf7\xc5",
    0x7086=>"\x8f\xef\xdd",
    0x7094=>"",
    0x7095=>"\x8f\xef\xde",
    0x7096=>"",
    0x7097=>"\x8f\xef\xdf",
    0x7098=>"",
    0x709b=>"",
    0x709f=>"\x8f\xef\xe2",
    0x70a4=>"\xf7\xc6",
    0x70ab=>"\xf7\xc7",
    0x70b0=>"",
    0x70b1=>"\x8f\xef\xe3",
    0x70b4=>"",
    0x70b7=>"\xf7\xc8",
    0x70bb=>"\x8f\xef\xe0",
    0x70ca=>"\x8f\xef\xe6",
    0x70d1=>"\x8f\xef\xe7",
    0x70d3=>"\x8f\xef\xe8",
    0x70d4=>"\xf7\xc9",
    0x70d5=>"",
    0x70d6=>"",
    0x70d8=>"\xf7\xca",
    0x70dc=>"\x8f\xef\xe9",
    0x70e4=>"\xf7\xcb",
    0x70ec=>"\x8f\xef\xe5",
    0x70fa=>"",
    0x7103=>"\x8f\xef\xea",
    0x7104=>"\x8f\xef\xeb",
    0x7105=>"",
    0x7106=>"\x8f\xef\xec",
    0x7107=>"\x8f\xef\xed",
    0x7108=>"\x8f\xef\xee",
    0x710b=>"",
    0x710c=>"\x8f\xef\xef",
    0x710f=>"\xf7\xcc",
    0x711e=>"\xf7\xce",
    0x7120=>"\xf7\xcf",
    0x712b=>"\xf7\xcd",
    0x712d=>"",
    0x712e=>"\xf7\xd0",
    0x712f=>"\x8f\xef\xf1",
    0x7130=>"\xf7\xd1",
    0x7131=>"\x8f\xef\xf2",
    0x7138=>"",
    0x7141=>"",
    0x7145=>"",
    0x7146=>"\xf7\xd2",
    0x7147=>"\xf7\xd3",
    0x714a=>"\x8f\xef\xf4",
    0x714b=>"",
    0x7150=>"\x8f\xef\xf3",
    0x7151=>"\xf7\xd4",
    0x7152=>"\xf7\xd6",
    0x7153=>"\x8f\xef\xf5",
    0x7157=>"",
    0x715a=>"",
    0x715c=>"\xf7\xd7",
    0x715e=>"\x8f\xef\xf6",
    0x7160=>"\xf7\xd8",
    0x7168=>"\xf7\xd9",
    0x7179=>"",
    0x7180=>"\x8f\xef\xf9",
    0x7185=>"\xf7\xdb",
    0x7187=>"\xf7\xdc",
    0x718c=>"",
    0x7192=>"\xf7\xdd",
    0x7196=>"\x8f\xef\xf8",
    0x719a=>"",
    0x719b=>"\x8f\xef\xfa",
    0x71a0=>"\x8f\xef\xfb",
    0x71a2=>"\x8f\xef\xfc",
    0x71ae=>"\x8f\xef\xfd",
    0x71af=>"\x8f\xef\xfe",
    0x71b0=>"",
    0x71b2=>"",
    0x71b3=>"\x8f\xf0\xa1",
    0x71ba=>"\xf7\xdf",
    0x71bf=>"",
    0x71c0=>"",
    0x71c1=>"\xf7\xde",
    0x71c4=>"\xf7\xe0",
    0x71cb=>"\x8f\xf0\xa3",
    0x71cc=>"",
    0x71d3=>"\x8f\xf0\xa4",
    0x71d6=>"",
    0x71d9=>"\x8f\xf0\xa5",
    0x71da=>"",
    0x71dc=>"\x8f\xf0\xa6",
    0x71f8=>"",
    0x71fe=>"\xf7\xe1",
    0x7200=>"\xf7\xe2",
    0x7207=>"\x8f\xf0\xa7",
    0x7208=>"",
    0x7209=>"",
    0x7213=>"",
    0x7215=>"\xf7\xe3",
    0x7217=>"",
    0x721a=>"",
    0x721d=>"",
    0x721f=>"",
    0x7224=>"",
    0x722b=>"\x8f\xf0\xaa",
    0x722f=>"",
    0x7234=>"\x8f\xf0\xab",
    0x7238=>"\x8f\xf0\xac",
    0x7239=>"\x8f\xf0\xad",
    0x7241=>"",
    0x7242=>"\x8f\xf0\xaf",
    0x7243=>"",
    0x7245=>"",
    0x724e=>"",
    0x724f=>"",
    0x7250=>"",
    0x7253=>"\x8f\xf0\xb0",
    0x7255=>"\xf7\xe4",
    0x7256=>"\xf7\xe5",
    0x7257=>"\x8f\xf0\xb1",
    0x725a=>"",
    0x725c=>"",
    0x725e=>"",
    0x7260=>"",
    0x7263=>"\x8f\xf0\xb2",
    0x7268=>"",
    0x726b=>"",
    0x726e=>"\x8f\xf0\xb4",
    0x726f=>"\x8f\xf0\xb5",
    0x7271=>"",
    0x7277=>"",
    0x7278=>"\x8f\xf0\xb6",
    0x727b=>"",
    0x727c=>"",
    0x727f=>"\x8f\xf0\xb7",
    0x7284=>"",
    0x7289=>"",
    0x728d=>"\xf7\xe7",
    0x728e=>"\x8f\xf0\xb8",
    0x7293=>"",
    0x729b=>"\xf7\xe8",
    0x72a8=>"",
    0x72ad=>"\x8f\xf0\xba",
    0x72ae=>"\x8f\xf0\xbb",
    0x72b0=>"\x8f\xf0\xbc",
    0x72b1=>"\x8f\xf0\xbd",
    0x72b4=>"",
    0x72be=>"\xf7\xe9",
    0x72c0=>"\xf7\xea",
    0x72c1=>"\x8f\xf0\xbe",
    0x72c7=>"",
    0x72c9=>"",
    0x72cc=>"\x8f\xf0\xc0",
    0x72d5=>"",
    0x72d6=>"",
    0x72d8=>"",
    0x72df=>"",
    0x72e5=>"",
    0x72f3=>"\x8f\xf0\xc3",
    0x72f4=>"",
    0x72fa=>"\x8f\xf0\xc4",
    0x72fb=>"\xf7\xeb",
    0x72fe=>"",
    0x7302=>"",
    0x7304=>"",
    0x7305=>"",
    0x7307=>"\x8f\xf0\xc5",
    0x730b=>"",
    0x730d=>"",
    0x7312=>"\x8f\xf0\xc6",
    0x7313=>"",
    0x7318=>"\x8f\xf0\xc7",
    0x7319=>"\x8f\xf0\xc8",
    0x731e=>"",
    0x7322=>"",
    0x7324=>"",
    0x7327=>"\xf7\xed",
    0x7328=>"\xf7\xee",
    0x732c=>"\x8f\xf0\xcb",
    0x7331=>"\x8f\xf0\xcc",
    0x7332=>"",
    0x7333=>"\x8f\xf0\xcd",
    0x7335=>"",
    0x7339=>"\x8f\xf0\xca",
    0x733a=>"",
    0x733b=>"",
    0x733d=>"\x8f\xf0\xce",
    0x7343=>"",
    0x734d=>"",
    0x7350=>"\xf7\xf0",
    0x7352=>"\x8f\xf0\xcf",
    0x7356=>"",
    0x7358=>"",
    0x735d=>"",
    0x735e=>"",
    0x735f=>"",
    0x7360=>"",
    0x7366=>"\xf7\xf1",
    0x7367=>"",
    0x7369=>"",
    0x736b=>"\x8f\xf0\xd1",
    0x736c=>"\x8f\xf0\xd2",
    0x736e=>"\x8f\xf0\xd4",
    0x736f=>"\x8f\xf0\xd5",
    0x7371=>"\x8f\xf0\xd6",
    0x7377=>"\x8f\xf0\xd7",
    0x7379=>"",
    0x737c=>"\xf7\xf2",
    0x7380=>"",
    0x7381=>"\x8f\xf0\xd8",
    0x7383=>"",
    0x7385=>"\x8f\xf0\xd9",
    0x7386=>"",
    0x738a=>"\x8f\xf0\xda",
    0x738e=>"",
    0x7390=>"",
    0x7393=>"",
    0x7394=>"\x8f\xf0\xdb",
    0x7395=>"\xf7\xf3",
    0x7397=>"",
    0x7398=>"\x8f\xf0\xdc",
    0x739c=>"\x8f\xf0\xdd",
    0x739e=>"\x8f\xf0\xde",
    0x739f=>"\xf7\xf4",
    0x73a0=>"\xf7\xf5",
    0x73a2=>"\xf7\xf6",
    0x73a5=>"\x8f\xf0\xdf",
    0x73a6=>"\xf7\xf7",
    0x73a8=>"\x8f\xf0\xe0",
    0x73aa=>"",
    0x73ab=>"\xf7\xf8",
    0x73ad=>"",
    0x73b5=>"\x8f\xf0\xe1",
    0x73b7=>"\x8f\xf0\xe2",
    0x73b9=>"\x8f\xf0\xe3",
    0x73bc=>"\x8f\xf0\xe4",
    0x73bd=>"",
    0x73bf=>"\x8f\xf0\xe5",
    0x73c5=>"\x8f\xf0\xe6",
    0x73c6=>"",
    0x73c9=>"\xf7\xf9",
    0x73cb=>"\x8f\xf0\xe7",
    0x73cc=>"",
    0x73cf=>"\xf7\xfa",
    0x73d2=>"",
    0x73d3=>"",
    0x73d6=>"\xf7\xfb",
    0x73d9=>"\xf7\xfc",
    0x73dd=>"",
    0x73e1=>"\x8f\xf0\xe8",
    0x73e3=>"\xf7\xfd",
    0x73e6=>"",
    0x73e7=>"\x8f\xf0\xe9",
    0x73e9=>"\xf7\xfe",
    0x73f4=>"",
    0x73f5=>"",
    0x73f7=>"",
    0x73f9=>"\x8f\xf0\xea",
    0x73fa=>"\x8f\xf0\xec",
    0x73fb=>"",
    0x73fd=>"",
    0x73ff=>"",
    0x7400=>"",
    0x7401=>"\x8f\xf0\xed",
    0x7404=>"",
    0x7407=>"\xf8\xa1",
    0x740a=>"\xf8\xa2",
    0x7411=>"",
    0x7413=>"\x8f\xf0\xeb",
    0x741a=>"\xf8\xa3",
    0x741b=>"\xf8\xa4",
    0x7424=>"\x8f\xf0\xee",
    0x7426=>"\xf8\xa6",
    0x7428=>"\xf8\xa7",
    0x7429=>"",
    0x742a=>"\xf8\xa8",
    0x742b=>"\xf8\xa9",
    0x742c=>"\xf8\xaa",
    0x742d=>"",
    0x742e=>"\xf8\xab",
    0x742f=>"\xf8\xac",
    0x7430=>"\xf8\xad",
    0x7431=>"\x8f\xf0\xef",
    0x7439=>"\x8f\xf0\xf0",
    0x7440=>"\x8f\xf0\xf2",
    0x7443=>"\x8f\xf0\xf3",
    0x7444=>"\xf8\xae",
    0x7446=>"\xf8\xaf",
    0x7447=>"\xf8\xb0",
    0x744b=>"\xf8\xb1",
    0x744d=>"\x8f\xf0\xf4",
    0x7451=>"",
    0x7452=>"\x8f\xf0\xf5",
    0x7453=>"\x8f\xf0\xf1",
    0x7457=>"\xf8\xb2",
    0x745d=>"\x8f\xf0\xf6",
    0x7462=>"\xf8\xb3",
    0x7466=>"",
    0x7467=>"",
    0x7468=>"",
    0x746b=>"\xf8\xb4",
    0x746d=>"\xf8\xb5",
    0x746e=>"",
    0x7471=>"\x8f\xf0\xf7",
    0x7472=>"",
    0x7480=>"",
    0x7481=>"\x8f\xf0\xf8",
    0x7485=>"\x8f\xf0\xf9",
    0x7486=>"\xf8\xb6",
    0x7487=>"\xf8\xb7",
    0x7488=>"\x8f\xf0\xfa",
    0x7489=>"\xf8\xb8",
    0x748f=>"",
    0x7490=>"\xf8\xbd",
    0x7491=>"",
    0x7492=>"\x8f\xf0\xfc",
    0x7497=>"\x8f\xf0\xfd",
    0x7498=>"\xf8\xb9",
    0x7499=>"\x8f\xf0\xfe",
    0x749a=>"",
    0x749c=>"\xf8\xba",
    0x749f=>"\xf8\xbb",
    0x74a0=>"\x8f\xf1\xa1",
    0x74a1=>"\x8f\xf1\xa2",
    0x74a3=>"\xf8\xbc",
    0x74a5=>"\x8f\xf1\xa3",
    0x74a6=>"\xf8\xbe",
    0x74a8=>"\xf8\xbf",
    0x74a9=>"\xf8\xc0",
    0x74aa=>"\x8f\xf1\xa4",
    0x74ab=>"\x8f\xf1\xa5",
    0x74ae=>"",
    0x74af=>"",
    0x74b1=>"",
    0x74b2=>"",
    0x74b5=>"\xf8\xc1",
    0x74b9=>"\x8f\xf1\xa6",
    0x74ba=>"\x8f\xf1\xa8",
    0x74bb=>"\x8f\xf1\xa7",
    0x74bf=>"\xf8\xc2",
    0x74c8=>"\xf8\xc3",
    0x74c9=>"\xf8\xc4",
    0x74cc=>"",
    0x74d0=>"",
    0x74d3=>"",
    0x74d6=>"\x8f\xf1\xa9",
    0x74d8=>"\x8f\xf1\xaa",
    0x74da=>"\xf8\xc5",
    0x74db=>"",
    0x74de=>"\x8f\xf1\xab",
    0x74df=>"",
    0x74e4=>"",
    0x74e8=>"",
    0x74ea=>"",
    0x74eb=>"\x8f\xf1\xad",
    0x74ef=>"\x8f\xf1\xac",
    0x74f4=>"",
    0x74fa=>"\x8f\xf1\xaf",
    0x74fb=>"",
    0x74fc=>"",
    0x74ff=>"\xf8\xc6",
    0x7501=>"\xf8\xc7",
    0x7506=>"",
    0x7512=>"",
    0x7516=>"",
    0x7517=>"\xf8\xc8",
    0x7520=>"\x8f\xf1\xb1",
    0x7521=>"",
    0x7524=>"\x8f\xf1\xb2",
    0x7527=>"",
    0x7529=>"",
    0x752a=>"\x8f\xf1\xb3",
    0x752f=>"\xf8\xc9",
    0x7536=>"",
    0x7539=>"",
    0x753d=>"\x8f\xf1\xb6",
    0x753e=>"\x8f\xf1\xb7",
    0x753f=>"",
    0x7540=>"\x8f\xf1\xb8",
    0x7543=>"",
    0x7547=>"",
    0x7548=>"\x8f\xf1\xb9",
    0x754e=>"\x8f\xf1\xba",
    0x7550=>"\x8f\xf1\xbb",
    0x7552=>"\x8f\xf1\xbc",
    0x7557=>"",
    0x755e=>"",
    0x755f=>"",
    0x7561=>"",
    0x756c=>"\x8f\xf1\xbd",
    0x756f=>"\xf8\xca",
    0x7571=>"\x8f\xf1\xbf",
    0x7572=>"\x8f\xf1\xbe",
    0x7579=>"\xf8\xcb",
    0x757a=>"\x8f\xf1\xc0",
    0x757b=>"",
    0x757c=>"",
    0x757d=>"\x8f\xf1\xc1",
    0x757e=>"\x8f\xf1\xc2",
    0x7581=>"\x8f\xf1\xc3",
    0x7585=>"",
    0x758c=>"\x8f\xf1\xc5",
    0x7590=>"",
    0x7592=>"\xf8\xcc",
    0x7593=>"",
    0x7595=>"",
    0x7599=>"",
    0x759c=>"",
    0x75a2=>"\x8f\xf1\xc7",
    0x75a4=>"",
    0x75b0=>"\x8f\xf1\xc9",
    0x75b4=>"",
    0x75b7=>"\x8f\xf1\xca",
    0x75ba=>"",
    0x75bf=>"\x8f\xf1\xcb",
    0x75c0=>"\x8f\xf1\xcc",
    0x75c1=>"",
    0x75c4=>"",
    0x75c6=>"\x8f\xf1\xcd",
    0x75cc=>"",
    0x75ce=>"\xf8\xce",
    0x75cf=>"\x8f\xf1\xce",
    0x75d3=>"\x8f\xf1\xcf",
    0x75d7=>"",
    0x75dc=>"",
    0x75dd=>"\x8f\xf1\xd0",
    0x75df=>"\x8f\xf1\xd1",
    0x75e0=>"\x8f\xf1\xd2",
    0x75e1=>"",
    0x75e4=>"\xf8\xcf",
    0x75e7=>"\x8f\xf1\xd3",
    0x75ec=>"\x8f\xf1\xd4",
    0x75ee=>"\x8f\xf1\xd5",
    0x75ef=>"",
    0x75f1=>"\x8f\xf1\xd6",
    0x75f9=>"\x8f\xf1\xd7",
    0x7600=>"\xf8\xd0",
    0x7602=>"\xf8\xd1",
    0x7603=>"\x8f\xf1\xd8",
    0x7604=>"",
    0x7607=>"\x8f\xf1\xda",
    0x7608=>"\xf8\xd2",
    0x760a=>"",
    0x760c=>"",
    0x760f=>"\x8f\xf1\xdb",
    0x7612=>"",
    0x7613=>"\x8f\xf1\xde",
    0x7615=>"\xf8\xd3",
    0x7616=>"\xf8\xd4",
    0x7618=>"\x8f\xf1\xd9",
    0x7619=>"\xf8\xd5",
    0x761b=>"\x8f\xf1\xdf",
    0x761c=>"\x8f\xf1\xe0",
    0x761d=>"",
    0x761e=>"\xf8\xd6",
    0x7623=>"",
    0x7625=>"\x8f\xf1\xe2",
    0x7626=>"\xfe\xfd", # [2004]
    0x7628=>"\x8f\xf1\xe3",
    0x7629=>"",
    0x762d=>"\xf8\xd7",
    0x7632=>"",
    0x7633=>"\x8f\xf1\xe5",
    0x7635=>"\xf8\xd8",
    0x7638=>"",
    0x7639=>"",
    0x763a=>"",
    0x763c=>"\x8f\xf1\xe4",
    0x7640=>"",
    0x7641=>"\x8f\xf1\xe8",
    0x7643=>"\xf8\xd9",
    0x7644=>"",
    0x7645=>"",
    0x7649=>"\x8f\xf1\xea",
    0x764a=>"",
    0x764b=>"\xf8\xda",
    0x7655=>"\x8f\xf1\xeb",
    0x7659=>"",
    0x765f=>"",
    0x7664=>"\xf8\xdb",
    0x7665=>"\xf8\xdc",
    0x766d=>"\xf8\xdd",
    0x766e=>"\x8f\xf1\xed",
    0x766f=>"\xf8\xde",
    0x7671=>"\xf8\xdf",
    0x7674=>"",
    0x7681=>"\xf8\xe0",
    0x7685=>"",
    0x768c=>"",
    0x768d=>"",
    0x7695=>"\x8f\xf1\xee",
    0x769b=>"\xf8\xe1",
    0x769c=>"\x8f\xf1\xef",
    0x769d=>"\xf8\xe2",
    0x769e=>"\xf8\xe3",
    0x769f=>"",
    0x76a0=>"\x8f\xf1\xf1",
    0x76a1=>"\x8f\xf1\xf0",
    0x76a2=>"",
    0x76a3=>"",
    0x76a4=>"",
    0x76a5=>"",
    0x76a6=>"\xf8\xe4",
    0x76a7=>"\x8f\xf1\xf2",
    0x76a8=>"\x8f\xf1\xf3",
    0x76aa=>"\xf8\xe5",
    0x76ad=>"",
    0x76af=>"\x8f\xf1\xf4",
    0x76b6=>"\xf8\xe6",
    0x76bd=>"",
    0x76c1=>"",
    0x76c5=>"\xf8\xe7",
    0x76c9=>"\x8f\xf1\xf6",
    0x76cb=>"",
    0x76cc=>"\xf8\xe8",
    0x76ce=>"\xf8\xe9",
    0x76d4=>"\xf8\xea",
    0x76d9=>"",
    0x76e0=>"",
    0x76e6=>"\xf8\xeb",
    0x76e8=>"\x8f\xf1\xf8",
    0x76ec=>"\x8f\xf1\xf9",
    0x76f0=>"",
    0x76f1=>"\xf8\xec",
    0x76f6=>"",
    0x76f9=>"",
    0x76fc=>"\xf8\xed",
    0x7700=>"",
    0x7706=>"",
    0x770a=>"\xf8\xee",
    0x770e=>"",
    0x7712=>"",
    0x7714=>"",
    0x7715=>"",
    0x7717=>"\x8f\xf1\xfb",
    0x7719=>"\xf8\xef",
    0x771a=>"\x8f\xf1\xfc",
    0x771c=>"",
    0x7722=>"",
    0x7728=>"",
    0x772d=>"\x8f\xf1\xfd",
    0x772e=>"",
    0x772f=>"",
    0x7734=>"\xf8\xf0",
    0x7735=>"\x8f\xf1\xfe",
    0x7736=>"\xf8\xf1",
    0x7739=>"",
    0x773d=>"",
    0x773e=>"",
    0x7742=>"",
    0x7745=>"",
    0x7746=>"\xf8\xf2",
    0x774a=>"",
    0x774d=>"\xf8\xf3",
    0x774e=>"\xf8\xf4",
    0x774f=>"",
    0x7752=>"",
    0x7756=>"",
    0x7757=>"",
    0x7758=>"\x8f\xf2\xa5",
    0x775c=>"\xf8\xf5",
    0x775e=>"",
    0x775f=>"\xf8\xf6",
    0x7760=>"\x8f\xf2\xa6",
    0x7762=>"\xf8\xf7",
    0x7764=>"",
    0x7767=>"",
    0x776a=>"\x8f\xf2\xa7",
    0x776c=>"",
    0x7770=>"",
    0x7772=>"\x8f\xf2\xa9",
    0x7773=>"",
    0x7774=>"",
    0x777a=>"\xf8\xf8",
    0x777c=>"\x8f\xf2\xaa",
    0x777d=>"\x8f\xf2\xab",
    0x7780=>"\xf8\xf9",
    0x7784=>"",
    0x778c=>"",
    0x778d=>"",
    0x7794=>"\xf8\xfa",
    0x7795=>"",
    0x7796=>"",
    0x779a=>"\x8f\xf2\xae",
    0x779f=>"\x8f\xf2\xaf",
    0x77a2=>"\x8f\xf2\xb0",
    0x77a4=>"\x8f\xf2\xb1",
    0x77a7=>"",
    0x77a9=>"\x8f\xf2\xb2",
    0x77aa=>"\xf8\xfb",
    0x77ae=>"",
    0x77af=>"",
    0x77b1=>"",
    0x77b5=>"",
    0x77be=>"",
    0x77c3=>"",
    0x77c9=>"",
    0x77d1=>"",
    0x77d2=>"",
    0x77d5=>"",
    0x77d9=>"",
    0x77de=>"\x8f\xf2\xb3",
    0x77df=>"\x8f\xf2\xb4",
    0x77e0=>"\xf8\xfc",
    0x77e4=>"\x8f\xf2\xb5",
    0x77e6=>"\x8f\xf2\xb6",
    0x77ea=>"\x8f\xf2\xb7",
    0x77ec=>"\x8f\xf2\xb8",
    0x77f0=>"\x8f\xf2\xba",
    0x77f1=>"",
    0x77f4=>"\x8f\xf2\xbb",
    0x77f8=>"",
    0x77fb=>"\x8f\xf2\xbc",
    0x7805=>"\x8f\xf2\xbe",
    0x7806=>"\x8f\xf2\xbf",
    0x7809=>"\x8f\xf2\xc0",
    0x780d=>"\x8f\xf2\xc1",
    0x780e=>"",
    0x7811=>"",
    0x7819=>"\x8f\xf2\xc2",
    0x781d=>"",
    0x7821=>"\x8f\xf2\xc3",
    0x7822=>"",
    0x7823=>"",
    0x782c=>"\x8f\xf2\xc4",
    0x782d=>"\xf8\xfd",
    0x782e=>"",
    0x7830=>"",
    0x7835=>"",
    0x7837=>"",
    0x7843=>"\xf9\xa1",
    0x7844=>"",
    0x7847=>"\x8f\xf2\xc5",
    0x7848=>"",
    0x784c=>"",
    0x784e=>"\xf9\xa2",
    0x784f=>"\xf9\xa3",
    0x7851=>"\xf9\xa4",
    0x7852=>"",
    0x785c=>"",
    0x785e=>"",
    0x7860=>"",
    0x7861=>"",
    0x7863=>"",
    0x7864=>"\x8f\xf2\xc6",
    0x7868=>"\xf9\xa5",
    0x786a=>"\x8f\xf2\xc7",
    0x786e=>"\xf9\xa6",
    0x787a=>"",
    0x787e=>"",
    0x788a=>"\x8f\xf2\xc9",
    0x788f=>"",
    0x7894=>"\x8f\xf2\xca",
    0x7898=>"",
    0x789d=>"\x8f\xf2\xcc",
    0x789e=>"\x8f\xf2\xcd",
    0x789f=>"\x8f\xf2\xce",
    0x78a1=>"",
    0x78a4=>"\x8f\xf2\xcb",
    0x78a8=>"",
    0x78ac=>"",
    0x78ad=>"\xf9\xaa",
    0x78b0=>"\xf9\xa8",
    0x78b1=>"",
    0x78b2=>"",
    0x78b3=>"",
    0x78bb=>"\x8f\xf2\xcf",
    0x78bd=>"",
    0x78bf=>"",
    0x78c7=>"",
    0x78c8=>"\x8f\xf2\xd0",
    0x78c9=>"",
    0x78cc=>"\x8f\xf2\xd1",
    0x78ce=>"\x8f\xf2\xd2",
    0x78d2=>"",
    0x78d3=>"",
    0x78d5=>"\x8f\xf2\xd3",
    0x78d6=>"",
    0x78db=>"",
    0x78df=>"",
    0x78e0=>"\x8f\xf2\xd4",
    0x78e1=>"\x8f\xf2\xd5",
    0x78e4=>"\xf9\xab",
    0x78e6=>"\x8f\xf2\xd6",
    0x78ea=>"",
    0x78f2=>"\xf9\xac",
    0x78f3=>"",
    0x78f6=>"",
    0x78f7=>"\xf9\xae",
    0x78f9=>"\x8f\xf2\xd7",
    0x78fa=>"\x8f\xf2\xd8",
    0x78fb=>"\x8f\xf2\xd9",
    0x78fe=>"\x8f\xf2\xda",
    0x78ff=>"",
    0x7900=>"\xf9\xad",
    0x7906=>"",
    0x790c=>"",
    0x7910=>"\x8f\xf2\xdc",
    0x791a=>"",
    0x791b=>"\x8f\xf2\xdd",
    0x791c=>"\xf9\xaf",
    0x791e=>"",
    0x791f=>"",
    0x7920=>"",
    0x7925=>"\x8f\xf2\xdf",
    0x7927=>"",
    0x7929=>"",
    0x792d=>"",
    0x792e=>"\xf9\xb0",
    0x7930=>"\x8f\xf2\xde",
    0x7931=>"\xf9\xb1",
    0x7934=>"\xf9\xb2",
    0x7935=>"",
    0x793b=>"\x8f\xf2\xe0",
    0x793d=>"",
    0x793f=>"",
    0x7944=>"",
    0x7945=>"\xf9\xb5",
    0x7946=>"\xf9\xb6",
    0x794a=>"\x8f\xf2\xe1",
    0x794b=>"",
    0x794f=>"",
    0x7951=>"",
    0x7954=>"",
    0x7958=>"\x8f\xf2\xe2",
    0x795b=>"\x8f\xf2\xe3",
    0x795c=>"\xf9\xba",
    0x7967=>"\x8f\xf2\xe5",
    0x7969=>"",
    0x796b=>"",
    0x7972=>"\x8f\xf2\xe6",
    0x7979=>"\xf9\xbe",
    0x797b=>"",
    0x797c=>"",
    0x797e=>"",
    0x798b=>"",
    0x798c=>"",
    0x7991=>"",
    0x7993=>"",
    0x7994=>"\x8f\xf2\xe7",
    0x7995=>"\x8f\xf2\xe8",
    0x7996=>"\x8f\xf2\xe9",
    0x7998=>"\xf9\xc2",
    0x799b=>"\x8f\xf2\xea",
    0x799c=>"",
    0x79a1=>"\x8f\xf2\xeb",
    0x79a8=>"",
    0x79a9=>"\x8f\xf2\xec",
    0x79ab=>"",
    0x79af=>"",
    0x79b1=>"\xf9\xc3",
    0x79b4=>"\x8f\xf2\xed",
    0x79b8=>"\xf9\xc4",
    0x79bb=>"\x8f\xf2\xee",
    0x79c2=>"\x8f\xf2\xef",
    0x79c4=>"",
    0x79c7=>"\x8f\xf2\xf0",
    0x79c8=>"\xf9\xc5",
    0x79ca=>"\xf9\xc6",
    0x79cc=>"\x8f\xf2\xf1",
    0x79cd=>"\x8f\xf2\xf2",
    0x79cf=>"",
    0x79d4=>"\xf9\xc8",
    0x79d6=>"\x8f\xf2\xf3",
    0x79da=>"",
    0x79dd=>"",
    0x79de=>"\xf9\xc9",
    0x79e0=>"",
    0x79e2=>"",
    0x79e5=>"",
    0x79ea=>"",
    0x79eb=>"\xf9\xca",
    0x79ed=>"\xf9\xcb",
    0x79f1=>"",
    0x79f8=>"",
    0x79fc=>"",
    0x7a02=>"",
    0x7a03=>"\xf9\xcc",
    0x7a07=>"",
    0x7a09=>"",
    0x7a0a=>"\x8f\xf2\xf8",
    0x7a0c=>"",
    0x7a11=>"\x8f\xf2\xf9",
    0x7a15=>"\x8f\xf2\xfa",
    0x7a1b=>"\x8f\xf2\xfb",
    0x7a1e=>"\x8f\xf2\xfc",
    0x7a21=>"",
    0x7a27=>"",
    0x7a2b=>"",
    0x7a2d=>"\x8f\xf2\xfe",
    0x7a2f=>"",
    0x7a30=>"",
    0x7a34=>"",
    0x7a35=>"",
    0x7a38=>"\x8f\xf3\xa1",
    0x7a39=>"\xf9\xce",
    0x7a3a=>"",
    0x7a44=>"",
    0x7a45=>"",
    0x7a47=>"\x8f\xf3\xa2",
    0x7a48=>"",
    0x7a4c=>"\x8f\xf3\xa3",
    0x7a55=>"",
    0x7a56=>"\x8f\xf3\xa4",
    0x7a59=>"\x8f\xf3\xa5",
    0x7a5c=>"\x8f\xf3\xa6",
    0x7a5d=>"\xf9\xcf",
    0x7a5f=>"\x8f\xf3\xa7",
    0x7a60=>"\x8f\xf3\xa8",
    0x7a65=>"",
    0x7a67=>"\x8f\xf3\xa9",
    0x7a6a=>"\x8f\xf3\xaa",
    0x7a6d=>"\xf9\xd0",
    0x7a75=>"\x8f\xf3\xab",
    0x7a78=>"\x8f\xf3\xac",
    0x7a7e=>"",
    0x7a80=>"",
    0x7a82=>"\x8f\xf3\xad",
    0x7a85=>"\xf9\xd2",
    0x7a86=>"",
    0x7a8a=>"\x8f\xf3\xae",
    0x7a8b=>"",
    0x7a90=>"\x8f\xf3\xaf",
    0x7a91=>"",
    0x7a94=>"",
    0x7a9e=>"",
    0x7aa0=>"\xf9\xd3",
    0x7aa3=>"\x8f\xf3\xb0",
    0x7aac=>"\x8f\xf3\xb1",
    0x7ab3=>"\xf9\xd5",
    0x7ab5=>"",
    0x7ab9=>"\x8f\xf3\xb4",
    0x7abb=>"\xf9\xd6",
    0x7abc=>"\x8f\xf3\xb5",
    0x7abe=>"\x8f\xf3\xb6",
    0x7ac6=>"",
    0x7ac9=>"",
    0x7acc=>"\x8f\xf3\xb8",
    0x7ace=>"\xf9\xd7",
    0x7ad1=>"\x8f\xf3\xb9",
    0x7adb=>"",
    0x7ae7=>"\x8f\xf3\xba",
    0x7ae8=>"\x8f\xf3\xbb",
    0x7ae9=>"",
    0x7aeb=>"\xf9\xd8",
    0x7aec=>"",
    0x7af1=>"",
    0x7af4=>"\x8f\xf3\xbc",
    0x7afb=>"",
    0x7afd=>"\xf9\xd9",
    0x7afe=>"",
    0x7b07=>"\x8f\xf3\xbf",
    0x7b12=>"\xf9\xda",
    0x7b14=>"",
    0x7b1f=>"",
    0x7b23=>"",
    0x7b27=>"\x8f\xf3\xc2",
    0x7b29=>"",
    0x7b2a=>"\x8f\xf3\xc3",
    0x7b2b=>"",
    0x7b2d=>"\xf9\xdb",
    0x7b2e=>"\x8f\xf3\xc4",
    0x7b2f=>"\x8f\xf3\xc5",
    0x7b30=>"",
    0x7b31=>"\x8f\xf3\xc6",
    0x7b34=>"",
    0x7b3b=>"\xf9\xdc",
    0x7b3d=>"\x8f\xf3\xc1",
    0x7b3f=>"",
    0x7b40=>"",
    0x7b41=>"\x8f\xf3\xca",
    0x7b47=>"\xf9\xdd",
    0x7b4e=>"\xf9\xde",
    0x7b55=>"\x8f\xf3\xcc",
    0x7b60=>"\xf9\xdf",
    0x7b64=>"\x8f\xf3\xce",
    0x7b66=>"\x8f\xf3\xcf",
    0x7b69=>"\x8f\xf3\xd0",
    0x7b6a=>"",
    0x7b6d=>"\xf9\xe0",
    0x7b6f=>"\xf9\xe1",
    0x7b72=>"\xf9\xe2",
    0x7b73=>"\x8f\xf3\xd1",
    0x7b77=>"",
    0x7b79=>"\x8f\xf3\xcd",
    0x7b7f=>"\x8f\xf3\xc9",
    0x7b84=>"",
    0x7b89=>"",
    0x7b8e=>"",
    0x7b90=>"\x8f\xf3\xd4",
    0x7b91=>"\x8f\xf3\xd5",
    0x7b96=>"",
    0x7b9b=>"\x8f\xf3\xd6",
    0x7b9e=>"\xf9\xe3",
    0x7ba0=>"",
    0x7ba5=>"",
    0x7bac=>"",
    0x7baf=>"\x8f\xf3\xd8",
    0x7bb0=>"",
    0x7bb2=>"",
    0x7bb5=>"\x8f\xf3\xd9",
    0x7bb6=>"",
    0x7bba=>"",
    0x7bbb=>"",
    0x7bbc=>"\x8f\xf3\xda",
    0x7bbd=>"",
    0x7bc2=>"",
    0x7bc5=>"\x8f\xf3\xdb",
    0x7bc8=>"",
    0x7bca=>"\x8f\xf3\xdc",
    0x7bd4=>"\x8f\xf3\xdf",
    0x7bd6=>"\x8f\xf3\xe0",
    0x7bd7=>"\xf9\xe5",
    0x7bd9=>"\xf9\xe6",
    0x7bda=>"\x8f\xf3\xe1",
    0x7bdb=>"",
    0x7be8=>"",
    0x7bea=>"\x8f\xf3\xe2",
    0x7bf0=>"\x8f\xf3\xe3",
    0x7bf2=>"",
    0x7bf4=>"",
    0x7bf5=>"",
    0x7bf8=>"",
    0x7bf9=>"",
    0x7bfa=>"",
    0x7bfc=>"",
    0x7bfe=>"",
    0x7c01=>"\xf9\xe7",
    0x7c02=>"",
    0x7c03=>"\x8f\xf3\xe4",
    0x7c04=>"",
    0x7c06=>"",
    0x7c09=>"",
    0x7c0b=>"\x8f\xf3\xe5",
    0x7c0c=>"",
    0x7c0e=>"\x8f\xf3\xe6",
    0x7c0f=>"\x8f\xf3\xe7",
    0x7c19=>"",
    0x7c1b=>"",
    0x7c1e=>"\xf9\xe9",
    0x7c20=>"\xf9\xea",
    0x7c25=>"",
    0x7c26=>"\x8f\xf3\xe8",
    0x7c28=>"",
    0x7c2c=>"",
    0x7c31=>"\xf9\xe8",
    0x7c33=>"\xf9\xeb",
    0x7c34=>"",
    0x7c36=>"\xf9\xec",
    0x7c39=>"",
    0x7c3a=>"",
    0x7c45=>"\x8f\xf3\xe9",
    0x7c46=>"",
    0x7c4a=>"\x8f\xf3\xea",
    0x7c51=>"\x8f\xf3\xeb",
    0x7c52=>"",
    0x7c53=>"",
    0x7c55=>"",
    0x7c57=>"\x8f\xf3\xec",
    0x7c59=>"\xf9\xef",
    0x7c5a=>"",
    0x7c5b=>"",
    0x7c5c=>"",
    0x7c5d=>"",
    0x7c5e=>"\x8f\xf3\xed",
    0x7c61=>"\x8f\xf3\xee",
    0x7c63=>"",
    0x7c67=>"",
    0x7c69=>"\x8f\xf3\xef",
    0x7c6d=>"\xf9\xf0",
    0x7c6e=>"\x8f\xf3\xf0",
    0x7c6f=>"\x8f\xf3\xf1",
    0x7c70=>"\x8f\xf3\xf2",
    0x7c72=>"",
    0x7c79=>"\xf9\xf1",
    0x7c7c=>"",
    0x7c7d=>"",
    0x7c86=>"",
    0x7c87=>"",
    0x7c8f=>"\xf9\xf2",
    0x7c94=>"\xf9\xf3",
    0x7c9e=>"",
    0x7ca0=>"\xf9\xf4",
    0x7ca6=>"\x8f\xf3\xf6",
    0x7cb0=>"",
    0x7cb6=>"\x8f\xf3\xf8",
    0x7cb7=>"\x8f\xf3\xf9",
    0x7cba=>"",
    0x7cbb=>"",
    0x7cbc=>"\xf9\xf5",
    0x7cbf=>"\x8f\xf3\xfa",
    0x7cc4=>"\x8f\xf3\xfc",
    0x7cc7=>"",
    0x7cc8=>"\x8f\xf3\xfe",
    0x7cc9=>"",
    0x7ccd=>"\x8f\xf4\xa1",
    0x7ccf=>"",
    0x7cd3=>"",
    0x7cd4=>"",
    0x7cd5=>"\xf9\xf6",
    0x7cd7=>"\x8f\xf4\xa3",
    0x7cd9=>"\xf9\xf7",
    0x7cda=>"",
    0x7cdd=>"\xf9\xf8",
    0x7ce6=>"\x8f\xf4\xa5",
    0x7ce9=>"",
    0x7ceb=>"\x8f\xf4\xa6",
    0x7cf5=>"\x8f\xf4\xa8",
    0x7d03=>"\x8f\xf4\xa9",
    0x7d07=>"\xf9\xf9",
    0x7d08=>"\xf9\xfa",
    0x7d09=>"\x8f\xf4\xaa",
    0x7d0f=>"",
    0x7d11=>"",
    0x7d12=>"\x8f\xf4\xac",
    0x7d13=>"\xf9\xfb",
    0x7d16=>"",
    0x7d1d=>"\xf9\xfc",
    0x7d1e=>"\x8f\xf4\xad",
    0x7d23=>"\xf9\xfd",
    0x7d26=>"",
    0x7d2a=>"",
    0x7d2d=>"",
    0x7d31=>"\xf9\xfe",
    0x7d3c=>"",
    0x7d3d=>"\x8f\xf4\xb0",
    0x7d3e=>"\x8f\xf4\xb1",
    0x7d40=>"\x8f\xf4\xb2",
    0x7d41=>"\xfa\xa1",
    0x7d47=>"\x8f\xf4\xb3",
    0x7d48=>"\xfa\xa2",
    0x7d4d=>"",
    0x7d51=>"",
    0x7d53=>"\xfa\xa3",
    0x7d57=>"",
    0x7d59=>"\x8f\xf4\xb7",
    0x7d5a=>"\x8f\xf4\xb8",
    0x7d5c=>"\xfa\xa4",
    0x7d5d=>"",
    0x7d65=>"",
    0x7d67=>"",
    0x7d6a=>"\x8f\xf4\xb9",
    0x7d70=>"\x8f\xf4\xba",
    0x7d78=>"",
    0x7d7a=>"\xfa\xa5",
    0x7d7b=>"",
    0x7d7f=>"\x8f\xf4\xbc",
    0x7d81=>"",
    0x7d82=>"",
    0x7d83=>"\xfa\xa6",
    0x7d85=>"",
    0x7d86=>"\x8f\xf4\xbe",
    0x7d88=>"\x8f\xf4\xbf",
    0x7d8b=>"\xfa\xa7",
    0x7d8c=>"\x8f\xf4\xc0",
    0x7d8d=>"",
    0x7d91=>"",
    0x7d96=>"",
    0x7d97=>"\x8f\xf4\xc1",
    0x7d9d=>"\x8f\xf4\xc3",
    0x7d9e=>"",
    0x7da0=>"\xfa\xa8",
    0x7da6=>"\xfa\xa9",
    0x7da7=>"\x8f\xf4\xc4",
    0x7daa=>"\x8f\xf4\xc5",
    0x7db3=>"",
    0x7db6=>"\x8f\xf4\xc6",
    0x7db7=>"\x8f\xf4\xc7",
    0x7db9=>"",
    0x7dc0=>"\x8f\xf4\xc8",
    0x7dc2=>"\xfa\xaa",
    0x7dc3=>"",
    0x7dc4=>"",
    0x7dc5=>"",
    0x7dc6=>"",
    0x7dcc=>"\xfa\xab",
    0x7dcd=>"",
    0x7dce=>"",
    0x7dd6=>"\xfa\xac",
    0x7dd7=>"\x8f\xf4\xc9",
    0x7dd9=>"\x8f\xf4\xca",
    0x7de2=>"",
    0x7de3=>"\xfa\xad",
    0x7de5=>"",
    0x7de6=>"\x8f\xf4\xcb",
    0x7dea=>"",
    0x7deb=>"",
    0x7ded=>"",
    0x7df1=>"\x8f\xf4\xcc",
    0x7df5=>"",
    0x7df6=>"",
    0x7df9=>"\x8f\xf4\xcd",
    0x7dfa=>"",
    0x7e00=>"",
    0x7e08=>"\xfa\xb0",
    0x7e10=>"\x8f\xf4\xd1",
    0x7e11=>"\xfa\xb1",
    0x7e15=>"\xfa\xb2",
    0x7e17=>"\x8f\xf4\xd2",
    0x7e1c=>"",
    0x7e1d=>"\x8f\xf4\xd3",
    0x7e20=>"\x8f\xf4\xd4",
    0x7e27=>"\x8f\xf4\xd5",
    0x7e28=>"\xfa\xaf",
    0x7e2c=>"\x8f\xf4\xd6",
    0x7e2d=>"",
    0x7e2f=>"",
    0x7e33=>"",
    0x7e36=>"",
    0x7e3f=>"",
    0x7e44=>"",
    0x7e45=>"\x8f\xf4\xd7",
    0x7e47=>"\xfa\xb4",
    0x7e4e=>"",
    0x7e50=>"",
    0x7e52=>"\xfa\xb5",
    0x7e58=>"",
    0x7e5f=>"",
    0x7e61=>"\xfa\xb6",
    0x7e62=>"",
    0x7e65=>"",
    0x7e6b=>"\xfe\xfe", # [2004]
    0x7e6e=>"",
    0x7e6f=>"",
    0x7e73=>"\x8f\xf4\xd8",
    0x7e75=>"\x8f\xf4\xd9",
    0x7e78=>"",
    0x7e7e=>"\x8f\xf4\xda",
    0x7e81=>"",
    0x7e86=>"\x8f\xf4\xdb",
    0x7e87=>"\x8f\xf4\xdc",
    0x7e8a=>"\xfa\xb7",
    0x7e8d=>"\xfa\xb8",
    0x7e91=>"\x8f\xf4\xde",
    0x7e95=>"",
    0x7e98=>"\x8f\xf4\xdf",
    0x7e9a=>"\x8f\xf4\xe0",
    0x7e9d=>"",
    0x7e9e=>"",
    0x7f3b=>"\x8f\xf4\xe3",
    0x7f3c=>"\x8f\xf4\xe2",
    0x7f3d=>"",
    0x7f3e=>"\x8f\xf4\xe4",
    0x7f3f=>"",
    0x7f43=>"\x8f\xf4\xe5",
    0x7f44=>"\x8f\xf4\xe6",
    0x7f47=>"\xfa\xb9",
    0x7f4f=>"\x8f\xf4\xe7",
    0x7f52=>"\x8f\xf4\xea",
    0x7f53=>"",
    0x7f5b=>"",
    0x7f5c=>"",
    0x7f5d=>"",
    0x7f61=>"\x8f\xf4\xec",
    0x7f63=>"\x8f\xf4\xed",
    0x7f64=>"\x8f\xf4\xee",
    0x7f65=>"",
    0x7f66=>"",
    0x7f6d=>"\x8f\xf4\xef",
    0x7f71=>"",
    0x7f7d=>"\x8f\xf4\xf0",
    0x7f7e=>"\x8f\xf4\xf1",
    0x7f7f=>"",
    0x7f80=>"",
    0x7f8b=>"",
    0x7f8d=>"",
    0x7f8f=>"",
    0x7f90=>"\x8f\xf4\xf3",
    0x7f91=>"\xfa\xbb",
    0x7f96=>"\x8f\xf4\xf6",
    0x7f97=>"\xfa\xbc",
    0x7f9c=>"\x8f\xf4\xf7",
    0x7fa1=>"",
    0x7fa2=>"",
    0x7fa6=>"",
    0x7faa=>"",
    0x7fad=>"\x8f\xf4\xf8",
    0x7fb4=>"",
    0x7fbc=>"",
    0x7fbf=>"\xfa\xbd",
    0x7fc0=>"",
    0x7fc3=>"\x8f\xf4\xfa",
    0x7fc8=>"",
    0x7fce=>"\xfa\xbe",
    0x7fcf=>"\x8f\xf4\xfb",
    0x7fdb=>"\xfa\xbf",
    0x7fdf=>"\xfa\xc0",
    0x7fe3=>"\x8f\xf4\xfc",
    0x7fe5=>"\x8f\xf4\xfd",
    0x7fe8=>"",
    0x7fec=>"\xfa\xc1",
    0x7fee=>"\xfa\xc2",
    0x7fef=>"\x8f\xf4\xfe",
    0x7ff2=>"\x8f\xf5\xa1",
    0x7ffa=>"\xfa\xc3",
    0x7ffd=>"",
    0x7ffe=>"",
    0x7fff=>"",
    0x8002=>"\x8f\xf5\xa2",
    0x8007=>"",
    0x8008=>"\x8f\xf5\xa4",
    0x800a=>"\x8f\xf5\xa3",
    0x800d=>"",
    0x800e=>"\x8f\xf5\xa5",
    0x800f=>"",
    0x8011=>"\x8f\xf5\xa6",
    0x8013=>"",
    0x8014=>"\xfa\xc5",
    0x8016=>"\x8f\xf5\xa7",
    0x801d=>"",
    0x801e=>"",
    0x801f=>"",
    0x8020=>"",
    0x8024=>"\x8f\xf5\xa8",
    0x8026=>"\xfa\xc6",
    0x802c=>"\x8f\xf5\xa9",
    0x802e=>"",
    0x8030=>"\x8f\xf5\xaa",
    0x8034=>"",
    0x8035=>"\xfa\xc7",
    0x8037=>"\xfa\xc8",
    0x8039=>"",
    0x803a=>"",
    0x803c=>"\xfa\xc9",
    0x803e=>"",
    0x8040=>"",
    0x8043=>"\x8f\xf5\xab",
    0x8044=>"",
    0x8060=>"",
    0x8064=>"",
    0x8066=>"\x8f\xf5\xac",
    0x806d=>"",
    0x8071=>"\x8f\xf5\xad",
    0x8075=>"\x8f\xf5\xae",
    0x807b=>"\x8f\xf5\xaf",
    0x8081=>"",
    0x8088=>"",
    0x808e=>"",
    0x8099=>"\x8f\xf5\xb0",
    0x809c=>"\x8f\xf5\xb1",
    0x809e=>"",
    0x80a4=>"\x8f\xf5\xb2",
    0x80a6=>"",
    0x80a7=>"\x8f\xf5\xb3",
    0x80ab=>"",
    0x80b8=>"\x8f\xf5\xb4",
    0x80b9=>"",
    0x80c5=>"\x8f\xf5\xb6",
    0x80c8=>"",
    0x80ca=>"\xfa\xca",
    0x80cd=>"",
    0x80cf=>"",
    0x80d2=>"",
    0x80d4=>"",
    0x80d5=>"\x8f\xf5\xb7",
    0x80d7=>"\xfa\xcb",
    0x80d8=>"\x8f\xf5\xb8",
    0x80e0=>"\xfa\xcc",
    0x80e6=>"\x8f\xf5\xb9",
    0x80ed=>"",
    0x80ee=>"",
    0x80f0=>"",
    0x80f2=>"",
    0x80f3=>"\xfa\xcd",
    0x80f5=>"\x8f\xf5\xbc",
    0x80f6=>"",
    0x80f9=>"",
    0x80fa=>"",
    0x80fb=>"\x8f\xf5\xbd",
    0x80fe=>"",
    0x8103=>"",
    0x810b=>"",
    0x810d=>"\x8f\xf5\xbb",
    0x8116=>"\x8f\xf5\xc0",
    0x8117=>"",
    0x8118=>"\xfa\xce",
    0x811c=>"",
    0x811e=>"\x8f\xf5\xc1",
    0x8120=>"",
    0x8124=>"\x8f\xf5\xc3",
    0x8127=>"\x8f\xf5\xc4",
    0x812c=>"\x8f\xf5\xc5",
    0x8130=>"",
    0x8135=>"\x8f\xf5\xbf",
    0x813a=>"",
    0x813c=>"",
    0x813d=>"\x8f\xf5\xc7",
    0x8145=>"",
    0x8147=>"",
    0x814a=>"\xfa\xcf",
    0x814c=>"",
    0x8152=>"",
    0x8157=>"",
    0x8160=>"\xfa\xd0",
    0x8161=>"",
    0x8167=>"\xfa\xd1",
    0x8168=>"\xfa\xd2",
    0x8169=>"\x8f\xf5\xc9",
    0x816d=>"\xfa\xd3",
    0x816f=>"",
    0x8177=>"",
    0x8181=>"\x8f\xf5\xcb",
    0x8184=>"\x8f\xf5\xcd",
    0x8185=>"\x8f\xf5\xce",
    0x8186=>"",
    0x818b=>"",
    0x818e=>"",
    0x8190=>"",
    0x8196=>"",
    0x8198=>"\x8f\xf5\xd0",
    0x819b=>"",
    0x819e=>"",
    0x81a2=>"",
    0x81ae=>"",
    0x81b2=>"\x8f\xf5\xd1",
    0x81b4=>"",
    0x81bb=>"\xfa\xd4",
    0x81c1=>"\x8f\xf5\xd2",
    0x81c3=>"\x8f\xf5\xd3",
    0x81c5=>"",
    0x81ca=>"\xfa\xd5",
    0x81cb=>"",
    0x81ce=>"",
    0x81cf=>"\xfa\xd6",
    0x81d5=>"",
    0x81d6=>"\x8f\xf5\xd4",
    0x81d7=>"\xfa\xd7",
    0x81db=>"\x8f\xf5\xd5",
    0x81dd=>"",
    0x81de=>"",
    0x81e1=>"",
    0x81e4=>"\x8f\xf5\xd7",
    0x81eb=>"",
    0x81ec=>"\x8f\xf5\xd9",
    0x81f0=>"",
    0x81f1=>"",
    0x81f2=>"",
    0x81f5=>"",
    0x81f6=>"",
    0x81f8=>"",
    0x81f9=>"",
    0x81fd=>"\x8f\xf5\xdb",
    0x81ff=>"\x8f\xf5\xdc",
    0x8200=>"",
    0x8203=>"",
    0x8204=>"\x8f\xf5\xde",
    0x820f=>"",
    0x8213=>"",
    0x8214=>"",
    0x8219=>"\x8f\xf5\xe0",
    0x821a=>"",
    0x821d=>"",
    0x8221=>"\x8f\xf5\xe1",
    0x8222=>"\x8f\xf5\xe2",
    0x8228=>"",
    0x8232=>"\x8f\xf5\xe4",
    0x8234=>"\x8f\xf5\xe5",
    0x823a=>"",
    0x823c=>"\x8f\xf5\xe6",
    0x8243=>"",
    0x8244=>"",
    0x8245=>"\x8f\xf5\xe9",
    0x8246=>"\x8f\xf5\xe7",
    0x8249=>"\x8f\xf5\xe8",
    0x824b=>"\x8f\xf5\xeb",
    0x824e=>"",
    0x824f=>"\x8f\xf5\xed",
    0x8251=>"",
    0x8256=>"",
    0x8257=>"\x8f\xf5\xef",
    0x825c=>"\x8f\xf5\xf1",
    0x8260=>"\xfa\xdb",
    0x8263=>"\x8f\xf5\xf2",
    0x8267=>"",
    0x826d=>"",
    0x8274=>"\xfa\xdc",
    0x8279=>"\x8f\xf5\xf6",
    0x827b=>"",
    0x827d=>"\x8f\xf5\xf8",
    0x827f=>"\x8f\xf5\xf9",
    0x8280=>"",
    0x8281=>"",
    0x8283=>"\x8f\xf5\xfa",
    0x8284=>"",
    0x8287=>"",
    0x8289=>"",
    0x828a=>"\x8f\xf5\xfb",
    0x828e=>"\xfa\xde",
    0x8291=>"",
    0x8293=>"\x8f\xf5\xfc",
    0x8294=>"",
    0x8296=>"",
    0x8298=>"",
    0x829a=>"",
    0x829b=>"",
    0x82a0=>"",
    0x82a1=>"\xfa\xdf",
    0x82a3=>"\xfa\xe0",
    0x82a4=>"\xfa\xe1",
    0x82a7=>"\x8f\xf5\xfd",
    0x82a8=>"\x8f\xf5\xfe",
    0x82a9=>"\xfa\xe2",
    0x82aa=>"",
    0x82ae=>"\xfa\xe3",
    0x82b0=>"",
    0x82b2=>"\x8f\xf6\xa1",
    0x82b4=>"\x8f\xf6\xa2",
    0x82b7=>"\xfa\xe4",
    0x82ba=>"\x8f\xf6\xa3",
    0x82bc=>"\x8f\xf6\xa4",
    0x82be=>"\xfa\xe5",
    0x82bf=>"\xfa\xe6",
    0x82c6=>"\xfa\xe7",
    0x82d0=>"",
    0x82d5=>"\xfa\xe8",
    0x82da=>"",
    0x82e0=>"",
    0x82e2=>"\x8f\xf6\xa5",
    0x82e4=>"",
    0x82e8=>"\x8f\xf6\xa6",
    0x82ea=>"",
    0x82ed=>"",
    0x82ef=>"",
    0x82f6=>"",
    0x82f7=>"\x8f\xf6\xa7",
    0x82fd=>"\xfa\xe9",
    0x82fe=>"\xfa\xea",
    0x8300=>"\xfa\xeb",
    0x8301=>"\xfa\xec",
    0x8307=>"\x8f\xf6\xa8",
    0x8308=>"\x8f\xf6\xa9",
    0x830a=>"",
    0x830b=>"",
    0x830c=>"\x8f\xf6\xaa",
    0x831b=>"\x8f\xf6\xac",
    0x831d=>"\x8f\xf6\xad",
    0x831e=>"",
    0x831f=>"",
    0x8321=>"",
    0x8322=>"\xfa\xee",
    0x832c=>"",
    0x832d=>"\xfa\xef",
    0x832e=>"",
    0x8330=>"\x8f\xf6\xae",
    0x8333=>"",
    0x8337=>"",
    0x833a=>"\xfa\xf0",
    0x833c=>"\x8f\xf6\xaf",
    0x833d=>"",
    0x8342=>"",
    0x8343=>"\xfa\xf1",
    0x8344=>"\x8f\xf6\xb0",
    0x8347=>"\xfa\xf2",
    0x834d=>"",
    0x834e=>"",
    0x8351=>"\xfa\xf3",
    0x8353=>"",
    0x8354=>"\x8f\xf6\xab",
    0x8355=>"\xfa\xf4",
    0x8356=>"",
    0x8357=>"\x8f\xf6\xb1",
    0x8362=>"\xfa\xed",
    0x8363=>"\x8f\xae\xca",
    0x8370=>"",
    0x8378=>"",
    0x837d=>"\xfa\xf5",
    0x837f=>"\x8f\xf6\xb3",
    0x8380=>"",
    0x8382=>"",
    0x8384=>"",
    0x8386=>"\xfa\xf6",
    0x838d=>"\x8f\xf6\xb6",
    0x8392=>"\xfa\xf7",
    0x8394=>"\x8f\xf6\xb7",
    0x8395=>"\x8f\xf6\xb8",
    0x8398=>"\xfa\xf8",
    0x8399=>"",
    0x839b=>"\x8f\xf6\xb9",
    0x839c=>"",
    0x839d=>"\x8f\xf6\xba",
    0x83a6=>"",
    0x83a7=>"\xfa\xf9",
    0x83a9=>"\xfa\xfa",
    0x83ac=>"",
    0x83ad=>"",
    0x83be=>"",
    0x83bf=>"\xfa\xfb",
    0x83c0=>"\xfa\xfc",
    0x83c7=>"\xfa\xfd",
    0x83c9=>"\x8f\xf6\xbb",
    0x83cf=>"\xfa\xfe",
    0x83d0=>"\x8f\xf6\xbc",
    0x83d1=>"\xfb\xa1",
    0x83d4=>"\x8f\xf6\xbd",
    0x83dd=>"\x8f\xf6\xbe",
    0x83e1=>"\xfb\xa2",
    0x83e5=>"\x8f\xf6\xbf",
    0x83e8=>"",
    0x83ea=>"\xfb\xa3",
    0x83f6=>"",
    0x83f8=>"",
    0x83f9=>"\x8f\xf6\xc0",
    0x83fc=>"",
    0x8401=>"\xfb\xa4",
    0x8406=>"\xfb\xa5",
    0x840a=>"\xfb\xa6",
    0x840f=>"\x8f\xf6\xc1",
    0x8411=>"\x8f\xf6\xc2",
    0x8415=>"\x8f\xf6\xc3",
    0x8417=>"\x8f\xf6\xc5",
    0x8419=>"",
    0x842f=>"",
    0x8439=>"\x8f\xf6\xc6",
    0x8445=>"",
    0x8447=>"",
    0x8448=>"\xfb\xa8",
    0x844a=>"\x8f\xf6\xc7",
    0x844d=>"",
    0x844f=>"\x8f\xf6\xc8",
    0x8451=>"\x8f\xf6\xc9",
    0x8452=>"\x8f\xf6\xca",
    0x8456=>"",
    0x8458=>"",
    0x8459=>"\x8f\xf6\xcb",
    0x845a=>"\x8f\xf6\xcc",
    0x845c=>"\x8f\xf6\xcd",
    0x845f=>"\xfb\xa9",
    0x8460=>"",
    0x8464=>"",
    0x8465=>"\x8f\xf6\xcf",
    0x8467=>"",
    0x846a=>"",
    0x8470=>"\xfb\xaa",
    0x8473=>"\xfb\xab",
    0x8474=>"",
    0x8476=>"\x8f\xf6\xd0",
    0x8478=>"\x8f\xf6\xd1",
    0x847c=>"\x8f\xf6\xd2",
    0x847d=>"",
    0x8481=>"\x8f\xf6\xd3",
    0x8485=>"\xfb\xac",
    0x8492=>"",
    0x8493=>"",
    0x8495=>"",
    0x8497=>"\x8f\xf6\xd6",
    0x849e=>"\xfb\xad",
    0x84a6=>"\x8f\xf6\xd7",
    0x84a8=>"",
    0x84a9=>"",
    0x84aa=>"",
    0x84af=>"\xfb\xae",
    0x84b1=>"",
    0x84b4=>"\xfb\xaf",
    0x84ba=>"\xfb\xb0",
    0x84bd=>"",
    0x84be=>"\x8f\xf6\xd8",
    0x84c0=>"\xfb\xb1",
    0x84c2=>"\xfb\xb2",
    0x84c7=>"",
    0x84c8=>"",
    0x84cc=>"",
    0x84ce=>"\x8f\xf6\xda",
    0x84cf=>"\x8f\xf6\xdb",
    0x84d3=>"\x8f\xf6\xdc",
    0x84dc=>"\x8f\xf6\xd5",
    0x84e7=>"\x8f\xf6\xde",
    0x84ea=>"\x8f\xf6\xdf",
    0x84ef=>"\x8f\xf6\xe0",
    0x84f0=>"\x8f\xf6\xe1",
    0x84f1=>"\x8f\xf6\xe2",
    0x84f2=>"",
    0x84f7=>"",
    0x84fa=>"\x8f\xf6\xe3",
    0x84fb=>"",
    0x84fd=>"\x8f\xf6\xe4",
    0x8502=>"",
    0x8503=>"",
    0x8507=>"",
    0x850c=>"\x8f\xf6\xe5",
    0x850e=>"",
    0x8510=>"",
    0x851b=>"\x8f\xf6\xe6",
    0x851c=>"",
    0x851e=>"\xfb\xb5",
    0x8522=>"",
    0x8523=>"\xfb\xb6",
    0x8524=>"\x8f\xf6\xe7",
    0x8525=>"\x8f\xf6\xe8",
    0x8527=>"",
    0x852a=>"",
    0x852b=>"\x8f\xf6\xe9",
    0x852f=>"\xfb\xb7",
    0x8532=>"\xfb\xb4",
    0x8533=>"",
    0x8534=>"\x8f\xf6\xea",
    0x8536=>"",
    0x853e=>"\x8f\xf6\xef",
    0x853f=>"",
    0x8546=>"",
    0x854f=>"\x8f\xf6\xeb",
    0x8550=>"",
    0x8551=>"\x8f\xf6\xf0",
    0x8552=>"",
    0x8553=>"\x8f\xf6\xf1",
    0x8556=>"",
    0x8559=>"\xfb\xb8",
    0x855c=>"",
    0x855d=>"",
    0x855e=>"\x8f\xf6\xf2",
    0x855f=>"",
    0x8560=>"",
    0x8561=>"\x8f\xf6\xf3",
    0x8562=>"\x8f\xf6\xf4",
    0x8564=>"\xfb\xb9",
    0x856b=>"",
    0x856f=>"\x8f\xf6\xec",
    0x8579=>"",
    0x857a=>"\xfb\xbc",
    0x857b=>"\x8f\xf6\xf6",
    0x857d=>"\x8f\xf6\xf7",
    0x857f=>"\x8f\xf6\xf8",
    0x8581=>"\x8f\xf6\xf9",
    0x8585=>"",
    0x8586=>"\x8f\xf6\xfa",
    0x8589=>"",
    0x858b=>"",
    0x858c=>"\xfb\xbd",
    0x858f=>"\xfb\xbe",
    0x8593=>"\x8f\xf6\xfb",
    0x8598=>"",
    0x859d=>"\x8f\xf6\xfc",
    0x859f=>"\x8f\xf6\xfd",
    0x85a0=>"",
    0x85a2=>"\xfb\xbf",
    0x85a5=>"",
    0x85a7=>"",
    0x85ad=>"\xfb\xbb",
    0x85b0=>"\xfb\xc0",
    0x85b4=>"",
    0x85b6=>"",
    0x85b7=>"\x8f\xf7\xa3",
    0x85b8=>"",
    0x85bc=>"\x8f\xf7\xa4",
    0x85bd=>"",
    0x85be=>"",
    0x85bf=>"",
    0x85c2=>"",
    0x85c7=>"\x8f\xf7\xa5",
    0x85ca=>"\x8f\xf7\xa6",
    0x85cb=>"\xfb\xc1",
    0x85ce=>"\xfb\xc2",
    0x85d8=>"\x8f\xf7\xa7",
    0x85d9=>"\x8f\xf7\xa8",
    0x85da=>"",
    0x85df=>"\x8f\xf7\xa9",
    0x85e0=>"",
    0x85e1=>"\x8f\xf7\xaa",
    0x85e6=>"\x8f\xf7\xab",
    0x85e8=>"",
    0x85ed=>"\xfb\xc3",
    0x85f3=>"",
    0x85f6=>"\x8f\xf7\xac",
    0x85fc=>"",
    0x85ff=>"\xfb\xc5",
    0x8600=>"\x8f\xf7\xad",
    0x8604=>"\xfb\xc6",
    0x8605=>"\xfb\xc7",
    0x860d=>"",
    0x860e=>"",
    0x8610=>"\xfb\xc8",
    0x8611=>"\x8f\xf7\xae",
    0x8612=>"\xfb\xc4",
    0x8618=>"\xfb\xca",
    0x8619=>"",
    0x861b=>"",
    0x861e=>"\x8f\xf7\xaf",
    0x8621=>"\x8f\xf7\xb0",
    0x8624=>"\x8f\xf7\xb1",
    0x8627=>"\x8f\xf7\xb2",
    0x8629=>"\xfb\xcb",
    0x8636=>"",
    0x8638=>"\xfb\xcc",
    0x8639=>"\x8f\xf7\xb4",
    0x863a=>"",
    0x863c=>"\x8f\xf7\xb5",
    0x863d=>"",
    0x8640=>"\x8f\xf7\xb7",
    0x8641=>"\xaf\xe8",
    0x8642=>"",
    0x8646=>"",
    0x8652=>"",
    0x8653=>"\x8f\xf7\xb9",
    0x8656=>"\x8f\xf7\xba",
    0x8657=>"\xfb\xcd",
    0x8658=>"",
    0x8659=>"",
    0x865b=>"\xfb\xce",
    0x865d=>"",
    0x8660=>"",
    0x8661=>"",
    0x8662=>"\xfb\xd0",
    0x8663=>"",
    0x8664=>"",
    0x8669=>"",
    0x866c=>"\xfb\xd2",
    0x866f=>"\x8f\xf7\xbb",
    0x8675=>"\xfb\xd3",
    0x8676=>"",
    0x8677=>"\x8f\xf7\xbc",
    0x867a=>"\x8f\xf7\xbd",
    0x8687=>"\x8f\xf7\xbe",
    0x8688=>"",
    0x8689=>"\x8f\xf7\xbf",
    0x868d=>"\x8f\xf7\xc0",
    0x8691=>"\x8f\xf7\xc1",
    0x8696=>"",
    0x8698=>"\xfb\xd4",
    0x869a=>"",
    0x869c=>"\x8f\xf7\xc2",
    0x869d=>"\x8f\xf7\xc3",
    0x86a1=>"",
    0x86a6=>"",
    0x86a7=>"",
    0x86a8=>"\x8f\xf7\xc4",
    0x86ad=>"",
    0x86b1=>"\x8f\xf7\xc6",
    0x86b3=>"\x8f\xf7\xc7",
    0x86b4=>"",
    0x86b5=>"",
    0x86b7=>"",
    0x86b8=>"\xfb\xd5",
    0x86b9=>"",
    0x86bf=>"",
    0x86c0=>"",
    0x86c1=>"\x8f\xf7\xc8",
    0x86c3=>"\x8f\xf7\xc9",
    0x86c5=>"",
    0x86d1=>"\x8f\xf7\xca",
    0x86d2=>"",
    0x86d5=>"\x8f\xf7\xcb",
    0x86d7=>"\x8f\xf7\xcc",
    0x86da=>"",
    0x86dc=>"",
    0x86e0=>"",
    0x86e3=>"\x8f\xf7\xcd",
    0x86e5=>"",
    0x86e6=>"\x8f\xf7\xce",
    0x86e7=>"",
    0x86fa=>"\xfb\xd6",
    0x86fc=>"\xfb\xd7",
    0x86fd=>"\xfb\xd8",
    0x8704=>"",
    0x8705=>"\x8f\xf7\xd0",
    0x8707=>"\x8f\xf7\xd1",
    0x870b=>"\xfb\xd9",
    0x870e=>"\x8f\xf7\xd2",
    0x870f=>"",
    0x8710=>"\x8f\xf7\xd3",
    0x8713=>"\x8f\xf7\xd4",
    0x8714=>"",
    0x8719=>"\x8f\xf7\xd5",
    0x871e=>"",
    0x871f=>"\x8f\xf7\xd6",
    0x8721=>"\x8f\xf7\xd7",
    0x8723=>"\x8f\xf7\xd8",
    0x8728=>"",
    0x872e=>"",
    0x872f=>"",
    0x8731=>"\x8f\xf7\xd9",
    0x8732=>"",
    0x8739=>"",
    0x873a=>"\x8f\xf7\xda",
    0x873c=>"",
    0x873d=>"",
    0x873e=>"\x8f\xf7\xdb",
    0x8740=>"\x8f\xf7\xdc",
    0x8743=>"\x8f\xf7\xdd",
    0x8745=>"",
    0x874d=>"",
    0x8751=>"\x8f\xf7\xde",
    0x8758=>"\x8f\xf7\xdf",
    0x875d=>"",
    0x8761=>"",
    0x8764=>"\x8f\xf7\xe0",
    0x8765=>"\x8f\xf7\xe1",
    0x876f=>"",
    0x8771=>"\xfb\xda",
    0x8772=>"\x8f\xf7\xe2",
    0x877b=>"",
    0x877c=>"\x8f\xf7\xe3",
    0x8783=>"",
    0x8784=>"",
    0x8785=>"",
    0x8786=>"",
    0x8787=>"\xfb\xdb",
    0x8788=>"\xfb\xdc",
    0x8789=>"\x8f\xf7\xe7",
    0x878b=>"\x8f\xf7\xe8",
    0x878c=>"",
    0x8790=>"",
    0x8793=>"\x8f\xf7\xe9",
    0x8795=>"",
    0x8797=>"",
    0x8798=>"",
    0x8799=>"",
    0x879e=>"",
    0x87a0=>"\x8f\xf7\xea",
    0x87a3=>"",
    0x87a7=>"\x8f\xf7\xe6",
    0x87ac=>"\xfb\xdd",
    0x87ad=>"\xfb\xde",
    0x87ae=>"",
    0x87b1=>"",
    0x87b5=>"\xfb\xdf",
    0x87be=>"\x8f\xf7\xed",
    0x87bf=>"",
    0x87c1=>"\x8f\xf7\xef",
    0x87c8=>"",
    0x87c9=>"",
    0x87ca=>"",
    0x87ce=>"\x8f\xf7\xf0",
    0x87d5=>"",
    0x87d6=>"\xfb\xe1",
    0x87d9=>"",
    0x87da=>"",
    0x87dc=>"",
    0x87df=>"\x8f\xf7\xf2",
    0x87e2=>"",
    0x87e3=>"\x8f\xf7\xf4",
    0x87e4=>"",
    0x87e5=>"\x8f\xf7\xf5",
    0x87e6=>"\x8f\xf7\xf6",
    0x87ea=>"\x8f\xf7\xf7",
    0x87eb=>"\x8f\xf7\xf8",
    0x87ec=>"\xfb\xe2",
    0x87ed=>"\x8f\xf7\xf9",
    0x87f1=>"",
    0x87f3=>"",
    0x87f5=>"\x8f\xf7\xf1",
    0x87f8=>"",
    0x87fa=>"",
    0x87ff=>"",
    0x8801=>"\x8f\xf7\xfa",
    0x8803=>"\x8f\xf7\xfb",
    0x8806=>"\xfb\xe3",
    0x8809=>"",
    0x880a=>"\xfb\xe4",
    0x880b=>"\x8f\xf7\xfc",
    0x8810=>"\xfb\xe5",
    0x8812=>"",
    0x8813=>"\x8f\xf7\xfd",
    0x8814=>"\xfb\xe6",
    0x8818=>"",
    0x8819=>"",
    0x881a=>"",
    0x881b=>"",
    0x881c=>"",
    0x881e=>"",
    0x881f=>"\xfb\xe7",
    0x8828=>"\x8f\xf7\xfe",
    0x882d=>"",
    0x882e=>"\x8f\xf8\xa1",
    0x8830=>"",
    0x8832=>"\x8f\xf8\xa2",
    0x8835=>"",
    0x883a=>"",
    0x883c=>"\x8f\xf8\xa3",
    0x8841=>"",
    0x8843=>"",
    0x8845=>"",
    0x8848=>"",
    0x8849=>"",
    0x884a=>"\x8f\xf8\xa5",
    0x884b=>"",
    0x884e=>"",
    0x8851=>"",
    0x8855=>"",
    0x8856=>"",
    0x8858=>"\x8f\xf8\xa6",
    0x885a=>"",
    0x885c=>"",
    0x885f=>"\x8f\xf8\xa7",
    0x8860=>"",
    0x8864=>"\x8f\xf8\xa8",
    0x8869=>"\x8f\xf8\xab",
    0x886f=>"\x8f\xf8\xad",
    0x8871=>"",
    0x8879=>"",
    0x887b=>"",
    0x8880=>"",
    0x8898=>"\xfb\xe8",
    0x889a=>"",
    0x889b=>"",
    0x889c=>"",
    0x889f=>"",
    0x88a0=>"\x8f\xf8\xae",
    0x88a8=>"",
    0x88aa=>"\xfb\xe9",
    0x88ba=>"",
    0x88bc=>"\x8f\xf8\xaf",
    0x88bd=>"\x8f\xf8\xb0",
    0x88be=>"\x8f\xf8\xb1",
    0x88c0=>"\x8f\xf8\xb2",
    0x88ca=>"\xfb\xea",
    0x88cb=>"",
    0x88cc=>"",
    0x88cd=>"",
    0x88ce=>"\xfb\xeb",
    0x88d1=>"\x8f\xf8\xb5",
    0x88d2=>"\x8f\xf8\xb3",
    0x88d3=>"\x8f\xf8\xb6",
    0x88db=>"\x8f\xf8\xb7",
    0x88de=>"",
    0x88e7=>"",
    0x88ef=>"",
    0x88f0=>"\x8f\xf8\xb8",
    0x88f1=>"\x8f\xf8\xb9",
    0x88f5=>"\xfb\xed",
    0x88f7=>"",
    0x8901=>"\x8f\xf8\xbb",
    0x8906=>"",
    0x890d=>"",
    0x890e=>"",
    0x890f=>"",
    0x8915=>"",
    0x8916=>"",
    0x8918=>"\xfb\xf0",
    0x8919=>"\xfb\xf1",
    0x891a=>"\xfb\xf2",
    0x891c=>"\xfb\xee",
    0x8920=>"",
    0x8926=>"",
    0x8927=>"\xfb\xf3",
    0x8928=>"",
    0x8930=>"\xfb\xf4",
    0x8931=>"",
    0x8932=>"\xfb\xf5",
    0x8935=>"",
    0x8937=>"\x8f\xf8\xbd",
    0x8939=>"\xfb\xf6",
    0x893a=>"",
    0x893e=>"",
    0x8940=>"\xfb\xf7",
    0x8942=>"\x8f\xf8\xbf",
    0x8945=>"\x8f\xf8\xc0",
    0x8946=>"",
    0x8949=>"\x8f\xf8\xc1",
    0x894f=>"",
    0x8952=>"",
    0x8957=>"",
    0x895a=>"",
    0x895b=>"",
    0x895c=>"",
    0x8961=>"",
    0x8962=>"\x8f\xf8\xc4",
    0x8963=>"",
    0x896b=>"",
    0x896e=>"",
    0x8970=>"",
    0x8973=>"",
    0x8975=>"",
    0x897a=>"",
    0x897b=>"",
    0x897c=>"",
    0x897d=>"",
    0x8980=>"\x8f\xf8\xc5",
    0x8989=>"\x8f\xf8\xc6",
    0x898d=>"",
    0x8990=>"\x8f\xf8\xc7",
    0x8994=>"\xfb\xf8",
    0x8995=>"",
    0x899b=>"",
    0x899c=>"",
    0x899f=>"\x8f\xf8\xc8",
    0x89a0=>"",
    0x89a5=>"",
    0x89b0=>"\x8f\xf8\xc9",
    0x89b4=>"",
    0x89b5=>"",
    0x89b6=>"",
    0x89b7=>"\x8f\xf8\xca",
    0x89bc=>"",
    0x89d4=>"\xfb\xfa",
    0x89d5=>"",
    0x89d6=>"\x8f\xf8\xcb",
    0x89d7=>"",
    0x89d8=>"\x8f\xf8\xcc",
    0x89e5=>"\xfb\xfb",
    0x89e9=>"",
    0x89eb=>"\x8f\xf8\xcd",
    0x89ed=>"",
    0x89f1=>"\x8f\xf8\xcf",
    0x89f3=>"\x8f\xf8\xd0",
    0x89f6=>"\xfb\xfc",
    0x89f9=>"",
    0x89fd=>"\x8f\xf8\xd1",
    0x89ff=>"\x8f\xf8\xd2",
    0x8a04=>"",
    0x8a05=>"",
    0x8a07=>"",
    0x8a0f=>"",
    0x8a11=>"\x8f\xf8\xd4",
    0x8a12=>"\xfb\xfd",
    0x8a14=>"\x8f\xf8\xd5",
    0x8a15=>"\xfb\xfe",
    0x8a1e=>"",
    0x8a20=>"",
    0x8a21=>"\x8f\xf8\xd7",
    0x8a22=>"\xfc\xa1",
    0x8a24=>"",
    0x8a26=>"",
    0x8a2b=>"",
    0x8a2c=>"",
    0x8a2f=>"",
    0x8a35=>"\x8f\xf8\xd8",
    0x8a37=>"\xfc\xa2",
    0x8a3d=>"",
    0x8a3e=>"\x8f\xf8\xd9",
    0x8a40=>"",
    0x8a43=>"",
    0x8a45=>"\x8f\xf8\xda",
    0x8a47=>"\xfc\xa3",
    0x8a49=>"",
    0x8a4d=>"\x8f\xf8\xdb",
    0x8a4e=>"\xfc\xa4",
    0x8a53=>"",
    0x8a56=>"",
    0x8a57=>"",
    0x8a58=>"\x8f\xf8\xdc",
    0x8a5c=>"",
    0x8a5d=>"\xfc\xa5",
    0x8a61=>"\xfc\xa6",
    0x8a65=>"",
    0x8a67=>"",
    0x8a75=>"\xfc\xa7",
    0x8a76=>"",
    0x8a77=>"",
    0x8a79=>"\xfc\xa8",
    0x8a7a=>"",
    0x8a7b=>"",
    0x8a7e=>"",
    0x8a7f=>"",
    0x8a80=>"",
    0x8a83=>"",
    0x8a86=>"",
    0x8a8b=>"",
    0x8a8f=>"",
    0x8a90=>"\x8f\xf8\xde",
    0x8a92=>"",
    0x8a96=>"",
    0x8a97=>"",
    0x8a99=>"",
    0x8a9f=>"",
    0x8aa7=>"\xfc\xa9",
    0x8aa9=>"",
    0x8aae=>"\x8f\xf8\xdd",
    0x8aaf=>"",
    0x8ab3=>"",
    0x8ab6=>"",
    0x8ab7=>"\x8f\xf8\xdf",
    0x8abb=>"",
    0x8abe=>"\x8f\xf8\xe0",
    0x8ac3=>"",
    0x8ac6=>"",
    0x8ac8=>"",
    0x8ac9=>"",
    0x8aca=>"",
    0x8ad0=>"\xfc\xaa",
    0x8ad1=>"",
    0x8ad3=>"",
    0x8ad4=>"",
    0x8ad5=>"",
    0x8ad7=>"\x8f\xf8\xe1",
    0x8add=>"",
    0x8adf=>"\xfc\xab",
    0x8aec=>"",
    0x8af0=>"",
    0x8af4=>"\xfc\xac",
    0x8af5=>"",
    0x8af6=>"\xfc\xad",
    0x8afc=>"\x8f\xf8\xe2",
    0x8aff=>"",
    0x8b05=>"\x8f\xf8\xe5",
    0x8b06=>"",
    0x8b0a=>"\x8f\xf8\xe4",
    0x8b0b=>"",
    0x8b0d=>"\x8f\xf8\xe6",
    0x8b11=>"",
    0x8b1c=>"\x8f\xf8\xe7",
    0x8b1e=>"",
    0x8b1f=>"\x8f\xf8\xe8",
    0x8b2d=>"\x8f\xf8\xe9",
    0x8b30=>"",
    0x8b37=>"",
    0x8b3c=>"",
    0x8b42=>"",
    0x8b43=>"\x8f\xf8\xea",
    0x8b44=>"",
    0x8b45=>"",
    0x8b46=>"\xfc\xb1",
    0x8b48=>"",
    0x8b4d=>"",
    0x8b51=>"\x8f\xf8\xec",
    0x8b52=>"",
    0x8b53=>"",
    0x8b54=>"\xfc\xb2",
    0x8b59=>"\xfc\xb3",
    0x8b5e=>"\x8f\xf8\xed",
    0x8b63=>"",
    0x8b69=>"\xfc\xb4",
    0x8b6d=>"",
    0x8b76=>"\x8f\xf8\xee",
    0x8b78=>"",
    0x8b79=>"",
    0x8b7c=>"",
    0x8b7e=>"",
    0x8b7f=>"\x8f\xf8\xef",
    0x8b81=>"\x8f\xf8\xf0",
    0x8b84=>"",
    0x8b85=>"",
    0x8b8b=>"\x8f\xf8\xf1",
    0x8b8d=>"",
    0x8b8f=>"",
    0x8b94=>"\x8f\xf8\xf2",
    0x8b95=>"\x8f\xf8\xf3",
    0x8b9c=>"\x8f\xf8\xf4",
    0x8b9d=>"\xfc\xb5",
    0x8b9e=>"\x8f\xf8\xf5",
    0x8b9f=>"",
    0x8c38=>"",
    0x8c39=>"\x8f\xf8\xf6",
    0x8c3d=>"\x8f\xf8\xf8",
    0x8c3e=>"",
    0x8c45=>"\x8f\xf8\xfb",
    0x8c47=>"\x8f\xf8\xfc",
    0x8c49=>"\xfc\xb6",
    0x8c4b=>"",
    0x8c4f=>"\x8f\xf8\xfd",
    0x8c51=>"",
    0x8c53=>"",
    0x8c54=>"\x8f\xf8\xfe",
    0x8c57=>"\x8f\xf9\xa1",
    0x8c58=>"",
    0x8c59=>"",
    0x8c5b=>"",
    0x8c5d=>"",
    0x8c63=>"",
    0x8c64=>"",
    0x8c66=>"",
    0x8c68=>"\xfc\xb7",
    0x8c69=>"\x8f\xf9\xa2",
    0x8c6d=>"\x8f\xf9\xa3",
    0x8c73=>"\x8f\xf9\xa4",
    0x8c75=>"",
    0x8c76=>"",
    0x8c7b=>"",
    0x8c7e=>"",
    0x8c86=>"",
    0x8c87=>"",
    0x8c8b=>"",
    0x8c90=>"",
    0x8c92=>"\x8f\xf9\xa7",
    0x8c93=>"\x8f\xf9\xa6",
    0x8c99=>"\x8f\xf9\xa8",
    0x8c9b=>"\x8f\xf9\xaa",
    0x8c9c=>"",
    0x8ca4=>"\x8f\xf9\xab",
    0x8cb9=>"",
    0x8cba=>"",
    0x8cc5=>"",
    0x8cc6=>"",
    0x8cc9=>"",
    0x8ccb=>"",
    0x8ccf=>"",
    0x8cd5=>"\x8f\xf9\xad",
    0x8cd6=>"\x8f\xf9\xac",
    0x8cd9=>"\x8f\xf9\xae",
    0x8cdd=>"",
    0x8ce1=>"\xfc\xb9",
    0x8ce8=>"",
    0x8cec=>"",
    0x8cef=>"",
    0x8cf0=>"\x8f\xf9\xb0",
    0x8cf1=>"\x8f\xf9\xb1",
    0x8cf2=>"",
    0x8cf4=>"\xfc\xba",
    0x8cf5=>"",
    0x8cf7=>"",
    0x8cf8=>"\xfc\xbb",
    0x8cfe=>"\xfc\xbc",
    0x8cff=>"",
    0x8d01=>"",
    0x8d03=>"",
    0x8d09=>"\x8f\xf9\xb3",
    0x8d0e=>"\x8f\xf9\xb4",
    0x8d12=>"\xfc\xbe",
    0x8d17=>"",
    0x8d1b=>"\xfc\xbf",
    0x8d65=>"",
    0x8d69=>"",
    0x8d6c=>"\x8f\xf9\xb5",
    0x8d6e=>"",
    0x8d7f=>"",
    0x8d82=>"",
    0x8d84=>"\x8f\xf9\xb6",
    0x8d88=>"",
    0x8d8d=>"",
    0x8d90=>"",
    0x8d91=>"",
    0x8d95=>"\x8f\xf9\xb7",
    0x8d9e=>"",
    0x8d9f=>"",
    0x8da0=>"",
    0x8da6=>"\x8f\xf9\xb8",
    0x8dab=>"",
    0x8dac=>"",
    0x8daf=>"\xfc\xc0",
    0x8db2=>"",
    0x8db5=>"",
    0x8db7=>"",
    0x8db9=>"",
    0x8dbb=>"",
    0x8dbc=>"",
    0x8dc0=>"",
    0x8dc5=>"",
    0x8dc6=>"\x8f\xf9\xba",
    0x8dc7=>"",
    0x8dc8=>"\x8f\xf9\xbb",
    0x8dca=>"",
    0x8dce=>"\xfc\xc1",
    0x8dd1=>"\xfc\xc2",
    0x8dd4=>"",
    0x8dd5=>"",
    0x8dd7=>"\xfc\xc3",
    0x8dd9=>"\x8f\xf9\xbc",
    0x8de4=>"",
    0x8de5=>"",
    0x8de7=>"",
    0x8dec=>"\x8f\xf9\xbd",
    0x8df0=>"",
    0x8df1=>"",
    0x8df2=>"",
    0x8df4=>"",
    0x8dfd=>"\x8f\xf9\xc0",
    0x8e01=>"",
    0x8e04=>"",
    0x8e05=>"",
    0x8e06=>"\x8f\xf9\xc1",
    0x8e0b=>"",
    0x8e0c=>"\x8f\xf9\xbe",
    0x8e11=>"",
    0x8e14=>"\x8f\xf9\xc3",
    0x8e16=>"\x8f\xf9\xc4",
    0x8e20=>"\xfc\xc4",
    0x8e21=>"\x8f\xf9\xc5",
    0x8e22=>"\x8f\xf9\xc6",
    0x8e23=>"\xfc\xc5",
    0x8e26=>"",
    0x8e27=>"\x8f\xf9\xc7",
    0x8e31=>"",
    0x8e33=>"",
    0x8e36=>"\x8f\xf9\xca",
    0x8e37=>"",
    0x8e38=>"",
    0x8e39=>"\x8f\xf9\xcb",
    0x8e3d=>"\xfc\xc6",
    0x8e40=>"",
    0x8e41=>"",
    0x8e4b=>"\x8f\xf9\xcc",
    0x8e4d=>"",
    0x8e4e=>"",
    0x8e4f=>"",
    0x8e54=>"\x8f\xf9\xcd",
    0x8e5b=>"",
    0x8e5c=>"",
    0x8e5d=>"",
    0x8e5e=>"",
    0x8e61=>"",
    0x8e62=>"\x8f\xf9\xce",
    0x8e69=>"",
    0x8e6c=>"\x8f\xf9\xcf",
    0x8e6d=>"\x8f\xf9\xd0",
    0x8e6f=>"\x8f\xf9\xd1",
    0x8e70=>"\xfc\xc7",
    0x8e71=>"",
    0x8e79=>"",
    0x8e7a=>"",
    0x8e7b=>"\xfc\xc8",
    0x8e82=>"",
    0x8e83=>"",
    0x8e89=>"",
    0x8e90=>"",
    0x8e92=>"",
    0x8e95=>"",
    0x8e98=>"\x8f\xf9\xd2",
    0x8e9a=>"",
    0x8e9b=>"",
    0x8e9d=>"",
    0x8e9e=>"\x8f\xf9\xd3",
    0x8ea2=>"",
    0x8ea7=>"",
    0x8ea9=>"",
    0x8ead=>"",
    0x8eae=>"\x8f\xf9\xd4",
    0x8eb3=>"\x8f\xf9\xd5",
    0x8eb5=>"\x8f\xf9\xd6",
    0x8eb6=>"\x8f\xf9\xd7",
    0x8eba=>"",
    0x8ebb=>"\x8f\xf9\xd8",
    0x8ec0=>"\xfc\xca",
    0x8ec1=>"",
    0x8ec3=>"",
    0x8ec4=>"",
    0x8ec7=>"",
    0x8ecf=>"",
    0x8ed1=>"\x8f\xf9\xda",
    0x8ed4=>"\x8f\xf9\xdb",
    0x8edc=>"",
    0x8ee8=>"",
    0x8eed=>"",
    0x8eee=>"",
    0x8ef0=>"",
    0x8ef1=>"",
    0x8ef7=>"",
    0x8ef9=>"\x8f\xf9\xdd",
    0x8efa=>"\xfc\xcc",
    0x8f00=>"\x8f\xf9\xdf",
    0x8f02=>"",
    0x8f07=>"",
    0x8f08=>"\x8f\xf9\xe0",
    0x8f0f=>"",
    0x8f10=>"",
    0x8f16=>"",
    0x8f17=>"\x8f\xf9\xe1",
    0x8f18=>"",
    0x8f1e=>"\xfc\xcd",
    0x8f20=>"",
    0x8f21=>"",
    0x8f23=>"",
    0x8f25=>"",
    0x8f27=>"",
    0x8f28=>"",
    0x8f2b=>"\x8f\xf9\xe2",
    0x8f2c=>"",
    0x8f2d=>"\xfc\xce",
    0x8f2e=>"",
    0x8f34=>"",
    0x8f35=>"",
    0x8f36=>"\xfc\xcf",
    0x8f37=>"",
    0x8f3a=>"",
    0x8f40=>"\x8f\xf9\xe3",
    0x8f41=>"",
    0x8f43=>"",
    0x8f47=>"",
    0x8f4a=>"\x8f\xf9\xe4",
    0x8f4f=>"",
    0x8f51=>"",
    0x8f52=>"",
    0x8f53=>"",
    0x8f54=>"\xfc\xd0",
    0x8f55=>"",
    0x8f58=>"\x8f\xf9\xe5",
    0x8f5d=>"",
    0x8f5e=>"",
    0x8f65=>"",
    0x8f9d=>"",
    0x8fa0=>"",
    0x8fa1=>"",
    0x8fa4=>"\x8f\xf9\xe7",
    0x8fa5=>"",
    0x8fa6=>"\xfc\xd2",
    0x8fb4=>"\x8f\xf9\xe8",
    0x8fb5=>"\xfc\xd3",
    0x8fb6=>"\x8f\xf9\xea",
    0x8fb8=>"",
    0x8fbe=>"",
    0x8fc0=>"",
    0x8fc1=>"\x8f\xf9\xec",
    0x8fc6=>"\x8f\xf9\xed",
    0x8fca=>"\x8f\xf9\xef",
    0x8fcb=>"",
    0x8fcd=>"\x8f\xf9\xf0",
    0x8fd0=>"",
    0x8fd2=>"",
    0x8fd3=>"\x8f\xf9\xf1",
    0x8fd5=>"\x8f\xf9\xf2",
    0x8fe0=>"\x8f\xf9\xf3",
    0x8fe3=>"",
    0x8fe4=>"\xfc\xd4",
    0x8fe8=>"\xfc\xd5",
    0x8fee=>"\xfc\xd6",
    0x8ff1=>"\x8f\xf9\xf4",
    0x8ff5=>"\x8f\xf9\xf5",
    0x8ff6=>"",
    0x8ffb=>"\x8f\xf9\xf6",
    0x8ffe=>"",
    0x9002=>"\x8f\xf9\xf7",
    0x9004=>"",
    0x9008=>"\xfc\xd7",
    0x900c=>"\x8f\xf9\xf8",
    0x9018=>"",
    0x901b=>"",
    0x9028=>"",
    0x9029=>"",
    0x902a=>"",
    0x902c=>"",
    0x902d=>"\xfc\xd8",
    0x902f=>"",
    0x9033=>"",
    0x9034=>"",
    0x9037=>"\x8f\xf9\xf9",
    0x903f=>"",
    0x9043=>"\x8f\xf9\xfb",
    0x9044=>"\x8f\xf9\xfc",
    0x904c=>"",
    0x905b=>"",
    0x905d=>"\x8f\xf9\xfd",
    0x9062=>"",
    0x9066=>"",
    0x9067=>"",
    0x906c=>"",
    0x9070=>"",
    0x9074=>"",
    0x9079=>"",
    0x9085=>"\x8f\xfa\xa2",
    0x9088=>"\xfc\xda",
    0x908b=>"",
    0x908c=>"\x8f\xfa\xa3",
    0x908e=>"",
    0x9090=>"\x8f\xfa\xa4",
    0x9095=>"\xfc\xdb",
    0x9097=>"\xfc\xdc",
    0x9098=>"",
    0x9099=>"\xfc\xdd",
    0x909b=>"\xfc\xde",
    0x90a0=>"",
    0x90a1=>"\x8f\xfa\xa6",
    0x90a2=>"\xfc\xdf",
    0x90a5=>"",
    0x90b0=>"\x8f\xfa\xa8",
    0x90b2=>"",
    0x90b3=>"\xfc\xe0",
    0x90b4=>"",
    0x90b6=>"\x8f\xfa\xa9",
    0x90bd=>"",
    0x90be=>"\xfc\xe1",
    0x90c3=>"\x8f\xfa\xaa",
    0x90c4=>"\xfc\xe2",
    0x90c5=>"\xfc\xe3",
    0x90c7=>"\xfc\xe4",
    0x90c8=>"\x8f\xfa\xab",
    0x90cc=>"",
    0x90d2=>"",
    0x90d5=>"",
    0x90d7=>"\xfc\xe5",
    0x90d8=>"",
    0x90d9=>"",
    0x90dc=>"\x8f\xfa\xad",
    0x90dd=>"\xfc\xe6",
    0x90de=>"\xfc\xe7",
    0x90df=>"\x8f\xfa\xae",
    0x90e5=>"",
    0x90eb=>"\x8f\xfa\xb3",
    0x90ef=>"\xfc\xe8",
    0x90f0=>"",
    0x90f2=>"\x8f\xfa\xb1",
    0x90f4=>"\xfc\xe9",
    0x90f6=>"\x8f\xfa\xb0",
    0x90fe=>"\x8f\xfa\xb4",
    0x90ff=>"\x8f\xfa\xb5",
    0x9100=>"\x8f\xfa\xb2",
    0x9104=>"\x8f\xfa\xb6",
    0x9105=>"",
    0x9106=>"\x8f\xfa\xb7",
    0x9108=>"",
    0x910d=>"",
    0x9110=>"",
    0x9114=>"\xfc\xeb",
    0x9115=>"\xfc\xec",
    0x9116=>"\xfc\xed",
    0x9117=>"",
    0x9118=>"\x8f\xfa\xb8",
    0x911a=>"",
    0x911c=>"\x8f\xfa\xb9",
    0x911e=>"\x8f\xfa\xba",
    0x9120=>"",
    0x9122=>"\xfc\xee",
    0x9123=>"\xfc\xef",
    0x9125=>"",
    0x9127=>"\xfc\xf0",
    0x9129=>"",
    0x912e=>"",
    0x912f=>"\xfc\xf1",
    0x9131=>"\xfc\xf2",
    0x9134=>"\xfc\xf3",
    0x9136=>"",
    0x9137=>"\x8f\xfa\xbb",
    0x9139=>"\x8f\xfa\xbc",
    0x913a=>"\x8f\xfa\xbd",
    0x913c=>"",
    0x913d=>"\xfc\xf4",
    0x9143=>"",
    0x9146=>"\x8f\xfa\xbe",
    0x9147=>"\x8f\xfa\xbf",
    0x9148=>"\xfc\xf5",
    0x914f=>"",
    0x9153=>"",
    0x9157=>"\x8f\xfa\xc0",
    0x9159=>"\x8f\xfa\xc1",
    0x915a=>"",
    0x915b=>"\xfc\xf6",
    0x9161=>"\x8f\xfa\xc2",
    0x9164=>"\x8f\xfa\xc3",
    0x9167=>"",
    0x916d=>"",
    0x9174=>"\x8f\xfa\xc4",
    0x9179=>"\x8f\xfa\xc5",
    0x917a=>"",
    0x917b=>"",
    0x9181=>"",
    0x9183=>"\xfc\xf7",
    0x9185=>"\x8f\xfa\xc6",
    0x9186=>"",
    0x918a=>"",
    0x918e=>"\x8f\xfa\xc7",
    0x9191=>"",
    0x9193=>"",
    0x9194=>"",
    0x9195=>"",
    0x9198=>"",
    0x919e=>"\xfc\xf8",
    0x91a1=>"",
    0x91a6=>"",
    0x91a8=>"\x8f\xfa\xc8",
    0x91ac=>"\xfc\xf9",
    0x91ad=>"",
    0x91ae=>"\x8f\xfa\xc9",
    0x91b0=>"",
    0x91b1=>"\xfc\xfa",
    0x91b2=>"",
    0x91b3=>"\x8f\xfa\xca",
    0x91b6=>"\x8f\xfa\xcb",
    0x91bb=>"",
    0x91bc=>"\xfc\xfb",
    0x91bd=>"",
    0x91bf=>"",
    0x91c2=>"",
    0x91c3=>"\x8f\xfa\xcc",
    0x91c4=>"\x8f\xfa\xcd",
    0x91c5=>"",
    0x91d3=>"",
    0x91d4=>"",
    0x91d7=>"\xfc\xfc",
    0x91d9=>"",
    0x91da=>"\x8f\xfa\xce",
    0x91de=>"",
    0x91e4=>"\xfc\xfe",
    0x91e5=>"\xfd\xa1",
    0x91e9=>"",
    0x91ea=>"",
    0x91ec=>"\x8f\xfa\xd1",
    0x91ed=>"\xfd\xa2",
    0x91ee=>"\x8f\xfa\xd2",
    0x91ef=>"",
    0x91f0=>"",
    0x91f1=>"\xfd\xa3",
    0x91f7=>"",
    0x91f9=>"",
    0x91fb=>"\xfc\xfd",
    0x91fd=>"",
    0x9200=>"",
    0x9201=>"\x8f\xfa\xd3",
    0x9204=>"",
    0x9205=>"",
    0x9206=>"",
    0x9207=>"\xfd\xa4",
    0x9209=>"",
    0x920a=>"\x8f\xfa\xd4",
    0x920c=>"",
    0x9210=>"\xfd\xa5",
    0x9212=>"",
    0x9213=>"",
    0x9216=>"\x8f\xfa\xd5",
    0x9217=>"\x8f\xfa\xd6",
    0x9218=>"",
    0x921c=>"",
    0x921d=>"",
    0x9223=>"",
    0x9224=>"",
    0x9225=>"",
    0x9226=>"",
    0x9228=>"",
    0x922e=>"",
    0x922f=>"",
    0x9230=>"",
    0x9233=>"\x8f\xfa\xd8",
    0x9235=>"",
    0x9236=>"",
    0x9238=>"\xfd\xa6",
    0x9239=>"\xfd\xa7",
    0x923a=>"\xfd\xa8",
    0x923c=>"\xfd\xa9",
    0x923e=>"",
    0x9240=>"\xfd\xaa",
    0x9242=>"\x8f\xfa\xd9",
    0x9243=>"\xfd\xab",
    0x9246=>"",
    0x9247=>"\x8f\xfa\xda",
    0x924a=>"\x8f\xfa\xdb",
    0x924d=>"",
    0x924e=>"\x8f\xfa\xdc",
    0x924f=>"\xfd\xac",
    0x9251=>"\x8f\xfa\xdd",
    0x9256=>"\x8f\xfa\xde",
    0x9258=>"",
    0x9259=>"\x8f\xfa\xdf",
    0x925c=>"",
    0x925d=>"",
    0x9260=>"\x8f\xfa\xe0",
    0x9261=>"\x8f\xfa\xe1",
    0x9265=>"\x8f\xfa\xe2",
    0x9267=>"\x8f\xfa\xe3",
    0x9268=>"\x8f\xfa\xe4",
    0x9269=>"",
    0x926e=>"",
    0x926f=>"",
    0x9270=>"",
    0x9275=>"",
    0x9276=>"",
    0x9277=>"",
    0x9278=>"\xfd\xad",
    0x9279=>"",
    0x927b=>"",
    0x927c=>"\x8f\xfa\xe7",
    0x927d=>"\x8f\xfa\xe8",
    0x927f=>"\x8f\xfa\xe9",
    0x9288=>"\xfd\xae",
    0x9289=>"\x8f\xfa\xea",
    0x928a=>"",
    0x928d=>"\x8f\xfa\xeb",
    0x928e=>"",
    0x9292=>"",
    0x9297=>"\x8f\xfa\xec",
    0x9299=>"\x8f\xfa\xed",
    0x929f=>"\x8f\xfa\xee",
    0x92a0=>"",
    0x92a4=>"",
    0x92a5=>"",
    0x92a7=>"\x8f\xfa\xef",
    0x92a8=>"",
    0x92ab=>"\x8f\xfa\xf0",
    0x92af=>"",
    0x92b2=>"\x8f\xfa\xf3",
    0x92b6=>"",
    0x92b8=>"",
    0x92ba=>"",
    0x92bb=>"",
    0x92bc=>"",
    0x92bd=>"",
    0x92bf=>"\x8f\xfa\xf4",
    0x92c0=>"\x8f\xfa\xf5",
    0x92c1=>"",
    0x92c2=>"\xfd\xaf",
    0x92c3=>"",
    0x92c5=>"",
    0x92c6=>"\x8f\xfa\xf6",
    0x92c7=>"",
    0x92c8=>"",
    0x92cb=>"\xfd\xb0",
    0x92cc=>"\xfd\xb1",
    0x92cd=>"",
    0x92ce=>"\x8f\xfa\xf7",
    0x92d0=>"\x8f\xfa\xf8",
    0x92d3=>"\xfd\xb2",
    0x92d5=>"",
    0x92d7=>"\x8f\xfa\xf9",
    0x92d8=>"",
    0x92d9=>"\x8f\xfa\xfa",
    0x92dc=>"",
    0x92dd=>"",
    0x92df=>"",
    0x92e0=>"\xfd\xb3",
    0x92e1=>"",
    0x92e3=>"",
    0x92e5=>"\x8f\xfa\xfb",
    0x92e7=>"\x8f\xfa\xfc",
    0x92e8=>"",
    0x92ec=>"",
    0x92ee=>"",
    0x92f0=>"",
    0x92f7=>"\x8f\xfb\xa2",
    0x92f9=>"\x8f\xfb\xa3",
    0x92fb=>"\x8f\xfb\xa4",
    0x92ff=>"\xfd\xb4",
    0x9300=>"",
    0x9302=>"\x8f\xfb\xa5",
    0x9304=>"\xfd\xb5",
    0x9308=>"",
    0x930d=>"\x8f\xfb\xa6",
    0x9311=>"\x8f\xfa\xfd",
    0x9314=>"",
    0x9315=>"\x8f\xfb\xa7",
    0x931c=>"",
    0x931d=>"\x8f\xfb\xa8",
    0x931e=>"\x8f\xfb\xa9",
    0x931f=>"\xfd\xb6",
    0x9321=>"\xfd\xb7",
    0x9324=>"",
    0x9325=>"\xfd\xb8",
    0x9327=>"\x8f\xfb\xaa",
    0x9329=>"\x8f\xfb\xab",
    0x932a=>"",
    0x9333=>"",
    0x9334=>"",
    0x9336=>"",
    0x9337=>"",
    0x9347=>"\x8f\xfb\xae",
    0x9348=>"\xfd\xb9",
    0x9349=>"\xfd\xba",
    0x934a=>"\xfd\xbb",
    0x9350=>"",
    0x9351=>"\x8f\xfb\xaf",
    0x9352=>"",
    0x9355=>"",
    0x9357=>"\x8f\xfb\xb0",
    0x9358=>"",
    0x935a=>"\x8f\xfb\xb1",
    0x935e=>"",
    0x9364=>"\xfd\xbc",
    0x9365=>"\xfd\xbd",
    0x9367=>"",
    0x9369=>"",
    0x936a=>"\xfd\xbe",
    0x936b=>"\x8f\xfb\xb2",
    0x936d=>"",
    0x936f=>"",
    0x9370=>"\xfd\xbf",
    0x9371=>"\x8f\xfb\xb3",
    0x9373=>"\x8f\xfb\xb4",
    0x9374=>"",
    0x9376=>"",
    0x937a=>"",
    0x937d=>"",
    0x937f=>"",
    0x9380=>"",
    0x9381=>"",
    0x9382=>"",
    0x9388=>"\x8f\xfb\xb8",
    0x938a=>"",
    0x938b=>"\x8f\xfb\xb9",
    0x938d=>"",
    0x938f=>"\x8f\xfb\xba",
    0x9392=>"",
    0x9395=>"",
    0x9398=>"",
    0x939b=>"\xfd\xc0",
    0x939e=>"\x8f\xfb\xbb",
    0x93a1=>"\x8f\xfb\xb5",
    0x93a3=>"\xfd\xc1",
    0x93a4=>"",
    0x93a6=>"",
    0x93a8=>"",
    0x93a9=>"",
    0x93ab=>"",
    0x93b4=>"",
    0x93b5=>"",
    0x93b6=>"",
    0x93ba=>"\xfd\xc2",
    0x93c1=>"\x8f\xfb\xc0",
    0x93c4=>"",
    0x93c5=>"",
    0x93c6=>"\xfd\xc3",
    0x93c7=>"\x8f\xfb\xc1",
    0x93c9=>"",
    0x93ca=>"",
    0x93cb=>"",
    0x93cc=>"",
    0x93cd=>"",
    0x93d3=>"",
    0x93d9=>"",
    0x93dc=>"\x8f\xfb\xc2",
    0x93de=>"\xfd\xc4",
    0x93df=>"\xfd\xc5",
    0x93e2=>"\x8f\xfb\xc3",
    0x93e6=>"",
    0x93e7=>"\x8f\xfb\xc4",
    0x93f1=>"\x8f\xfb\xbf",
    0x93f5=>"\x8f\xfb\xbc",
    0x93f7=>"",
    0x93f8=>"",
    0x93f9=>"",
    0x93fa=>"",
    0x93fb=>"\x8f\xfb\xc9",
    0x93fd=>"\xfd\xc7",
    0x9401=>"",
    0x9402=>"",
    0x9404=>"\xfd\xc6",
    0x9408=>"",
    0x9409=>"\x8f\xfb\xc5",
    0x940d=>"",
    0x940e=>"",
    0x940f=>"\x8f\xfb\xc6",
    0x9415=>"",
    0x9416=>"\x8f\xfb\xc7",
    0x9417=>"\x8f\xfb\xc8",
    0x941f=>"",
    0x942e=>"",
    0x942f=>"",
    0x9431=>"",
    0x9432=>"\x8f\xfb\xca",
    0x9433=>"\xfd\xc8",
    0x9434=>"\x8f\xfb\xcb",
    0x943b=>"\x8f\xfb\xcc",
    0x943d=>"",
    0x943f=>"",
    0x9443=>"",
    0x9445=>"\x8f\xfb\xcd",
    0x9448=>"",
    0x944a=>"\xfd\xc9",
    0x944c=>"",
    0x9455=>"",
    0x9459=>"",
    0x945c=>"",
    0x945f=>"",
    0x9461=>"",
    0x9463=>"\xfd\xca",
    0x9468=>"",
    0x946b=>"\xfd\xcb",
    0x946d=>"\x8f\xfb\xd0",
    0x946e=>"",
    0x946f=>"\x8f\xfb\xd1",
    0x9471=>"\xfd\xcc",
    0x9472=>"\xfd\xcd",
    0x9483=>"",
    0x9484=>"",
    0x9578=>"\x8f\xfb\xd2",
    0x9579=>"\x8f\xfb\xd3",
    0x957e=>"",
    0x9584=>"",
    0x9586=>"\x8f\xfb\xd4",
    0x9588=>"",
    0x958c=>"\x8f\xfb\xd5",
    0x958d=>"\x8f\xfb\xd6",
    0x958e=>"\xfd\xce",
    0x959d=>"",
    0x959e=>"",
    0x959f=>"\xfd\xcf",
    0x95a1=>"",
    0x95a6=>"\xfd\xd0",
    0x95a9=>"\xfd\xd1",
    0x95ab=>"\x8f\xfb\xd8",
    0x95ac=>"\xfd\xd2",
    0x95b4=>"\x8f\xfb\xd9",
    0x95b6=>"\xfd\xd3",
    0x95ba=>"",
    0x95bd=>"\xfd\xd4",
    0x95bf=>"",
    0x95c6=>"",
    0x95c8=>"\x8f\xfb\xdb",
    0x95c9=>"",
    0x95cb=>"\xfd\xd5",
    0x95d0=>"\xfd\xd6",
    0x95d1=>"",
    0x95d2=>"",
    0x95d3=>"\xfd\xd7",
    0x95d9=>"",
    0x95da=>"\xfd\xd9",
    0x95dd=>"",
    0x95de=>"\xfd\xda",
    0x95df=>"",
    0x95e0=>"",
    0x95e4=>"",
    0x95e6=>"",
    0x961d=>"\x8f\xfa\xa5",
    0x961e=>"",
    0x9622=>"",
    0x9624=>"",
    0x9625=>"",
    0x9626=>"",
    0x962c=>"\x8f\xfb\xde",
    0x9631=>"",
    0x9633=>"\x8f\xfb\xdf",
    0x9634=>"\x8f\xfb\xe0",
    0x9637=>"",
    0x9638=>"",
    0x9639=>"",
    0x963a=>"",
    0x963c=>"\x8f\xfb\xe2",
    0x963d=>"",
    0x9641=>"\x8f\xfb\xe3",
    0x9652=>"",
    0x9654=>"",
    0x9656=>"",
    0x9657=>"",
    0x9658=>"\xfd\xdb",
    0x9661=>"\x8f\xfb\xe4",
    0x966e=>"",
    0x9674=>"",
    0x967b=>"",
    0x967c=>"",
    0x967e=>"",
    0x967f=>"",
    0x9681=>"",
    0x9682=>"\x8f\xfb\xe6",
    0x9683=>"",
    0x9684=>"\xfd\xdc",
    0x9689=>"",
    0x9691=>"",
    0x9696=>"",
    0x969a=>"\x8f\xfb\xe8",
    0x969d=>"\xfd\xde",
    0x969f=>"",
    0x96a4=>"\xfd\xdf",
    0x96a5=>"\xfd\xe0",
    0x96a6=>"",
    0x96a9=>"\x8f\xfb\xeb",
    0x96ae=>"",
    0x96af=>"\x8f\xfb\xec",
    0x96b3=>"\x8f\xfb\xed",
    0x96ba=>"\x8f\xfb\xee",
    0x96bd=>"\x8f\xfb\xef",
    0x96ca=>"",
    0x96d2=>"\xfd\xe1",
    0x96d8=>"\x8f\xfb\xf2",
    0x96da=>"\x8f\xfb\xf3",
    0x96dd=>"\x8f\xfb\xf4",
    0x96de=>"\xfd\xe2",
    0x96df=>"",
    0x96e9=>"\xfd\xe4",
    0x96ef=>"\xfd\xe5",
    0x96f1=>"",
    0x96fa=>"",
    0x9702=>"",
    0x9703=>"",
    0x9705=>"",
    0x9709=>"",
    0x9714=>"\x8f\xfb\xf6",
    0x971a=>"",
    0x971b=>"",
    0x971d=>"",
    0x9721=>"",
    0x9722=>"",
    0x9723=>"\x8f\xfb\xf7",
    0x9728=>"",
    0x9731=>"",
    0x9733=>"\xfd\xe6",
    0x9736=>"\x8f\xfb\xf9",
    0x973b=>"\xfd\xe7",
    0x9741=>"\x8f\xfb\xfa",
    0x9743=>"",
    0x9747=>"\x8f\xfb\xfb",
    0x974a=>"",
    0x974d=>"\xfd\xe8",
    0x974e=>"\xfd\xe9",
    0x974f=>"\xfd\xea",
    0x9755=>"\x8f\xfb\xfc",
    0x9757=>"\x8f\xfb\xfd",
    0x9758=>"",
    0x975a=>"\xfd\xeb",
    0x975b=>"\x8f\xfb\xfe",
    0x9763=>"",
    0x9767=>"",
    0x976a=>"\x8f\xfc\xa1",
    0x976e=>"\xfd\xec",
    0x9773=>"\xfd\xed",
    0x9776=>"",
    0x9777=>"",
    0x9778=>"",
    0x977b=>"",
    0x977d=>"",
    0x977f=>"",
    0x9780=>"",
    0x9789=>"",
    0x9795=>"\xfd\xee",
    0x9796=>"\x8f\xfc\xa4",
    0x9797=>"",
    0x9799=>"",
    0x979a=>"\x8f\xfc\xa5",
    0x979e=>"\x8f\xfc\xa6",
    0x979f=>"",
    0x97a2=>"\x8f\xfc\xa7",
    0x97ac=>"",
    0x97ae=>"\xfd\xef",
    0x97b1=>"\x8f\xfc\xa8",
    0x97b2=>"\x8f\xfc\xa9",
    0x97b5=>"",
    0x97b6=>"",
    0x97b8=>"",
    0x97b9=>"",
    0x97ba=>"\xfd\xf0",
    0x97bc=>"",
    0x97be=>"\x8f\xfc\xaa",
    0x97bf=>"",
    0x97c1=>"\xfd\xf1",
    0x97c4=>"",
    0x97c5=>"",
    0x97c7=>"",
    0x97c9=>"\xfd\xf2",
    0x97ca=>"",
    0x97cc=>"\x8f\xfc\xab",
    0x97cd=>"",
    0x97ce=>"",
    0x97d0=>"",
    0x97d1=>"\x8f\xfc\xac",
    0x97d4=>"\x8f\xfc\xad",
    0x97d7=>"",
    0x97d8=>"\x8f\xfc\xae",
    0x97d9=>"\x8f\xfc\xaf",
    0x97db=>"\xfd\xf4",
    0x97dd=>"",
    0x97de=>"\xfd\xf3",
    0x97e0=>"",
    0x97e1=>"\x8f\xfc\xb0",
    0x97e4=>"",
    0x97ef=>"",
    0x97f1=>"\x8f\xfc\xb1",
    0x97f4=>"\xfd\xf5",
    0x97f7=>"",
    0x97f8=>"",
    0x97fa=>"",
    0x9804=>"\x8f\xfc\xb2",
    0x9807=>"",
    0x980a=>"\xfd\xf7",
    0x980d=>"\x8f\xfc\xb3",
    0x980e=>"\x8f\xfc\xb4",
    0x9814=>"\x8f\xfc\xb5",
    0x9816=>"\x8f\xfc\xb6",
    0x9819=>"",
    0x981c=>"",
    0x981e=>"\xfd\xf8",
    0x9820=>"",
    0x9823=>"\x8f\xfc\xb9",
    0x9825=>"\x8f\xfc\xbc",
    0x9826=>"",
    0x982b=>"\xfd\xf9",
    0x982e=>"",
    0x982f=>"",
    0x9830=>"\xfd\xfa",
    0x9832=>"\x8f\xfc\xba",
    0x9833=>"\x8f\xfc\xbb",
    0x9835=>"",
    0x983e=>"",
    0x9844=>"",
    0x9847=>"\x8f\xfc\xbd",
    0x984a=>"",
    0x9851=>"",
    0x9852=>"\xfd\xfc",
    0x9853=>"\xfd\xfd",
    0x9856=>"\xfd\xfe",
    0x9857=>"\xfe\xa1",
    0x9859=>"\xfe\xa2",
    0x985a=>"\xfe\xa3",
    0x9862=>"",
    0x9863=>"",
    0x9865=>"\xfe\xa5",
    0x9866=>"\x8f\xfc\xbe",
    0x986a=>"",
    0x986c=>"\xfe\xa6",
    0x98ab=>"\x8f\xfc\xbf",
    0x98ad=>"\x8f\xfc\xc0",
    0x98ae=>"",
    0x98b0=>"\x8f\xfc\xc1",
    0x98b4=>"",
    0x98b7=>"\x8f\xfc\xc3",
    0x98b8=>"\x8f\xfc\xc4",
    0x98ba=>"\xfe\xa7",
    0x98bb=>"\x8f\xfc\xc5",
    0x98bc=>"\x8f\xfc\xc6",
    0x98bf=>"\x8f\xfc\xc7",
    0x98c2=>"\x8f\xfc\xc8",
    0x98c5=>"",
    0x98c7=>"\x8f\xfc\xc9",
    0x98c8=>"\xfe\xa8",
    0x98cb=>"\x8f\xfc\xca",
    0x98cc=>"",
    0x98e0=>"\x8f\xfc\xcb",
    0x98e1=>"\x8f\xfc\xcd",
    0x98e3=>"\x8f\xfc\xce",
    0x98e5=>"\x8f\xfc\xcf",
    0x98e6=>"",
    0x98e7=>"\xfe\xa9",
    0x98ea=>"\x8f\xfc\xd0",
    0x98f0=>"\x8f\xfc\xd1",
    0x98f1=>"\x8f\xfc\xd2",
    0x98f3=>"\x8f\xfc\xd3",
    0x98f6=>"",
    0x9902=>"",
    0x9907=>"",
    0x9908=>"\x8f\xfc\xd4",
    0x9911=>"",
    0x9915=>"",
    0x9916=>"\x8f\xfc\xd7",
    0x9917=>"\x8f\xfc\xd8",
    0x991a=>"\x8f\xfc\xda",
    0x991b=>"\x8f\xfc\xdb",
    0x991c=>"\x8f\xfc\xdc",
    0x991f=>"",
    0x9922=>"",
    0x9926=>"",
    0x9927=>"",
    0x992b=>"",
    0x9931=>"\x8f\xfc\xde",
    0x9932=>"\x8f\xfc\xdf",
    0x9933=>"\x8f\xfc\xe0",
    0x9934=>"",
    0x9935=>"",
    0x9939=>"",
    0x993a=>"\x8f\xfc\xe1",
    0x993b=>"\x8f\xfc\xe2",
    0x993c=>"\x8f\xfc\xe3",
    0x9940=>"\x8f\xfc\xe4",
    0x9941=>"\x8f\xfc\xe5",
    0x9946=>"\x8f\xfc\xe6",
    0x9947=>"",
    0x9948=>"",
    0x994d=>"\x8f\xfc\xe7",
    0x994e=>"\x8f\xfc\xe8",
    0x9954=>"",
    0x9958=>"\xfe\xaa",
    0x9959=>"",
    0x995b=>"",
    0x995c=>"\x8f\xfc\xe9",
    0x995e=>"",
    0x995f=>"\x8f\xfc\xea",
    0x9960=>"\x8f\xfc\xeb",
    0x999b=>"",
    0x999d=>"",
    0x999e=>"\xfe\xab",
    0x999f=>"",
    0x99a3=>"\x8f\xfc\xec",
    0x99a6=>"\x8f\xfc\xed",
    0x99b0=>"",
    0x99b1=>"",
    0x99b2=>"",
    0x99b5=>"",
    0x99b9=>"\x8f\xfc\xee",
    0x99ba=>"",
    0x99bd=>"\x8f\xfc\xef",
    0x99bf=>"\x8f\xfc\xf0",
    0x99c3=>"\x8f\xfc\xf1",
    0x99c9=>"\x8f\xfc\xf2",
    0x99d3=>"",
    0x99d4=>"\x8f\xfc\xf3",
    0x99d9=>"\x8f\xfc\xf4",
    0x99da=>"",
    0x99dc=>"",
    0x99de=>"\x8f\xfc\xf5",
    0x99e7=>"",
    0x99ea=>"",
    0x99eb=>"",
    0x99ec=>"",
    0x99f0=>"\x8f\xfc\xf7",
    0x99f4=>"",
    0x99f5=>"",
    0x99f9=>"\x8f\xfc\xf8",
    0x99fc=>"\x8f\xfc\xf9",
    0x99fd=>"",
    0x99fe=>"",
    0x9a02=>"\xfe\xac",
    0x9a03=>"\xfe\xad",
    0x9a04=>"",
    0x9a0a=>"\x8f\xfc\xfa",
    0x9a0b=>"",
    0x9a0c=>"",
    0x9a10=>"",
    0x9a11=>"\x8f\xfc\xfb",
    0x9a16=>"\x8f\xfc\xfc",
    0x9a1a=>"\x8f\xfc\xfd",
    0x9a1e=>"",
    0x9a20=>"\x8f\xfc\xfe",
    0x9a22=>"",
    0x9a23=>"",
    0x9a24=>"\xfe\xae",
    0x9a27=>"",
    0x9a2d=>"\xfe\xaf",
    0x9a2e=>"\xfe\xb0",
    0x9a31=>"\x8f\xfd\xa1",
    0x9a33=>"",
    0x9a35=>"",
    0x9a36=>"\x8f\xfd\xa2",
    0x9a38=>"\xfe\xb1",
    0x9a41=>"",
    0x9a44=>"\x8f\xfd\xa3",
    0x9a47=>"",
    0x9a4a=>"\xfe\xb2",
    0x9a4b=>"",
    0x9a4c=>"\x8f\xfd\xa4",
    0x9a4e=>"\xfe\xb3",
    0x9a51=>"",
    0x9a52=>"\xfe\xb4",
    0x9a54=>"",
    0x9a56=>"",
    0x9a58=>"\x8f\xfd\xa5",
    0x9a5d=>"",
    0x9aaa=>"",
    0x9aac=>"",
    0x9aae=>"",
    0x9aaf=>"\x8f\xfd\xa7",
    0x9ab2=>"",
    0x9ab4=>"",
    0x9ab5=>"",
    0x9ab6=>"\xfe\xb5",
    0x9ab7=>"\x8f\xfd\xa9",
    0x9ab9=>"\x8f\xfd\xab",
    0x9abb=>"",
    0x9abe=>"",
    0x9abf=>"",
    0x9ac1=>"\xfe\xb6",
    0x9ac3=>"\xfe\xb7",
    0x9ac6=>"\x8f\xfd\xad",
    0x9ac8=>"",
    0x9ace=>"\xfe\xb8",
    0x9ad0=>"\x8f\xfd\xae",
    0x9ad2=>"\x8f\xfd\xaf",
    0x9ad5=>"\x8f\xfd\xb0",
    0x9ad6=>"\xfe\xb9",
    0x9ad7=>"",
    0x9adb=>"",
    0x9adc=>"\x8f\xfd\xb2",
    0x9ae0=>"\x8f\xfd\xb3",
    0x9ae4=>"",
    0x9ae5=>"\x8f\xfd\xb4",
    0x9ae7=>"",
    0x9ae9=>"\x8f\xfd\xb5",
    0x9aec=>"",
    0x9af2=>"",
    0x9af3=>"",
    0x9af5=>"",
    0x9af9=>"\xfe\xba",
    0x9afa=>"",
    0x9afd=>"",
    0x9aff=>"",
    0x9b00=>"",
    0x9b01=>"",
    0x9b02=>"\xfe\xbb",
    0x9b03=>"\x8f\xfd\xb6",
    0x9b04=>"",
    0x9b05=>"",
    0x9b08=>"\xfe\xbc",
    0x9b09=>"",
    0x9b0b=>"",
    0x9b0c=>"\x8f\xfd\xb7",
    0x9b0d=>"",
    0x9b0e=>"",
    0x9b10=>"\x8f\xfd\xb8",
    0x9b12=>"\x8f\xfd\xb9",
    0x9b16=>"\x8f\xfd\xba",
    0x9b19=>"",
    0x9b1b=>"",
    0x9b1c=>"\x8f\xfd\xbb",
    0x9b20=>"\xfe\xbd",
    0x9b26=>"",
    0x9b2b=>"\x8f\xfd\xbc",
    0x9b2d=>"\xfe\xbf",
    0x9b33=>"\x8f\xfd\xbd",
    0x9b34=>"",
    0x9b35=>"",
    0x9b37=>"",
    0x9b39=>"",
    0x9b3a=>"",
    0x9b3d=>"\x8f\xfd\xbe",
    0x9b48=>"",
    0x9b4b=>"\x8f\xfd\xc0",
    0x9b4c=>"",
    0x9b55=>"",
    0x9b56=>"",
    0x9b57=>"",
    0x9b5b=>"",
    0x9b5e=>"\xfe\xc0",
    0x9b61=>"",
    0x9b63=>"\x8f\xfd\xc1",
    0x9b65=>"\x8f\xfd\xc2",
    0x9b66=>"\xfe\xc2",
    0x9b68=>"",
    0x9b6a=>"",
    0x9b6b=>"\x8f\xfd\xc3",
    0x9b6c=>"\x8f\xfd\xc4",
    0x9b6d=>"",
    0x9b6e=>"",
    0x9b72=>"\xfe\xc3",
    0x9b73=>"\x8f\xfd\xc5",
    0x9b75=>"\xfe\xc4",
    0x9b76=>"\x8f\xfd\xc6",
    0x9b77=>"\x8f\xfd\xc7",
    0x9b78=>"",
    0x9b79=>"\xfe\xc1",
    0x9b7f=>"",
    0x9b80=>"",
    0x9b84=>"\xfe\xc5",
    0x9b85=>"",
    0x9b86=>"",
    0x9b87=>"",
    0x9b89=>"",
    0x9b8a=>"\xfe\xc6",
    0x9b8b=>"",
    0x9b8d=>"",
    0x9b8f=>"\xfe\xc7",
    0x9b90=>"",
    0x9b94=>"",
    0x9b9a=>"",
    0x9b9d=>"",
    0x9b9e=>"\xfe\xc8",
    0x9ba6=>"\x8f\xfd\xc8",
    0x9ba7=>"\xfe\xc9",
    0x9ba9=>"",
    0x9bac=>"\x8f\xfd\xc9",
    0x9bb0=>"",
    0x9bb1=>"\x8f\xfd\xca",
    0x9bb2=>"\x8f\xfd\xcd",
    0x9bb7=>"",
    0x9bb8=>"\x8f\xfd\xce",
    0x9bbb=>"",
    0x9bbc=>"",
    0x9bbe=>"\x8f\xfd\xcf",
    0x9bbf=>"",
    0x9bc1=>"\xfe\xca",
    0x9bc7=>"\x8f\xfd\xd0",
    0x9bc8=>"",
    0x9bce=>"\xfe\xcb",
    0x9bd0=>"",
    0x9bd7=>"",
    0x9bd8=>"\x8f\xfd\xd2",
    0x9bdd=>"\x8f\xfd\xd3",
    0x9bdf=>"",
    0x9be5=>"\xfe\xcc",
    0x9be7=>"\x8f\xfd\xd4",
    0x9bea=>"\x8f\xfd\xd5",
    0x9beb=>"\x8f\xfd\xd6",
    0x9bee=>"\x8f\xfd\xd8",
    0x9bef=>"\x8f\xfd\xd7",
    0x9bf3=>"\x8f\xfd\xd1",
    0x9bf7=>"\x8f\xfd\xdc",
    0x9bf8=>"\xfe\xcd",
    0x9bf9=>"",
    0x9bfa=>"\x8f\xfd\xda",
    0x9bfd=>"\xfe\xce",
    0x9bff=>"",
    0x9c00=>"\xfe\xcf",
    0x9c02=>"",
    0x9c0b=>"",
    0x9c0f=>"",
    0x9c11=>"",
    0x9c16=>"\x8f\xfd\xde",
    0x9c18=>"\x8f\xfd\xdf",
    0x9c19=>"\x8f\xfd\xe0",
    0x9c1a=>"\x8f\xfd\xe1",
    0x9c1c=>"",
    0x9c1d=>"\x8f\xfd\xe2",
    0x9c1e=>"",
    0x9c22=>"\x8f\xfd\xe3",
    0x9c23=>"\xfe\xd0",
    0x9c26=>"",
    0x9c27=>"\x8f\xfd\xe4",
    0x9c28=>"",
    0x9c29=>"\x8f\xfd\xe5",
    0x9c2a=>"\x8f\xfd\xe6",
    0x9c31=>"\x8f\xfd\xe8",
    0x9c35=>"",
    0x9c36=>"\x8f\xfd\xe9",
    0x9c37=>"\x8f\xfd\xea",
    0x9c3d=>"",
    0x9c41=>"\xfe\xd1",
    0x9c43=>"",
    0x9c44=>"",
    0x9c45=>"\x8f\xfd\xeb",
    0x9c49=>"\x8f\xfd\xee",
    0x9c4a=>"\x8f\xfd\xef",
    0x9c4e=>"",
    0x9c4f=>"\xfe\xd2",
    0x9c50=>"\xfe\xd3",
    0x9c53=>"\xfe\xd4",
    0x9c54=>"\x8f\xfd\xf1",
    0x9c56=>"",
    0x9c58=>"\x8f\xfd\xf2",
    0x9c5b=>"\x8f\xfd\xf3",
    0x9c5c=>"\x8f\xfd\xec",
    0x9c5d=>"\x8f\xfd\xf4",
    0x9c5e=>"",
    0x9c5f=>"\x8f\xfd\xf5",
    0x9c63=>"\xfe\xd5",
    0x9c65=>"\xfe\xd6",
    0x9c68=>"",
    0x9c69=>"\x8f\xfd\xf6",
    0x9c6a=>"\x8f\xfd\xf7",
    0x9c6b=>"\x8f\xfd\xf8",
    0x9c6d=>"\x8f\xfd\xf9",
    0x9c6e=>"\x8f\xfd\xfa",
    0x9c70=>"\x8f\xfd\xfb",
    0x9c72=>"\x8f\xfd\xfc",
    0x9c75=>"\x8f\xfd\xfd",
    0x9c77=>"\xfe\xd7",
    0x9c7a=>"\x8f\xfd\xfe",
    0x9c7b=>"",
    0x9ce6=>"\x8f\xfe\xa1",
    0x9cf2=>"\x8f\xfe\xa2",
    0x9cf7=>"",
    0x9cf9=>"",
    0x9d02=>"\x8f\xfe\xa4",
    0x9d0b=>"\x8f\xfe\xa3",
    0x9d11=>"\x8f\xfe\xa6",
    0x9d17=>"\x8f\xfe\xa7",
    0x9d18=>"\x8f\xfe\xa8",
    0x9d1c=>"",
    0x9d1d=>"\xfe\xd8",
    0x9d1e=>"\xfe\xd9",
    0x9d2f=>"",
    0x9d30=>"",
    0x9d32=>"\x8f\xfe\xac",
    0x9d33=>"",
    0x9d34=>"",
    0x9d3a=>"",
    0x9d3c=>"",
    0x9d3d=>"",
    0x9d42=>"\x8f\xfe\xae",
    0x9d43=>"\xfe\xda",
    0x9d45=>"",
    0x9d47=>"\xfe\xdb",
    0x9d4a=>"\x8f\xfe\xaf",
    0x9d52=>"\xfe\xdc",
    0x9d53=>"",
    0x9d54=>"",
    0x9d5f=>"\x8f\xfe\xb0",
    0x9d62=>"\x8f\xfe\xb1",
    0x9d63=>"\xfe\xdd",
    0x9d65=>"",
    0x9d69=>"\x8f\xfe\xb3",
    0x9d6a=>"",
    0x9d6b=>"\x8f\xfe\xb4",
    0x9d70=>"\xfe\xde",
    0x9d73=>"\x8f\xfe\xb6",
    0x9d76=>"\x8f\xfe\xb7",
    0x9d77=>"\x8f\xfe\xb8",
    0x9d7b=>"",
    0x9d7c=>"\xfe\xdf",
    0x9d7e=>"\x8f\xfe\xb9",
    0x9d83=>"",
    0x9d84=>"\x8f\xfe\xba",
    0x9d86=>"",
    0x9d8a=>"\xfe\xe0",
    0x9d8d=>"\x8f\xfe\xbb",
    0x9d8e=>"",
    0x9d92=>"",
    0x9d93=>"",
    0x9d95=>"",
    0x9d96=>"\xfe\xe1",
    0x9d97=>"",
    0x9d98=>"",
    0x9d99=>"\x8f\xfe\xbc",
    0x9da1=>"\x8f\xfe\xbd",
    0x9daa=>"",
    0x9dac=>"\xfe\xe3",
    0x9dae=>"",
    0x9db1=>"",
    0x9db5=>"\x8f\xfe\xbf",
    0x9db9=>"\x8f\xfe\xc0",
    0x9dbc=>"\xfe\xe4",
    0x9dbd=>"\x8f\xfe\xc1",
    0x9dbf=>"\x8f\xfe\xbe",
    0x9dc0=>"\xfe\xe2",
    0x9dc3=>"\x8f\xfe\xc2",
    0x9dc7=>"\x8f\xfe\xc3",
    0x9dc9=>"\x8f\xfe\xc4",
    0x9dca=>"",
    0x9dd4=>"",
    0x9dd5=>"",
    0x9dd6=>"\x8f\xfe\xc5",
    0x9dd7=>"\xfe\xe5",
    0x9dda=>"\x8f\xfe\xc6",
    0x9dde=>"",
    0x9ddf=>"\x8f\xfe\xc7",
    0x9de0=>"\x8f\xfe\xc8",
    0x9de3=>"\x8f\xfe\xc9",
    0x9de5=>"",
    0x9de7=>"\xfe\xe7",
    0x9de9=>"",
    0x9deb=>"",
    0x9dee=>"",
    0x9df0=>"",
    0x9df3=>"",
    0x9df4=>"\x8f\xfe\xca",
    0x9dfe=>"",
    0x9e02=>"\x8f\xfe\xcd",
    0x9e07=>"\xfe\xe8",
    0x9e0a=>"\x8f\xfe\xcc",
    0x9e0d=>"\x8f\xfe\xce",
    0x9e0e=>"",
    0x9e10=>"",
    0x9e11=>"",
    0x9e12=>"",
    0x9e15=>"\xfe\xe9",
    0x9e16=>"",
    0x9e19=>"\x8f\xfe\xcf",
    0x9e1c=>"\x8f\xfe\xd0",
    0x9e1d=>"\x8f\xfe\xd1",
    0x9e7a=>"",
    0x9e7b=>"\x8f\xfe\xd2",
    0x9e7c=>"\xfe\xea",
    0x9e80=>"\x8f\xfe\xd4",
    0x9e82=>"",
    0x9e83=>"",
    0x9e84=>"",
    0x9e85=>"\x8f\xfe\xd5",
    0x9e87=>"",
    0x9e8e=>"",
    0x9e8f=>"",
    0x9e96=>"",
    0x9e98=>"",
    0x9e9b=>"\x8f\xfe\xd6",
    0x9e9e=>"\xfe\xeb",
    0x9ea4=>"\xfe\xec",
    0x9ea8=>"\x8f\xfe\xd7",
    0x9eac=>"\xfe\xed",
    0x9eae=>"",
    0x9eaf=>"\xfe\xee",
    0x9eb0=>"",
    0x9eb3=>"",
    0x9eb4=>"\xfe\xef",
    0x9eb5=>"\xfe\xf0",
    0x9ebd=>"\x8f\xfe\xd9",
    0x9ec3=>"\xfe\xf1",
    0x9ec6=>"",
    0x9ec8=>"",
    0x9ecb=>"",
    0x9ed1=>"\xfe\xf2",
    0x9ed5=>"",
    0x9edf=>"\x8f\xfe\xdb",
    0x9ee4=>"",
    0x9ee7=>"\x8f\xfe\xdc",
    0x9eec=>"",
    0x9eed=>"",
    0x9eee=>"\x8f\xfe\xdd",
    0x9ef0=>"",
    0x9ef1=>"",
    0x9ef2=>"",
    0x9ef5=>"",
    0x9ef8=>"",
    0x9eff=>"\x8f\xfe\xde",
    0x9f02=>"\x8f\xfe\xdf",
    0x9f03=>"\x8f\xfe\xe1",
    0x9f09=>"",
    0x9f0f=>"",
    0x9f10=>"\xfe\xf3",
    0x9f11=>"",
    0x9f12=>"",
    0x9f14=>"",
    0x9f16=>"",
    0x9f17=>"\x8f\xfe\xe2",
    0x9f19=>"\x8f\xfe\xe3",
    0x9f1a=>"",
    0x9f1b=>"",
    0x9f1f=>"",
    0x9f22=>"",
    0x9f26=>"",
    0x9f2a=>"",
    0x9f2b=>"",
    0x9f2f=>"\x8f\xfe\xe4",
    0x9f31=>"",
    0x9f32=>"",
    0x9f34=>"",
    0x9f37=>"\x8f\xfe\xe5",
    0x9f39=>"\xfe\xf4",
    0x9f3a=>"\x8f\xfe\xe6",
    0x9f3c=>"",
    0x9f3d=>"\x8f\xfe\xe7",
    0x9f3f=>"",
    0x9f41=>"\x8f\xfe\xe8",
    0x9f43=>"",
    0x9f44=>"",
    0x9f45=>"\x8f\xfe\xe9",
    0x9f46=>"\x8f\xfe\xea",
    0x9f47=>"",
    0x9f53=>"\x8f\xfe\xeb",
    0x9f55=>"\x8f\xfe\xec",
    0x9f56=>"",
    0x9f57=>"\xfe\xf5",
    0x9f58=>"\x8f\xfe\xed",
    0x9f5a=>"",
    0x9f5d=>"\x8f\xfe\xef",
    0x9f5e=>"",
    0x9f68=>"",
    0x9f69=>"\x8f\xfe\xf1",
    0x9f6d=>"\x8f\xfe\xf3",
    0x9f6e=>"",
    0x9f6f=>"",
    0x9f70=>"\x8f\xfe\xf4",
    0x9f71=>"",
    0x9f73=>"",
    0x9f75=>"\x8f\xfe\xf5",
    0x9f7a=>"",
    0x9f7d=>"",
    0x9f8f=>"",
    0x9f90=>"\xfe\xf6",
    0x9f91=>"",
    0x9f92=>"",
    0x9f94=>"\xfe\xf7",
    0x9f96=>"",
    0x9f97=>"\xfe\xf8",
    0x9f9e=>"",
    0x9fa1=>"",
    0x9fa2=>"\xfe\xf9",
    0x9fa3=>"",
    0x9fa5=>"",
    0xf91d=>"\xf6\xbb",
    0xf928=>"\xf4\xae",
    0xf929=>"\xf5\xce",
    0xf936=>"\xfb\xcf",
    0xf970=>"\xf6\xc9",
    0xf9d0=>"\xfe\xa4",
    0xf9dc=>"\xfd\xdd",
    0xfa0f=>"\xaf\xcb",
    0xfa10=>"\xaf\xd7",
    0xfa11=>"\xcf\xf2",
    0xfa13=>"\x8f\xae\xf9",
    0xfa14=>"\xf5\xfa",
    0xfa15=>"\xf7\xda",
    0xfa16=>"\xf7\xef",
    0xfa19=>"\xf9\xbc",
    0xfa1a=>"\xf9\xbd",
    0xfa1b=>"\xf9\xc1",
    0xfa1f=>"\xfb\xba",
    0xfa20=>"\x8f\xf7\xb8",
    0xfa21=>"\x8f\xf7\xc5",
    0xfa22=>"\xfc\xae",
    0xfa24=>"\x8f\xf9\xee",
    0xfa26=>"\xfc\xea",
    0xfa30=>"\xae\xb8",
    0xfa31=>"\xae\xc9",
    0xfa32=>"\xae\xd0",
    0xfa33=>"\xae\xe3",
    0xfa34=>"\xae\xe8",
    0xfa35=>"\xae\xee",
    0xfa36=>"\xaf\xac",
    0xfa37=>"\xaf\xaf",
    0xfa38=>"\xaf\xb6",
    0xfa39=>"\xaf\xda",
    0xfa3a=>"\xaf\xde",
    0xfa3b=>"\xcf\xe1",
    0xfa3c=>"\xcf\xe2",
    0xfa3d=>"\xf4\xd0",
    0xfa3e=>"\xf4\xdc",
    0xfa3f=>"\xf4\xde",
    0xfa40=>"\xf4\xe1",
    0xfa41=>"\xf5\xa8",
    0xfa42=>"\xf5\xab",
    0xfa43=>"\xf5\xc3",
    0xfa44=>"\xf5\xe5",
    0xfa45=>"\xf6\xe9",
    0xfa46=>"\xf6\xf7",
    0xfa47=>"\xf7\xa5",
    0xfa48=>"\xf7\xd5",
    0xfa49=>"\x8f\xf0\xa9",
    0xfa4a=>"\xf8\xa5",
    0xfa4b=>"\xf9\xa7",
    0xfa4c=>"\xf9\xb3",
    0xfa4d=>"\xf9\xb4",
    0xfa4e=>"\xf9\xb7",
    0xfa4f=>"\xf9\xb8",
    0xfa50=>"\xf9\xb9",
    0xfa51=>"\xf9\xbb",
    0xfa52=>"\xf9\xbf",
    0xfa53=>"\xf9\xc0",
    0xfa54=>"\xf9\xcd",
    0xfa55=>"\xf9\xd1",
    0xfa56=>"\xf9\xe4",
    0xfa57=>"\xfa\xae",
    0xfa58=>"\x8f\xf4\xd0",
    0xfa59=>"\xfa\xb3",
    0xfa5a=>"\xfa\xba",
    0xfa5b=>"\xfa\xc4",
    0xfa5c=>"\xfa\xd8",
    0xfa5d=>"\x8f\xf5\xf4",
    0xfa5e=>"\x8f\xf5\xf5",
    0xfa5f=>"\xfb\xa7",
    0xfa60=>"\xfb\xef",
    0xfa61=>"\xfb\xf9",
    0xfa62=>"\xfc\xaf",
    0xfa63=>"\xfc\xb0",
    0xfa64=>"\xfc\xb8",
    0xfa65=>"\xfc\xbd",
    0xfa66=>"\x8f\xf9\xe9",
    0xfa67=>"\xfc\xd9",
    0xfa68=>"\xfd\xe3",
    0xfa69=>"\xfd\xf6",
    0xfa6a=>"\xfd\xfb",
    0xfe45=>"\xa3\xbe",
    0xfe46=>"\xa3\xbd",
    0xff02=>"\xa2\xb0",
    0xff07=>"\xa2\xaf",
    0xff0d=>"\xa2\xb1",
    0xff3c=>"\xa1\xc0",
    0xff5e=>"\xa2\xb2",
    0xff5f=>"\xa2\xd6",
    0xff60=>"\xa2\xd7",
    0x2000b=>"\xae\xa2",
    0x20089=>"\x8f\xa1\xa1",
    0x200a2=>"\x8f\xa1\xab",
    0x200a4=>"\x8f\xa1\xae",
    0x201a2=>"\x8f\xa1\xb6",
    0x20213=>"\x8f\xa1\xc6",
    0x2032b=>"\x8f\xa1\xf0",
    0x20371=>"\x8f\xa1\xf9",
    0x20381=>"\x8f\xa1\xf7",
    0x203f9=>"\x8f\xa3\xa2",
    0x2044a=>"\x8f\xa3\xa5",
    0x20509=>"\x8f\xa3\xa7",
    0x205d6=>"\x8f\xa3\xb1",
    0x20628=>"\x8f\xa3\xb2",
    0x2074f=>"\x8f\xa3\xb8",
    0x20807=>"\x8f\xa3\xbf",
    0x2083a=>"\x8f\xa3\xc1",
    0x208b9=>"\x8f\xa3\xca",
    0x2097c=>"\x8f\xa3\xd2",
    0x2099d=>"\x8f\xa3\xd3",
    0x20ad3=>"\x8f\xa3\xd9",
    0x20b1d=>"\x8f\xa3\xdc",
    0x20b9f=>"\xcf\xd4", # [2004]
    0x20d45=>"\x8f\xa3\xf7",
    0x20de1=>"\x8f\xa4\xaa",
    0x20e64=>"\x8f\xa4\xba",
    0x20e6d=>"\x8f\xa4\xb2",
    0x20e95=>"\x8f\xa4\xb1",
    0x20f5f=>"\x8f\xa4\xbd",
    0x21201=>"\x8f\xa4\xd9",
    0x2123d=>"\xaf\xc2",
    0x21255=>"\x8f\xa4\xdc",
    0x21274=>"\x8f\xa4\xe3",
    0x2127b=>"\x8f\xa4\xde",
    0x212d7=>"\x8f\xa4\xeb",
    0x212e4=>"\x8f\xa4\xea",
    0x212fd=>"\x8f\xa4\xf2",
    0x2131b=>"\xaf\xcc",
    0x21336=>"\x8f\xa4\xf4",
    0x21344=>"\x8f\xa4\xf5",
    0x213c4=>"\x8f\xa5\xa5",
    0x2146d=>"\x8f\xa5\xb2",
    0x2146e=>"\xaf\xe0",
    0x215d7=>"\x8f\xa5\xbe",
    0x21647=>"\x8f\xa5\xc7",
    0x216b4=>"\xcf\xe3",
    0x21706=>"\x8f\xa5\xd5",
    0x21742=>"\x8f\xa5\xd6",
    0x218bd=>"\xaf\xfb",
    0x219c3=>"\x8f\xa5\xfe",
    0x21c56=>"\x8f\xa8\xb0",
    0x21d2d=>"\x8f\xa8\xb7",
    0x21d45=>"\x8f\xa8\xb8",
    0x21d62=>"\x8f\xa8\xbb",
    0x21d78=>"\x8f\xa8\xba",
    0x21d92=>"\x8f\xa8\xc5",
    0x21d9c=>"\x8f\xa8\xc0",
    0x21da1=>"\x8f\xa8\xbf",
    0x21db7=>"\x8f\xa8\xc8",
    0x21de0=>"\x8f\xa8\xca",
    0x21e33=>"\x8f\xa8\xcb",
    0x21e34=>"\xcf\xee",
    0x21f1e=>"\x8f\xa8\xdb",
    0x21f76=>"\x8f\xa8\xe6",
    0x21ffa=>"\x8f\xa8\xec",
    0x2217b=>"\x8f\xac\xa2",
    0x22218=>"\x8f\xfe\xd3",
    0x2231e=>"\x8f\xac\xab",
    0x223ad=>"\x8f\xac\xb0",
    0x226f3=>"\x8f\xac\xd0",
    0x2285b=>"\x8f\xac\xe5",
    0x228ab=>"\x8f\xac\xed",
    0x2298f=>"\x8f\xac\xf2",
    0x22ab8=>"\x8f\xad\xa4",
    0x22b46=>"\x8f\xad\xb2",
    0x22b4f=>"\x8f\xad\xa9",
    0x22b50=>"\x8f\xad\xaa",
    0x22ba6=>"\x8f\xad\xb5",
    0x22c1d=>"\x8f\xad\xb4",
    0x22c24=>"\x8f\xad\xb9",
    0x22de1=>"\x8f\xad\xd6",
    0x231b6=>"\x8f\xae\xa4",
    0x231c3=>"\x8f\xad\xfd",
    0x231c4=>"\xf5\xba",
    0x231f5=>"\x8f\xae\xa3",
    0x23372=>"\x8f\xae\xba",
    0x233d0=>"\x8f\xae\xc2",
    0x233d2=>"\x8f\xae\xbd",
    0x233d3=>"\x8f\xae\xbc",
    0x233d5=>"\x8f\xae\xc4",
    0x233da=>"\x8f\xae\xc7",
    0x233df=>"\x8f\xae\xc9",
    0x233e4=>"\x8f\xae\xc3",
    0x2344a=>"\x8f\xae\xd5",
    0x2344b=>"\x8f\xae\xd7",
    0x23451=>"\x8f\xae\xd6",
    0x23465=>"\x8f\xae\xdb",
    0x234e4=>"\x8f\xae\xf7",
    0x2355a=>"\x8f\xae\xf8",
    0x23594=>"\x8f\xaf\xaa",
    0x235c4=>"\xf5\xf2",
    0x23638=>"\x8f\xaf\xc2",
    0x23639=>"\x8f\xaf\xbf",
    0x2363a=>"\x8f\xaf\xc3",
    0x23647=>"\x8f\xaf\xc0",
    0x2370c=>"\x8f\xaf\xd9",
    0x2371c=>"\x8f\xaf\xce",
    0x2373f=>"\xf6\xa9",
    0x23763=>"\xf6\xb2",
    0x23764=>"\x8f\xaf\xe1",
    0x237e7=>"\x8f\xaf\xea",
    0x237ff=>"\x8f\xaf\xe9",
    0x23824=>"\x8f\xaf\xf0",
    0x2383d=>"\x8f\xaf\xf5",
    0x23a98=>"\x8f\xee\xa3",
    0x23c7f=>"\x8f\xee\xb4",
    0x23cfe=>"\xf6\xe0",
    0x23d00=>"\x8f\xee\xc9",
    0x23d0e=>"\x8f\xf4\xf5",
    0x23d40=>"\x8f\xee\xdc",
    0x23dd3=>"\x8f\xee\xe0",
    0x23df9=>"\x8f\xee\xdf",
    0x23dfa=>"\x8f\xee\xde",
    0x23f7e=>"\x8f\xef\xb2",
    0x24096=>"\x8f\xef\xc7",
    0x24103=>"\x8f\xef\xcd",
    0x241c6=>"\x8f\xef\xe1",
    0x241fe=>"\x8f\xef\xe4",
    0x243bc=>"\x8f\xf0\xa2",
    0x24629=>"\x8f\xf0\xb3",
    0x246a5=>"\x8f\xf0\xb9",
    0x247f1=>"\xf7\xec",
    0x24896=>"\x8f\xf0\xd3",
    0x24a4d=>"\x8f\xf0\xfb",
    0x24b56=>"\x8f\xf1\xae",
    0x24b6f=>"\x8f\xf1\xb0",
    0x24c16=>"\x8f\xf1\xb5",
    0x24d14=>"\x8f\xf1\xc4",
    0x24e0e=>"\x8f\xf1\xdd",
    0x24e37=>"\x8f\xf1\xe1",
    0x24e6a=>"\x8f\xf1\xe6",
    0x24e8b=>"\x8f\xf1\xe9",
    0x2504a=>"\x8f\xf1\xf5",
    0x25055=>"\x8f\xf1\xf7",
    0x25122=>"\x8f\xf1\xfa",
    0x251a9=>"\x8f\xf2\xa1",
    0x251cd=>"\x8f\xf2\xa4",
    0x251e5=>"\x8f\xf2\xa3",
    0x2521e=>"\x8f\xf2\xa8",
    0x2524c=>"\x8f\xf2\xac",
    0x2542e=>"\x8f\xf2\xbd",
    0x2548e=>"\xf8\xfe",
    0x254d9=>"\x8f\xf2\xc8",
    0x2550e=>"\xf9\xa9",
    0x255a7=>"\x8f\xf2\xdb",
    0x25771=>"\xf9\xc7",
    0x257a9=>"\x8f\xf2\xf5",
    0x257b4=>"\x8f\xf2\xf6",
    0x259c4=>"\xf9\xd4",
    0x259d4=>"\x8f\xf3\xb2",
    0x25ae3=>"\x8f\xf3\xbe",
    0x25ae4=>"\x8f\xf3\xbd",
    0x25af1=>"\x8f\xf3\xc0",
    0x25bb2=>"\x8f\xf3\xd2",
    0x25c4b=>"\x8f\xf3\xdd",
    0x25c64=>"\x8f\xf3\xde",
    0x25da1=>"\xf9\xee",
    0x25e2e=>"\x8f\xf3\xf3",
    0x25e56=>"\x8f\xf3\xf4",
    0x25e62=>"\x8f\xf3\xf7",
    0x25e65=>"\x8f\xf3\xf5",
    0x25ec2=>"\x8f\xf3\xfd",
    0x25ed8=>"\x8f\xf3\xfb",
    0x25ee8=>"\x8f\xf4\xa2",
    0x25f23=>"\x8f\xf4\xa4",
    0x25f5c=>"\x8f\xf4\xa7",
    0x25fd4=>"\x8f\xf4\xaf",
    0x25fe0=>"\x8f\xf4\xae",
    0x25ffb=>"\x8f\xf4\xb5",
    0x2600c=>"\x8f\xf4\xb4",
    0x26017=>"\x8f\xf4\xbd",
    0x26060=>"\x8f\xf4\xc2",
    0x260ed=>"\x8f\xf4\xcf",
    0x26270=>"\x8f\xf4\xe9",
    0x26286=>"\x8f\xf4\xeb",
    0x2634c=>"\x8f\xf4\xf2",
    0x26402=>"\x8f\xf4\xf9",
    0x2667e=>"\x8f\xf5\xb5",
    0x266b0=>"\x8f\xf5\xba",
    0x2671d=>"\x8f\xf5\xc6",
    0x268dd=>"\x8f\xf5\xd6",
    0x268ea=>"\x8f\xf5\xd8",
    0x26951=>"\x8f\xf5\xda",
    0x2696f=>"\x8f\xf5\xdd",
    0x269dd=>"\x8f\xf5\xdf",
    0x26a1e=>"\x8f\xf5\xe3",
    0x26a58=>"\x8f\xf5\xea",
    0x26a8c=>"\x8f\xf5\xf0",
    0x26ab7=>"\x8f\xf5\xf3",
    0x26aff=>"\xfa\xdd",
    0x26c29=>"\x8f\xa5\xc4",
    0x26c73=>"\x8f\xf6\xc4",
    0x26cdd=>"\x8f\xf6\xce",
    0x26e40=>"\xfb\xb3",
    0x26e65=>"\x8f\xf6\xdd",
    0x26f94=>"\x8f\xf6\xf5",
    0x26ff6=>"\x8f\xf7\xa1",
    0x26ff7=>"\x8f\xf7\xa2",
    0x26ff8=>"\x8f\xf6\xfe",
    0x270f4=>"\xfb\xc9",
    0x2710d=>"\x8f\xf7\xb3",
    0x27139=>"\x8f\xf7\xb6",
    0x273da=>"\x8f\xf7\xe5",
    0x273db=>"\x8f\xf7\xe4",
    0x273fe=>"\x8f\xf7\xeb",
    0x27410=>"\x8f\xf7\xee",
    0x27449=>"\x8f\xf7\xf3",
    0x27614=>"\x8f\xf8\xaa",
    0x27615=>"\x8f\xf8\xa9",
    0x27631=>"\x8f\xf8\xac",
    0x27684=>"\xfb\xec",
    0x27693=>"\x8f\xf8\xb4",
    0x2770e=>"\x8f\xf8\xbc",
    0x27723=>"\x8f\xf8\xbe",
    0x27752=>"\x8f\xf8\xc2",
    0x27985=>"\x8f\xf8\xd6",
    0x27a84=>"\x8f\xf8\xe3",
    0x27bb3=>"\x8f\xf8\xf7",
    0x27bbe=>"\x8f\xf8\xf9",
    0x27bc7=>"\x8f\xf8\xfa",
    0x27cb8=>"\x8f\xf9\xa5",
    0x27da0=>"\x8f\xf9\xaf",
    0x27e10=>"\x8f\xf9\xb2",
    0x27fb7=>"\x8f\xf9\xb9",
    0x2808a=>"\x8f\xf9\xc2",
    0x280bb=>"\x8f\xf9\xc8",
    0x28277=>"\xfc\xc9",
    0x28282=>"\x8f\xf9\xd9",
    0x282f3=>"\x8f\xf9\xde",
    0x283cd=>"\xfc\xd1",
    0x2840c=>"\x8f\xf9\xe6",
    0x28455=>"\x8f\xf9\xeb",
    0x2856b=>"\x8f\xf9\xfa",
    0x285c8=>"\x8f\xf9\xfe",
    0x285c9=>"\x8f\xfa\xa1",
    0x286d7=>"\x8f\xfa\xac",
    0x286fa=>"\x8f\xfa\xaf",
    0x28946=>"\x8f\xfa\xd0",
    0x28949=>"\x8f\xfa\xcf",
    0x2896b=>"\x8f\xfa\xd7",
    0x28987=>"\x8f\xfa\xe5",
    0x28988=>"\x8f\xfa\xe6",
    0x289ba=>"\x8f\xfa\xf1",
    0x289bb=>"\x8f\xfa\xf2",
    0x28a1e=>"\x8f\xfa\xfe",
    0x28a29=>"\x8f\xfb\xa1",
    0x28a43=>"\x8f\xfb\xad",
    0x28a71=>"\x8f\xfb\xac",
    0x28a99=>"\x8f\xfb\xb6",
    0x28acd=>"\x8f\xfb\xb7",
    0x28add=>"\x8f\xfb\xbe",
    0x28ae4=>"\x8f\xfb\xbd",
    0x28bc1=>"\x8f\xfb\xce",
    0x28bef=>"\x8f\xfb\xcf",
    0x28d10=>"\x8f\xfb\xd7",
    0x28d71=>"\x8f\xfb\xda",
    0x28dfb=>"\x8f\xfb\xdc",
    0x28e1f=>"\x8f\xfb\xdd",
    0x28e36=>"\x8f\xfb\xe1",
    0x28e89=>"\x8f\xfb\xe5",
    0x28eeb=>"\x8f\xfb\xe7",
    0x28f32=>"\x8f\xfb\xe9",
    0x28ff8=>"\x8f\xfb\xf1",
    0x292a0=>"\x8f\xfc\xa2",
    0x292b1=>"\x8f\xfc\xa3",
    0x29490=>"\x8f\xfc\xb8",
    0x295cf=>"\x8f\xfc\xc2",
    0x2967f=>"\x8f\xfc\xcc",
    0x296f0=>"\x8f\xfc\xd6",
    0x29719=>"\x8f\xfc\xd9",
    0x29750=>"\x8f\xfc\xdd",
    0x298c6=>"\x8f\xfc\xf6",
    0x29a72=>"\x8f\xfd\xac",
    0x29ddb=>"\x8f\xfd\xcb",
    0x29e15=>"\x8f\xfd\xd9",
    0x29e3d=>"\x8f\xfd\xcc",
    0x29e49=>"\x8f\xfd\xdd",
    0x29e8a=>"\x8f\xfd\xdb",
    0x29ec4=>"\x8f\xfd\xe7",
    0x29edb=>"\x8f\xfd\xf0",
    0x29ee9=>"\x8f\xfd\xed",
    0x29fce=>"\x8f\xfe\xa5",
    0x2a01a=>"\x8f\xfe\xab",
    0x2a02f=>"\x8f\xfe\xa9",
    0x2a082=>"\x8f\xfe\xb5",
    0x2a0f9=>"\x8f\xfe\xb2",
    0x2a190=>"\xfe\xe6",
    0x2a38c=>"\x8f\xfe\xd8",
    0x2a437=>"\x8f\xfe\xda",
    0x2a5f1=>"\x8f\xfe\xee",
    0x2a602=>"\x8f\xfe\xf0",
    0x2a61a=>"\x8f\xfe\xf2",
    0x2a6b2=>"\x8f\xfe\xf6",
  }


  def self.euc_jis_2004()
    self.euc_hook = proc do |e|
      EUCJIS2004_UCS_MAP[e]
    end

    self.unicode_euc_hook = proc do |u|
      UCS_EUCJIS2004_MAP[u]
    end
  end
end

Uconv.euc_jis_2004
